{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#Using deep features to build an image classifier\n",
    "\n",
    "#Fire up GraphLab Create"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "A newer version of GraphLab Create (v1.7.1) is available! Your current version is v1.6.1.\n",
      "\n",
      "You can use pip to upgrade the graphlab-create package. For more information see https://dato.com/products/create/upgrade.\n"
     ]
    }
   ],
   "source": [
    "import graphlab"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#Load a common image analysis dataset\n",
    "\n",
    "We will use a popular benchmark dataset in computer vision called CIFAR-10.  \n",
    "\n",
    "(We've reduced the data to just 4 categories = {'cat','bird','automobile','dog'}.)\n",
    "\n",
    "This dataset is already split into a training set and test set.  "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "[INFO] This non-commercial license of GraphLab Create is assigned to danielbenitezr@yahoo.com and will expire on September 27, 2016. For commercial licensing options, visit https://dato.com/buy/.\n",
      "\n",
      "[INFO] Start server at: ipc:///tmp/graphlab_server-7549 - Server binary: /home/balrog/anaconda/lib/python2.7/site-packages/graphlab/unity_server - Server log: /tmp/graphlab_server_1450965010.log\n",
      "[INFO] GraphLab Server Version: 1.6.1\n"
     ]
    }
   ],
   "source": [
    "image_train = graphlab.SFrame('image_train_data/')\n",
    "image_test = graphlab.SFrame('image_test_data/')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#Exploring the image data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "graphlab.canvas.set_target('ipynb')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "application/javascript": [
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//cdnjs.cloudflare.com/ajax/libs/font-awesome/4.1.0/css/font-awesome.min.css\"\n",
       "}));\n",
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//dato.com/files/canvas/1.6.1/css/canvas.css\"\n",
       "}));\n",
       "\n",
       "            (function(){\n",
       "\n",
       "                var e = null;\n",
       "                if (typeof element == 'undefined') {\n",
       "                    var scripts = document.getElementsByTagName('script');\n",
       "                    var thisScriptTag = scripts[scripts.length-1];\n",
       "                    var parentDiv = thisScriptTag.parentNode;\n",
       "                    e = document.createElement('div');\n",
       "                    parentDiv.appendChild(e);\n",
       "                } else {\n",
       "                    e = element[0];\n",
       "                }\n",
       "\n",
       "                if (typeof requirejs !== 'undefined') {\n",
       "                    // disable load timeout; ipython_app.js is large and can take a while to load.\n",
       "                    requirejs.config({waitSeconds: 0});\n",
       "                }\n",
       "\n",
       "                require(['//dato.com/files/canvas/1.6.1/js/ipython_app.js'], function(IPythonApp){\n",
       "                    var app = new IPythonApp();\n",
       "                    app.attachView('sarray','Images', {\"ipython\": true, \"rows\": [{\"format\": \"raw\", \"value\": [73, 77, 58, 71, 68, 50, 77, 69, 44, 120, 116, 83, 125, 120, 90, 155, 148, 117, 147, 152, 106, 133, 136, 92, 112, 101, 75, 100, 84, 68, 100, 78, 74, 69, 49, 51, 22, 16, 13, 35, 27, 24, 52, 40, 40, 70, 55, 54, 117, 97, 89, 122, 101, 99, 103, 85, 88, 88, 74, 73, 68, 59, 52, 72, 65, 52, 82, 73, 60, 84, 72, 68, 84, 67, 73, 77, 56, 65, 93, 75, 81, 117, 102, 98, 174, 171, 146, 183, 210, 149, 180, 214, 143, 185, 225, 144, 73, 74, 52, 75, 68, 55, 78, 64, 50, 103, 90, 64, 80, 65, 35, 127, 110, 80, 136, 127, 98, 141, 134, 109, 129, 113, 92, 115, 97, 72, 111, 91, 61, 115, 96, 67, 94, 83, 65, 92, 78, 65, 78, 60, 53, 89, 68, 64, 123, 99, 92, 117, 93, 92, 118, 97, 102, 121, 103, 103, 137, 125, 116, 168, 159, 141, 134, 124, 104, 98, 86, 74, 135, 124, 115, 133, 131, 108, 158, 167, 126, 163, 185, 125, 184, 217, 143, 181, 229, 139, 172, 220, 129, 174, 218, 127, 77, 72, 64, 94, 82, 79, 99, 81, 73, 116, 97, 74, 130, 106, 74, 149, 122, 93, 138, 118, 101, 134, 121, 109, 148, 140, 117, 154, 143, 113, 149, 137, 99, 145, 127, 87, 168, 136, 102, 174, 137, 111, 180, 137, 121, 178, 134, 126, 160, 126, 127, 141, 112, 124, 110, 84, 100, 110, 87, 99, 105, 90, 94, 124, 121, 106, 151, 162, 119, 155, 177, 117, 190, 216, 152, 192, 220, 151, 201, 236, 156, 193, 234, 155, 165, 208, 135, 175, 213, 139, 191, 230, 152, 185, 226, 142, 90, 85, 88, 99, 88, 91, 107, 92, 91, 108, 90, 78, 114, 92, 74, 137, 109, 98, 146, 115, 114, 130, 106, 113, 114, 100, 103, 130, 120, 106, 145, 137, 111, 129, 117, 87, 173, 142, 118, 164, 125, 112, 151, 112, 102, 150, 116, 102, 138, 111, 110, 146, 121, 130, 121, 97, 107, 100, 76, 86, 122, 108, 114, 137, 133, 128, 145, 151, 127, 150, 166, 125, 157, 172, 127, 148, 153, 116, 130, 133, 97, 114, 124, 83, 88, 105, 75, 191, 209, 166, 206, 238, 174, 186, 224, 154, 88, 82, 94, 94, 85, 89, 96, 85, 83, 120, 109, 98, 87, 71, 61, 110, 87, 85, 133, 101, 107, 130, 100, 117, 117, 96, 115, 112, 98, 95, 119, 110, 93, 125, 116, 98, 163, 140, 132, 145, 113, 113, 118, 87, 84, 125, 105, 89, 112, 99, 88, 94, 82, 77, 87, 75, 71, 73, 59, 59, 83, 73, 73, 68, 59, 59, 66, 59, 55, 76, 69, 62, 49, 42, 31, 52, 40, 38, 61, 48, 39, 85, 85, 49, 176, 188, 152, 213, 235, 182, 199, 229, 163, 121, 145, 94, 72, 67, 75, 77, 70, 68, 96, 86, 78, 151, 145, 124, 87, 79, 58, 96, 80, 71, 121, 96, 99, 117, 91, 107, 101, 81, 99, 99, 83, 87, 92, 80, 79, 79, 67, 68, 176, 153, 156, 152, 118, 118, 111, 74, 69, 111, 83, 70, 113, 105, 85, 74, 72, 54, 49, 46, 34, 41, 36, 31, 38, 32, 31, 34, 27, 25, 46, 36, 32, 74, 61, 54, 46, 32, 28, 42, 30, 37, 60, 57, 44, 144, 154, 101, 215, 233, 174, 195, 224, 158, 134, 154, 98, 60, 61, 35, 66, 64, 49, 69, 63, 49, 80, 70, 58, 128, 127, 99, 83, 84, 53, 71, 62, 48, 89, 70, 72, 91, 70, 80, 73, 54, 61, 71, 57, 56, 63, 51, 52, 95, 83, 93, 195, 172, 185, 136, 100, 103, 112, 71, 65, 98, 61, 52, 107, 96, 69, 104, 102, 74, 64, 59, 43, 34, 27, 21, 29, 25, 24, 41, 35, 34, 47, 34, 31, 86, 66, 62, 54, 35, 34, 38, 29, 35, 78, 85, 66, 176, 193, 131, 173, 190, 130, 112, 129, 92, 62, 62, 41, 56, 41, 36, 103, 106, 70, 73, 71, 46, 66, 58, 44, 104, 106, 77, 80, 87, 52, 49, 46, 29, 53, 43, 41, 52, 37, 41, 50, 35, 36, 58, 43, 44, 52, 36, 44, 142, 124, 144, 188, 161, 187, 128, 86, 89, 110, 65, 54, 89, 57, 44, 119, 108, 79, 128, 126, 92, 93, 89, 69, 65, 60, 45, 39, 32, 20, 38, 30, 25, 42, 29, 26, 86, 62, 60, 74, 43, 41, 103, 83, 82, 126, 128, 112, 134, 144, 105, 82, 84, 55, 52, 47, 46, 56, 40, 46, 63, 41, 46, 58, 62, 34, 61, 60, 38, 67, 62, 47, 134, 139, 111, 129, 139, 107, 51, 54, 35, 38, 35, 29, 25, 18, 19, 30, 21, 26, 38, 25, 37, 70, 52, 72, 160, 139, 163, 134, 110, 126, 131, 104, 104, 155, 133, 117, 132, 119, 98, 120, 116, 92, 136, 138, 103, 112, 114, 90, 87, 88, 61, 81, 72, 44, 58, 44, 34, 56, 41, 39, 100, 72, 72, 145, 103, 101, 155, 119, 116, 110, 99, 91, 87, 82, 76, 76, 62, 61, 65, 51, 48, 64, 51, 45, 58, 43, 34, 9, 9, 5, 27, 24, 16, 59, 53, 42, 152, 154, 130, 182, 188, 161, 58, 61, 42, 43, 44, 33, 17, 16, 13, 18, 16, 20, 50, 43, 55, 89, 78, 99, 102, 87, 105, 106, 96, 98, 115, 131, 146, 172, 195, 207, 222, 229, 224, 142, 146, 140, 123, 126, 101, 138, 137, 112, 107, 109, 85, 98, 91, 65, 82, 63, 53, 79, 55, 55, 110, 77, 78, 148, 109, 109, 125, 94, 92, 76, 60, 54, 76, 65, 59, 81, 67, 58, 90, 85, 57, 93, 91, 57, 84, 85, 47, 9, 8, 13, 15, 11, 10, 36, 30, 26, 106, 104, 88, 186, 187, 165, 73, 76, 58, 51, 56, 40, 64, 67, 55, 92, 89, 83, 84, 77, 79, 74, 62, 72, 99, 84, 98, 120, 118, 136, 83, 109, 145, 145, 180, 210, 205, 226, 242, 149, 163, 185, 129, 135, 120, 136, 132, 104, 105, 107, 87, 112, 113, 90, 86, 72, 61, 92, 66, 67, 94, 66, 66, 70, 43, 41, 68, 42, 43, 74, 53, 51, 76, 59, 52, 57, 43, 31, 74, 64, 41, 86, 82, 54, 91, 95, 61, 32, 28, 26, 44, 37, 37, 45, 34, 33, 84, 75, 65, 176, 174, 155, 95, 98, 78, 53, 60, 40, 83, 86, 66, 131, 123, 109, 100, 87, 80, 116, 97, 99, 93, 74, 83, 50, 47, 64, 52, 63, 81, 164, 189, 201, 175, 210, 230, 107, 134, 166, 106, 113, 102, 115, 107, 80, 110, 106, 91, 103, 110, 85, 88, 86, 66, 67, 50, 43, 75, 59, 50, 71, 58, 52, 52, 33, 34, 77, 56, 51, 91, 73, 61, 60, 45, 34, 68, 48, 49, 56, 42, 36, 38, 34, 17, 72, 53, 46, 68, 47, 48, 84, 64, 60, 97, 80, 72, 170, 165, 148, 117, 122, 96, 57, 63, 39, 80, 80, 61, 77, 72, 56, 95, 83, 79, 101, 80, 86, 88, 62, 74, 63, 42, 56, 29, 30, 39, 104, 132, 154, 110, 154, 201, 69, 104, 131, 73, 78, 64, 118, 97, 83, 128, 110, 100, 118, 118, 89, 102, 104, 70, 82, 79, 50, 112, 106, 78, 100, 93, 78, 52, 40, 38, 87, 69, 57, 91, 74, 59, 64, 51, 43, 69, 54, 54, 59, 52, 35, 94, 100, 57, 66, 48, 39, 75, 56, 52, 83, 65, 59, 85, 73, 64, 155, 155, 136, 131, 138, 115, 58, 61, 48, 71, 69, 57, 56, 54, 36, 60, 50, 42, 79, 61, 68, 118, 92, 112, 115, 88, 109, 95, 86, 109, 80, 93, 136, 58, 85, 153, 74, 92, 137, 67, 62, 58, 123, 105, 89, 120, 115, 100, 111, 115, 90, 114, 115, 87, 88, 86, 57, 90, 85, 54, 111, 103, 75, 93, 78, 58, 106, 86, 68, 82, 65, 53, 60, 49, 40, 77, 72, 49, 131, 138, 100, 142, 167, 109, 81, 68, 55, 70, 57, 46, 79, 64, 59, 55, 50, 42, 125, 133, 112, 132, 144, 116, 66, 69, 48, 62, 61, 44, 62, 64, 42, 49, 45, 27, 95, 80, 86, 174, 151, 179, 117, 97, 124, 88, 78, 117, 67, 70, 131, 58, 69, 151, 74, 81, 147, 57, 48, 56, 113, 97, 80, 104, 104, 87, 99, 106, 80, 108, 109, 81, 106, 103, 77, 82, 76, 53, 115, 108, 78, 165, 155, 122, 122, 107, 88, 63, 55, 42, 63, 67, 49, 144, 152, 126, 158, 172, 143, 126, 151, 117, 99, 88, 72, 70, 60, 42, 48, 37, 31, 35, 35, 28, 104, 117, 94, 128, 144, 105, 95, 104, 60, 71, 75, 40, 67, 74, 45, 110, 111, 86, 138, 128, 130, 94, 77, 103, 37, 29, 51, 42, 39, 85, 60, 63, 138, 77, 85, 178, 69, 76, 157, 52, 44, 59, 104, 82, 64, 93, 85, 70, 96, 102, 71, 105, 107, 74, 106, 103, 84, 82, 74, 69, 104, 97, 96, 105, 98, 105, 89, 80, 101, 82, 83, 102, 110, 124, 131, 133, 148, 145, 104, 116, 120, 84, 94, 105, 98, 94, 62, 107, 106, 66, 67, 76, 43, 82, 98, 63, 102, 119, 79, 110, 128, 83, 96, 114, 58, 101, 122, 59, 101, 122, 70, 173, 185, 156, 125, 130, 112, 72, 76, 53, 57, 62, 50, 47, 49, 100, 71, 74, 176, 101, 108, 225, 76, 74, 167, 67, 53, 64, 116, 80, 70, 103, 82, 83, 85, 86, 73, 81, 80, 74, 78, 77, 87, 79, 78, 103, 82, 83, 114, 81, 84, 116, 98, 98, 137, 106, 105, 148, 106, 109, 148, 84, 97, 122, 82, 90, 122, 80, 82, 119, 91, 97, 56, 126, 139, 75, 128, 153, 87, 143, 173, 105, 124, 149, 87, 113, 130, 79, 102, 115, 63, 131, 147, 94, 136, 157, 116, 150, 165, 140, 127, 141, 111, 83, 97, 55, 45, 58, 45, 71, 81, 140, 110, 122, 232, 109, 123, 240, 79, 75, 154, 71, 61, 70, 77, 62, 71, 75, 63, 84, 72, 69, 83, 85, 83, 106, 97, 97, 126, 88, 89, 124, 84, 89, 124, 84, 89, 122, 92, 94, 130, 100, 97, 138, 91, 89, 129, 80, 88, 117, 76, 82, 118, 81, 84, 122, 58, 66, 45, 112, 133, 80, 90, 115, 57, 148, 177, 108, 115, 141, 73, 101, 116, 66, 102, 106, 64, 137, 142, 107, 118, 131, 106, 120, 134, 108, 137, 154, 118, 62, 81, 40, 20, 40, 33, 67, 82, 144, 119, 137, 240, 109, 131, 240, 70, 65, 141, 53, 29, 46, 38, 34, 49, 41, 44, 73, 59, 57, 85, 63, 67, 100, 81, 83, 116, 85, 87, 120, 82, 85, 118, 88, 93, 126, 91, 94, 127, 86, 85, 119, 61, 59, 91, 67, 71, 97, 69, 74, 107, 64, 70, 103, 74, 77, 56, 140, 158, 110, 96, 112, 64, 128, 142, 90, 103, 117, 66, 86, 95, 57, 69, 76, 39, 114, 122, 86, 98, 109, 76, 88, 104, 65, 92, 112, 70, 57, 80, 35, 65, 83, 62, 78, 90, 143, 112, 126, 231, 111, 130, 248, 103, 89, 194, 148, 81, 110, 72, 39, 33, 22, 28, 42, 41, 48, 68, 47, 59, 82, 68, 75, 103, 80, 81, 115, 75, 77, 113, 68, 74, 108, 64, 67, 98, 60, 59, 87, 46, 44, 68, 45, 46, 70, 57, 60, 91, 47, 56, 85, 69, 61, 41, 118, 122, 84, 97, 105, 55, 74, 85, 34, 66, 72, 33, 64, 63, 39, 52, 50, 30, 104, 106, 78, 136, 144, 105, 98, 116, 70, 99, 121, 80, 107, 127, 87, 87, 109, 74, 82, 100, 143, 96, 115, 220, 96, 124, 246, 121, 116, 239, 192, 103, 167, 78, 40, 46, 36, 43, 54, 80, 78, 105, 79, 90, 117, 74, 79, 108, 66, 65, 98, 64, 62, 92, 38, 39, 61, 36, 36, 58, 42, 40, 63, 41, 38, 60, 42, 42, 63, 60, 62, 91, 54, 61, 89, 64, 59, 52, 70, 72, 49, 78, 88, 39, 94, 109, 52, 113, 120, 80, 77, 71, 51, 57, 52, 37, 82, 81, 58, 145, 152, 117, 151, 169, 126, 138, 156, 120, 104, 118, 85, 78, 100, 67, 64, 84, 117, 77, 97, 190, 74, 102, 213, 80, 103, 200, 149, 124, 193, 70, 57, 107, 37, 49, 80, 56, 60, 89, 56, 61, 94, 47, 50, 79, 38, 37, 65, 34, 31, 56, 30, 26, 49, 30, 26, 48, 36, 33, 54, 39, 36, 56, 46, 45, 65, 55, 56, 83, 50, 54, 81, 98, 107, 103, 86, 93, 74, 111, 120, 76, 140, 152, 99, 147, 154, 115, 92, 91, 66, 66, 69, 44, 76, 83, 53, 135, 143, 110, 119, 134, 96, 106, 117, 86, 89, 94, 71, 52, 64, 40, 39, 51, 67, 71, 82, 143, 73, 85, 169, 39, 58, 119, 102, 121, 172, 122, 105, 183, 54, 48, 98, 34, 44, 63, 33, 32, 56, 31, 31, 52, 25, 26, 43, 22, 21, 41, 26, 22, 45, 29, 26, 47, 34, 31, 49, 41, 38, 56, 54, 50, 73, 48, 45, 73, 41, 43, 66, 75, 88, 83, 83, 86, 77, 106, 101, 79, 127, 131, 90, 133, 139, 99, 112, 115, 84, 84, 96, 60, 91, 105, 69, 100, 108, 78, 109, 121, 86, 61, 64, 38, 77, 71, 58, 74, 75, 62, 30, 34, 33, 67, 70, 99, 85, 83, 141, 40, 39, 82, 63, 65, 100, 93, 83, 140, 60, 49, 88, 37, 32, 47, 25, 19, 35, 25, 24, 36, 19, 22, 30, 25, 28, 31, 24, 24, 26, 23, 22, 30, 35, 33, 47, 38, 34, 53, 53, 45, 70, 52, 46, 73, 40, 40, 58, 62, 68, 57, 86, 77, 72, 87, 73, 63, 95, 94, 64, 128, 134, 100, 89, 92, 66, 70, 80, 47, 94, 105, 72, 73, 82, 52, 117, 128, 91, 85, 90, 60, 81, 79, 61, 63, 67, 47, 25, 25, 12, 66, 53, 66, 74, 64, 99, 30, 28, 54, 44, 40, 57, 43, 51, 70, 33, 39, 55, 29, 22, 35, 23, 19, 32, 19, 19, 27, 26, 29, 32, 96, 103, 88, 109, 118, 80, 59, 66, 36, 39, 41, 35, 43, 41, 60, 46, 42, 72, 53, 50, 73, 48, 46, 57, 78, 74, 64, 73, 57, 47, 92, 78, 62, 95, 95, 66, 114, 120, 92, 83, 86, 66, 95, 98, 75, 112, 116, 93, 77, 83, 59, 92, 99, 65, 106, 113, 79, 59, 63, 37, 46, 51, 29, 35, 30, 20, 92, 57, 71, 91, 65, 85, 21, 19, 32, 23, 24, 35, 32, 34, 45, 30, 32, 43, 21, 22, 34, 19, 21, 31, 17, 19, 25, 22, 24, 28, 100, 109, 91, 172, 191, 135, 156, 177, 108, 108, 124, 74, 46, 57, 44, 35, 44, 60, 45, 48, 69, 48, 44, 66, 72, 64, 59, 78, 67, 51, 96, 86, 58, 129, 129, 91, 101, 107, 73, 91, 97, 73, 109, 118, 94, 126, 131, 112, 95, 92, 83, 67, 65, 49, 126, 125, 102, 71, 68, 48, 58, 54, 50, 56, 43, 46, 116, 67, 84, 120, 72, 90, 21, 11, 21, 11, 11, 19, 21, 20, 28, 25, 25, 33, 23, 22, 30, 16, 16, 24, 13, 13, 20, 18, 18, 24, 39, 45, 46, 135, 151, 129, 175, 199, 144, 163, 192, 123, 122, 150, 89, 61, 82, 44, 34, 43, 45, 37, 36, 60, 83, 88, 64, 87, 96, 61, 98, 102, 60, 140, 143, 95, 103, 109, 67, 96, 107, 78, 94, 111, 84, 127, 140, 114, 113, 114, 96, 54, 54, 43, 111, 111, 97, 98, 96, 80, 70, 69, 61, 63, 55, 51, 127, 75, 86, 149, 85, 102, 35, 18, 26, 5, 5, 10, 15, 12, 17, 19, 16, 21, 21, 18, 23, 19, 17, 22, 15, 12, 20, 16, 13, 23, 21, 19, 33, 41, 46, 51, 129, 144, 123, 183, 207, 169, 178, 206, 159, 154, 181, 124, 76, 96, 59, 27, 35, 25, 92, 112, 62, 84, 109, 57, 110, 127, 76, 136, 147, 93, 102, 112, 69, 109, 123, 97, 112, 133, 109, 99, 119, 84, 130, 141, 104, 83, 91, 70, 73, 80, 64, 117, 123, 102, 66, 80, 49, 73, 80, 57, 131, 89, 91, 158, 92, 106, 70, 46, 52, 10, 5, 7, 12, 7, 10, 13, 7, 11, 16, 11, 14, 19, 14, 18, 23, 18, 26, 23, 18, 30, 27, 22, 34, 29, 25, 34, 39, 42, 47, 141, 151, 158, 181, 196, 203, 174, 195, 176, 156, 177, 138, 59, 71, 48, 84, 106, 56, 86, 105, 58, 118, 133, 84, 119, 138, 88, 90, 109, 78, 126, 142, 131, 149, 167, 153, 79, 95, 68, 117, 128, 95, 130, 139, 108, 69, 76, 47, 121, 131, 97, 102, 121, 77, 79, 80, 56, 143, 100, 102, 169, 93, 108, 116, 71, 78, 44, 28, 29, 13, 9, 10, 14, 8, 15, 16, 10, 16, 16, 13, 18, 14, 14, 19, 19, 22, 26, 18, 21, 24, 21, 24, 22, 28, 35, 27, 32, 42, 38, 54, 67, 68, 79, 95, 78, 159, 177, 137, 117, 133, 94, 76, 96, 60, 81, 98, 56, 103, 116, 73, 110, 125, 82, 99, 114, 84, 94, 107, 91, 82, 96, 76, 77, 85, 59, 98, 97, 69, 137, 137, 108, 103, 104, 76, 122, 127, 94, 141, 148, 108, 86, 71, 52, 138, 84, 90, 183, 104, 119, 133, 86, 91, 68, 47, 49, 29, 20, 25, 9, 6, 17, 11, 10, 18, 16, 18, 21, 13, 19, 21, 14, 23, 24, 44, 54, 56, 123, 134, 127, 106, 126, 88, 87, 115, 51, 72, 101, 36, 56, 80, 36, 69, 90, 40, 104, 120, 69, 102, 120, 92, 91, 109, 62, 95, 110, 62, 103, 114, 75, 88, 96, 65, 72, 81, 52, 85, 94, 64, 80, 83, 53, 94, 89, 62, 120, 119, 91, 135, 139, 110, 90, 102, 68, 136, 157, 117, 128, 132, 104, 112, 98, 73, 147, 127, 97, 110, 95, 74, 74, 57, 49, 64, 47, 49, 20, 9, 20, 12, 7, 15, 11, 10, 14, 12, 14, 18, 14, 19, 22, 49, 57, 55, 129, 143, 122, 119, 141, 87, 107, 138, 53, 104, 139, 46, 100, 134, 55, 72, 97, 38, 48, 59, 29], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387024}, {\"format\": \"raw\", \"value\": [7, 5, 8, 7, 5, 8, 5, 4, 6, 7, 4, 7, 11, 5, 9, 11, 5, 9, 17, 11, 15, 25, 19, 23, 18, 9, 17, 9, 1, 9, 13, 7, 15, 24, 19, 27, 21, 19, 25, 34, 32, 35, 52, 43, 42, 40, 27, 26, 19, 9, 10, 11, 6, 10, 20, 16, 18, 36, 29, 28, 25, 20, 22, 23, 19, 22, 32, 21, 22, 33, 26, 29, 58, 57, 61, 73, 75, 81, 83, 91, 94, 61, 68, 66, 69, 71, 66, 82, 84, 78, 80, 85, 81, 69, 73, 68, 6, 4, 8, 6, 4, 9, 5, 3, 8, 7, 4, 8, 10, 3, 9, 8, 2, 8, 11, 5, 11, 21, 15, 21, 12, 6, 13, 5, 1, 8, 16, 16, 24, 35, 39, 49, 55, 63, 69, 97, 104, 102, 131, 130, 123, 87, 82, 73, 49, 44, 38, 48, 46, 41, 71, 67, 59, 86, 79, 68, 87, 84, 75, 93, 91, 85, 80, 75, 70, 67, 67, 64, 113, 118, 119, 129, 140, 142, 114, 124, 124, 76, 81, 76, 76, 77, 68, 85, 86, 77, 86, 88, 81, 81, 80, 72, 1, 1, 6, 7, 7, 12, 8, 8, 13, 10, 9, 14, 18, 17, 22, 19, 17, 23, 18, 16, 22, 31, 29, 35, 36, 36, 42, 38, 39, 45, 79, 83, 89, 84, 90, 96, 93, 100, 102, 148, 154, 146, 148, 145, 131, 114, 105, 89, 102, 91, 76, 85, 71, 59, 88, 67, 54, 92, 69, 52, 90, 69, 55, 97, 82, 70, 108, 100, 87, 98, 96, 86, 88, 94, 88, 128, 141, 138, 130, 139, 135, 94, 96, 86, 97, 94, 81, 98, 96, 83, 96, 96, 85, 86, 84, 73, 33, 38, 43, 62, 68, 73, 68, 73, 79, 68, 74, 79, 56, 61, 66, 40, 45, 50, 58, 64, 69, 71, 77, 82, 63, 70, 76, 70, 76, 81, 99, 104, 105, 79, 82, 80, 132, 133, 127, 162, 157, 145, 118, 102, 84, 109, 86, 64, 95, 70, 47, 73, 47, 27, 84, 55, 34, 101, 68, 45, 92, 62, 41, 76, 51, 32, 85, 68, 48, 114, 104, 87, 96, 97, 85, 104, 112, 104, 135, 141, 132, 114, 113, 100, 113, 108, 91, 108, 104, 87, 98, 97, 83, 84, 83, 74, 79, 89, 93, 99, 109, 112, 103, 113, 116, 99, 110, 113, 74, 86, 89, 93, 104, 108, 116, 127, 130, 106, 118, 121, 89, 99, 104, 79, 86, 88, 97, 99, 93, 119, 115, 103, 142, 133, 119, 117, 100, 83, 116, 89, 66, 126, 91, 64, 105, 69, 42, 89, 60, 34, 98, 70, 41, 114, 83, 51, 115, 86, 56, 109, 83, 56, 84, 59, 34, 97, 79, 58, 112, 105, 90, 102, 103, 91, 116, 118, 106, 112, 110, 94, 114, 109, 89, 112, 106, 87, 106, 103, 88, 79, 80, 70, 54, 60, 62, 85, 94, 94, 91, 102, 100, 91, 101, 102, 88, 97, 102, 81, 91, 94, 103, 113, 115, 127, 138, 138, 87, 92, 93, 131, 132, 125, 162, 158, 140, 165, 154, 130, 139, 119, 95, 118, 91, 66, 135, 105, 75, 129, 95, 65, 112, 76, 50, 104, 71, 44, 114, 82, 50, 130, 96, 60, 139, 107, 71, 135, 105, 75, 119, 89, 67, 87, 65, 44, 112, 97, 80, 107, 100, 84, 103, 98, 82, 109, 104, 85, 111, 107, 84, 109, 107, 87, 101, 100, 85, 86, 86, 72, 39, 43, 50, 55, 60, 66, 62, 70, 75, 44, 52, 58, 19, 25, 35, 59, 66, 73, 140, 148, 154, 74, 82, 86, 70, 71, 69, 179, 175, 162, 172, 162, 138, 157, 140, 111, 143, 118, 90, 131, 99, 71, 141, 108, 75, 135, 100, 68, 127, 91, 63, 115, 79, 48, 123, 88, 54, 142, 109, 75, 147, 117, 83, 134, 104, 73, 136, 104, 79, 122, 96, 73, 144, 126, 104, 133, 122, 101, 110, 102, 83, 110, 103, 83, 111, 107, 85, 104, 102, 83, 95, 94, 81, 92, 91, 83, 36, 38, 48, 28, 31, 42, 33, 38, 49, 23, 29, 42, 27, 31, 46, 106, 111, 124, 80, 86, 97, 27, 32, 40, 111, 111, 106, 165, 156, 138, 159, 141, 116, 148, 127, 96, 143, 118, 88, 145, 114, 84, 149, 116, 82, 142, 108, 75, 134, 97, 69, 132, 95, 63, 132, 101, 70, 145, 121, 95, 145, 121, 92, 136, 108, 76, 128, 94, 64, 141, 112, 84, 175, 154, 127, 166, 152, 126, 135, 126, 105, 107, 101, 81, 107, 103, 83, 102, 100, 82, 98, 97, 82, 87, 87, 78, 43, 43, 49, 25, 27, 36, 31, 34, 45, 35, 38, 52, 37, 40, 56, 37, 40, 55, 40, 43, 56, 93, 96, 106, 162, 162, 154, 161, 151, 131, 143, 122, 97, 148, 125, 96, 145, 122, 94, 139, 112, 83, 145, 117, 83, 148, 118, 85, 146, 113, 85, 149, 117, 89, 159, 138, 116, 188, 177, 160, 154, 138, 114, 138, 110, 77, 132, 98, 65, 146, 119, 87, 187, 168, 137, 170, 157, 128, 157, 150, 125, 113, 108, 87, 101, 96, 79, 102, 100, 83, 103, 103, 84, 84, 85, 69, 83, 84, 79, 47, 49, 50, 39, 43, 47, 38, 41, 51, 29, 31, 46, 36, 38, 51, 77, 79, 90, 83, 86, 94, 146, 150, 141, 201, 193, 173, 156, 133, 110, 145, 122, 97, 160, 140, 116, 135, 114, 88, 129, 106, 76, 135, 110, 81, 133, 106, 82, 163, 141, 120, 194, 188, 176, 210, 213, 206, 154, 144, 126, 144, 116, 83, 140, 110, 77, 149, 126, 94, 187, 172, 141, 172, 164, 134, 172, 166, 139, 136, 131, 110, 95, 90, 76, 104, 102, 85, 105, 105, 85, 94, 94, 81, 95, 94, 87, 96, 97, 89, 75, 77, 73, 49, 52, 55, 41, 43, 53, 35, 35, 46, 17, 19, 29, 48, 49, 52, 130, 130, 117, 193, 186, 168, 184, 168, 148, 166, 150, 129, 187, 173, 151, 158, 143, 118, 146, 130, 102, 165, 146, 119, 160, 140, 115, 180, 167, 151, 215, 216, 212, 214, 220, 218, 151, 140, 122, 152, 125, 91, 162, 137, 103, 155, 131, 100, 176, 158, 129, 173, 165, 136, 181, 177, 151, 148, 143, 124, 91, 85, 71, 101, 97, 81, 99, 99, 81, 87, 88, 81, 74, 71, 67, 105, 103, 92, 114, 112, 100, 79, 82, 74, 67, 70, 69, 59, 55, 61, 16, 19, 29, 78, 76, 73, 131, 123, 104, 165, 159, 140, 190, 186, 170, 181, 175, 159, 186, 178, 158, 179, 169, 144, 180, 168, 142, 196, 182, 155, 180, 165, 138, 181, 175, 157, 222, 223, 217, 218, 215, 210, 148, 130, 110, 154, 128, 91, 171, 151, 113, 156, 128, 97, 170, 145, 116, 181, 169, 140, 184, 184, 159, 155, 152, 133, 94, 85, 69, 100, 93, 77, 94, 93, 78, 78, 81, 74, 73, 71, 70, 65, 63, 63, 100, 100, 88, 112, 115, 99, 106, 105, 95, 92, 86, 83, 37, 41, 46, 96, 98, 90, 138, 131, 108, 155, 150, 130, 185, 185, 172, 197, 196, 185, 200, 194, 179, 200, 191, 169, 208, 197, 174, 202, 189, 164, 186, 173, 146, 193, 184, 164, 215, 211, 200, 205, 197, 186, 140, 118, 94, 147, 119, 81, 169, 149, 112, 157, 131, 100, 170, 146, 118, 192, 181, 152, 184, 181, 155, 148, 142, 122, 95, 84, 67, 101, 93, 77, 100, 97, 83, 85, 87, 82, 45, 44, 56, 36, 34, 55, 61, 61, 66, 93, 95, 84, 123, 118, 103, 116, 110, 97, 74, 80, 76, 131, 135, 122, 148, 142, 116, 147, 142, 121, 198, 198, 185, 216, 217, 208, 211, 208, 196, 204, 197, 177, 209, 200, 179, 205, 194, 172, 205, 192, 168, 206, 194, 172, 210, 201, 184, 186, 176, 157, 138, 114, 86, 149, 119, 82, 168, 147, 112, 162, 140, 109, 170, 150, 122, 190, 178, 150, 185, 177, 152, 141, 132, 112, 94, 86, 69, 108, 101, 86, 96, 92, 81, 87, 87, 83, 29, 30, 52, 17, 17, 46, 38, 40, 59, 45, 48, 50, 95, 90, 76, 143, 137, 120, 132, 137, 125, 150, 152, 133, 145, 134, 108, 147, 138, 116, 208, 206, 191, 213, 213, 201, 209, 206, 192, 197, 191, 174, 200, 192, 174, 192, 182, 163, 201, 190, 169, 208, 194, 172, 208, 197, 176, 183, 173, 149, 142, 121, 91, 154, 125, 90, 169, 148, 115, 164, 146, 115, 165, 149, 122, 178, 166, 140, 188, 176, 155, 138, 130, 112, 81, 77, 63, 87, 84, 75, 83, 81, 74, 82, 82, 75, 57, 63, 75, 28, 34, 46, 27, 33, 47, 51, 56, 64, 66, 64, 57, 123, 117, 101, 144, 146, 130, 152, 148, 126, 130, 111, 86, 150, 135, 113, 204, 198, 179, 215, 212, 192, 217, 214, 194, 214, 208, 193, 219, 212, 196, 208, 200, 182, 213, 202, 183, 208, 195, 175, 199, 189, 168, 199, 191, 166, 155, 137, 108, 139, 113, 81, 157, 135, 104, 171, 154, 125, 161, 147, 120, 178, 167, 142, 187, 175, 156, 118, 113, 99, 73, 76, 66, 71, 75, 71, 84, 85, 83, 89, 89, 77, 54, 61, 71, 46, 54, 59, 39, 46, 54, 75, 80, 90, 76, 76, 80, 69, 67, 64, 142, 141, 130, 150, 138, 117, 121, 101, 74, 158, 142, 120, 198, 192, 174, 216, 214, 195, 205, 201, 184, 217, 209, 196, 239, 228, 213, 213, 202, 186, 211, 201, 186, 215, 206, 188, 201, 195, 175, 200, 195, 173, 166, 152, 125, 140, 117, 85, 153, 132, 95, 167, 149, 118, 165, 153, 127, 172, 166, 142, 177, 167, 152, 102, 97, 89, 85, 90, 87, 76, 84, 85, 84, 89, 91, 73, 78, 74, 37, 42, 61, 44, 50, 64, 41, 48, 59, 53, 57, 67, 48, 48, 61, 30, 34, 44, 119, 115, 111, 131, 115, 95, 133, 116, 87, 173, 162, 138, 207, 204, 188, 222, 221, 210, 218, 213, 200, 192, 180, 159, 205, 190, 167, 209, 197, 176, 216, 209, 192, 217, 213, 196, 231, 230, 212, 208, 205, 186, 169, 157, 133, 148, 129, 94, 164, 143, 101, 161, 140, 108, 169, 155, 131, 163, 159, 138, 154, 147, 135, 89, 83, 81, 83, 88, 90, 93, 100, 102, 110, 117, 119, 56, 67, 71, 35, 41, 62, 55, 62, 79, 59, 67, 79, 41, 46, 57, 63, 65, 78, 65, 70, 80, 74, 71, 67, 117, 102, 82, 156, 140, 112, 170, 161, 137, 200, 197, 182, 226, 227, 216, 224, 218, 201, 176, 160, 129, 171, 155, 124, 212, 200, 174, 229, 225, 205, 221, 219, 202, 224, 222, 204, 203, 198, 178, 172, 160, 135, 160, 141, 109, 166, 142, 105, 153, 130, 99, 171, 154, 131, 163, 156, 139, 118, 114, 105, 76, 73, 70, 71, 73, 70, 95, 98, 94, 130, 134, 128, 123, 130, 127, 48, 55, 76, 78, 86, 102, 80, 90, 101, 47, 53, 64, 44, 47, 59, 104, 111, 120, 107, 106, 101, 128, 115, 94, 168, 153, 126, 179, 171, 149, 201, 200, 187, 225, 226, 217, 226, 221, 207, 184, 165, 141, 174, 156, 133, 226, 215, 198, 233, 232, 221, 225, 226, 213, 214, 212, 194, 186, 178, 156, 176, 163, 137, 173, 155, 126, 163, 138, 106, 140, 116, 87, 171, 154, 132, 157, 149, 137, 90, 88, 81, 84, 82, 75, 83, 82, 73, 96, 95, 85, 111, 113, 103, 139, 146, 137, 38, 47, 63, 80, 91, 102, 115, 126, 133, 76, 84, 92, 35, 40, 52, 38, 46, 54, 111, 112, 106, 161, 150, 129, 171, 157, 130, 179, 173, 152, 194, 195, 182, 210, 213, 205, 222, 220, 211, 203, 190, 177, 200, 188, 174, 233, 225, 216, 226, 227, 222, 224, 227, 217, 209, 206, 188, 182, 173, 149, 184, 171, 144, 178, 162, 136, 161, 140, 112, 140, 119, 90, 165, 152, 130, 141, 136, 127, 103, 101, 93, 120, 115, 101, 114, 110, 94, 116, 115, 101, 102, 108, 98, 109, 117, 113, 77, 90, 100, 76, 89, 95, 132, 146, 147, 132, 142, 147, 84, 90, 101, 50, 60, 67, 103, 105, 99, 171, 161, 139, 176, 164, 138, 181, 175, 155, 186, 187, 175, 203, 206, 198, 209, 210, 201, 196, 194, 181, 206, 201, 186, 214, 211, 197, 220, 222, 211, 215, 219, 207, 194, 191, 172, 184, 173, 148, 193, 179, 153, 180, 167, 142, 168, 151, 125, 147, 132, 102, 158, 150, 127, 123, 122, 114, 87, 84, 74, 119, 111, 93, 115, 108, 89, 123, 124, 108, 133, 143, 135, 117, 128, 129, 85, 99, 103, 146, 160, 160, 139, 155, 154, 163, 177, 178, 152, 163, 164, 99, 110, 110, 113, 116, 113, 178, 172, 153, 182, 173, 149, 188, 179, 159, 185, 178, 160, 197, 193, 178, 203, 201, 186, 182, 182, 165, 150, 150, 137, 172, 170, 155, 194, 192, 172, 192, 190, 170, 197, 193, 170, 199, 190, 164, 195, 185, 158, 180, 170, 144, 173, 162, 137, 151, 144, 115, 149, 147, 128, 105, 107, 106, 59, 58, 60, 88, 85, 76, 103, 100, 84, 117, 116, 97, 150, 153, 137, 142, 150, 142, 119, 131, 133, 129, 139, 136, 164, 178, 176, 146, 160, 160, 160, 172, 167, 159, 170, 166, 109, 112, 112, 169, 166, 150, 194, 190, 170, 194, 186, 167, 182, 171, 149, 198, 189, 168, 210, 205, 185, 186, 183, 165, 123, 122, 111, 149, 146, 133, 190, 183, 162, 204, 195, 170, 208, 200, 176, 190, 183, 160, 194, 188, 165, 185, 178, 157, 175, 168, 150, 142, 138, 119, 119, 119, 109, 76, 76, 84, 37, 39, 51, 63, 64, 67, 82, 83, 77, 96, 94, 84, 116, 114, 104, 125, 130, 118, 145, 150, 152, 97, 100, 98, 123, 129, 127, 131, 141, 141, 95, 106, 103, 113, 124, 122, 125, 128, 131, 155, 153, 141, 198, 198, 182, 199, 195, 179, 191, 181, 159, 183, 172, 149, 208, 200, 178, 204, 200, 181, 149, 148, 135, 176, 172, 158, 209, 200, 178, 214, 202, 176, 196, 184, 161, 197, 189, 169, 199, 195, 178, 166, 162, 148, 163, 157, 143, 129, 125, 109, 102, 100, 92, 62, 61, 66, 73, 75, 81, 109, 112, 111, 101, 102, 98, 104, 105, 104, 104, 105, 103, 129, 134, 122, 108, 110, 109, 112, 112, 107, 73, 76, 72, 59, 65, 65, 72, 81, 80, 46, 56, 57, 69, 73, 81, 128, 128, 122, 171, 173, 161, 196, 195, 180, 210, 201, 180, 192, 182, 160, 182, 173, 151, 180, 175, 155, 131, 127, 115, 170, 164, 150, 198, 188, 165, 195, 180, 155, 194, 181, 159, 207, 199, 180, 179, 176, 161, 145, 143, 128, 157, 155, 132, 144, 143, 119, 134, 133, 114, 121, 121, 109, 133, 135, 122, 142, 145, 128, 124, 128, 111, 104, 107, 97, 121, 123, 118, 131, 133, 122, 106, 108, 104, 119, 119, 112, 117, 120, 113, 93, 99, 97, 77, 83, 84, 60, 68, 72, 46, 51, 62, 107, 107, 105, 165, 166, 153, 174, 172, 156, 201, 193, 174, 211, 204, 185, 202, 196, 177, 171, 165, 144, 130, 125, 112, 166, 159, 144, 164, 152, 128, 163, 151, 125, 167, 157, 135, 159, 151, 129, 151, 145, 126, 153, 150, 129, 146, 146, 120, 139, 139, 113, 132, 131, 108, 136, 135, 114, 134, 132, 108, 136, 135, 108, 135, 136, 110, 113, 114, 96, 107, 108, 97, 127, 129, 119, 120, 125, 119, 115, 118, 109, 137, 143, 134, 170, 177, 174, 133, 138, 140, 81, 89, 95, 34, 40, 54, 80, 83, 85, 160, 159, 148, 160, 155, 139, 161, 154, 136, 175, 171, 156, 186, 183, 167, 166, 160, 139, 154, 149, 133, 166, 159, 142, 159, 149, 125, 157, 149, 122, 150, 144, 119, 158, 152, 126, 168, 162, 134, 161, 156, 130, 135, 135, 116, 133, 131, 115, 132, 129, 112, 140, 136, 118, 133, 127, 109, 134, 127, 107, 138, 133, 112, 138, 136, 120, 125, 125, 116, 125, 126, 119, 165, 175, 168, 159, 166, 160, 136, 143, 138, 158, 163, 157, 185, 188, 180, 148, 156, 154, 85, 95, 99, 79, 85, 87, 122, 116, 117, 152, 145, 128, 147, 141, 119, 153, 147, 132, 161, 156, 139, 160, 154, 135, 163, 159, 136, 167, 163, 139, 167, 161, 139, 168, 162, 137, 163, 158, 135, 163, 157, 137, 163, 159, 132, 159, 158, 127, 153, 150, 128, 157, 152, 135, 159, 155, 131, 164, 159, 136, 152, 149, 135, 138, 137, 121, 133, 130, 114, 117, 116, 108, 115, 116, 119, 94, 99, 105, 150, 153, 139, 135, 136, 121, 129, 129, 113, 141, 134, 110, 156, 144, 110, 164, 157, 128, 148, 143, 115, 139, 130, 103, 142, 130, 111, 152, 143, 111, 163, 155, 120, 176, 169, 143, 169, 161, 138, 168, 158, 139, 176, 168, 141, 183, 175, 144, 182, 174, 145, 184, 174, 151, 188, 176, 159, 188, 176, 159, 176, 164, 143, 168, 159, 127, 167, 161, 127, 169, 162, 134, 153, 149, 112, 164, 159, 125, 165, 159, 134, 137, 131, 104, 112, 107, 87, 72, 72, 69, 45, 51, 63, 26, 32, 51, 156, 156, 139, 153, 151, 130, 138, 136, 110, 141, 129, 95, 151, 126, 83, 156, 136, 93, 144, 125, 79, 153, 131, 82, 156, 138, 100, 146, 134, 90, 165, 155, 117, 182, 174, 148, 159, 150, 127, 122, 107, 89, 173, 159, 131, 177, 163, 128, 179, 165, 128, 177, 163, 124, 178, 164, 123, 175, 158, 117, 167, 150, 105, 161, 145, 98, 160, 151, 115, 165, 156, 127, 155, 148, 110, 160, 155, 119, 165, 151, 116, 148, 132, 93, 103, 93, 68, 57, 58, 56, 23, 32, 48, 38, 45, 64, 183, 193, 183, 191, 199, 185, 182, 189, 171, 165, 163, 142, 159, 146, 123, 142, 133, 109, 138, 128, 100, 140, 126, 94, 123, 109, 80, 128, 119, 86, 133, 126, 104, 134, 130, 121, 135, 131, 119, 124, 115, 97, 144, 133, 106, 139, 126, 92, 148, 134, 100, 161, 148, 110, 144, 133, 91, 137, 125, 84, 139, 126, 86, 141, 131, 96, 148, 143, 123, 163, 156, 141, 150, 142, 115, 146, 136, 110, 145, 129, 97, 138, 121, 82, 121, 110, 82, 83, 83, 76, 67, 74, 81, 114, 120, 119], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452206224}, {\"format\": \"raw\", \"value\": [169, 122, 65, 131, 108, 75, 193, 196, 192, 218, 221, 222, 211, 215, 216, 206, 214, 216, 200, 211, 212, 193, 206, 206, 186, 201, 201, 182, 197, 196, 178, 192, 192, 173, 187, 187, 167, 182, 182, 160, 175, 175, 155, 169, 169, 150, 164, 164, 144, 158, 158, 139, 153, 153, 134, 148, 148, 133, 144, 144, 130, 140, 141, 126, 136, 137, 125, 136, 137, 128, 138, 139, 131, 141, 142, 131, 144, 144, 149, 163, 163, 176, 194, 192, 173, 192, 190, 172, 187, 187, 169, 183, 183, 166, 181, 181, 165, 119, 62, 127, 104, 72, 189, 192, 187, 217, 220, 221, 209, 213, 215, 204, 211, 214, 198, 208, 209, 190, 204, 204, 184, 199, 199, 180, 194, 194, 175, 189, 189, 171, 185, 185, 165, 179, 179, 159, 172, 172, 155, 167, 168, 151, 163, 163, 146, 157, 158, 140, 152, 152, 136, 147, 147, 133, 143, 144, 129, 139, 140, 126, 136, 137, 126, 136, 137, 128, 138, 139, 131, 141, 141, 132, 144, 145, 151, 166, 165, 176, 193, 192, 173, 191, 189, 172, 186, 186, 169, 183, 183, 166, 180, 180, 163, 117, 60, 126, 103, 71, 186, 189, 185, 218, 221, 222, 210, 214, 215, 203, 210, 213, 197, 208, 209, 192, 205, 205, 186, 201, 201, 180, 195, 194, 176, 190, 190, 171, 185, 185, 165, 179, 179, 159, 172, 172, 157, 166, 168, 154, 162, 163, 148, 156, 158, 143, 151, 153, 138, 146, 148, 133, 143, 144, 130, 140, 141, 128, 138, 139, 128, 138, 139, 128, 138, 139, 131, 141, 142, 134, 146, 147, 154, 169, 168, 176, 194, 192, 174, 192, 190, 173, 187, 187, 170, 184, 184, 168, 182, 182, 160, 114, 57, 125, 101, 69, 184, 187, 183, 218, 221, 222, 209, 213, 215, 203, 210, 212, 197, 208, 208, 191, 205, 205, 186, 201, 200, 180, 194, 194, 176, 190, 190, 171, 185, 185, 165, 179, 179, 160, 173, 173, 159, 166, 169, 155, 160, 163, 149, 155, 158, 144, 150, 152, 139, 145, 148, 133, 143, 144, 130, 139, 140, 128, 138, 139, 128, 138, 139, 128, 138, 139, 131, 141, 142, 135, 146, 147, 159, 173, 173, 178, 195, 193, 175, 192, 191, 173, 188, 187, 170, 184, 184, 167, 182, 181, 163, 109, 55, 126, 97, 67, 183, 183, 180, 218, 220, 221, 209, 212, 214, 202, 210, 212, 196, 207, 207, 190, 204, 204, 184, 199, 199, 178, 194, 193, 176, 190, 190, 173, 185, 185, 168, 178, 179, 159, 168, 170, 151, 158, 161, 150, 158, 160, 147, 155, 157, 141, 149, 151, 138, 145, 147, 134, 143, 144, 129, 137, 139, 127, 136, 138, 127, 135, 137, 127, 135, 135, 131, 136, 134, 136, 141, 141, 164, 172, 173, 179, 190, 191, 176, 188, 189, 172, 187, 187, 168, 183, 183, 167, 182, 181, 166, 108, 55, 128, 96, 67, 180, 179, 176, 218, 219, 221, 209, 212, 214, 202, 210, 212, 194, 205, 206, 188, 202, 202, 182, 197, 196, 178, 193, 192, 175, 189, 188, 171, 181, 182, 165, 172, 174, 158, 163, 166, 147, 154, 155, 139, 146, 147, 129, 136, 137, 123, 130, 131, 122, 129, 130, 127, 133, 136, 130, 136, 139, 129, 135, 137, 125, 132, 134, 121, 127, 129, 120, 123, 122, 125, 129, 130, 158, 165, 168, 167, 176, 180, 153, 164, 168, 161, 175, 175, 167, 181, 180, 166, 180, 180, 167, 109, 56, 129, 98, 68, 177, 176, 173, 218, 219, 221, 208, 211, 213, 202, 209, 212, 194, 205, 206, 187, 201, 201, 182, 197, 196, 180, 192, 192, 175, 185, 186, 161, 168, 171, 159, 164, 167, 164, 167, 170, 164, 168, 168, 147, 151, 150, 126, 129, 129, 119, 123, 122, 111, 115, 115, 109, 112, 115, 122, 125, 128, 130, 133, 136, 127, 130, 133, 124, 128, 130, 123, 128, 129, 148, 154, 157, 177, 186, 190, 157, 170, 175, 135, 148, 153, 159, 171, 171, 168, 180, 180, 167, 178, 179, 167, 110, 56, 129, 98, 68, 176, 175, 172, 220, 220, 222, 209, 212, 214, 202, 209, 212, 195, 206, 207, 188, 202, 202, 183, 198, 197, 182, 193, 194, 168, 176, 178, 147, 152, 155, 166, 168, 172, 173, 173, 176, 175, 176, 175, 170, 171, 169, 157, 158, 156, 135, 136, 133, 126, 127, 126, 115, 115, 118, 116, 116, 121, 135, 135, 140, 149, 148, 153, 134, 136, 140, 137, 144, 147, 158, 168, 171, 158, 170, 175, 121, 136, 144, 124, 138, 144, 166, 175, 177, 170, 178, 180, 168, 177, 179, 161, 107, 56, 125, 95, 65, 174, 173, 169, 221, 222, 224, 211, 214, 216, 204, 211, 214, 197, 207, 208, 189, 202, 202, 184, 197, 197, 184, 191, 193, 161, 165, 168, 141, 143, 147, 177, 176, 181, 196, 194, 198, 188, 188, 185, 175, 175, 170, 160, 160, 156, 149, 149, 144, 130, 129, 127, 119, 118, 122, 123, 122, 127, 144, 143, 147, 127, 125, 130, 93, 94, 98, 108, 117, 121, 113, 125, 130, 97, 111, 117, 93, 109, 118, 105, 120, 127, 151, 158, 161, 172, 178, 180, 168, 174, 176, 112, 86, 54, 100, 79, 55, 177, 171, 161, 221, 222, 222, 212, 216, 219, 208, 213, 216, 201, 207, 209, 194, 201, 203, 189, 195, 197, 185, 188, 189, 162, 163, 164, 146, 147, 148, 184, 184, 185, 209, 208, 208, 191, 189, 184, 170, 168, 161, 160, 157, 151, 153, 150, 144, 134, 132, 127, 117, 119, 118, 125, 127, 128, 132, 134, 135, 89, 91, 92, 63, 68, 69, 79, 91, 94, 84, 97, 101, 96, 110, 114, 105, 120, 125, 99, 113, 118, 136, 145, 150, 146, 157, 157, 164, 173, 171, 103, 90, 68, 95, 81, 61, 172, 165, 154, 222, 225, 224, 213, 217, 220, 210, 214, 217, 203, 207, 210, 197, 201, 204, 192, 196, 198, 180, 181, 182, 165, 165, 164, 166, 166, 165, 182, 182, 182, 206, 206, 205, 200, 198, 193, 186, 184, 178, 175, 173, 167, 160, 158, 152, 155, 155, 149, 136, 139, 137, 125, 129, 128, 135, 139, 138, 87, 91, 90, 74, 80, 80, 89, 102, 105, 92, 107, 110, 128, 142, 145, 131, 145, 148, 137, 150, 154, 136, 148, 152, 136, 151, 151, 154, 166, 165, 110, 94, 69, 95, 85, 68, 165, 162, 154, 220, 223, 222, 212, 216, 219, 209, 213, 216, 203, 207, 210, 197, 201, 204, 184, 188, 190, 162, 163, 163, 153, 153, 153, 165, 165, 165, 175, 175, 175, 194, 194, 193, 189, 189, 186, 174, 175, 171, 166, 166, 162, 134, 134, 130, 168, 169, 165, 160, 164, 162, 141, 145, 144, 143, 147, 146, 84, 88, 87, 68, 74, 74, 86, 99, 101, 102, 116, 120, 134, 148, 151, 142, 156, 159, 145, 159, 161, 133, 148, 150, 132, 149, 154, 111, 124, 130, 99, 81, 55, 77, 71, 57, 159, 160, 156, 218, 221, 222, 212, 216, 219, 210, 214, 217, 202, 206, 209, 176, 181, 184, 148, 152, 154, 139, 139, 140, 141, 141, 141, 153, 153, 153, 150, 150, 150, 159, 160, 159, 138, 139, 138, 127, 129, 127, 145, 146, 145, 82, 84, 82, 141, 143, 141, 188, 192, 191, 142, 146, 145, 95, 99, 98, 77, 81, 80, 54, 60, 60, 83, 96, 98, 99, 113, 116, 120, 134, 137, 144, 158, 161, 131, 145, 147, 132, 149, 152, 96, 115, 125, 72, 87, 100, 106, 86, 58, 75, 73, 61, 153, 158, 156, 221, 224, 224, 215, 219, 221, 209, 213, 216, 169, 173, 176, 136, 139, 142, 132, 135, 138, 134, 134, 135, 133, 133, 133, 145, 145, 145, 145, 145, 145, 149, 149, 149, 157, 160, 160, 152, 156, 156, 130, 133, 133, 111, 114, 114, 135, 138, 138, 190, 194, 193, 154, 158, 157, 102, 106, 105, 67, 70, 69, 50, 56, 56, 93, 105, 107, 115, 129, 133, 124, 139, 143, 126, 140, 144, 115, 130, 131, 105, 124, 125, 79, 99, 112, 86, 102, 119, 118, 92, 59, 81, 77, 65, 152, 155, 153, 224, 223, 220, 220, 220, 219, 192, 193, 195, 133, 134, 135, 127, 129, 130, 134, 135, 136, 134, 134, 134, 129, 129, 129, 132, 132, 132, 158, 158, 158, 163, 163, 163, 169, 169, 170, 167, 168, 169, 141, 142, 142, 155, 157, 157, 175, 176, 176, 148, 148, 146, 150, 151, 149, 118, 122, 121, 54, 60, 60, 57, 63, 63, 113, 124, 124, 132, 153, 162, 113, 141, 155, 116, 138, 147, 114, 128, 131, 90, 104, 107, 98, 113, 120, 124, 138, 147, 124, 96, 62, 87, 82, 69, 149, 151, 147, 226, 224, 220, 206, 205, 204, 150, 150, 150, 125, 125, 125, 128, 128, 128, 131, 131, 131, 132, 132, 132, 137, 137, 137, 136, 136, 136, 140, 140, 140, 170, 170, 170, 196, 196, 196, 214, 214, 214, 215, 214, 214, 209, 209, 209, 202, 201, 201, 164, 164, 160, 171, 171, 169, 117, 120, 119, 48, 54, 55, 56, 64, 66, 135, 150, 153, 131, 160, 174, 114, 151, 173, 124, 154, 169, 162, 179, 186, 179, 186, 191, 167, 173, 179, 143, 149, 155, 126, 103, 72, 91, 84, 69, 145, 146, 140, 222, 221, 218, 173, 173, 172, 126, 126, 126, 130, 130, 130, 132, 132, 132, 131, 131, 131, 134, 134, 134, 148, 148, 148, 149, 149, 149, 133, 133, 133, 140, 140, 140, 172, 172, 172, 200, 200, 200, 214, 214, 214, 217, 217, 217, 206, 206, 205, 179, 179, 175, 151, 151, 149, 124, 127, 126, 81, 88, 88, 85, 96, 98, 139, 161, 169, 130, 162, 178, 113, 151, 172, 129, 163, 182, 171, 193, 206, 223, 225, 233, 224, 224, 232, 190, 190, 198, 134, 115, 88, 98, 89, 73, 145, 143, 136, 198, 199, 197, 134, 134, 134, 117, 116, 116, 120, 120, 120, 130, 130, 130, 132, 132, 132, 134, 134, 134, 154, 154, 154, 165, 165, 165, 154, 154, 154, 150, 150, 150, 153, 153, 153, 162, 162, 162, 171, 171, 171, 181, 181, 181, 180, 180, 179, 168, 168, 165, 164, 165, 162, 152, 155, 154, 123, 130, 130, 123, 134, 138, 139, 162, 172, 149, 177, 191, 133, 164, 181, 152, 184, 202, 152, 175, 190, 215, 218, 226, 237, 238, 245, 211, 213, 221, 126, 110, 85, 98, 87, 69, 138, 135, 126, 154, 156, 155, 112, 113, 113, 115, 115, 115, 116, 116, 116, 123, 123, 123, 132, 132, 132, 134, 134, 134, 148, 148, 148, 161, 161, 161, 171, 171, 171, 179, 179, 179, 180, 180, 180, 170, 170, 170, 174, 174, 174, 182, 183, 182, 185, 184, 184, 181, 181, 178, 172, 173, 170, 176, 178, 178, 149, 155, 156, 137, 147, 151, 146, 165, 173, 169, 189, 197, 177, 198, 207, 151, 177, 189, 153, 176, 188, 198, 209, 214, 189, 199, 203, 207, 216, 221, 138, 112, 72, 122, 97, 65, 131, 116, 101, 120, 119, 119, 109, 110, 111, 114, 114, 114, 119, 120, 120, 139, 139, 139, 137, 137, 137, 133, 133, 133, 150, 150, 150, 161, 161, 161, 175, 175, 175, 183, 184, 184, 175, 178, 177, 188, 190, 190, 196, 198, 198, 205, 208, 207, 203, 206, 205, 169, 172, 172, 176, 174, 177, 201, 197, 201, 155, 159, 161, 145, 159, 162, 137, 158, 168, 177, 192, 197, 213, 223, 226, 171, 186, 193, 168, 187, 196, 170, 187, 191, 165, 180, 182, 194, 204, 207, 155, 107, 60, 145, 103, 64, 120, 97, 79, 104, 102, 102, 117, 118, 119, 127, 126, 126, 126, 126, 126, 147, 147, 147, 152, 152, 152, 138, 138, 138, 145, 145, 145, 157, 157, 157, 155, 155, 155, 169, 170, 170, 175, 179, 178, 183, 187, 186, 206, 210, 209, 211, 215, 213, 202, 207, 206, 165, 171, 173, 172, 171, 176, 171, 167, 173, 172, 174, 177, 162, 175, 179, 146, 166, 176, 179, 191, 197, 228, 234, 236, 213, 222, 226, 193, 207, 212, 195, 209, 209, 221, 231, 232, 232, 238, 239, 160, 96, 50, 143, 93, 55, 102, 78, 59, 97, 98, 98, 118, 121, 122, 134, 134, 133, 141, 141, 141, 144, 144, 144, 152, 152, 152, 166, 166, 166, 161, 161, 161, 174, 174, 174, 178, 178, 178, 194, 194, 194, 204, 207, 206, 185, 189, 188, 189, 193, 192, 195, 199, 198, 186, 191, 191, 141, 151, 152, 135, 142, 144, 174, 177, 180, 193, 196, 199, 168, 175, 179, 149, 164, 171, 159, 171, 177, 198, 207, 210, 224, 232, 234, 222, 229, 231, 221, 226, 225, 236, 242, 241, 242, 249, 251, 160, 93, 41, 141, 88, 47, 91, 67, 48, 95, 97, 98, 129, 131, 133, 161, 161, 160, 157, 157, 157, 147, 147, 147, 155, 155, 155, 189, 189, 189, 199, 199, 199, 176, 177, 176, 159, 159, 159, 153, 154, 154, 155, 158, 158, 164, 168, 167, 171, 175, 174, 158, 162, 161, 148, 153, 152, 129, 142, 141, 141, 156, 156, 170, 182, 182, 189, 193, 196, 180, 180, 185, 148, 156, 161, 149, 161, 166, 172, 183, 187, 206, 211, 212, 227, 228, 227, 231, 233, 236, 217, 225, 229, 205, 219, 225, 154, 97, 38, 137, 90, 45, 92, 69, 49, 97, 98, 100, 133, 135, 137, 159, 158, 157, 151, 151, 151, 138, 137, 137, 153, 152, 152, 187, 186, 187, 221, 221, 221, 205, 205, 205, 178, 178, 178, 156, 156, 156, 160, 164, 163, 175, 179, 178, 176, 180, 179, 147, 151, 150, 124, 129, 128, 151, 166, 165, 158, 179, 177, 158, 176, 175, 180, 184, 187, 184, 180, 185, 163, 168, 169, 162, 173, 177, 173, 186, 191, 212, 215, 214, 222, 221, 218, 224, 230, 236, 184, 197, 207, 155, 179, 193, 152, 100, 37, 136, 90, 40, 110, 86, 62, 112, 111, 110, 135, 132, 133, 163, 157, 155, 155, 151, 150, 148, 144, 144, 159, 156, 157, 179, 178, 180, 215, 214, 217, 220, 219, 222, 197, 196, 200, 188, 187, 190, 169, 172, 172, 143, 147, 146, 161, 165, 164, 161, 165, 164, 108, 114, 112, 136, 150, 147, 167, 183, 180, 183, 196, 193, 191, 196, 196, 191, 190, 191, 175, 176, 176, 163, 168, 169, 190, 195, 197, 231, 232, 232, 215, 214, 213, 219, 222, 225, 207, 214, 219, 212, 223, 230, 154, 97, 31, 136, 88, 37, 109, 84, 58, 112, 112, 109, 136, 137, 141, 154, 152, 155, 165, 163, 166, 185, 183, 185, 182, 180, 182, 171, 173, 176, 185, 188, 190, 193, 196, 199, 186, 189, 192, 180, 183, 185, 178, 182, 182, 172, 176, 175, 156, 160, 159, 151, 155, 154, 143, 149, 147, 156, 167, 164, 192, 203, 199, 211, 218, 215, 228, 232, 231, 237, 239, 238, 219, 219, 219, 202, 202, 202, 217, 217, 217, 238, 238, 238, 234, 234, 234, 220, 220, 220, 202, 202, 202, 233, 233, 232, 160, 99, 30, 145, 96, 44, 114, 86, 59, 105, 98, 91, 117, 120, 123, 153, 157, 162, 181, 184, 187, 197, 198, 202, 191, 192, 194, 170, 176, 175, 156, 163, 161, 176, 184, 182, 195, 203, 201, 199, 205, 204, 202, 206, 205, 198, 202, 201, 161, 165, 164, 143, 147, 146, 159, 165, 163, 184, 193, 190, 208, 217, 214, 223, 229, 227, 234, 236, 235, 244, 244, 244, 245, 245, 245, 232, 232, 232, 225, 225, 225, 242, 242, 242, 242, 242, 242, 222, 222, 223, 218, 218, 218, 226, 226, 226, 166, 106, 39, 160, 111, 59, 146, 110, 75, 127, 102, 80, 118, 102, 86, 149, 138, 126, 183, 177, 169, 202, 200, 196, 207, 208, 207, 193, 196, 194, 166, 169, 167, 177, 180, 177, 200, 203, 200, 215, 218, 216, 218, 222, 221, 210, 214, 213, 189, 193, 192, 170, 174, 173, 173, 178, 177, 187, 193, 191, 206, 211, 209, 228, 230, 229, 234, 233, 233, 237, 235, 235, 234, 234, 234, 231, 231, 231, 229, 229, 229, 233, 233, 233, 230, 230, 230, 223, 223, 223, 225, 225, 225, 228, 228, 228, 155, 102, 41, 145, 97, 46, 149, 103, 60, 149, 103, 63, 150, 103, 62, 150, 110, 73, 154, 129, 102, 164, 153, 138, 169, 166, 159, 174, 168, 165, 122, 114, 112, 114, 107, 105, 130, 123, 122, 159, 154, 153, 215, 217, 216, 226, 230, 229, 215, 219, 218, 200, 204, 203, 204, 208, 207, 213, 217, 216, 215, 217, 217, 222, 221, 222, 226, 222, 224, 226, 222, 224, 222, 221, 221, 221, 221, 221, 223, 223, 223, 224, 224, 224, 224, 224, 224, 220, 220, 220, 219, 219, 219, 222, 222, 222, 147, 93, 35, 139, 85, 39, 145, 91, 42, 159, 103, 42, 187, 121, 47, 192, 123, 47, 173, 114, 43, 152, 109, 47, 142, 112, 63, 142, 110, 78, 127, 94, 71, 124, 95, 79, 123, 96, 89, 140, 118, 115, 185, 174, 167, 213, 206, 200, 227, 225, 220, 231, 233, 231, 235, 238, 236, 234, 236, 235, 230, 230, 234, 226, 226, 235, 223, 223, 232, 222, 221, 226, 222, 221, 221, 222, 221, 220, 222, 222, 222, 222, 222, 222, 222, 222, 222, 220, 220, 220, 218, 218, 218, 219, 219, 219, 146, 87, 31, 143, 83, 39, 152, 94, 43, 170, 113, 45, 190, 124, 43, 198, 125, 37, 203, 129, 38, 198, 132, 43, 189, 133, 49, 184, 130, 50, 180, 128, 55, 170, 123, 62, 156, 113, 63, 145, 106, 64, 140, 109, 73, 143, 116, 86, 157, 136, 112, 176, 160, 143, 192, 180, 165, 206, 196, 183, 219, 209, 205, 229, 220, 225, 232, 225, 229, 232, 227, 226, 232, 229, 226, 228, 226, 224, 224, 224, 224, 222, 224, 225, 222, 223, 225, 221, 221, 222, 220, 220, 220, 219, 219, 219, 148, 87, 28, 143, 82, 31, 146, 85, 30, 153, 94, 30, 169, 110, 41, 185, 122, 49, 196, 129, 49, 201, 132, 48, 204, 136, 47, 207, 141, 39, 208, 144, 42, 208, 147, 52, 205, 146, 58, 199, 144, 61, 186, 137, 63, 175, 128, 62, 165, 119, 64, 152, 109, 64, 144, 105, 66, 141, 109, 73, 150, 120, 95, 165, 138, 123, 184, 161, 146, 201, 183, 167, 211, 200, 192, 225, 218, 212, 229, 226, 223, 228, 229, 229, 226, 228, 229, 223, 223, 223, 221, 221, 221, 220, 220, 220], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387088}, {\"format\": \"raw\", \"value\": [154, 179, 152, 159, 183, 157, 165, 189, 162, 174, 199, 171, 168, 194, 164, 162, 187, 158, 156, 182, 152, 157, 182, 154, 149, 173, 147, 146, 170, 144, 146, 170, 144, 148, 172, 146, 153, 178, 152, 156, 181, 155, 156, 180, 154, 149, 173, 146, 141, 163, 136, 148, 171, 143, 159, 182, 154, 153, 175, 147, 136, 160, 133, 126, 150, 124, 125, 149, 123, 135, 160, 133, 144, 169, 142, 144, 169, 142, 136, 160, 134, 130, 154, 127, 131, 157, 131, 129, 161, 137, 125, 158, 133, 122, 155, 131, 156, 177, 152, 160, 180, 155, 163, 184, 159, 163, 186, 161, 165, 190, 164, 163, 187, 161, 151, 176, 150, 144, 168, 143, 142, 166, 143, 138, 162, 138, 141, 165, 141, 152, 176, 153, 156, 180, 156, 158, 182, 159, 157, 181, 157, 156, 180, 157, 154, 178, 153, 157, 181, 156, 157, 181, 156, 154, 178, 152, 150, 174, 148, 143, 167, 141, 142, 166, 140, 138, 162, 136, 142, 167, 141, 139, 166, 139, 138, 165, 138, 127, 154, 127, 117, 145, 118, 118, 150, 126, 120, 152, 128, 118, 150, 126, 146, 169, 143, 130, 152, 126, 128, 151, 125, 131, 155, 130, 138, 163, 139, 141, 164, 141, 140, 164, 140, 140, 164, 142, 145, 168, 148, 140, 163, 143, 136, 160, 139, 137, 160, 140, 142, 165, 144, 148, 171, 151, 152, 175, 155, 152, 175, 154, 150, 175, 151, 151, 177, 153, 152, 178, 154, 151, 177, 153, 150, 175, 149, 142, 166, 140, 148, 172, 146, 145, 169, 143, 133, 159, 133, 124, 153, 125, 126, 156, 128, 125, 154, 126, 122, 151, 124, 118, 150, 126, 112, 144, 120, 107, 139, 115, 141, 168, 140, 131, 157, 131, 121, 147, 121, 115, 140, 117, 110, 133, 112, 109, 133, 111, 117, 142, 119, 126, 151, 129, 133, 156, 136, 130, 153, 133, 131, 154, 135, 128, 151, 132, 136, 159, 139, 136, 159, 139, 133, 157, 137, 133, 157, 137, 130, 158, 135, 126, 155, 131, 123, 151, 128, 120, 148, 124, 122, 148, 123, 122, 146, 120, 120, 145, 118, 115, 139, 113, 107, 134, 107, 104, 134, 106, 109, 139, 111, 113, 143, 114, 113, 144, 116, 111, 143, 119, 105, 137, 113, 107, 139, 115, 135, 161, 134, 133, 158, 135, 133, 158, 136, 135, 157, 139, 115, 138, 117, 104, 130, 106, 102, 131, 109, 101, 130, 110, 111, 140, 119, 124, 151, 132, 139, 163, 145, 141, 164, 148, 139, 163, 144, 135, 159, 140, 125, 152, 132, 114, 143, 122, 108, 142, 120, 115, 148, 125, 122, 150, 127, 119, 143, 119, 112, 138, 111, 99, 127, 100, 100, 128, 100, 94, 122, 94, 94, 122, 94, 104, 132, 105, 113, 142, 115, 116, 145, 118, 110, 140, 113, 97, 129, 104, 98, 130, 106, 106, 138, 114, 140, 164, 139, 130, 154, 132, 131, 154, 134, 136, 158, 139, 131, 154, 133, 134, 159, 140, 126, 152, 142, 113, 142, 135, 106, 137, 126, 105, 133, 120, 125, 151, 135, 128, 153, 134, 129, 154, 135, 121, 148, 129, 116, 146, 125, 106, 139, 118, 99, 134, 113, 104, 136, 115, 112, 139, 117, 119, 142, 119, 114, 140, 114, 107, 136, 108, 105, 134, 106, 109, 139, 110, 111, 140, 114, 112, 140, 117, 121, 149, 125, 114, 142, 119, 113, 142, 118, 103, 135, 110, 98, 131, 105, 100, 133, 107, 126, 150, 125, 119, 143, 121, 118, 141, 121, 119, 143, 121, 110, 134, 113, 117, 139, 126, 195, 213, 216, 200, 221, 231, 198, 224, 227, 142, 167, 164, 109, 132, 123, 120, 143, 129, 116, 139, 124, 119, 144, 129, 124, 152, 136, 120, 150, 133, 106, 135, 119, 102, 129, 112, 108, 133, 113, 111, 133, 113, 116, 143, 117, 118, 147, 119, 117, 146, 118, 115, 144, 116, 110, 138, 113, 100, 128, 105, 104, 132, 109, 109, 137, 114, 104, 133, 109, 100, 133, 105, 97, 130, 102, 99, 132, 104, 119, 144, 118, 112, 136, 114, 110, 132, 113, 114, 138, 116, 105, 128, 107, 116, 136, 124, 204, 218, 222, 189, 204, 217, 174, 192, 202, 113, 130, 137, 92, 106, 112, 106, 120, 122, 104, 119, 117, 112, 128, 125, 115, 134, 130, 120, 141, 136, 118, 140, 129, 109, 131, 117, 107, 130, 113, 95, 118, 99, 97, 123, 99, 103, 133, 104, 111, 140, 112, 111, 140, 112, 115, 144, 116, 108, 137, 110, 102, 131, 103, 100, 129, 102, 100, 129, 102, 95, 127, 97, 100, 133, 102, 98, 131, 100, 122, 147, 122, 121, 146, 124, 120, 144, 124, 117, 142, 121, 114, 139, 116, 119, 138, 123, 110, 123, 122, 91, 102, 112, 72, 82, 97, 52, 59, 75, 62, 67, 85, 66, 69, 88, 65, 69, 82, 91, 97, 108, 117, 126, 136, 83, 95, 103, 93, 110, 107, 117, 136, 126, 117, 138, 124, 107, 129, 111, 101, 128, 103, 98, 127, 98, 101, 130, 101, 99, 128, 99, 113, 142, 111, 126, 155, 121, 127, 157, 123, 122, 151, 117, 112, 142, 108, 105, 138, 106, 104, 137, 106, 105, 138, 106, 120, 149, 125, 122, 150, 127, 112, 141, 118, 115, 144, 118, 115, 143, 117, 120, 142, 126, 99, 116, 118, 62, 74, 89, 116, 124, 140, 79, 81, 101, 74, 74, 96, 74, 76, 97, 38, 39, 59, 44, 46, 65, 98, 103, 118, 49, 55, 69, 34, 46, 52, 73, 89, 86, 114, 133, 119, 115, 137, 113, 107, 132, 103, 102, 129, 100, 94, 121, 91, 88, 115, 86, 98, 126, 94, 111, 138, 103, 118, 146, 111, 122, 149, 114, 122, 150, 116, 120, 150, 121, 118, 149, 120, 109, 140, 110, 115, 144, 122, 120, 149, 127, 116, 145, 123, 120, 148, 124, 121, 147, 123, 128, 150, 136, 117, 134, 138, 70, 83, 99, 91, 100, 116, 72, 74, 93, 113, 114, 131, 112, 116, 133, 48, 50, 67, 30, 31, 46, 53, 55, 66, 62, 66, 75, 49, 61, 64, 75, 92, 87, 97, 119, 101, 106, 131, 102, 108, 134, 104, 98, 124, 95, 96, 122, 93, 98, 124, 95, 101, 127, 99, 103, 129, 101, 103, 129, 101, 99, 125, 98, 109, 135, 108, 120, 149, 121, 123, 152, 124, 104, 133, 106, 105, 131, 112, 106, 132, 113, 108, 134, 115, 109, 134, 115, 103, 126, 108, 115, 134, 123, 182, 196, 200, 162, 175, 186, 109, 119, 131, 114, 117, 130, 75, 76, 91, 62, 67, 80, 135, 139, 149, 90, 92, 100, 42, 41, 48, 69, 69, 74, 90, 97, 97, 108, 122, 114, 103, 124, 106, 100, 127, 99, 108, 135, 107, 113, 138, 112, 110, 136, 110, 109, 135, 109, 111, 137, 113, 109, 133, 114, 102, 127, 108, 94, 119, 100, 93, 118, 98, 97, 124, 100, 100, 127, 103, 97, 124, 100, 101, 125, 109, 109, 132, 117, 114, 137, 122, 116, 138, 124, 104, 123, 111, 144, 160, 153, 188, 199, 204, 119, 131, 141, 163, 173, 179, 235, 238, 244, 198, 200, 207, 133, 139, 147, 124, 129, 139, 60, 61, 71, 37, 34, 43, 51, 43, 52, 71, 67, 72, 101, 105, 104, 121, 134, 123, 112, 134, 116, 108, 133, 110, 110, 136, 111, 111, 137, 113, 108, 133, 109, 107, 132, 110, 102, 126, 109, 100, 124, 107, 95, 120, 103, 95, 120, 102, 96, 119, 99, 98, 121, 101, 101, 124, 104, 112, 134, 121, 112, 133, 120, 126, 148, 134, 121, 141, 130, 110, 128, 117, 119, 134, 127, 131, 143, 148, 101, 112, 122, 159, 169, 175, 185, 189, 195, 118, 121, 128, 51, 57, 66, 18, 23, 35, 17, 17, 30, 28, 22, 34, 37, 27, 40, 56, 46, 58, 69, 64, 72, 94, 99, 99, 116, 128, 123, 117, 138, 122, 100, 125, 104, 100, 125, 104, 92, 118, 96, 92, 118, 97, 92, 118, 97, 97, 122, 102, 96, 121, 101, 91, 116, 95, 89, 112, 92, 94, 118, 97, 95, 118, 98, 102, 126, 110, 100, 124, 106, 98, 122, 102, 97, 121, 100, 98, 121, 99, 102, 124, 108, 116, 135, 132, 118, 134, 143, 96, 108, 123, 50, 59, 74, 26, 33, 48, 20, 26, 40, 20, 24, 34, 22, 20, 31, 27, 24, 35, 38, 38, 48, 53, 51, 65, 56, 54, 68, 60, 61, 71, 84, 85, 93, 107, 119, 116, 98, 119, 108, 99, 122, 108, 95, 121, 104, 88, 115, 97, 90, 117, 99, 86, 113, 93, 84, 109, 88, 88, 114, 91, 88, 116, 92, 95, 123, 98, 92, 120, 96, 99, 124, 107, 97, 122, 102, 94, 120, 98, 96, 121, 98, 101, 125, 101, 101, 125, 105, 99, 121, 112, 125, 144, 150, 83, 100, 115, 46, 61, 76, 37, 48, 66, 18, 28, 44, 21, 24, 37, 26, 23, 37, 35, 33, 47, 45, 47, 60, 46, 47, 62, 45, 44, 59, 48, 48, 60, 54, 54, 64, 71, 77, 80, 86, 97, 94, 99, 113, 106, 104, 121, 111, 91, 111, 99, 96, 120, 106, 86, 111, 94, 86, 111, 91, 87, 113, 91, 90, 115, 92, 100, 124, 102, 95, 120, 97, 117, 142, 125, 105, 130, 110, 104, 129, 108, 97, 121, 100, 90, 114, 90, 92, 116, 93, 89, 111, 97, 130, 151, 149, 173, 193, 199, 116, 133, 142, 85, 99, 112, 69, 81, 97, 35, 38, 54, 29, 25, 44, 38, 34, 53, 39, 41, 57, 34, 35, 50, 36, 35, 50, 40, 40, 52, 47, 47, 56, 59, 58, 65, 71, 70, 76, 85, 87, 89, 99, 104, 103, 93, 104, 98, 89, 107, 96, 85, 107, 93, 87, 111, 93, 85, 111, 90, 90, 111, 92, 97, 119, 99, 94, 116, 96, 105, 130, 114, 104, 129, 109, 94, 120, 98, 91, 115, 94, 106, 130, 107, 109, 133, 109, 101, 124, 106, 94, 115, 105, 154, 172, 167, 172, 188, 187, 209, 221, 225, 157, 168, 176, 48, 52, 64, 33, 30, 44, 35, 33, 47, 30, 32, 45, 27, 28, 43, 32, 31, 45, 34, 34, 46, 42, 42, 51, 54, 50, 61, 63, 58, 70, 67, 65, 73, 80, 81, 85, 101, 107, 106, 104, 117, 110, 102, 120, 110, 106, 130, 115, 106, 133, 115, 106, 131, 112, 98, 122, 103, 96, 120, 101, 99, 123, 106, 104, 129, 109, 99, 123, 102, 92, 115, 95, 103, 127, 104, 104, 128, 103, 97, 121, 100, 87, 110, 92, 80, 101, 85, 101, 117, 108, 150, 161, 161, 51, 60, 65, 18, 21, 29, 24, 22, 31, 26, 24, 34, 23, 24, 34, 22, 23, 37, 27, 26, 40, 28, 28, 40, 35, 35, 46, 47, 45, 57, 53, 49, 63, 52, 51, 61, 59, 60, 66, 74, 78, 80, 96, 105, 101, 114, 129, 120, 106, 129, 114, 112, 140, 121, 117, 145, 126, 106, 134, 115, 104, 132, 113, 98, 121, 102, 102, 125, 106, 99, 122, 103, 86, 109, 90, 90, 113, 94, 95, 118, 99, 89, 112, 93, 88, 114, 94, 97, 122, 105, 133, 148, 142, 170, 180, 184, 35, 44, 53, 15, 18, 25, 21, 22, 31, 46, 46, 58, 29, 30, 43, 23, 24, 38, 27, 29, 42, 29, 31, 44, 32, 34, 46, 35, 36, 50, 36, 36, 49, 36, 35, 46, 47, 44, 52, 62, 60, 65, 78, 80, 80, 91, 101, 93, 87, 108, 90, 97, 124, 101, 107, 129, 111, 109, 132, 114, 101, 124, 106, 85, 108, 90, 88, 111, 93, 87, 110, 92, 87, 110, 93, 93, 116, 99, 90, 113, 96, 88, 111, 94, 92, 112, 97, 154, 166, 156, 194, 200, 198, 177, 182, 188, 38, 47, 57, 17, 26, 37, 43, 50, 64, 71, 78, 94, 25, 31, 49, 18, 22, 37, 22, 25, 39, 19, 21, 36, 29, 31, 46, 39, 42, 55, 31, 32, 44, 29, 27, 38, 34, 30, 39, 47, 43, 49, 65, 65, 67, 77, 85, 80, 85, 103, 89, 90, 112, 94, 97, 117, 101, 105, 125, 109, 95, 115, 99, 80, 102, 88, 73, 95, 81, 78, 101, 86, 83, 106, 91, 83, 105, 91, 79, 102, 87, 78, 101, 86, 84, 105, 92, 83, 99, 91, 69, 82, 79, 114, 130, 131, 100, 120, 124, 98, 114, 127, 139, 154, 169, 128, 142, 160, 49, 62, 82, 26, 33, 50, 12, 17, 33, 52, 56, 71, 141, 145, 160, 87, 90, 104, 40, 41, 53, 30, 28, 39, 24, 20, 29, 33, 30, 36, 46, 48, 51, 66, 72, 71, 67, 79, 73, 67, 83, 74, 83, 99, 87, 86, 103, 90, 97, 113, 101, 99, 121, 109, 82, 104, 92, 73, 95, 83, 75, 97, 85, 76, 98, 85, 78, 100, 87, 84, 106, 93, 81, 106, 94, 65, 90, 82, 53, 71, 67, 176, 193, 191, 226, 245, 245, 212, 228, 237, 127, 143, 156, 102, 118, 134, 87, 102, 120, 53, 62, 80, 94, 100, 117, 187, 194, 207, 144, 151, 167, 51, 55, 71, 36, 37, 49, 31, 29, 40, 27, 23, 32, 37, 34, 40, 49, 50, 55, 62, 67, 70, 70, 76, 79, 73, 82, 82, 67, 80, 71, 77, 91, 81, 96, 109, 99, 98, 122, 108, 81, 105, 92, 81, 105, 92, 75, 99, 86, 78, 101, 89, 88, 110, 98, 85, 107, 95, 90, 111, 103, 112, 128, 125, 160, 167, 167, 242, 245, 247, 251, 255, 255, 213, 226, 231, 114, 128, 136, 84, 97, 109, 94, 107, 120, 104, 113, 128, 192, 200, 213, 131, 139, 154, 29, 36, 55, 31, 35, 50, 31, 31, 44, 26, 25, 36, 31, 28, 36, 42, 40, 46, 41, 42, 48, 37, 39, 45, 40, 42, 50, 64, 68, 74, 91, 102, 96, 95, 107, 99, 105, 117, 108, 77, 106, 85, 78, 106, 89, 90, 117, 104, 91, 119, 107, 87, 115, 103, 87, 112, 101, 88, 110, 101, 132, 147, 143, 217, 222, 224, 238, 242, 244, 220, 224, 226, 225, 229, 232, 223, 233, 236, 219, 231, 234, 199, 210, 214, 186, 197, 202, 194, 207, 211, 159, 172, 178, 35, 44, 56, 22, 28, 43, 28, 31, 44, 27, 29, 39, 30, 32, 39, 36, 38, 43, 38, 40, 44, 39, 42, 46, 35, 38, 43, 32, 35, 40, 47, 51, 54, 105, 110, 107, 113, 119, 113, 112, 118, 108, 79, 107, 89, 88, 115, 99, 87, 114, 101, 88, 115, 103, 102, 129, 117, 97, 121, 110, 102, 123, 113, 125, 142, 135, 141, 153, 151, 137, 150, 147, 104, 117, 115, 111, 125, 123, 117, 135, 132, 110, 128, 125, 89, 107, 104, 90, 109, 106, 98, 115, 113, 95, 110, 111, 66, 78, 83, 64, 72, 80, 53, 62, 65, 56, 66, 64, 61, 72, 67, 72, 84, 76, 73, 84, 76, 80, 91, 84, 82, 94, 86, 87, 98, 91, 91, 102, 94, 114, 122, 110, 118, 126, 112, 114, 122, 106, 103, 128, 115, 106, 131, 117, 101, 126, 112, 100, 126, 112, 105, 129, 115, 104, 126, 113, 107, 126, 114, 125, 145, 133, 102, 124, 114, 104, 126, 116, 104, 126, 116, 90, 113, 102, 93, 117, 105, 92, 116, 105, 100, 124, 113, 114, 137, 126, 104, 126, 116, 106, 124, 117, 124, 139, 136, 117, 129, 129, 101, 116, 108, 100, 118, 103, 107, 125, 108, 98, 116, 97, 92, 110, 90, 108, 126, 107, 117, 136, 117, 103, 122, 103, 106, 123, 103, 107, 119, 98, 108, 119, 98, 117, 129, 107, 122, 144, 136, 118, 140, 130, 125, 148, 135, 118, 141, 126, 107, 129, 114, 116, 136, 122, 120, 136, 123, 121, 139, 126, 115, 139, 124, 122, 145, 130, 128, 151, 137, 116, 139, 124, 118, 141, 124, 105, 128, 111, 116, 138, 121, 118, 141, 124, 110, 134, 117, 108, 130, 116, 119, 138, 127, 122, 138, 131, 130, 145, 134, 130, 146, 130, 128, 145, 126, 111, 128, 107, 98, 115, 93, 107, 123, 102, 115, 132, 110, 111, 128, 107, 122, 138, 116, 112, 125, 102, 110, 123, 102, 114, 127, 109, 115, 135, 127, 124, 144, 133, 136, 157, 142, 118, 141, 123, 118, 140, 123, 119, 139, 123, 120, 137, 123, 116, 134, 119, 118, 140, 124, 117, 139, 122, 120, 141, 124, 120, 141, 123, 111, 131, 111, 112, 132, 113, 115, 135, 115, 113, 133, 113, 106, 129, 108, 113, 134, 116, 119, 138, 125, 117, 134, 122, 127, 141, 128, 124, 137, 123, 122, 136, 119, 124, 138, 120, 115, 130, 111, 111, 126, 107, 110, 125, 106, 120, 135, 116, 133, 149, 128, 125, 140, 117, 107, 122, 101, 118, 132, 114, 125, 146, 129, 126, 147, 127, 124, 146, 124, 115, 139, 116, 119, 145, 122, 116, 140, 119, 120, 143, 125, 125, 148, 132, 120, 143, 126, 124, 145, 127, 125, 144, 125, 123, 141, 121, 132, 153, 134, 127, 148, 129, 104, 125, 106, 109, 129, 110, 123, 140, 119, 115, 130, 114, 121, 135, 125, 127, 140, 128, 127, 142, 127, 107, 123, 108, 100, 117, 101, 109, 125, 109, 108, 126, 108, 99, 120, 99, 100, 121, 100, 106, 127, 106, 116, 136, 115, 123, 141, 117, 126, 140, 118, 131, 144, 122, 125, 145, 127, 127, 148, 128, 125, 146, 124, 116, 138, 115, 118, 141, 118, 109, 132, 111, 118, 141, 123, 117, 140, 123, 107, 130, 112, 110, 131, 112, 123, 142, 121, 130, 149, 127, 129, 150, 130, 118, 140, 120, 115, 136, 116, 126, 147, 127, 131, 148, 126, 115, 130, 114, 123, 137, 127, 126, 141, 128, 118, 134, 119, 110, 127, 111, 95, 112, 96, 101, 118, 102, 100, 118, 101, 97, 118, 99, 104, 125, 107, 99, 120, 101, 109, 130, 111, 120, 137, 119, 128, 142, 125, 129, 141, 125, 119, 136, 120, 121, 138, 119, 135, 153, 132, 119, 136, 114, 113, 130, 109, 113, 133, 114, 110, 133, 115, 112, 137, 118, 102, 126, 105, 102, 124, 102, 105, 124, 100, 115, 134, 110, 115, 137, 114, 113, 136, 113, 131, 153, 130, 134, 156, 132, 132, 152, 129, 117, 135, 119, 102, 120, 109, 121, 139, 126, 130, 147, 131, 119, 136, 120, 101, 118, 102, 110, 127, 111, 101, 119, 103, 95, 115, 99, 97, 118, 101, 99, 120, 103, 115, 135, 119, 132, 148, 135, 136, 149, 137, 146, 157, 146], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387152}, {\"format\": \"raw\", \"value\": [216, 195, 180, 201, 178, 160, 210, 184, 164, 212, 188, 171, 217, 195, 178, 202, 178, 158, 177, 150, 128, 188, 162, 141, 198, 176, 157, 196, 173, 157, 198, 175, 162, 207, 184, 173, 197, 177, 162, 197, 178, 163, 213, 194, 179, 201, 182, 166, 187, 169, 150, 193, 176, 156, 209, 191, 175, 186, 168, 155, 140, 120, 100, 131, 112, 91, 80, 64, 46, 62, 43, 21, 96, 73, 51, 133, 110, 93, 139, 119, 101, 149, 132, 112, 142, 124, 105, 172, 149, 130, 196, 177, 153, 202, 189, 166, 202, 179, 164, 222, 197, 179, 211, 184, 165, 200, 176, 162, 200, 178, 164, 200, 176, 157, 187, 161, 136, 194, 169, 141, 199, 176, 149, 199, 175, 155, 196, 171, 158, 212, 187, 178, 210, 191, 176, 192, 173, 158, 183, 164, 149, 205, 186, 171, 198, 180, 163, 178, 161, 144, 194, 177, 161, 163, 146, 130, 137, 116, 95, 122, 104, 83, 81, 65, 48, 66, 47, 26, 85, 63, 44, 120, 98, 83, 122, 97, 80, 123, 95, 75, 133, 104, 83, 164, 139, 119, 173, 152, 128, 176, 160, 137, 190, 165, 150, 186, 159, 142, 222, 193, 174, 210, 185, 171, 191, 169, 154, 194, 170, 150, 202, 175, 152, 201, 175, 148, 198, 174, 145, 199, 173, 149, 193, 166, 149, 198, 173, 158, 208, 188, 173, 189, 170, 155, 170, 151, 136, 184, 165, 150, 198, 180, 166, 169, 151, 136, 167, 150, 132, 152, 135, 116, 129, 109, 86, 93, 75, 53, 75, 60, 43, 72, 54, 32, 79, 57, 36, 95, 74, 55, 119, 94, 74, 133, 103, 82, 131, 99, 78, 143, 115, 94, 145, 122, 96, 133, 115, 90, 194, 167, 154, 160, 131, 116, 183, 152, 134, 199, 174, 156, 213, 192, 171, 193, 170, 150, 182, 156, 137, 196, 169, 148, 197, 170, 146, 207, 180, 156, 203, 176, 151, 203, 177, 154, 195, 175, 159, 179, 159, 144, 188, 169, 154, 191, 172, 157, 199, 181, 168, 194, 176, 162, 181, 164, 146, 170, 153, 133, 130, 110, 87, 69, 50, 29, 76, 60, 43, 72, 54, 33, 75, 53, 28, 104, 84, 57, 117, 96, 72, 140, 117, 96, 130, 105, 85, 134, 106, 84, 147, 123, 96, 159, 140, 114, 187, 162, 153, 180, 153, 139, 182, 157, 139, 193, 170, 155, 208, 186, 168, 211, 189, 165, 197, 173, 151, 199, 173, 154, 190, 164, 144, 196, 167, 146, 214, 182, 159, 216, 185, 162, 207, 184, 164, 197, 171, 155, 199, 172, 158, 202, 178, 164, 208, 187, 175, 209, 189, 177, 206, 186, 172, 197, 177, 162, 119, 99, 82, 58, 39, 22, 65, 47, 31, 79, 60, 43, 70, 47, 28, 107, 82, 61, 128, 107, 86, 137, 119, 99, 141, 123, 102, 134, 111, 87, 137, 115, 91, 145, 127, 105, 192, 170, 160, 194, 170, 157, 186, 167, 150, 182, 160, 149, 188, 162, 148, 200, 173, 150, 195, 167, 143, 186, 159, 138, 180, 154, 133, 167, 139, 117, 200, 168, 145, 211, 180, 155, 227, 202, 177, 220, 190, 169, 205, 175, 157, 209, 185, 167, 208, 189, 174, 202, 184, 170, 221, 203, 189, 209, 191, 177, 102, 83, 69, 60, 41, 26, 73, 54, 39, 89, 70, 55, 93, 71, 56, 116, 92, 75, 142, 121, 103, 159, 142, 123, 145, 129, 108, 145, 124, 100, 135, 114, 92, 136, 118, 99, 201, 179, 165, 173, 151, 139, 144, 129, 115, 150, 130, 119, 160, 133, 121, 172, 142, 124, 183, 149, 129, 198, 166, 145, 193, 167, 144, 157, 131, 106, 169, 142, 115, 197, 171, 141, 210, 187, 157, 212, 184, 158, 210, 181, 158, 233, 211, 189, 224, 209, 191, 221, 207, 191, 228, 214, 197, 180, 167, 150, 88, 71, 55, 83, 64, 49, 92, 73, 58, 99, 80, 65, 110, 91, 75, 118, 99, 82, 138, 120, 103, 163, 146, 128, 149, 131, 113, 158, 136, 115, 149, 128, 107, 125, 107, 86, 198, 177, 160, 129, 110, 98, 77, 66, 57, 104, 94, 85, 138, 122, 114, 159, 136, 128, 180, 152, 138, 191, 162, 144, 205, 178, 159, 205, 180, 158, 178, 155, 129, 213, 193, 164, 206, 184, 155, 209, 181, 156, 222, 193, 171, 226, 203, 181, 237, 221, 202, 231, 217, 199, 230, 217, 198, 177, 163, 144, 81, 64, 47, 97, 78, 63, 97, 78, 63, 100, 81, 66, 110, 93, 78, 121, 107, 91, 128, 112, 96, 150, 133, 118, 161, 143, 127, 165, 143, 126, 162, 141, 121, 128, 111, 88, 206, 186, 165, 164, 147, 136, 99, 90, 84, 72, 73, 66, 89, 89, 86, 108, 99, 98, 150, 133, 126, 191, 168, 154, 195, 166, 153, 208, 182, 167, 213, 193, 172, 200, 181, 158, 193, 170, 146, 210, 181, 161, 214, 184, 167, 204, 179, 163, 220, 201, 182, 226, 208, 188, 233, 216, 197, 158, 141, 121, 93, 74, 58, 101, 82, 67, 102, 84, 68, 116, 96, 81, 107, 92, 76, 129, 119, 103, 135, 122, 107, 147, 129, 116, 168, 148, 135, 183, 160, 145, 178, 157, 138, 151, 134, 110, 223, 201, 182, 202, 182, 169, 181, 165, 152, 120, 113, 101, 82, 80, 75, 79, 76, 78, 83, 78, 80, 138, 124, 119, 200, 176, 163, 213, 191, 178, 215, 198, 183, 194, 179, 164, 196, 180, 167, 210, 191, 176, 201, 180, 165, 180, 161, 148, 186, 171, 157, 208, 193, 179, 206, 192, 178, 162, 148, 134, 140, 126, 110, 106, 92, 75, 90, 74, 59, 118, 100, 87, 95, 80, 67, 94, 82, 68, 134, 118, 104, 125, 104, 89, 147, 124, 107, 188, 164, 145, 189, 168, 148, 148, 132, 109, 211, 188, 172, 201, 177, 164, 209, 186, 167, 202, 183, 165, 178, 164, 154, 126, 117, 113, 70, 64, 67, 67, 61, 62, 134, 128, 123, 192, 187, 183, 155, 153, 152, 153, 151, 150, 166, 158, 152, 163, 154, 140, 171, 160, 144, 173, 159, 148, 175, 165, 156, 186, 178, 168, 200, 191, 181, 204, 195, 185, 182, 172, 159, 160, 148, 133, 138, 123, 108, 136, 119, 103, 99, 82, 68, 94, 77, 64, 131, 110, 94, 145, 119, 99, 148, 121, 98, 174, 149, 126, 176, 155, 133, 146, 130, 109, 204, 181, 165, 206, 182, 169, 206, 184, 165, 207, 186, 166, 217, 196, 179, 215, 195, 182, 150, 137, 129, 70, 67, 65, 85, 90, 94, 125, 131, 137, 106, 115, 122, 122, 130, 136, 144, 138, 134, 146, 138, 126, 157, 147, 132, 170, 158, 148, 177, 168, 160, 188, 181, 173, 203, 196, 187, 193, 185, 177, 164, 153, 146, 157, 143, 134, 158, 142, 127, 170, 152, 132, 128, 111, 92, 109, 90, 75, 142, 119, 101, 159, 132, 110, 178, 148, 124, 180, 153, 131, 150, 127, 106, 137, 119, 99, 224, 200, 185, 207, 184, 171, 194, 172, 153, 207, 185, 166, 220, 195, 175, 222, 196, 174, 193, 177, 161, 125, 117, 109, 114, 109, 104, 126, 122, 119, 111, 110, 109, 126, 125, 124, 140, 135, 131, 151, 145, 134, 151, 143, 130, 160, 150, 141, 167, 160, 153, 186, 181, 174, 198, 194, 186, 171, 166, 158, 115, 107, 104, 92, 81, 79, 97, 85, 76, 107, 94, 80, 128, 113, 99, 128, 111, 98, 148, 128, 112, 153, 128, 108, 163, 134, 112, 175, 146, 125, 146, 120, 100, 130, 110, 91, 215, 191, 176, 204, 181, 168, 204, 181, 163, 206, 186, 170, 217, 192, 172, 231, 203, 178, 161, 146, 127, 116, 108, 97, 115, 103, 94, 114, 104, 96, 126, 119, 113, 136, 131, 127, 159, 156, 153, 162, 158, 148, 146, 139, 128, 149, 141, 133, 161, 156, 151, 187, 184, 178, 194, 191, 185, 144, 140, 135, 58, 56, 54, 131, 128, 128, 155, 150, 149, 71, 64, 63, 33, 23, 20, 86, 75, 66, 148, 133, 121, 165, 146, 131, 136, 111, 93, 147, 115, 95, 145, 117, 98, 142, 120, 102, 209, 186, 171, 206, 183, 169, 205, 182, 165, 201, 182, 166, 205, 184, 166, 212, 189, 167, 184, 167, 149, 122, 113, 99, 104, 98, 87, 96, 90, 86, 108, 101, 100, 113, 107, 105, 141, 137, 133, 152, 148, 140, 158, 153, 144, 156, 149, 143, 150, 145, 140, 179, 175, 171, 185, 181, 178, 101, 98, 96, 160, 162, 162, 212, 216, 219, 120, 121, 126, 93, 93, 98, 65, 68, 74, 118, 120, 120, 115, 103, 92, 129, 109, 91, 112, 90, 70, 101, 75, 51, 106, 83, 60, 129, 109, 91, 196, 172, 158, 203, 180, 166, 200, 177, 163, 188, 168, 152, 198, 179, 162, 204, 185, 168, 202, 183, 166, 156, 142, 125, 99, 93, 80, 96, 88, 87, 91, 81, 84, 94, 86, 83, 119, 113, 107, 144, 139, 133, 156, 151, 145, 168, 163, 157, 149, 142, 138, 136, 132, 129, 180, 178, 176, 105, 105, 105, 188, 193, 194, 226, 233, 235, 177, 184, 187, 155, 161, 166, 137, 150, 161, 177, 190, 197, 122, 112, 101, 106, 84, 63, 116, 94, 73, 127, 106, 80, 109, 89, 67, 118, 100, 83, 186, 163, 148, 191, 168, 153, 192, 169, 154, 186, 164, 148, 194, 174, 157, 210, 190, 173, 203, 183, 166, 191, 170, 156, 125, 106, 98, 102, 88, 86, 97, 90, 90, 97, 94, 91, 117, 112, 107, 135, 130, 124, 138, 133, 127, 148, 143, 137, 153, 149, 144, 134, 131, 128, 157, 157, 154, 108, 110, 110, 165, 171, 167, 225, 235, 229, 217, 226, 226, 179, 186, 191, 133, 144, 153, 149, 159, 163, 145, 138, 129, 114, 97, 81, 135, 116, 99, 174, 151, 130, 155, 133, 115, 138, 118, 104, 201, 178, 159, 196, 173, 155, 194, 172, 153, 186, 162, 146, 197, 174, 158, 211, 188, 172, 202, 179, 163, 181, 155, 141, 139, 112, 102, 106, 88, 77, 97, 89, 81, 92, 90, 84, 101, 96, 90, 121, 116, 110, 129, 124, 118, 129, 124, 118, 144, 141, 136, 167, 167, 162, 175, 177, 174, 142, 146, 145, 117, 122, 117, 199, 204, 197, 217, 222, 219, 170, 174, 174, 120, 125, 126, 119, 120, 117, 142, 133, 123, 144, 128, 113, 148, 129, 112, 146, 120, 102, 168, 144, 126, 173, 151, 135, 201, 179, 157, 202, 180, 159, 213, 192, 170, 207, 183, 166, 188, 162, 147, 185, 159, 145, 152, 126, 112, 119, 91, 76, 114, 87, 67, 124, 105, 82, 96, 85, 68, 74, 66, 58, 78, 73, 68, 99, 94, 89, 119, 114, 108, 129, 125, 118, 142, 141, 135, 175, 177, 171, 200, 204, 201, 193, 199, 198, 134, 135, 135, 110, 106, 105, 175, 172, 168, 158, 156, 148, 125, 119, 108, 125, 112, 100, 131, 116, 101, 160, 141, 123, 159, 136, 116, 149, 122, 101, 134, 108, 86, 156, 133, 109, 181, 157, 137, 183, 159, 140, 183, 159, 140, 182, 157, 138, 170, 142, 122, 117, 88, 67, 94, 66, 47, 99, 73, 54, 105, 79, 57, 116, 91, 62, 115, 94, 69, 101, 86, 69, 81, 74, 62, 84, 78, 69, 90, 84, 78, 97, 93, 89, 132, 131, 128, 179, 180, 178, 203, 207, 205, 212, 221, 219, 208, 207, 210, 136, 129, 128, 127, 121, 112, 136, 127, 113, 124, 112, 93, 135, 119, 100, 147, 129, 114, 163, 141, 123, 163, 137, 115, 162, 135, 110, 138, 111, 86, 135, 111, 83, 166, 142, 124, 162, 138, 120, 133, 109, 91, 108, 83, 61, 108, 78, 51, 88, 54, 24, 78, 47, 20, 102, 76, 56, 116, 88, 70, 113, 80, 55, 87, 58, 32, 126, 108, 84, 145, 134, 112, 93, 85, 68, 73, 67, 57, 76, 73, 69, 116, 115, 118, 190, 191, 194, 203, 206, 207, 201, 208, 206, 208, 209, 207, 197, 194, 186, 181, 176, 161, 173, 162, 148, 124, 110, 93, 146, 130, 110, 168, 149, 135, 178, 154, 138, 163, 138, 114, 166, 140, 113, 145, 119, 92, 143, 117, 91, 154, 133, 116, 147, 127, 109, 145, 125, 108, 103, 81, 61, 91, 63, 39, 100, 70, 43, 83, 56, 31, 103, 77, 56, 114, 85, 64, 97, 68, 46, 62, 39, 19, 81, 66, 47, 160, 151, 126, 153, 146, 122, 137, 130, 110, 141, 137, 121, 101, 103, 102, 171, 174, 176, 196, 197, 194, 187, 187, 180, 188, 186, 180, 180, 176, 167, 165, 159, 145, 95, 89, 81, 67, 55, 43, 124, 102, 83, 150, 126, 108, 179, 155, 132, 192, 168, 140, 171, 145, 120, 156, 130, 104, 136, 110, 85, 174, 158, 141, 189, 173, 157, 185, 169, 153, 145, 127, 110, 93, 70, 50, 105, 79, 55, 82, 59, 37, 84, 61, 41, 79, 54, 33, 58, 37, 20, 45, 27, 13, 50, 34, 20, 101, 93, 68, 161, 153, 125, 177, 168, 140, 186, 179, 151, 97, 96, 86, 83, 82, 77, 148, 143, 132, 167, 159, 146, 169, 160, 147, 139, 128, 113, 94, 81, 68, 30, 26, 19, 25, 17, 9, 68, 46, 32, 114, 91, 71, 148, 125, 99, 181, 157, 130, 183, 157, 133, 150, 124, 100, 114, 88, 65, 183, 171, 155, 184, 172, 156, 167, 155, 139, 167, 152, 136, 154, 135, 117, 135, 112, 91, 106, 86, 68, 74, 58, 44, 54, 39, 27, 35, 22, 13, 40, 23, 12, 54, 33, 18, 59, 50, 31, 99, 91, 66, 128, 116, 86, 147, 133, 100, 127, 113, 86, 73, 59, 39, 68, 54, 38, 96, 80, 65, 113, 96, 75, 117, 95, 71, 99, 76, 57, 40, 31, 19, 15, 14, 9, 24, 15, 8, 61, 47, 28, 105, 83, 60, 141, 113, 93, 146, 119, 99, 135, 108, 87, 102, 75, 54, 167, 156, 140, 168, 157, 141, 173, 162, 147, 183, 169, 156, 181, 164, 148, 184, 165, 147, 159, 142, 125, 132, 119, 105, 124, 116, 103, 92, 82, 71, 94, 75, 60, 108, 83, 64, 86, 72, 55, 80, 67, 47, 84, 71, 47, 89, 76, 49, 99, 81, 51, 104, 81, 53, 87, 65, 44, 86, 69, 53, 103, 83, 57, 130, 99, 70, 124, 94, 74, 42, 32, 20, 11, 15, 8, 17, 15, 8, 39, 27, 11, 83, 60, 40, 119, 91, 73, 124, 96, 77, 115, 89, 71, 84, 59, 42, 162, 150, 133, 162, 150, 135, 167, 155, 143, 171, 155, 144, 167, 150, 137, 169, 152, 136, 166, 150, 132, 160, 146, 130, 132, 121, 104, 126, 112, 89, 126, 109, 84, 110, 89, 67, 145, 124, 103, 156, 139, 120, 121, 109, 94, 68, 61, 48, 44, 35, 19, 61, 40, 22, 83, 57, 38, 106, 92, 75, 116, 100, 73, 140, 111, 86, 134, 106, 93, 39, 33, 25, 9, 15, 6, 23, 17, 8, 42, 24, 13, 60, 38, 21, 64, 44, 23, 105, 80, 61, 81, 60, 44, 45, 30, 19, 172, 163, 148, 184, 175, 163, 173, 164, 154, 156, 141, 129, 164, 146, 131, 152, 135, 117, 159, 142, 122, 156, 139, 120, 141, 126, 107, 127, 111, 85, 121, 103, 77, 130, 111, 90, 151, 135, 117, 166, 150, 133, 162, 147, 129, 121, 107, 89, 66, 54, 36, 72, 52, 32, 93, 69, 47, 100, 85, 65, 101, 87, 64, 137, 114, 94, 118, 96, 85, 28, 21, 14, 13, 17, 10, 24, 22, 16, 31, 21, 14, 35, 22, 11, 34, 22, 7, 81, 67, 50, 56, 44, 30, 25, 18, 7, 195, 186, 171, 200, 191, 179, 211, 201, 192, 201, 185, 171, 183, 163, 144, 162, 142, 121, 154, 135, 111, 133, 114, 90, 134, 115, 92, 131, 113, 85, 128, 111, 84, 121, 105, 86, 134, 122, 107, 136, 121, 104, 126, 107, 85, 113, 91, 67, 108, 90, 67, 108, 88, 62, 110, 88, 61, 111, 93, 70, 120, 104, 84, 109, 92, 75, 113, 96, 83, 82, 72, 62, 32, 29, 23, 14, 14, 12, 24, 23, 19, 17, 14, 8, 16, 11, 4, 48, 42, 30, 47, 42, 31, 36, 34, 24, 146, 132, 113, 167, 153, 136, 162, 147, 134, 150, 131, 114, 152, 131, 108, 152, 132, 106, 156, 136, 108, 144, 122, 94, 133, 109, 82, 137, 116, 86, 130, 112, 86, 125, 108, 89, 135, 119, 102, 119, 102, 83, 131, 110, 88, 148, 125, 102, 130, 109, 85, 118, 98, 68, 112, 92, 60, 123, 102, 76, 137, 118, 98, 133, 115, 97, 127, 109, 91, 167, 148, 130, 137, 123, 112, 40, 38, 35, 10, 12, 7, 12, 12, 7, 16, 11, 7, 18, 15, 9, 23, 19, 14, 36, 33, 27, 138, 119, 95, 150, 131, 110, 152, 132, 114, 157, 135, 114, 161, 137, 113, 158, 136, 109, 152, 129, 100, 137, 113, 85, 132, 108, 80, 139, 118, 88, 126, 108, 83, 145, 127, 108, 139, 119, 98, 113, 93, 73, 156, 135, 113, 170, 149, 126, 136, 113, 87, 133, 112, 81, 134, 115, 81, 148, 125, 97, 131, 108, 87, 122, 100, 80, 125, 103, 80, 163, 138, 114, 185, 164, 145, 129, 123, 114, 12, 13, 7, 4, 5, 0, 15, 9, 7, 10, 5, 3, 13, 8, 5, 32, 25, 21, 140, 116, 95, 134, 113, 92, 171, 153, 131, 162, 138, 115, 150, 123, 99, 157, 131, 106, 149, 122, 97, 153, 130, 106, 145, 128, 108, 140, 123, 103, 133, 117, 97, 147, 130, 112, 157, 135, 119, 132, 109, 91, 144, 122, 100, 157, 135, 111, 149, 126, 100, 156, 132, 105, 149, 126, 99, 153, 129, 102, 143, 121, 94, 130, 105, 81, 123, 97, 76, 166, 144, 122, 175, 160, 132, 174, 164, 139, 119, 114, 103, 22, 20, 16, 17, 13, 9, 22, 18, 11, 28, 24, 16, 28, 24, 16, 123, 99, 78, 132, 111, 90, 159, 141, 119, 144, 121, 97, 133, 107, 82, 149, 123, 98, 153, 127, 102, 156, 134, 111, 152, 135, 116, 147, 130, 111, 141, 124, 105, 155, 137, 118, 165, 142, 126, 150, 127, 109, 142, 119, 98, 152, 130, 107, 164, 140, 116, 163, 140, 115, 158, 134, 110, 158, 135, 111, 150, 129, 103, 140, 117, 93, 134, 109, 87, 169, 150, 129, 182, 167, 142, 185, 169, 144, 188, 174, 162, 84, 74, 70, 20, 15, 10, 33, 29, 20, 42, 38, 29, 30, 26, 17], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387216}, {\"format\": \"raw\", \"value\": [33, 44, 27, 29, 44, 31, 32, 45, 34, 38, 53, 38, 46, 62, 45, 38, 54, 44, 42, 59, 47, 51, 72, 53, 52, 77, 61, 82, 113, 101, 60, 90, 74, 58, 87, 67, 107, 141, 134, 153, 194, 210, 172, 215, 239, 177, 215, 238, 189, 223, 242, 186, 221, 239, 182, 218, 238, 183, 219, 238, 181, 217, 236, 182, 217, 237, 184, 218, 237, 179, 215, 234, 175, 212, 234, 173, 210, 231, 171, 207, 229, 167, 205, 227, 159, 200, 225, 157, 197, 221, 162, 199, 216, 160, 194, 213, 25, 40, 24, 24, 40, 27, 23, 36, 29, 25, 38, 31, 36, 50, 39, 38, 51, 42, 47, 60, 50, 55, 70, 55, 50, 67, 55, 52, 76, 54, 34, 57, 45, 42, 69, 52, 54, 86, 60, 104, 140, 133, 142, 181, 188, 154, 191, 203, 160, 197, 209, 168, 206, 218, 191, 226, 246, 189, 225, 242, 189, 225, 240, 185, 221, 236, 184, 220, 238, 188, 224, 244, 183, 218, 238, 153, 188, 199, 166, 201, 217, 178, 214, 235, 177, 211, 232, 174, 209, 227, 167, 199, 217, 165, 198, 220, 55, 56, 47, 47, 56, 46, 53, 61, 52, 48, 57, 50, 46, 53, 48, 53, 52, 49, 72, 63, 60, 108, 100, 94, 94, 91, 84, 83, 79, 69, 70, 66, 61, 56, 71, 59, 51, 78, 59, 54, 83, 65, 65, 95, 85, 86, 114, 109, 87, 118, 107, 98, 132, 121, 140, 174, 178, 135, 169, 171, 138, 172, 174, 120, 153, 153, 131, 164, 162, 148, 181, 185, 131, 160, 167, 73, 102, 94, 108, 142, 139, 164, 200, 217, 142, 177, 189, 129, 162, 165, 110, 137, 133, 123, 153, 154, 71, 70, 68, 64, 69, 67, 88, 91, 92, 91, 96, 97, 63, 68, 69, 42, 39, 42, 86, 61, 63, 149, 142, 145, 119, 117, 120, 135, 104, 104, 122, 90, 88, 76, 88, 91, 60, 84, 81, 72, 95, 89, 66, 89, 80, 66, 92, 75, 51, 76, 62, 58, 84, 67, 82, 106, 91, 77, 103, 88, 69, 96, 87, 60, 83, 80, 68, 96, 86, 70, 99, 88, 52, 73, 68, 38, 59, 47, 64, 92, 76, 117, 146, 147, 73, 102, 93, 52, 77, 64, 43, 66, 50, 51, 75, 60, 57, 66, 65, 59, 63, 62, 96, 105, 108, 104, 116, 125, 83, 78, 82, 73, 64, 66, 96, 88, 90, 126, 138, 147, 105, 122, 131, 118, 115, 121, 117, 100, 102, 101, 108, 114, 91, 109, 117, 99, 120, 128, 91, 111, 118, 101, 123, 123, 87, 99, 95, 99, 102, 89, 111, 113, 102, 98, 109, 99, 77, 86, 82, 79, 85, 87, 80, 95, 93, 80, 95, 90, 79, 92, 90, 70, 76, 73, 77, 83, 76, 81, 91, 87, 56, 68, 61, 47, 57, 51, 39, 55, 47, 42, 60, 48, 84, 78, 81, 102, 94, 97, 118, 117, 118, 116, 120, 125, 97, 100, 107, 83, 86, 93, 92, 102, 111, 99, 129, 146, 98, 136, 151, 81, 122, 141, 66, 93, 107, 75, 85, 87, 107, 120, 122, 104, 123, 129, 102, 120, 129, 107, 120, 126, 91, 89, 88, 89, 70, 64, 99, 98, 97, 80, 86, 86, 55, 52, 52, 60, 55, 54, 65, 62, 61, 87, 88, 87, 81, 82, 82, 96, 93, 94, 92, 87, 89, 92, 93, 93, 111, 116, 117, 116, 120, 120, 82, 89, 84, 87, 99, 93, 68, 70, 71, 95, 103, 105, 48, 65, 72, 62, 68, 73, 77, 103, 113, 52, 93, 110, 79, 94, 101, 117, 129, 132, 94, 125, 136, 78, 116, 132, 79, 113, 128, 85, 90, 93, 67, 69, 69, 56, 68, 67, 80, 83, 80, 99, 84, 79, 101, 81, 78, 104, 80, 76, 73, 63, 62, 56, 48, 48, 71, 51, 47, 90, 76, 71, 117, 99, 87, 132, 102, 86, 136, 104, 90, 146, 121, 102, 153, 136, 116, 145, 132, 118, 147, 144, 135, 162, 167, 162, 130, 137, 132, 117, 129, 129, 82, 96, 101, 82, 88, 91, 14, 17, 22, 28, 28, 29, 79, 91, 97, 71, 110, 124, 80, 102, 111, 135, 126, 123, 135, 130, 130, 122, 120, 120, 151, 149, 149, 155, 139, 139, 85, 74, 66, 47, 57, 49, 74, 91, 91, 63, 74, 79, 59, 67, 71, 71, 76, 79, 57, 63, 68, 48, 52, 57, 73, 73, 69, 65, 65, 62, 139, 133, 116, 154, 144, 132, 141, 140, 136, 152, 149, 140, 139, 147, 139, 128, 130, 123, 102, 113, 115, 100, 116, 120, 130, 146, 147, 101, 111, 100, 124, 134, 139, 99, 102, 99, 39, 36, 36, 60, 59, 56, 88, 87, 88, 97, 107, 115, 122, 116, 123, 135, 115, 117, 137, 124, 124, 135, 124, 121, 151, 134, 128, 153, 139, 134, 115, 114, 87, 94, 124, 113, 94, 131, 127, 63, 102, 96, 38, 64, 74, 49, 75, 77, 53, 85, 85, 39, 65, 72, 50, 77, 86, 65, 92, 94, 142, 152, 147, 139, 163, 169, 93, 138, 155, 130, 162, 176, 104, 151, 170, 112, 137, 143, 109, 141, 149, 96, 148, 166, 104, 147, 160, 91, 113, 93, 129, 137, 140, 113, 110, 108, 93, 89, 88, 114, 106, 106, 124, 112, 111, 136, 116, 111, 129, 95, 87, 131, 98, 88, 136, 117, 107, 112, 97, 83, 136, 127, 111, 135, 122, 106, 98, 105, 94, 94, 134, 130, 86, 132, 116, 65, 112, 96, 51, 86, 88, 68, 104, 95, 57, 90, 89, 45, 74, 82, 72, 104, 109, 90, 127, 127, 154, 174, 168, 134, 156, 161, 85, 124, 138, 125, 156, 168, 114, 152, 167, 111, 138, 149, 116, 132, 129, 106, 146, 153, 109, 145, 159, 106, 130, 121, 102, 100, 100, 128, 121, 125, 124, 118, 122, 115, 108, 108, 105, 98, 96, 111, 92, 79, 122, 74, 53, 143, 106, 82, 108, 98, 86, 46, 37, 32, 86, 76, 67, 119, 105, 88, 100, 105, 98, 110, 126, 119, 98, 125, 110, 84, 113, 104, 75, 98, 97, 85, 108, 104, 68, 93, 96, 70, 96, 101, 90, 120, 124, 109, 142, 149, 153, 169, 166, 89, 110, 114, 49, 73, 81, 113, 138, 147, 123, 143, 148, 123, 135, 139, 146, 129, 119, 138, 132, 118, 145, 137, 126, 136, 125, 111, 55, 51, 47, 97, 92, 91, 92, 92, 88, 92, 86, 78, 99, 87, 72, 116, 90, 70, 151, 104, 75, 172, 137, 104, 136, 115, 94, 120, 102, 80, 144, 123, 101, 159, 137, 110, 156, 137, 112, 167, 147, 123, 169, 154, 129, 158, 146, 124, 142, 131, 113, 134, 127, 112, 114, 116, 106, 116, 122, 115, 124, 135, 129, 147, 166, 160, 166, 170, 158, 117, 127, 124, 111, 113, 114, 154, 149, 141, 185, 166, 140, 179, 148, 129, 157, 123, 110, 143, 121, 101, 142, 116, 91, 122, 95, 74, 37, 38, 30, 81, 70, 59, 112, 92, 82, 127, 101, 92, 146, 115, 99, 168, 128, 104, 189, 146, 110, 200, 164, 123, 201, 166, 127, 210, 173, 132, 213, 172, 133, 212, 172, 133, 215, 178, 135, 212, 178, 136, 209, 173, 136, 205, 166, 128, 190, 157, 123, 185, 155, 121, 176, 148, 119, 176, 151, 122, 191, 163, 138, 205, 184, 155, 203, 190, 158, 195, 180, 151, 197, 167, 147, 193, 162, 133, 183, 157, 124, 160, 129, 109, 116, 89, 76, 109, 94, 81, 112, 94, 75, 114, 95, 68, 67, 58, 44, 96, 76, 62, 123, 89, 81, 153, 115, 106, 167, 138, 124, 177, 138, 120, 183, 142, 121, 186, 149, 127, 194, 154, 127, 200, 157, 127, 202, 154, 128, 201, 154, 132, 202, 155, 128, 183, 144, 115, 157, 125, 97, 165, 133, 104, 188, 155, 125, 213, 174, 144, 227, 186, 153, 236, 200, 154, 233, 203, 156, 223, 194, 149, 201, 179, 138, 184, 166, 132, 164, 143, 113, 156, 143, 119, 144, 138, 125, 113, 86, 71, 107, 82, 69, 94, 83, 71, 69, 58, 47, 88, 85, 63, 61, 64, 55, 45, 42, 37, 39, 28, 25, 87, 66, 56, 117, 93, 82, 134, 99, 92, 145, 111, 106, 160, 121, 114, 172, 128, 117, 185, 137, 120, 192, 147, 125, 155, 119, 102, 106, 79, 68, 109, 89, 73, 165, 146, 116, 213, 185, 143, 232, 188, 150, 232, 184, 152, 226, 182, 144, 213, 183, 136, 191, 175, 131, 166, 150, 120, 148, 131, 109, 144, 144, 126, 147, 151, 136, 168, 178, 168, 159, 160, 152, 98, 64, 48, 88, 69, 55, 48, 45, 38, 31, 28, 22, 68, 73, 44, 39, 47, 41, 24, 26, 26, 8, 9, 9, 16, 13, 12, 22, 15, 14, 27, 20, 20, 40, 31, 29, 62, 46, 42, 87, 66, 62, 130, 95, 81, 118, 88, 71, 86, 78, 68, 160, 150, 121, 218, 202, 153, 238, 216, 166, 223, 195, 148, 207, 172, 124, 194, 163, 116, 168, 148, 113, 148, 138, 115, 153, 141, 122, 148, 120, 98, 148, 130, 110, 160, 175, 167, 160, 180, 179, 162, 186, 187, 117, 115, 109, 83, 54, 39, 61, 55, 45, 35, 36, 29, 36, 42, 31, 71, 86, 45, 44, 46, 40, 34, 38, 36, 10, 9, 8, 13, 12, 12, 14, 15, 13, 12, 11, 13, 11, 9, 8, 6, 6, 5, 21, 20, 19, 35, 32, 33, 29, 24, 24, 96, 95, 83, 199, 190, 157, 221, 196, 149, 178, 155, 109, 145, 130, 98, 130, 117, 93, 127, 114, 94, 138, 127, 108, 138, 132, 114, 145, 139, 116, 147, 121, 93, 141, 128, 110, 162, 183, 182, 140, 158, 157, 90, 104, 101, 67, 69, 57, 52, 48, 36, 40, 48, 32, 67, 83, 49, 74, 88, 51, 80, 101, 52, 69, 85, 55, 42, 51, 40, 10, 10, 11, 15, 12, 12, 17, 16, 12, 14, 13, 12, 11, 10, 9, 7, 7, 8, 11, 10, 9, 25, 24, 22, 34, 29, 26, 81, 85, 78, 124, 126, 106, 137, 123, 94, 113, 106, 88, 104, 91, 78, 131, 109, 90, 141, 125, 107, 98, 94, 78, 79, 73, 56, 98, 94, 74, 130, 116, 92, 117, 114, 98, 96, 109, 103, 74, 84, 71, 55, 60, 42, 42, 43, 30, 39, 44, 31, 64, 79, 44, 88, 115, 58, 83, 105, 53, 69, 86, 45, 90, 113, 60, 74, 90, 51, 23, 25, 20, 12, 9, 11, 14, 12, 11, 11, 11, 11, 9, 9, 9, 8, 7, 8, 8, 8, 7, 19, 15, 13, 21, 16, 13, 54, 61, 63, 98, 106, 100, 116, 109, 91, 121, 112, 95, 123, 108, 91, 147, 133, 112, 113, 106, 91, 37, 35, 33, 15, 14, 12, 35, 30, 24, 93, 94, 77, 84, 91, 79, 65, 69, 52, 50, 55, 32, 41, 45, 27, 49, 53, 36, 74, 90, 50, 89, 117, 56, 88, 114, 54, 67, 86, 45, 35, 50, 25, 88, 112, 58, 85, 108, 57, 42, 53, 32, 10, 11, 11, 13, 12, 13, 11, 11, 12, 9, 9, 9, 10, 8, 9, 9, 9, 8, 16, 13, 12, 19, 14, 12, 50, 54, 48, 98, 105, 91, 120, 119, 103, 128, 123, 106, 141, 132, 107, 136, 126, 105, 75, 75, 72, 46, 49, 51, 17, 19, 18, 26, 24, 18, 61, 63, 44, 49, 54, 35, 43, 49, 32, 51, 59, 39, 66, 76, 45, 88, 105, 57, 90, 114, 53, 92, 116, 55, 90, 112, 55, 63, 79, 42, 34, 49, 25, 68, 87, 48, 56, 75, 42, 37, 47, 30, 10, 12, 12, 9, 10, 12, 11, 10, 12, 9, 8, 8, 10, 9, 9, 12, 12, 11, 15, 14, 13, 18, 13, 12, 55, 61, 57, 101, 111, 100, 118, 114, 90, 146, 135, 102, 157, 141, 99, 112, 104, 81, 66, 73, 75, 42, 45, 43, 22, 24, 24, 30, 30, 22, 42, 44, 29, 32, 37, 22, 55, 66, 40, 85, 105, 60, 98, 119, 63, 99, 124, 67, 103, 124, 78, 98, 114, 67, 94, 110, 60, 82, 99, 51, 64, 79, 39, 46, 54, 39, 29, 34, 27, 18, 20, 18, 9, 12, 12, 8, 11, 11, 10, 11, 12, 10, 11, 12, 10, 12, 12, 13, 13, 14, 12, 12, 13, 16, 15, 13, 35, 33, 32, 57, 58, 53, 93, 84, 57, 137, 122, 82, 139, 123, 84, 78, 78, 66, 52, 59, 62, 36, 38, 33, 27, 32, 32, 29, 29, 25, 48, 53, 40, 68, 82, 53, 95, 112, 63, 103, 123, 67, 96, 119, 62, 108, 130, 89, 135, 151, 135, 122, 137, 115, 98, 116, 77, 102, 122, 86, 62, 76, 53, 38, 42, 35, 28, 33, 26, 20, 26, 22, 17, 23, 20, 13, 18, 15, 11, 13, 12, 10, 14, 15, 12, 16, 17, 12, 15, 17, 10, 12, 15, 13, 12, 12, 21, 15, 14, 24, 20, 18, 64, 56, 31, 96, 87, 47, 85, 78, 46, 43, 47, 44, 63, 65, 61, 67, 65, 58, 47, 52, 46, 62, 64, 50, 88, 99, 67, 101, 122, 74, 105, 123, 71, 102, 118, 68, 97, 117, 65, 97, 116, 73, 110, 127, 101, 112, 132, 106, 93, 109, 74, 72, 86, 69, 38, 50, 42, 33, 40, 29, 27, 36, 23, 18, 30, 19, 18, 26, 18, 17, 22, 16, 17, 19, 15, 15, 17, 16, 10, 13, 12, 11, 12, 14, 12, 13, 16, 11, 11, 11, 13, 13, 14, 17, 18, 18, 49, 44, 23, 64, 59, 28, 48, 47, 28, 36, 46, 35, 76, 79, 68, 108, 105, 90, 91, 101, 76, 103, 112, 80, 101, 112, 77, 103, 116, 74, 110, 125, 76, 110, 126, 77, 100, 116, 68, 97, 116, 65, 89, 109, 59, 90, 111, 63, 92, 102, 68, 41, 48, 32, 21, 32, 19, 54, 62, 49, 43, 50, 39, 29, 41, 29, 25, 35, 23, 20, 26, 18, 18, 24, 17, 15, 20, 14, 14, 19, 14, 13, 17, 15, 14, 13, 14, 13, 17, 13, 13, 17, 14, 12, 16, 18, 23, 23, 18, 23, 21, 15, 19, 22, 17, 44, 62, 36, 83, 91, 72, 124, 131, 101, 116, 131, 94, 111, 124, 81, 103, 121, 77, 107, 128, 83, 103, 124, 74, 105, 122, 72, 103, 118, 67, 100, 117, 63, 93, 114, 56, 95, 117, 59, 76, 93, 53, 30, 45, 26, 20, 33, 17, 99, 88, 81, 95, 88, 84, 91, 86, 80, 78, 79, 71, 64, 72, 66, 53, 57, 54, 40, 43, 38, 25, 32, 24, 21, 29, 21, 17, 22, 18, 19, 26, 20, 21, 28, 21, 16, 20, 20, 22, 21, 22, 43, 42, 38, 29, 34, 28, 52, 72, 41, 90, 109, 70, 108, 123, 80, 120, 126, 88, 116, 126, 80, 106, 126, 75, 109, 129, 79, 104, 129, 74, 98, 128, 68, 98, 124, 62, 101, 116, 62, 100, 109, 60, 93, 108, 55, 55, 75, 38, 23, 38, 20, 23, 31, 21, 53, 44, 33, 64, 55, 45, 92, 72, 62, 74, 55, 51, 59, 53, 54, 81, 70, 66, 130, 127, 120, 66, 80, 73, 24, 33, 22, 27, 34, 28, 26, 32, 28, 28, 34, 30, 27, 34, 27, 52, 60, 45, 92, 99, 76, 72, 84, 62, 83, 99, 60, 110, 123, 79, 112, 121, 84, 118, 127, 92, 119, 127, 89, 112, 120, 81, 116, 125, 79, 109, 126, 70, 103, 124, 66, 98, 120, 62, 98, 120, 63, 104, 119, 67, 96, 112, 65, 54, 70, 38, 27, 41, 22, 23, 32, 21, 48, 60, 36, 75, 86, 66, 115, 113, 96, 56, 52, 39, 27, 21, 17, 34, 25, 22, 174, 173, 171, 146, 160, 154, 30, 45, 30, 38, 49, 37, 49, 56, 46, 51, 59, 45, 70, 79, 59, 94, 102, 77, 111, 116, 85, 103, 114, 80, 106, 118, 81, 114, 125, 82, 117, 126, 85, 116, 128, 84, 115, 125, 80, 116, 121, 78, 112, 120, 74, 101, 119, 62, 105, 121, 68, 108, 118, 73, 97, 115, 66, 99, 118, 68, 101, 118, 71, 70, 85, 49, 30, 42, 24, 24, 33, 20, 83, 96, 56, 106, 107, 80, 104, 115, 85, 86, 96, 64, 71, 73, 54, 58, 57, 47, 150, 151, 151, 185, 194, 185, 66, 80, 56, 70, 80, 57, 96, 101, 78, 97, 107, 78, 107, 118, 87, 109, 117, 87, 112, 118, 83, 114, 124, 87, 110, 126, 85, 106, 125, 78, 116, 131, 83, 119, 135, 86, 127, 139, 96, 133, 142, 104, 139, 148, 112, 125, 140, 98, 112, 126, 76, 115, 120, 79, 106, 115, 71, 97, 112, 63, 101, 114, 71, 68, 81, 50, 34, 43, 27, 27, 36, 23, 106, 97, 60, 103, 91, 58, 85, 100, 53, 92, 105, 61, 91, 106, 69, 65, 74, 51, 80, 85, 74, 143, 152, 131, 97, 107, 73, 86, 96, 62, 106, 110, 78, 114, 120, 88, 115, 124, 90, 125, 135, 104, 136, 147, 117, 147, 159, 132, 151, 164, 136, 140, 156, 125, 137, 150, 121, 128, 143, 110, 133, 150, 114, 139, 152, 119, 141, 147, 122, 121, 135, 102, 110, 124, 76, 107, 119, 74, 103, 115, 70, 96, 112, 60, 97, 112, 60, 78, 91, 52, 54, 64, 36, 44, 56, 31, 97, 91, 59, 92, 97, 57, 88, 108, 61, 95, 113, 65, 95, 112, 70, 87, 103, 72, 97, 109, 83, 122, 134, 104, 121, 132, 98, 107, 118, 87, 132, 139, 110, 157, 161, 142, 157, 164, 143, 156, 163, 144, 146, 158, 133, 143, 155, 128, 139, 148, 122, 122, 133, 100, 116, 133, 93, 108, 128, 87, 104, 129, 79, 107, 128, 76, 111, 123, 77, 101, 117, 67, 106, 120, 74, 109, 120, 76, 99, 115, 62, 91, 110, 55, 97, 113, 60, 96, 107, 59, 81, 94, 47, 71, 88, 41, 106, 119, 91, 128, 141, 115, 142, 158, 137, 142, 157, 138, 125, 139, 125, 150, 161, 146, 143, 151, 133, 141, 149, 131, 149, 159, 144, 143, 153, 138, 147, 153, 140, 134, 138, 124, 106, 118, 89, 111, 124, 90, 106, 124, 81, 103, 122, 71, 106, 118, 71, 100, 115, 66, 91, 114, 60, 95, 116, 64, 94, 114, 68, 98, 115, 70, 107, 120, 72, 107, 119, 73, 111, 120, 81, 108, 117, 78, 90, 108, 56, 90, 106, 53, 102, 114, 66, 100, 108, 63, 81, 94, 47, 71, 90, 40], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387344}, {\"format\": \"raw\", \"value\": [97, 51, 31, 104, 58, 38, 107, 61, 40, 107, 62, 41, 111, 65, 44, 116, 69, 46, 119, 72, 48, 118, 71, 47, 121, 74, 50, 127, 79, 55, 129, 83, 60, 125, 87, 69, 116, 79, 60, 118, 78, 58, 133, 91, 69, 139, 94, 71, 144, 98, 75, 146, 103, 83, 133, 94, 73, 112, 75, 55, 131, 92, 74, 148, 103, 87, 156, 108, 92, 156, 110, 89, 151, 105, 83, 150, 104, 81, 152, 106, 83, 152, 107, 84, 144, 98, 75, 141, 95, 71, 141, 95, 71, 139, 93, 69, 87, 42, 24, 92, 46, 29, 98, 53, 35, 101, 55, 38, 106, 60, 42, 107, 60, 40, 111, 63, 43, 113, 66, 45, 112, 65, 44, 119, 71, 50, 110, 66, 47, 92, 61, 47, 99, 72, 58, 98, 68, 55, 106, 74, 62, 119, 84, 72, 119, 83, 73, 109, 77, 67, 90, 61, 49, 94, 66, 52, 108, 75, 61, 124, 83, 71, 141, 96, 82, 142, 96, 78, 135, 89, 71, 132, 86, 68, 125, 80, 61, 120, 75, 56, 123, 78, 58, 126, 79, 59, 125, 79, 58, 122, 75, 54, 119, 75, 51, 120, 76, 52, 125, 80, 56, 126, 82, 58, 128, 84, 61, 128, 87, 65, 130, 90, 69, 135, 94, 73, 133, 93, 72, 131, 90, 69, 111, 73, 53, 107, 83, 68, 133, 113, 103, 98, 81, 76, 57, 42, 45, 80, 66, 75, 95, 83, 95, 87, 81, 91, 74, 68, 72, 83, 70, 68, 98, 74, 66, 132, 94, 83, 147, 101, 87, 143, 97, 82, 143, 97, 81, 136, 90, 74, 127, 81, 65, 122, 77, 61, 135, 88, 71, 137, 91, 72, 133, 86, 67, 123, 77, 58, 136, 91, 67, 139, 94, 69, 143, 98, 73, 145, 99, 75, 147, 103, 78, 145, 106, 82, 146, 108, 84, 140, 103, 81, 114, 80, 60, 91, 59, 43, 79, 49, 35, 84, 58, 42, 84, 66, 53, 39, 30, 26, 36, 34, 43, 91, 94, 114, 129, 134, 159, 132, 139, 163, 119, 124, 142, 69, 67, 76, 70, 52, 51, 150, 113, 103, 174, 127, 111, 170, 123, 104, 168, 121, 102, 166, 119, 99, 164, 117, 97, 160, 113, 94, 158, 110, 90, 158, 109, 87, 154, 105, 83, 147, 98, 76, 135, 89, 67, 134, 88, 66, 137, 91, 68, 140, 94, 71, 141, 94, 72, 144, 97, 74, 145, 101, 80, 108, 72, 53, 51, 22, 9, 37, 15, 5, 41, 22, 11, 45, 24, 12, 32, 17, 8, 16, 13, 12, 37, 42, 53, 109, 117, 140, 143, 151, 180, 126, 134, 162, 140, 149, 173, 87, 91, 107, 57, 47, 53, 120, 91, 87, 166, 125, 113, 167, 120, 102, 166, 119, 100, 164, 117, 98, 161, 114, 95, 160, 113, 95, 161, 113, 93, 161, 112, 89, 159, 110, 86, 157, 108, 84, 132, 86, 67, 132, 86, 66, 136, 89, 70, 136, 89, 70, 140, 92, 73, 146, 96, 76, 140, 97, 80, 81, 51, 39, 27, 7, 0, 25, 12, 3, 36, 25, 15, 37, 25, 21, 26, 19, 20, 32, 33, 40, 63, 68, 83, 110, 116, 140, 120, 125, 153, 99, 105, 132, 115, 124, 148, 100, 107, 127, 80, 77, 89, 102, 85, 90, 146, 114, 111, 161, 118, 105, 163, 118, 103, 163, 118, 103, 162, 117, 102, 164, 119, 105, 166, 120, 104, 167, 120, 101, 164, 117, 98, 159, 112, 93, 118, 71, 55, 122, 76, 59, 126, 79, 63, 127, 80, 64, 129, 82, 65, 131, 87, 67, 112, 78, 63, 49, 29, 23, 17, 4, 2, 27, 14, 9, 37, 22, 15, 30, 19, 20, 41, 36, 41, 48, 48, 56, 80, 81, 94, 118, 115, 134, 115, 109, 132, 98, 95, 116, 109, 112, 131, 113, 119, 136, 94, 94, 107, 96, 84, 93, 124, 96, 98, 159, 118, 109, 160, 116, 106, 160, 117, 107, 163, 119, 109, 168, 125, 115, 170, 126, 115, 170, 125, 111, 168, 123, 109, 165, 120, 106, 109, 62, 45, 113, 66, 49, 119, 71, 54, 122, 74, 57, 123, 75, 58, 122, 79, 60, 93, 61, 47, 25, 8, 5, 15, 4, 3, 32, 16, 12, 35, 15, 11, 27, 15, 17, 50, 40, 44, 87, 77, 81, 92, 81, 89, 127, 115, 130, 127, 116, 135, 108, 103, 120, 120, 115, 133, 119, 113, 127, 117, 107, 113, 98, 80, 85, 106, 78, 80, 149, 108, 101, 152, 108, 100, 150, 106, 97, 150, 105, 96, 151, 105, 95, 150, 104, 92, 149, 102, 88, 147, 100, 86, 144, 97, 83, 123, 77, 59, 128, 82, 64, 130, 85, 66, 133, 87, 69, 137, 90, 72, 139, 92, 75, 106, 69, 56, 31, 10, 4, 24, 10, 5, 32, 15, 10, 31, 13, 10, 28, 16, 17, 60, 44, 44, 99, 76, 73, 101, 78, 80, 131, 114, 125, 137, 127, 142, 129, 123, 137, 141, 128, 145, 131, 109, 118, 130, 104, 97, 116, 87, 80, 118, 84, 83, 158, 116, 108, 160, 116, 105, 157, 112, 101, 159, 111, 99, 157, 108, 94, 156, 107, 91, 154, 104, 87, 150, 100, 83, 144, 94, 77, 123, 84, 63, 129, 90, 69, 132, 93, 72, 135, 95, 75, 139, 98, 78, 145, 102, 83, 124, 88, 74, 51, 26, 18, 33, 14, 9, 31, 15, 10, 31, 14, 11, 32, 17, 15, 74, 52, 47, 106, 77, 69, 117, 87, 84, 134, 111, 117, 142, 126, 136, 144, 129, 135, 154, 131, 140, 149, 116, 117, 148, 110, 95, 141, 101, 85, 143, 102, 95, 161, 121, 112, 165, 124, 113, 163, 120, 108, 165, 120, 106, 163, 117, 102, 165, 117, 101, 163, 116, 98, 160, 112, 95, 156, 108, 91, 132, 90, 70, 136, 94, 75, 138, 96, 76, 138, 96, 76, 142, 99, 80, 143, 103, 84, 133, 97, 83, 69, 40, 32, 38, 15, 11, 31, 15, 10, 22, 8, 3, 34, 14, 9, 83, 54, 43, 123, 87, 74, 135, 99, 90, 137, 106, 107, 139, 116, 121, 140, 120, 122, 152, 123, 129, 159, 121, 117, 159, 116, 96, 151, 106, 86, 169, 125, 114, 173, 134, 124, 168, 129, 117, 166, 125, 113, 166, 124, 109, 165, 121, 106, 160, 116, 99, 155, 110, 92, 150, 105, 87, 149, 105, 86, 145, 97, 78, 146, 98, 79, 147, 99, 81, 152, 104, 86, 155, 108, 90, 155, 114, 94, 139, 103, 87, 68, 36, 29, 37, 13, 9, 32, 16, 11, 18, 4, 0, 52, 27, 18, 103, 68, 53, 130, 88, 71, 160, 119, 107, 160, 126, 123, 153, 126, 129, 153, 129, 132, 168, 139, 145, 179, 141, 136, 168, 123, 103, 160, 113, 94, 181, 137, 128, 190, 152, 142, 179, 142, 130, 174, 136, 123, 172, 131, 116, 170, 128, 113, 166, 123, 106, 162, 118, 99, 154, 110, 91, 148, 103, 84, 142, 93, 70, 143, 95, 74, 147, 100, 80, 149, 104, 84, 154, 109, 90, 158, 114, 92, 123, 86, 68, 55, 27, 16, 37, 18, 10, 30, 15, 9, 30, 13, 7, 83, 49, 37, 128, 85, 67, 145, 98, 79, 173, 129, 116, 180, 145, 142, 174, 145, 148, 175, 144, 148, 182, 151, 152, 191, 151, 140, 183, 131, 107, 172, 120, 99, 179, 137, 126, 199, 161, 152, 196, 158, 149, 193, 153, 143, 191, 150, 137, 187, 143, 130, 182, 138, 123, 179, 133, 115, 175, 128, 108, 174, 125, 105, 143, 96, 72, 147, 100, 77, 149, 104, 82, 150, 107, 86, 152, 110, 90, 140, 100, 81, 94, 60, 45, 44, 19, 10, 36, 18, 11, 25, 11, 6, 52, 34, 26, 116, 80, 65, 144, 98, 79, 158, 109, 89, 184, 138, 123, 187, 151, 146, 179, 148, 150, 182, 148, 147, 189, 157, 152, 197, 156, 139, 191, 137, 108, 183, 129, 103, 181, 138, 122, 191, 153, 144, 195, 157, 148, 191, 150, 140, 190, 148, 135, 188, 145, 132, 185, 141, 126, 182, 137, 118, 179, 133, 113, 176, 128, 108, 152, 107, 82, 151, 108, 84, 156, 114, 91, 160, 119, 98, 151, 112, 92, 119, 84, 69, 88, 59, 49, 44, 22, 15, 32, 16, 11, 24, 9, 4, 59, 38, 29, 126, 87, 71, 156, 107, 87, 174, 121, 100, 193, 144, 128, 198, 159, 152, 187, 154, 153, 189, 152, 152, 200, 165, 162, 203, 159, 143, 201, 145, 116, 191, 134, 108, 187, 142, 127, 196, 158, 148, 198, 160, 151, 193, 153, 142, 192, 151, 138, 192, 148, 135, 188, 145, 130, 187, 145, 125, 184, 141, 120, 182, 137, 115, 137, 94, 69, 138, 97, 72, 140, 100, 77, 140, 101, 79, 119, 84, 63, 108, 77, 64, 91, 65, 58, 39, 20, 15, 25, 10, 7, 21, 7, 3, 72, 51, 41, 142, 101, 83, 164, 114, 92, 186, 133, 110, 198, 148, 131, 205, 165, 157, 195, 160, 160, 195, 156, 161, 206, 167, 169, 217, 170, 160, 210, 150, 129, 192, 133, 114, 188, 141, 131, 190, 151, 141, 190, 151, 142, 183, 142, 132, 184, 141, 129, 182, 138, 126, 180, 137, 122, 180, 139, 120, 174, 132, 112, 171, 128, 106, 114, 69, 50, 117, 73, 50, 119, 77, 55, 111, 75, 55, 95, 63, 46, 111, 80, 71, 70, 46, 41, 26, 12, 9, 15, 5, 3, 46, 32, 27, 102, 77, 66, 147, 106, 92, 156, 106, 91, 184, 133, 118, 212, 163, 152, 213, 170, 166, 202, 164, 163, 200, 163, 161, 209, 167, 166, 224, 176, 172, 198, 147, 138, 181, 131, 120, 189, 146, 133, 176, 137, 122, 168, 126, 115, 164, 118, 110, 162, 115, 108, 160, 115, 107, 156, 112, 101, 153, 108, 94, 153, 107, 92, 149, 103, 87, 118, 74, 54, 120, 76, 53, 122, 81, 60, 101, 67, 48, 98, 70, 55, 86, 62, 57, 37, 18, 16, 21, 10, 6, 19, 7, 4, 75, 56, 47, 121, 94, 83, 123, 94, 91, 130, 96, 93, 165, 124, 117, 205, 161, 154, 215, 171, 166, 205, 163, 159, 204, 164, 157, 214, 172, 165, 209, 167, 164, 168, 130, 129, 140, 110, 112, 149, 121, 119, 164, 129, 119, 163, 121, 111, 161, 115, 104, 160, 112, 102, 154, 109, 99, 148, 103, 91, 145, 98, 85, 144, 96, 82, 141, 94, 77, 132, 91, 67, 136, 95, 70, 133, 95, 73, 99, 67, 50, 82, 56, 45, 43, 25, 22, 24, 9, 6, 27, 13, 6, 40, 23, 17, 104, 81, 73, 99, 74, 70, 67, 51, 58, 94, 75, 79, 123, 92, 89, 173, 133, 126, 218, 172, 164, 216, 170, 161, 213, 170, 160, 217, 176, 166, 174, 138, 131, 129, 103, 103, 95, 80, 91, 80, 65, 78, 124, 97, 97, 161, 126, 118, 172, 130, 115, 175, 130, 112, 169, 125, 108, 161, 116, 101, 161, 114, 98, 163, 116, 98, 157, 110, 91, 130, 93, 65, 142, 104, 77, 128, 92, 70, 81, 51, 36, 54, 29, 20, 35, 15, 7, 37, 18, 7, 35, 16, 4, 62, 44, 35, 76, 58, 56, 77, 60, 66, 55, 41, 48, 72, 52, 54, 133, 102, 97, 180, 140, 130, 228, 183, 171, 229, 183, 173, 225, 181, 171, 223, 182, 169, 175, 140, 126, 135, 109, 103, 89, 74, 83, 74, 61, 76, 98, 75, 82, 117, 86, 80, 161, 123, 104, 176, 132, 109, 178, 134, 112, 172, 127, 109, 170, 123, 105, 169, 123, 103, 165, 119, 97, 126, 90, 64, 131, 94, 69, 120, 88, 66, 67, 43, 28, 37, 18, 8, 41, 19, 10, 34, 14, 4, 31, 16, 7, 48, 35, 31, 54, 39, 43, 89, 74, 86, 83, 71, 84, 96, 72, 73, 173, 130, 118, 210, 160, 142, 236, 192, 178, 227, 191, 185, 228, 192, 187, 237, 195, 180, 207, 163, 141, 172, 135, 121, 103, 81, 85, 93, 79, 94, 106, 84, 96, 85, 56, 57, 115, 81, 69, 154, 115, 96, 165, 124, 106, 162, 118, 102, 159, 113, 94, 158, 112, 92, 157, 111, 89, 127, 84, 63, 128, 87, 67, 117, 84, 66, 61, 37, 26, 29, 13, 5, 29, 13, 8, 20, 6, 2, 30, 17, 12, 71, 53, 49, 98, 72, 70, 123, 94, 97, 90, 74, 84, 102, 75, 75, 197, 151, 136, 229, 179, 160, 239, 199, 187, 212, 183, 182, 214, 187, 188, 240, 205, 195, 229, 186, 166, 207, 167, 151, 140, 113, 110, 96, 75, 83, 134, 107, 114, 141, 110, 109, 127, 93, 83, 143, 103, 87, 155, 111, 95, 155, 109, 92, 156, 108, 91, 155, 108, 88, 152, 105, 84, 135, 88, 68, 136, 94, 74, 122, 88, 73, 56, 32, 26, 21, 7, 5, 14, 8, 8, 10, 2, 2, 64, 47, 43, 129, 102, 93, 156, 118, 106, 160, 121, 109, 109, 83, 77, 143, 115, 108, 214, 176, 164, 239, 200, 189, 235, 202, 196, 199, 172, 173, 195, 175, 178, 228, 205, 201, 239, 210, 199, 235, 204, 191, 203, 173, 165, 152, 121, 117, 174, 141, 136, 184, 152, 143, 157, 123, 110, 139, 99, 82, 153, 104, 85, 156, 104, 85, 155, 105, 88, 157, 108, 89, 156, 107, 87, 135, 91, 69, 122, 83, 63, 77, 49, 36, 28, 13, 9, 9, 4, 6, 4, 8, 11, 11, 8, 11, 63, 45, 45, 119, 90, 86, 146, 111, 101, 167, 130, 116, 176, 143, 125, 205, 175, 159, 237, 208, 198, 236, 208, 204, 206, 179, 180, 187, 162, 164, 185, 163, 163, 200, 182, 178, 221, 205, 199, 242, 223, 216, 236, 211, 204, 216, 186, 177, 195, 164, 153, 164, 137, 126, 128, 101, 90, 122, 88, 74, 154, 107, 90, 156, 102, 85, 157, 105, 88, 158, 106, 88, 156, 104, 85, 118, 80, 60, 67, 42, 29, 20, 5, 0, 8, 4, 1, 13, 19, 18, 20, 24, 27, 19, 16, 18, 48, 33, 34, 102, 78, 75, 142, 113, 106, 155, 124, 112, 193, 157, 138, 223, 191, 176, 236, 211, 204, 218, 195, 194, 190, 162, 166, 171, 139, 140, 171, 142, 136, 187, 167, 162, 200, 187, 186, 228, 214, 211, 238, 216, 208, 225, 195, 184, 192, 162, 150, 159, 135, 125, 102, 86, 79, 72, 52, 47, 115, 80, 68, 154, 105, 87, 153, 102, 84, 151, 100, 80, 148, 98, 77, 67, 36, 27, 19, 9, 7, 7, 3, 0, 15, 13, 11, 46, 51, 53, 65, 67, 71, 32, 29, 32, 41, 31, 31, 90, 73, 69, 132, 109, 102, 160, 130, 121, 175, 136, 125, 184, 151, 141, 179, 154, 149, 184, 158, 156, 188, 153, 153, 169, 127, 124, 156, 117, 109, 175, 145, 140, 188, 165, 165, 193, 170, 168, 199, 169, 160, 196, 162, 150, 181, 150, 141, 145, 120, 113, 87, 76, 77, 71, 66, 72, 87, 64, 60, 125, 82, 65, 130, 81, 60, 125, 77, 55, 123, 75, 53, 33, 13, 8, 4, 0, 2, 26, 20, 20, 79, 70, 74, 77, 73, 85, 77, 81, 92, 61, 64, 72, 35, 31, 36, 68, 57, 59, 100, 83, 81, 145, 121, 117, 155, 121, 113, 145, 112, 103, 138, 108, 99, 139, 107, 98, 151, 113, 104, 150, 106, 96, 144, 96, 85, 150, 107, 99, 155, 120, 115, 158, 125, 120, 169, 133, 124, 180, 145, 137, 170, 139, 136, 113, 89, 88, 83, 74, 82, 110, 106, 118, 115, 93, 96, 117, 74, 62, 127, 79, 57, 119, 71, 49, 117, 69, 47, 36, 19, 14, 3, 1, 3, 31, 27, 27, 93, 86, 90, 77, 75, 87, 47, 52, 64, 49, 52, 62, 23, 21, 28, 58, 48, 51, 84, 68, 68, 109, 87, 86, 136, 105, 102, 138, 104, 96, 137, 103, 87, 137, 99, 80, 129, 88, 69, 124, 78, 61, 130, 80, 63, 133, 85, 70, 143, 101, 88, 154, 117, 106, 159, 126, 116, 158, 127, 121, 139, 112, 109, 90, 69, 68, 64, 57, 65, 82, 81, 93, 104, 84, 87, 133, 92, 79, 144, 96, 75, 141, 93, 72, 138, 91, 69, 45, 24, 14, 10, 6, 3, 9, 6, 3, 30, 27, 26, 41, 44, 49, 35, 38, 45, 41, 39, 43, 69, 60, 59, 78, 61, 57, 92, 71, 66, 102, 78, 73, 105, 75, 72, 116, 83, 74, 129, 92, 73, 134, 93, 68, 131, 87, 62, 127, 81, 57, 129, 81, 59, 136, 88, 68, 144, 100, 80, 141, 103, 86, 135, 104, 91, 126, 99, 90, 118, 93, 87, 95, 75, 71, 53, 46, 50, 54, 51, 59, 85, 67, 67, 121, 83, 69, 131, 85, 62, 131, 84, 61, 128, 81, 58, 82, 53, 33, 22, 11, 4, 35, 25, 25, 54, 43, 46, 25, 22, 22, 16, 14, 16, 51, 40, 37, 116, 92, 78, 100, 71, 53, 72, 46, 31, 83, 60, 48, 99, 69, 57, 104, 70, 55, 112, 75, 56, 118, 76, 54, 123, 78, 53, 127, 80, 55, 127, 80, 58, 131, 83, 60, 130, 83, 60, 128, 84, 64, 123, 85, 71, 111, 80, 67, 105, 78, 63, 104, 81, 71, 72, 53, 47, 74, 51, 47, 101, 70, 62, 115, 77, 61, 122, 78, 54, 123, 78, 53, 120, 76, 50, 79, 51, 33, 21, 10, 4, 62, 49, 51, 102, 88, 90, 84, 79, 76, 56, 51, 50, 44, 30, 26, 77, 53, 42, 86, 57, 42, 71, 42, 26, 66, 39, 25, 79, 47, 33, 90, 55, 40, 96, 60, 42, 106, 66, 47, 116, 74, 52, 129, 85, 64, 128, 84, 65, 119, 74, 53, 111, 66, 46, 103, 62, 45, 97, 62, 51, 93, 64, 53, 111, 84, 69, 114, 87, 71, 115, 84, 66, 128, 91, 69, 136, 92, 66, 136, 90, 63, 134, 89, 65, 131, 87, 63, 129, 85, 61, 61, 36, 20, 15, 6, 1, 53, 40, 40, 105, 89, 89, 98, 88, 83, 102, 89, 87, 75, 58, 55, 64, 41, 34, 97, 68, 57, 121, 89, 75, 130, 97, 81, 113, 78, 63, 99, 63, 47, 93, 57, 41, 90, 54, 37, 93, 56, 39, 107, 70, 52, 110, 71, 55, 107, 67, 50, 113, 74, 56, 120, 84, 70, 112, 82, 74, 128, 101, 99, 140, 111, 111, 131, 96, 92, 133, 91, 80, 133, 86, 71, 133, 84, 65, 134, 85, 65, 133, 87, 66, 131, 86, 65, 128, 84, 63], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387408}, {\"format\": \"raw\", \"value\": [93, 96, 88, 102, 106, 97, 117, 121, 111, 118, 122, 110, 114, 121, 108, 113, 122, 109, 117, 125, 110, 133, 138, 121, 131, 133, 114, 134, 135, 114, 140, 142, 123, 132, 134, 123, 126, 129, 113, 128, 131, 107, 130, 130, 115, 162, 155, 144, 156, 147, 131, 139, 134, 117, 146, 143, 125, 142, 140, 121, 135, 134, 114, 136, 135, 118, 139, 138, 122, 143, 142, 126, 148, 147, 131, 146, 144, 128, 148, 144, 124, 152, 145, 123, 147, 140, 119, 147, 140, 120, 150, 143, 123, 144, 138, 117, 127, 123, 102, 139, 134, 112, 145, 140, 117, 152, 148, 123, 155, 154, 125, 142, 142, 110, 141, 140, 108, 159, 157, 124, 160, 156, 124, 157, 152, 119, 162, 153, 121, 175, 164, 138, 178, 167, 137, 178, 168, 132, 172, 161, 136, 130, 114, 97, 149, 129, 108, 186, 168, 143, 185, 169, 140, 180, 165, 134, 177, 165, 132, 176, 167, 135, 168, 160, 129, 174, 165, 134, 174, 165, 134, 165, 156, 125, 166, 152, 120, 186, 168, 136, 188, 170, 138, 181, 163, 131, 183, 164, 132, 184, 168, 134, 149, 138, 105, 160, 149, 115, 162, 152, 115, 176, 165, 127, 183, 173, 134, 168, 159, 118, 158, 148, 108, 166, 156, 117, 173, 162, 125, 173, 162, 125, 174, 161, 122, 187, 172, 137, 186, 170, 133, 183, 170, 129, 179, 167, 140, 120, 105, 87, 154, 134, 111, 197, 176, 147, 189, 168, 134, 179, 161, 124, 179, 164, 127, 180, 165, 128, 171, 156, 119, 179, 164, 127, 183, 167, 131, 180, 164, 128, 178, 160, 124, 188, 167, 131, 189, 169, 131, 181, 160, 121, 178, 158, 117, 176, 158, 117, 166, 152, 112, 169, 155, 114, 174, 161, 117, 179, 166, 121, 184, 170, 127, 189, 174, 134, 186, 171, 132, 173, 159, 121, 163, 149, 111, 167, 155, 115, 169, 160, 118, 171, 159, 122, 166, 151, 111, 168, 158, 116, 166, 160, 138, 133, 127, 111, 159, 148, 123, 191, 175, 143, 193, 176, 139, 183, 169, 132, 179, 168, 132, 180, 163, 127, 178, 159, 123, 187, 169, 133, 193, 174, 138, 189, 171, 135, 181, 165, 128, 183, 168, 129, 184, 169, 128, 174, 160, 116, 159, 146, 100, 161, 147, 101, 170, 156, 116, 177, 163, 122, 182, 169, 126, 181, 168, 123, 176, 162, 120, 184, 168, 130, 187, 172, 132, 173, 161, 118, 163, 153, 108, 161, 153, 107, 170, 163, 117, 172, 160, 120, 159, 144, 102, 169, 159, 117, 160, 158, 137, 140, 140, 123, 165, 160, 128, 184, 170, 131, 191, 174, 132, 179, 167, 128, 169, 161, 125, 170, 156, 118, 167, 151, 112, 175, 159, 120, 187, 172, 133, 178, 163, 124, 163, 150, 109, 168, 157, 113, 172, 161, 114, 163, 154, 102, 154, 145, 90, 155, 145, 92, 162, 151, 113, 166, 155, 116, 182, 171, 130, 186, 176, 133, 183, 170, 128, 183, 168, 127, 179, 167, 122, 167, 159, 109, 158, 154, 98, 156, 152, 94, 170, 162, 109, 176, 161, 114, 173, 155, 107, 180, 168, 122, 157, 154, 131, 136, 137, 113, 158, 154, 110, 165, 151, 102, 176, 157, 109, 172, 157, 115, 169, 158, 120, 167, 156, 112, 161, 149, 103, 162, 150, 104, 170, 159, 112, 163, 151, 104, 158, 145, 97, 165, 153, 101, 168, 156, 101, 163, 153, 93, 162, 152, 88, 162, 153, 90, 150, 139, 96, 153, 143, 97, 163, 153, 106, 178, 167, 124, 180, 169, 127, 172, 162, 119, 166, 158, 111, 153, 147, 95, 145, 141, 81, 149, 146, 80, 160, 153, 94, 176, 164, 111, 183, 170, 114, 176, 167, 117, 153, 149, 127, 136, 132, 105, 159, 151, 101, 167, 154, 105, 173, 158, 112, 172, 157, 117, 166, 154, 117, 167, 155, 113, 170, 158, 111, 169, 158, 104, 167, 157, 100, 166, 156, 101, 165, 156, 104, 163, 155, 100, 163, 154, 94, 163, 153, 90, 161, 150, 88, 159, 150, 90, 138, 127, 79, 152, 142, 90, 155, 145, 93, 163, 152, 105, 162, 151, 110, 162, 154, 114, 163, 155, 114, 151, 144, 98, 144, 137, 82, 154, 149, 87, 151, 143, 87, 153, 144, 91, 158, 150, 93, 162, 157, 106, 154, 150, 129, 146, 138, 113, 172, 161, 114, 176, 165, 120, 170, 158, 117, 155, 143, 104, 153, 140, 103, 154, 140, 102, 170, 158, 112, 176, 165, 110, 171, 161, 102, 168, 157, 101, 159, 150, 98, 156, 149, 95, 164, 156, 97, 160, 152, 90, 151, 140, 82, 160, 148, 95, 154, 144, 94, 159, 149, 97, 162, 152, 100, 165, 154, 106, 162, 151, 109, 159, 149, 112, 163, 153, 118, 164, 154, 118, 149, 140, 98, 138, 129, 82, 144, 135, 89, 139, 128, 82, 142, 133, 80, 158, 152, 104, 154, 151, 129, 149, 141, 119, 167, 155, 115, 166, 154, 114, 162, 150, 109, 152, 141, 98, 152, 140, 98, 150, 136, 95, 160, 147, 101, 163, 152, 99, 162, 150, 97, 163, 151, 99, 151, 140, 89, 154, 144, 91, 164, 153, 95, 162, 150, 90, 159, 145, 87, 160, 145, 91, 154, 144, 93, 154, 144, 92, 151, 141, 90, 156, 146, 96, 164, 154, 109, 155, 143, 106, 156, 144, 111, 161, 148, 118, 158, 145, 112, 133, 122, 85, 127, 116, 76, 148, 136, 95, 158, 148, 99, 157, 151, 103, 156, 152, 129, 145, 137, 117, 162, 149, 114, 161, 149, 111, 161, 150, 108, 158, 147, 101, 152, 141, 93, 155, 142, 98, 161, 148, 103, 160, 148, 100, 154, 142, 94, 149, 137, 89, 153, 140, 91, 160, 147, 95, 167, 153, 99, 164, 149, 93, 162, 146, 90, 156, 139, 86, 145, 135, 83, 150, 140, 90, 151, 141, 90, 153, 143, 91, 157, 146, 97, 158, 146, 104, 156, 143, 107, 157, 143, 111, 164, 151, 116, 149, 137, 99, 141, 131, 90, 159, 147, 105, 167, 157, 108, 157, 151, 104, 151, 147, 125, 141, 133, 113, 162, 149, 113, 158, 146, 106, 156, 145, 100, 159, 149, 98, 159, 149, 97, 156, 143, 96, 159, 146, 101, 160, 146, 104, 144, 131, 89, 139, 126, 84, 147, 134, 87, 154, 140, 92, 163, 148, 100, 160, 144, 94, 158, 141, 89, 157, 139, 89, 151, 141, 88, 152, 142, 92, 155, 145, 95, 157, 147, 93, 153, 143, 88, 162, 150, 100, 161, 148, 103, 165, 152, 110, 168, 156, 111, 165, 153, 105, 164, 154, 107, 167, 156, 109, 164, 155, 102, 161, 155, 106, 146, 142, 121, 135, 127, 104, 160, 148, 105, 159, 148, 102, 153, 143, 92, 157, 148, 93, 158, 148, 93, 150, 138, 87, 150, 138, 93, 149, 135, 97, 134, 120, 83, 139, 125, 88, 139, 127, 84, 140, 129, 85, 148, 135, 94, 157, 142, 100, 156, 140, 94, 155, 140, 93, 146, 136, 83, 149, 139, 90, 156, 146, 96, 158, 148, 93, 160, 150, 91, 160, 149, 91, 163, 152, 97, 168, 156, 103, 164, 153, 95, 160, 151, 89, 154, 146, 90, 154, 145, 92, 150, 142, 86, 147, 142, 92, 118, 114, 93, 119, 112, 85, 157, 147, 96, 161, 151, 99, 157, 148, 93, 160, 151, 95, 149, 140, 82, 147, 136, 83, 150, 136, 92, 138, 123, 87, 119, 104, 71, 132, 117, 83, 130, 119, 80, 136, 126, 87, 136, 124, 89, 144, 130, 95, 149, 135, 94, 150, 137, 92, 141, 132, 81, 146, 136, 89, 150, 140, 91, 153, 143, 87, 155, 147, 86, 155, 148, 86, 157, 150, 90, 159, 151, 91, 159, 152, 90, 151, 145, 80, 147, 142, 82, 151, 145, 86, 147, 139, 88, 116, 110, 75, 64, 62, 45, 98, 95, 63, 153, 146, 95, 147, 139, 89, 156, 147, 98, 155, 145, 95, 144, 134, 83, 155, 143, 90, 151, 136, 89, 138, 120, 82, 125, 108, 74, 126, 112, 79, 125, 115, 82, 133, 122, 87, 135, 122, 90, 135, 120, 92, 140, 127, 91, 142, 131, 87, 141, 131, 84, 149, 137, 93, 153, 141, 93, 155, 144, 88, 158, 150, 91, 151, 146, 87, 152, 146, 88, 147, 142, 84, 148, 142, 84, 148, 143, 84, 153, 149, 89, 153, 147, 87, 139, 130, 87, 85, 78, 59, 36, 35, 24, 87, 86, 56, 147, 142, 95, 144, 137, 92, 152, 144, 100, 148, 138, 94, 148, 137, 90, 159, 146, 94, 158, 140, 92, 146, 126, 85, 152, 134, 97, 131, 119, 86, 127, 116, 85, 141, 128, 94, 149, 132, 101, 134, 116, 93, 145, 130, 101, 149, 139, 97, 157, 145, 97, 155, 142, 97, 161, 149, 100, 155, 143, 89, 154, 143, 89, 153, 143, 92, 157, 147, 96, 151, 141, 90, 150, 140, 89, 154, 144, 93, 161, 152, 95, 161, 151, 94, 131, 120, 84, 57, 50, 40, 29, 28, 25, 87, 86, 61, 150, 144, 101, 148, 141, 97, 154, 145, 100, 152, 142, 95, 152, 140, 92, 160, 146, 96, 159, 141, 94, 149, 130, 88, 154, 137, 101, 136, 123, 89, 137, 124, 91, 155, 139, 102, 155, 135, 102, 146, 123, 103, 154, 136, 112, 152, 138, 104, 152, 138, 90, 143, 130, 84, 156, 144, 95, 146, 135, 85, 134, 122, 71, 151, 138, 89, 152, 139, 91, 156, 142, 94, 152, 139, 90, 153, 140, 92, 159, 146, 95, 161, 148, 100, 106, 95, 68, 39, 32, 30, 26, 25, 28, 88, 85, 66, 154, 145, 108, 150, 142, 99, 151, 142, 94, 155, 144, 95, 159, 146, 97, 159, 144, 96, 150, 133, 88, 145, 128, 87, 138, 122, 86, 157, 143, 108, 170, 155, 120, 169, 151, 111, 143, 120, 84, 157, 131, 112, 156, 134, 116, 153, 136, 110, 148, 134, 90, 141, 129, 84, 146, 137, 91, 134, 127, 81, 128, 119, 73, 144, 133, 87, 143, 131, 86, 139, 127, 82, 143, 131, 85, 147, 135, 90, 144, 131, 92, 120, 110, 75, 59, 52, 35, 29, 25, 28, 26, 25, 28, 92, 87, 69, 150, 140, 104, 154, 144, 100, 151, 140, 90, 157, 144, 96, 154, 139, 93, 154, 135, 92, 151, 134, 91, 150, 135, 94, 141, 127, 90, 157, 143, 108, 163, 148, 113, 164, 146, 105, 152, 129, 91, 159, 133, 112, 152, 130, 115, 150, 132, 111, 136, 125, 84, 133, 124, 81, 138, 134, 90, 128, 126, 86, 117, 113, 78, 115, 108, 76, 112, 104, 72, 95, 88, 56, 100, 93, 60, 110, 102, 71, 90, 81, 59, 55, 50, 31, 31, 30, 22, 25, 24, 28, 29, 28, 25, 101, 95, 73, 152, 140, 103, 160, 149, 103, 163, 150, 100, 160, 146, 100, 159, 142, 101, 158, 138, 98, 156, 139, 99, 154, 141, 102, 155, 142, 105, 152, 137, 102, 155, 140, 106, 146, 130, 90, 155, 135, 95, 154, 131, 107, 155, 135, 118, 149, 132, 111, 136, 128, 91, 130, 126, 85, 129, 129, 90, 113, 116, 83, 84, 85, 63, 66, 64, 53, 53, 50, 39, 41, 38, 27, 38, 35, 24, 40, 38, 28, 29, 27, 22, 21, 23, 17, 22, 27, 26, 20, 22, 26, 33, 32, 23, 114, 107, 79, 153, 141, 101, 156, 144, 95, 161, 149, 98, 167, 151, 109, 168, 148, 114, 167, 145, 109, 162, 144, 106, 152, 140, 102, 147, 136, 98, 150, 134, 100, 153, 138, 107, 141, 128, 89, 147, 130, 89, 148, 130, 102, 150, 134, 112, 141, 126, 103, 124, 120, 93, 114, 112, 85, 92, 92, 69, 68, 70, 52, 45, 46, 38, 38, 37, 39, 30, 29, 30, 25, 24, 25, 24, 23, 24, 22, 21, 23, 19, 20, 21, 18, 21, 20, 18, 23, 24, 17, 19, 21, 31, 30, 22, 123, 113, 86, 160, 145, 101, 147, 135, 84, 155, 142, 96, 162, 147, 111, 162, 145, 112, 163, 142, 107, 152, 135, 96, 150, 138, 97, 137, 127, 86, 146, 133, 96, 150, 136, 104, 137, 124, 89, 145, 130, 94, 143, 127, 101, 141, 126, 104, 129, 114, 90, 66, 66, 53, 62, 61, 52, 50, 49, 43, 42, 40, 38, 37, 35, 36, 31, 31, 31, 23, 23, 24, 21, 21, 22, 22, 22, 23, 21, 21, 21, 20, 20, 21, 20, 21, 21, 18, 19, 19, 15, 15, 16, 19, 19, 17, 107, 96, 75, 157, 140, 94, 139, 126, 75, 143, 130, 91, 151, 138, 108, 156, 142, 109, 155, 138, 102, 150, 134, 94, 149, 136, 94, 140, 130, 89, 143, 133, 96, 139, 126, 91, 125, 111, 78, 136, 121, 94, 133, 116, 94, 135, 119, 97, 131, 115, 91, 32, 34, 29, 39, 40, 37, 37, 37, 36, 37, 37, 38, 33, 32, 33, 23, 23, 23, 22, 22, 22, 21, 21, 20, 20, 20, 20, 20, 20, 20, 21, 21, 21, 22, 22, 22, 19, 19, 19, 14, 14, 14, 12, 12, 11, 70, 63, 46, 138, 124, 83, 146, 134, 87, 138, 124, 89, 140, 125, 99, 149, 133, 104, 157, 138, 107, 153, 136, 101, 146, 132, 93, 133, 120, 83, 127, 115, 81, 126, 113, 78, 128, 113, 81, 130, 115, 89, 128, 111, 90, 126, 110, 88, 126, 109, 86, 30, 31, 32, 35, 37, 37, 32, 34, 34, 31, 34, 32, 29, 31, 29, 20, 20, 20, 21, 21, 21, 19, 19, 19, 19, 19, 19, 20, 20, 20, 20, 20, 20, 20, 20, 20, 19, 19, 19, 14, 14, 14, 10, 10, 10, 39, 36, 23, 119, 111, 77, 136, 124, 82, 136, 120, 88, 136, 116, 94, 140, 121, 96, 153, 135, 109, 147, 131, 100, 134, 119, 84, 121, 106, 72, 117, 102, 71, 123, 108, 75, 124, 109, 77, 120, 103, 78, 130, 113, 92, 132, 114, 93, 133, 115, 92, 30, 28, 33, 30, 30, 32, 30, 32, 32, 30, 35, 33, 26, 29, 27, 22, 22, 22, 20, 20, 20, 18, 18, 18, 18, 18, 18, 19, 19, 19, 19, 19, 19, 20, 20, 20, 17, 17, 17, 15, 15, 15, 12, 12, 12, 18, 18, 10, 90, 87, 59, 119, 109, 70, 127, 109, 79, 144, 123, 101, 146, 127, 104, 147, 129, 107, 147, 130, 103, 146, 129, 97, 141, 123, 90, 133, 115, 84, 136, 118, 85, 123, 104, 73, 121, 102, 78, 142, 122, 103, 141, 121, 100, 142, 123, 100, 34, 28, 28, 31, 27, 28, 32, 32, 32, 31, 33, 32, 25, 27, 26, 24, 24, 24, 19, 19, 19, 16, 16, 16, 18, 18, 18, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 15, 15, 15, 12, 12, 12, 12, 12, 7, 80, 77, 54, 137, 126, 88, 137, 118, 86, 149, 130, 105, 147, 131, 107, 139, 121, 99, 139, 122, 96, 148, 129, 97, 145, 125, 92, 129, 108, 77, 150, 130, 97, 140, 121, 90, 131, 111, 87, 134, 113, 93, 138, 117, 97, 131, 111, 89, 97, 87, 83, 34, 27, 25, 38, 35, 34, 38, 38, 38, 24, 25, 25, 19, 19, 19, 14, 14, 14, 14, 14, 14, 16, 15, 15, 16, 16, 16, 17, 17, 17, 18, 18, 18, 16, 16, 16, 13, 13, 13, 12, 12, 12, 14, 13, 10, 82, 78, 57, 143, 130, 92, 147, 128, 93, 145, 131, 102, 124, 114, 85, 125, 109, 86, 124, 107, 79, 125, 106, 73, 139, 118, 83, 140, 117, 84, 135, 114, 80, 138, 118, 88, 128, 106, 83, 123, 101, 82, 129, 107, 87, 123, 103, 81, 178, 159, 142, 57, 44, 31, 63, 58, 54, 69, 67, 68, 20, 18, 18, 15, 16, 16, 10, 11, 12, 11, 12, 13, 13, 13, 13, 13, 13, 12, 12, 13, 13, 13, 14, 15, 12, 13, 13, 12, 12, 11, 13, 11, 8, 25, 22, 14, 90, 84, 59, 136, 123, 84, 146, 128, 91, 136, 123, 91, 114, 106, 75, 110, 95, 69, 118, 100, 72, 126, 108, 75, 138, 118, 83, 144, 122, 88, 122, 101, 70, 128, 107, 81, 125, 104, 83, 115, 94, 76, 114, 94, 76, 110, 90, 71, 176, 147, 111, 93, 75, 42, 109, 104, 92, 128, 124, 121, 33, 28, 24, 14, 14, 12, 12, 14, 15, 10, 13, 15, 11, 12, 11, 14, 12, 9, 12, 12, 12, 11, 13, 14, 10, 12, 11, 17, 16, 10, 32, 25, 15, 62, 55, 34, 105, 98, 64, 134, 120, 81, 140, 123, 86, 133, 118, 87, 118, 106, 79, 113, 97, 70, 119, 102, 75, 118, 101, 72, 126, 108, 78, 125, 107, 76, 103, 83, 58, 109, 88, 70, 112, 93, 76, 112, 93, 79, 105, 87, 73, 97, 81, 67, 162, 137, 94, 126, 111, 70, 156, 153, 131, 197, 192, 179, 106, 95, 82, 40, 31, 23, 17, 13, 9, 14, 13, 10, 15, 12, 7, 17, 12, 6, 15, 12, 8, 14, 13, 10, 19, 19, 12, 55, 51, 37, 95, 85, 64, 111, 103, 71, 130, 122, 83, 142, 129, 90, 136, 120, 85, 128, 113, 83, 118, 103, 78, 117, 100, 75, 118, 100, 75, 111, 94, 69, 114, 97, 71, 107, 90, 63, 102, 83, 63, 104, 84, 69, 99, 80, 65, 105, 87, 74, 97, 81, 68, 89, 74, 62, 140, 126, 82, 126, 117, 75, 154, 154, 121, 210, 204, 177, 176, 156, 133, 126, 104, 84, 63, 48, 33, 27, 17, 6, 38, 28, 16, 46, 36, 24, 35, 27, 16, 36, 31, 19, 60, 56, 38, 98, 91, 65, 129, 118, 83, 136, 126, 86, 135, 128, 86, 143, 131, 92, 136, 121, 87, 128, 112, 83, 114, 98, 75, 121, 103, 80, 116, 98, 74, 112, 94, 70, 114, 96, 73, 117, 99, 78, 115, 96, 79, 106, 87, 72, 93, 74, 60, 89, 73, 59, 85, 70, 58, 86, 71, 60, 116, 111, 69, 118, 114, 74, 133, 133, 92, 183, 174, 137, 182, 155, 124, 172, 141, 111, 141, 116, 92, 83, 64, 44, 80, 63, 43, 96, 78, 59, 92, 79, 58, 91, 83, 60, 92, 87, 58, 98, 91, 55, 129, 118, 73, 143, 132, 86, 126, 118, 75, 127, 117, 79, 122, 109, 76, 119, 103, 77, 113, 96, 74, 124, 106, 85, 117, 99, 75, 114, 97, 71, 114, 96, 74, 111, 93, 77, 106, 87, 73, 94, 76, 62, 95, 78, 65, 72, 57, 45, 65, 52, 41, 86, 72, 63], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387472}, {\"format\": \"raw\", \"value\": [35, 59, 53, 36, 56, 56, 42, 62, 64, 40, 59, 63, 43, 60, 65, 79, 103, 89, 77, 104, 74, 67, 88, 65, 70, 93, 73, 61, 82, 69, 60, 80, 70, 56, 74, 74, 52, 69, 73, 46, 67, 63, 56, 77, 64, 55, 75, 63, 48, 68, 57, 41, 61, 57, 109, 132, 137, 115, 140, 140, 75, 101, 93, 78, 102, 94, 82, 103, 100, 104, 126, 133, 98, 125, 121, 89, 116, 103, 73, 99, 86, 75, 98, 101, 80, 100, 111, 101, 131, 143, 148, 186, 196, 145, 179, 185, 36, 59, 52, 31, 51, 48, 30, 49, 48, 41, 58, 60, 47, 60, 64, 73, 93, 80, 81, 107, 78, 61, 80, 62, 55, 74, 61, 60, 78, 67, 61, 78, 70, 54, 69, 70, 53, 67, 71, 47, 61, 61, 54, 69, 63, 48, 64, 58, 45, 62, 56, 32, 49, 50, 69, 90, 89, 80, 103, 93, 44, 65, 58, 54, 71, 68, 70, 86, 82, 88, 110, 105, 80, 108, 84, 58, 83, 62, 50, 73, 63, 55, 77, 72, 67, 87, 93, 83, 110, 109, 79, 108, 91, 77, 105, 94, 25, 47, 41, 24, 43, 39, 30, 48, 45, 35, 50, 49, 53, 63, 63, 78, 91, 83, 89, 105, 85, 79, 87, 74, 74, 82, 69, 72, 78, 72, 62, 65, 66, 60, 65, 69, 65, 71, 72, 54, 59, 60, 51, 61, 58, 41, 51, 51, 34, 47, 49, 31, 46, 47, 38, 55, 54, 55, 73, 62, 52, 68, 65, 61, 73, 74, 65, 76, 77, 67, 87, 75, 68, 95, 68, 52, 74, 60, 43, 63, 57, 42, 63, 55, 48, 69, 62, 62, 88, 70, 57, 81, 61, 48, 72, 57, 83, 96, 94, 81, 96, 96, 54, 62, 61, 106, 93, 97, 144, 126, 133, 156, 133, 140, 169, 144, 148, 175, 147, 153, 175, 149, 154, 172, 144, 154, 166, 138, 149, 161, 138, 149, 159, 140, 149, 148, 132, 141, 138, 124, 131, 121, 104, 113, 96, 85, 95, 73, 71, 79, 58, 64, 67, 57, 70, 63, 50, 63, 62, 62, 73, 72, 62, 72, 71, 58, 71, 68, 57, 79, 62, 49, 71, 58, 44, 60, 54, 38, 55, 52, 36, 57, 52, 58, 82, 63, 53, 74, 61, 48, 71, 57, 189, 196, 199, 173, 189, 195, 101, 101, 99, 131, 106, 102, 173, 140, 137, 187, 147, 141, 198, 152, 149, 201, 150, 155, 207, 148, 163, 221, 153, 172, 226, 165, 184, 230, 175, 192, 234, 181, 202, 226, 166, 186, 217, 135, 158, 209, 122, 146, 196, 115, 137, 181, 107, 130, 165, 106, 127, 149, 106, 120, 119, 89, 103, 91, 85, 89, 68, 76, 75, 52, 64, 62, 50, 68, 57, 43, 62, 53, 38, 56, 49, 35, 50, 49, 33, 51, 48, 52, 73, 56, 50, 70, 54, 40, 60, 49, 143, 152, 153, 122, 138, 146, 70, 71, 72, 81, 81, 75, 121, 123, 115, 120, 117, 106, 104, 96, 88, 103, 74, 74, 150, 67, 76, 139, 70, 80, 138, 78, 91, 143, 88, 105, 168, 103, 121, 177, 89, 112, 153, 83, 99, 147, 88, 100, 134, 74, 89, 128, 68, 87, 124, 66, 88, 125, 66, 87, 124, 66, 89, 124, 77, 99, 108, 78, 95, 62, 68, 66, 47, 64, 57, 36, 52, 50, 38, 52, 52, 71, 79, 83, 72, 86, 95, 64, 84, 83, 69, 89, 86, 69, 88, 89, 91, 69, 81, 62, 61, 70, 43, 40, 38, 74, 83, 90, 97, 117, 127, 89, 99, 100, 69, 76, 79, 94, 60, 64, 123, 54, 64, 88, 87, 81, 79, 77, 81, 98, 105, 114, 154, 121, 133, 163, 93, 108, 166, 164, 164, 132, 147, 161, 75, 80, 101, 77, 76, 92, 55, 52, 73, 59, 55, 78, 56, 53, 76, 72, 67, 84, 73, 60, 82, 72, 72, 73, 83, 92, 68, 101, 109, 93, 109, 110, 90, 112, 124, 137, 103, 137, 172, 96, 133, 169, 93, 134, 175, 90, 135, 177, 124, 100, 86, 78, 67, 62, 50, 49, 47, 94, 110, 92, 90, 109, 101, 76, 87, 74, 59, 59, 54, 104, 55, 52, 122, 63, 64, 91, 105, 88, 72, 78, 79, 98, 118, 110, 142, 140, 131, 163, 110, 116, 133, 141, 148, 98, 120, 145, 65, 82, 115, 70, 78, 103, 69, 77, 98, 88, 99, 118, 81, 91, 107, 103, 124, 123, 100, 128, 131, 91, 105, 112, 146, 151, 94, 152, 159, 110, 125, 139, 114, 76, 109, 105, 86, 126, 114, 99, 135, 126, 75, 105, 123, 40, 59, 90, 158, 165, 97, 102, 92, 65, 74, 68, 61, 112, 118, 95, 115, 121, 100, 106, 110, 80, 70, 60, 55, 118, 49, 55, 118, 69, 60, 111, 123, 87, 65, 65, 63, 101, 109, 81, 147, 146, 103, 160, 98, 99, 115, 114, 110, 107, 116, 121, 54, 72, 109, 44, 54, 86, 58, 66, 85, 109, 120, 110, 89, 91, 102, 56, 79, 117, 82, 111, 126, 100, 122, 134, 121, 130, 99, 135, 148, 95, 82, 103, 102, 72, 114, 103, 72, 114, 114, 89, 135, 129, 63, 92, 104, 37, 41, 48, 141, 140, 86, 160, 86, 75, 162, 107, 96, 130, 105, 99, 114, 99, 94, 96, 79, 76, 84, 65, 62, 131, 48, 52, 76, 37, 44, 64, 55, 55, 54, 49, 54, 74, 70, 60, 112, 104, 86, 155, 85, 91, 129, 117, 113, 115, 128, 128, 58, 71, 105, 51, 58, 85, 67, 72, 83, 123, 137, 115, 91, 95, 103, 48, 63, 102, 76, 99, 113, 107, 132, 136, 102, 116, 113, 110, 126, 104, 57, 80, 95, 74, 107, 103, 74, 107, 103, 76, 117, 111, 47, 66, 83, 45, 47, 51, 142, 104, 66, 207, 48, 63, 202, 78, 86, 187, 86, 93, 187, 108, 111, 167, 117, 116, 136, 97, 94, 156, 51, 59, 104, 48, 59, 80, 59, 65, 64, 53, 60, 49, 36, 46, 57, 41, 53, 140, 60, 78, 108, 82, 96, 76, 82, 99, 63, 65, 91, 60, 61, 85, 71, 72, 88, 119, 126, 117, 90, 92, 104, 71, 75, 103, 100, 115, 124, 125, 146, 142, 99, 112, 137, 89, 109, 139, 81, 109, 153, 86, 113, 143, 82, 108, 127, 70, 96, 119, 57, 69, 95, 61, 64, 70, 138, 87, 55, 204, 44, 50, 196, 53, 54, 221, 51, 66, 233, 68, 89, 223, 87, 103, 177, 93, 100, 200, 102, 115, 206, 101, 118, 175, 86, 101, 143, 70, 82, 110, 58, 72, 83, 54, 66, 144, 61, 78, 129, 68, 88, 64, 58, 79, 64, 54, 72, 65, 54, 71, 77, 61, 78, 110, 89, 97, 98, 77, 94, 83, 64, 86, 112, 96, 107, 131, 123, 126, 96, 95, 122, 77, 84, 126, 70, 91, 144, 72, 101, 152, 79, 113, 165, 90, 125, 171, 104, 133, 171, 97, 121, 155, 139, 80, 55, 178, 57, 46, 170, 66, 54, 214, 44, 51, 225, 37, 51, 224, 49, 65, 188, 59, 70, 208, 86, 98, 236, 97, 118, 243, 112, 136, 233, 115, 136, 213, 97, 117, 185, 80, 99, 193, 75, 98, 190, 74, 100, 154, 59, 81, 153, 49, 70, 155, 48, 69, 167, 59, 81, 174, 65, 89, 169, 64, 86, 171, 65, 89, 179, 83, 109, 175, 88, 114, 156, 84, 111, 128, 90, 124, 65, 61, 106, 35, 44, 87, 36, 54, 104, 59, 82, 126, 74, 100, 145, 69, 104, 160, 156, 80, 54, 117, 47, 34, 99, 61, 46, 200, 67, 59, 219, 44, 48, 203, 46, 50, 183, 42, 45, 220, 34, 49, 230, 47, 66, 239, 73, 95, 242, 95, 120, 246, 114, 139, 248, 124, 151, 233, 117, 144, 229, 126, 152, 237, 101, 131, 236, 68, 98, 234, 59, 88, 240, 67, 98, 241, 74, 104, 237, 80, 111, 239, 94, 128, 237, 108, 143, 232, 108, 144, 231, 123, 160, 215, 138, 173, 176, 109, 142, 138, 82, 114, 94, 61, 98, 53, 43, 80, 30, 39, 79, 23, 43, 89, 140, 97, 61, 73, 43, 36, 82, 75, 73, 171, 72, 62, 215, 45, 46, 193, 49, 47, 177, 45, 45, 224, 39, 49, 222, 39, 51, 226, 41, 59, 233, 46, 67, 237, 61, 86, 240, 89, 119, 231, 99, 127, 238, 135, 158, 249, 158, 183, 248, 147, 173, 247, 127, 155, 245, 103, 134, 243, 96, 130, 245, 109, 146, 245, 118, 156, 243, 122, 162, 243, 126, 167, 242, 128, 171, 240, 131, 172, 237, 130, 170, 222, 129, 164, 210, 119, 155, 191, 101, 139, 144, 78, 116, 75, 51, 85, 135, 137, 78, 71, 66, 49, 82, 78, 74, 144, 74, 66, 208, 43, 44, 188, 46, 44, 173, 41, 41, 219, 38, 43, 214, 44, 51, 216, 52, 64, 219, 42, 55, 229, 33, 53, 205, 38, 59, 189, 51, 68, 230, 66, 92, 246, 102, 131, 249, 144, 171, 252, 167, 193, 252, 167, 195, 252, 152, 183, 250, 130, 165, 247, 123, 160, 247, 119, 157, 250, 113, 150, 247, 110, 147, 242, 103, 141, 237, 98, 136, 234, 96, 134, 230, 99, 140, 226, 103, 143, 234, 107, 145, 223, 92, 128, 144, 156, 85, 106, 108, 68, 117, 115, 108, 141, 94, 86, 197, 47, 42, 183, 53, 46, 172, 48, 43, 218, 49, 49, 210, 45, 47, 211, 42, 47, 211, 38, 48, 217, 34, 49, 220, 34, 53, 215, 39, 60, 226, 39, 63, 235, 37, 64, 240, 56, 84, 244, 96, 124, 248, 135, 164, 250, 169, 194, 249, 197, 213, 249, 143, 171, 234, 98, 134, 223, 94, 129, 236, 67, 102, 226, 57, 90, 213, 48, 80, 204, 46, 78, 187, 58, 88, 170, 53, 88, 171, 65, 101, 198, 72, 102, 132, 145, 119, 117, 118, 82, 104, 104, 98, 110, 82, 73, 182, 66, 55, 178, 58, 48, 169, 49, 42, 215, 50, 48, 207, 46, 45, 209, 46, 45, 208, 41, 45, 214, 30, 42, 217, 29, 44, 218, 33, 51, 219, 35, 57, 228, 32, 54, 228, 31, 55, 231, 36, 61, 236, 52, 79, 239, 89, 115, 243, 131, 157, 239, 117, 147, 185, 129, 151, 134, 117, 137, 171, 50, 77, 174, 32, 58, 154, 34, 56, 136, 32, 55, 122, 67, 86, 108, 46, 65, 105, 28, 52, 109, 60, 81, 107, 133, 158, 119, 122, 116, 130, 126, 121, 68, 62, 55, 108, 64, 45, 150, 76, 57, 166, 48, 43, 210, 48, 46, 203, 46, 42, 206, 43, 43, 207, 37, 41, 209, 29, 39, 207, 27, 40, 209, 32, 45, 212, 36, 53, 216, 33, 51, 220, 33, 51, 222, 31, 53, 222, 32, 53, 224, 35, 57, 224, 44, 69, 195, 76, 98, 143, 146, 151, 115, 125, 117, 104, 60, 69, 116, 41, 63, 124, 70, 92, 115, 66, 85, 98, 64, 80, 97, 68, 80, 95, 60, 71, 84, 69, 78, 86, 115, 147, 93, 102, 127, 121, 115, 117, 42, 43, 42, 28, 19, 14, 68, 42, 30, 135, 47, 43, 197, 51, 51, 200, 46, 43, 202, 41, 40, 202, 35, 38, 202, 31, 38, 203, 27, 38, 210, 31, 44, 168, 33, 46, 123, 25, 38, 147, 32, 48, 201, 39, 56, 213, 29, 47, 209, 28, 45, 203, 26, 43, 144, 47, 55, 98, 112, 117, 123, 146, 154, 109, 102, 114, 101, 82, 100, 108, 103, 120, 100, 99, 114, 84, 88, 95, 79, 90, 94, 71, 83, 88, 66, 76, 76, 91, 120, 145, 71, 92, 123, 90, 88, 83, 62, 66, 40, 34, 36, 25, 28, 23, 16, 58, 26, 24, 121, 40, 39, 174, 47, 47, 198, 45, 45, 199, 39, 39, 199, 38, 42, 206, 43, 54, 193, 38, 48, 84, 23, 28, 42, 24, 29, 61, 41, 48, 125, 40, 52, 200, 30, 46, 201, 26, 40, 179, 24, 36, 120, 38, 38, 82, 90, 98, 108, 134, 160, 114, 130, 146, 72, 81, 84, 68, 75, 75, 63, 68, 68, 54, 56, 52, 49, 54, 49, 49, 55, 53, 50, 56, 51, 91, 115, 119, 84, 99, 110, 106, 101, 84, 120, 124, 67, 104, 111, 64, 68, 69, 42, 29, 29, 18, 35, 19, 16, 83, 29, 29, 153, 48, 50, 193, 50, 51, 194, 41, 42, 182, 45, 51, 137, 35, 40, 55, 29, 29, 79, 65, 67, 93, 83, 87, 77, 56, 65, 145, 34, 46, 182, 27, 39, 156, 29, 39, 115, 34, 34, 83, 41, 39, 103, 96, 105, 85, 96, 97, 48, 47, 41, 53, 52, 49, 56, 58, 54, 48, 53, 49, 47, 55, 55, 49, 57, 56, 50, 55, 51, 77, 92, 80, 79, 91, 84, 93, 97, 75, 125, 135, 67, 124, 135, 68, 115, 121, 69, 80, 84, 51, 35, 37, 24, 25, 19, 16, 50, 22, 23, 111, 35, 38, 171, 43, 46, 188, 44, 47, 104, 30, 31, 54, 43, 42, 66, 56, 56, 75, 67, 66, 81, 78, 82, 90, 45, 55, 165, 31, 42, 150, 30, 38, 104, 30, 32, 90, 38, 42, 96, 84, 86, 61, 65, 62, 47, 47, 43, 52, 56, 52, 52, 59, 56, 48, 52, 51, 48, 53, 51, 47, 53, 54, 55, 49, 53, 98, 126, 136, 103, 125, 127, 90, 102, 78, 127, 137, 75, 125, 137, 73, 125, 135, 78, 121, 129, 75, 95, 101, 55, 52, 54, 32, 24, 23, 16, 26, 14, 13, 60, 22, 22, 107, 34, 33, 69, 33, 31, 52, 47, 45, 60, 54, 46, 92, 84, 77, 88, 85, 88, 65, 49, 59, 135, 29, 39, 132, 26, 28, 100, 31, 33, 100, 52, 48, 78, 67, 61, 51, 57, 52, 50, 53, 50, 52, 58, 57, 53, 60, 58, 54, 56, 58, 57, 50, 56, 60, 45, 58, 62, 60, 86, 110, 162, 203, 136, 170, 186, 95, 103, 79, 129, 137, 79, 131, 142, 82, 126, 135, 66, 124, 134, 65, 119, 130, 70, 111, 120, 66, 75, 78, 47, 32, 32, 22, 13, 13, 11, 16, 14, 11, 34, 28, 25, 58, 51, 47, 93, 90, 78, 182, 182, 181, 115, 111, 115, 45, 44, 47, 93, 38, 44, 123, 42, 46, 105, 25, 31, 86, 18, 19, 66, 31, 37, 64, 48, 53, 63, 44, 52, 64, 47, 61, 64, 51, 71, 64, 66, 98, 65, 88, 129, 61, 96, 140, 62, 95, 115, 79, 112, 134, 75, 96, 102, 58, 62, 46, 119, 126, 66, 125, 135, 69, 128, 136, 71, 135, 141, 78, 130, 139, 74, 127, 138, 70, 120, 129, 68, 92, 98, 56, 48, 50, 32, 21, 23, 17, 19, 18, 16, 57, 55, 53, 95, 93, 86, 127, 129, 135, 95, 93, 98, 46, 42, 49, 107, 98, 102, 192, 167, 173, 125, 92, 115, 85, 69, 99, 66, 69, 98, 58, 75, 115, 74, 95, 132, 90, 113, 145, 72, 105, 143, 61, 89, 115, 56, 75, 81, 44, 54, 52, 62, 74, 51, 26, 40, 34, 19, 33, 27, 39, 45, 37, 111, 117, 64, 127, 137, 71, 120, 128, 66, 127, 134, 70, 130, 139, 72, 127, 137, 68, 123, 133, 58, 123, 131, 65, 112, 120, 68, 68, 76, 48, 37, 41, 29, 61, 60, 59, 106, 108, 106, 91, 90, 73, 74, 71, 65, 49, 49, 53, 67, 65, 69, 115, 121, 125, 90, 116, 131, 71, 98, 127, 66, 85, 109, 56, 71, 91, 57, 67, 77, 63, 71, 71, 48, 57, 54, 37, 45, 39, 37, 42, 38, 29, 36, 27, 48, 61, 40, 13, 34, 31, 15, 32, 26, 31, 40, 34, 96, 103, 61, 121, 130, 71, 113, 125, 62, 118, 128, 63, 126, 135, 69, 131, 140, 67, 127, 135, 61, 126, 134, 66, 134, 140, 81, 122, 131, 75, 95, 102, 62, 79, 79, 63, 141, 140, 142, 127, 126, 113, 72, 69, 63, 41, 43, 46, 19, 22, 23, 21, 16, 21, 22, 21, 22, 30, 22, 23, 36, 20, 19, 25, 13, 14, 17, 15, 16, 30, 36, 31, 31, 35, 33, 22, 28, 27, 21, 29, 27, 23, 35, 26, 36, 53, 34, 34, 52, 51, 17, 29, 23, 24, 35, 27, 68, 77, 43, 106, 115, 63, 115, 127, 68, 118, 128, 67, 121, 131, 62, 126, 134, 61, 125, 134, 63, 121, 133, 62, 125, 135, 70, 126, 134, 71, 125, 133, 75, 111, 115, 75, 128, 123, 117, 133, 130, 129, 73, 71, 70, 31, 32, 32, 17, 18, 20, 17, 12, 18, 15, 11, 16, 13, 10, 14, 12, 10, 14, 10, 10, 14, 12, 16, 16, 19, 25, 24, 18, 24, 25, 13, 21, 18, 12, 22, 16, 15, 28, 17, 23, 40, 22, 29, 39, 37, 12, 21, 20, 33, 44, 27, 58, 68, 36, 75, 83, 47, 107, 117, 66, 113, 124, 65, 114, 124, 61, 123, 134, 66, 120, 132, 65, 113, 126, 58, 120, 133, 67, 128, 138, 74, 125, 137, 76, 124, 135, 77, 109, 113, 80, 90, 87, 80, 51, 50, 48, 17, 21, 21, 12, 15, 17, 13, 15, 18, 15, 17, 19, 15, 18, 18, 14, 19, 18, 12, 19, 16, 12, 20, 15, 13, 21, 16, 13, 22, 17, 13, 26, 18, 16, 30, 20, 17, 34, 22, 22, 40, 24, 9, 20, 31, 11, 20, 29, 42, 49, 31, 63, 73, 42, 60, 69, 40, 70, 79, 43, 97, 107, 55, 119, 128, 67, 120, 132, 64, 117, 132, 64, 118, 129, 69, 122, 135, 76, 127, 140, 76, 124, 140, 76, 128, 140, 76, 126, 137, 80, 103, 114, 67, 68, 76, 48, 33, 42, 29, 22, 31, 24, 17, 26, 21, 17, 27, 21, 17, 27, 19, 19, 31, 21, 17, 31, 22, 18, 31, 22, 20, 33, 23, 21, 35, 24, 21, 37, 25, 24, 40, 27, 27, 43, 28, 28, 46, 28, 4, 19, 34, 9, 21, 31, 38, 47, 32, 61, 72, 41, 59, 72, 39, 59, 69, 39, 70, 80, 43, 106, 117, 64, 123, 134, 69, 115, 129, 65, 120, 134, 75, 119, 133, 76, 115, 130, 67, 116, 132, 66, 121, 133, 70, 128, 140, 83, 125, 138, 80, 111, 127, 69, 101, 116, 70, 79, 93, 53, 58, 73, 41, 47, 65, 39, 42, 57, 36, 32, 46, 31, 27, 43, 30, 25, 41, 29, 26, 41, 29, 29, 44, 30, 30, 47, 31, 33, 50, 32, 35, 52, 33, 35, 51, 32], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387536}, {\"format\": \"raw\", \"value\": [205, 193, 195, 200, 187, 193, 202, 190, 193, 173, 162, 159, 131, 121, 113, 130, 119, 113, 169, 158, 152, 220, 209, 203, 229, 218, 213, 221, 210, 204, 194, 183, 177, 209, 199, 193, 200, 189, 183, 185, 172, 166, 174, 158, 153, 191, 172, 168, 197, 177, 173, 201, 183, 176, 202, 185, 177, 198, 181, 171, 206, 190, 178, 200, 184, 171, 205, 189, 176, 204, 190, 178, 193, 179, 167, 197, 183, 170, 220, 206, 193, 230, 217, 203, 234, 221, 207, 239, 226, 207, 222, 209, 192, 208, 194, 179, 135, 123, 124, 144, 132, 135, 151, 139, 141, 104, 93, 89, 92, 82, 73, 91, 80, 73, 89, 78, 72, 156, 145, 139, 226, 215, 209, 212, 201, 195, 202, 191, 185, 210, 199, 193, 205, 194, 188, 216, 203, 197, 205, 190, 185, 200, 183, 179, 204, 186, 181, 190, 173, 163, 187, 170, 160, 196, 179, 170, 209, 192, 183, 203, 186, 179, 218, 201, 194, 197, 182, 176, 190, 176, 167, 207, 193, 182, 216, 202, 188, 222, 209, 191, 224, 211, 193, 224, 211, 193, 226, 213, 196, 223, 210, 193, 151, 140, 140, 75, 63, 65, 111, 100, 100, 123, 113, 107, 125, 115, 105, 115, 103, 95, 107, 95, 87, 117, 105, 97, 196, 183, 176, 209, 196, 189, 166, 154, 146, 183, 172, 166, 213, 201, 195, 204, 192, 186, 194, 180, 175, 191, 178, 172, 188, 174, 167, 180, 166, 151, 184, 170, 156, 171, 156, 146, 189, 174, 167, 207, 192, 187, 203, 187, 185, 200, 185, 182, 201, 186, 180, 207, 193, 183, 227, 214, 198, 220, 208, 188, 208, 196, 175, 204, 191, 174, 206, 193, 176, 207, 195, 176, 219, 207, 206, 184, 172, 173, 114, 103, 102, 96, 86, 79, 46, 36, 29, 79, 66, 57, 101, 87, 78, 90, 76, 67, 134, 120, 111, 207, 193, 184, 181, 168, 160, 192, 180, 174, 205, 195, 189, 198, 187, 181, 205, 193, 187, 225, 214, 208, 232, 221, 213, 212, 200, 185, 195, 182, 169, 207, 194, 185, 226, 212, 207, 239, 225, 223, 221, 206, 206, 232, 217, 216, 245, 231, 225, 237, 223, 213, 246, 234, 218, 223, 210, 190, 213, 201, 178, 225, 212, 195, 205, 192, 175, 203, 190, 171, 215, 204, 202, 200, 188, 188, 159, 148, 146, 111, 100, 93, 98, 87, 76, 109, 94, 85, 94, 78, 70, 77, 61, 53, 87, 71, 63, 193, 176, 168, 214, 199, 190, 219, 206, 200, 211, 199, 193, 223, 213, 207, 236, 227, 220, 243, 235, 228, 222, 214, 206, 191, 181, 170, 212, 201, 191, 228, 217, 209, 235, 223, 218, 204, 192, 189, 226, 213, 210, 248, 234, 230, 243, 229, 222, 232, 218, 207, 203, 190, 175, 166, 153, 134, 190, 178, 158, 209, 196, 179, 201, 188, 171, 213, 200, 182, 199, 188, 184, 201, 189, 188, 200, 189, 185, 110, 100, 91, 97, 86, 72, 90, 74, 64, 81, 64, 55, 85, 68, 59, 77, 60, 51, 187, 170, 161, 219, 203, 194, 206, 193, 186, 207, 195, 189, 216, 206, 200, 224, 217, 209, 223, 218, 210, 202, 197, 189, 199, 189, 183, 222, 211, 207, 231, 220, 215, 227, 216, 210, 202, 191, 185, 208, 197, 190, 218, 204, 195, 212, 198, 187, 197, 183, 171, 176, 162, 149, 168, 155, 139, 186, 173, 157, 214, 201, 184, 209, 196, 178, 212, 199, 183, 206, 195, 190, 213, 202, 200, 220, 209, 205, 130, 120, 110, 77, 66, 52, 88, 72, 61, 82, 65, 55, 83, 66, 56, 71, 54, 44, 129, 112, 102, 192, 176, 166, 218, 205, 198, 221, 209, 203, 220, 211, 204, 229, 223, 214, 227, 224, 214, 208, 205, 197, 207, 196, 195, 219, 207, 206, 224, 213, 209, 204, 193, 187, 205, 195, 186, 209, 198, 187, 217, 204, 190, 198, 184, 170, 197, 183, 170, 206, 192, 180, 222, 208, 197, 224, 210, 197, 220, 207, 188, 226, 213, 195, 231, 217, 203, 222, 211, 205, 213, 202, 198, 218, 207, 204, 156, 146, 140, 63, 51, 46, 84, 65, 60, 115, 95, 91, 106, 86, 82, 93, 73, 69, 87, 67, 63, 110, 90, 87, 179, 164, 160, 232, 220, 215, 220, 208, 203, 223, 211, 208, 221, 211, 208, 211, 202, 198, 211, 198, 197, 218, 204, 202, 214, 201, 194, 214, 202, 190, 217, 206, 191, 227, 215, 198, 234, 221, 202, 226, 213, 194, 226, 213, 195, 228, 214, 200, 227, 213, 199, 235, 221, 206, 231, 217, 197, 224, 210, 193, 222, 207, 195, 212, 201, 195, 187, 176, 172, 198, 187, 185, 171, 160, 159, 111, 98, 97, 101, 82, 78, 135, 114, 110, 117, 96, 93, 89, 68, 65, 86, 65, 61, 80, 59, 56, 92, 76, 71, 159, 145, 139, 215, 200, 196, 232, 216, 213, 226, 211, 208, 224, 208, 206, 222, 207, 204, 213, 199, 192, 209, 195, 184, 224, 211, 196, 227, 215, 195, 234, 222, 199, 241, 229, 205, 231, 220, 196, 222, 209, 188, 214, 201, 182, 223, 210, 193, 221, 208, 191, 199, 185, 168, 205, 191, 175, 211, 196, 186, 211, 200, 194, 182, 171, 167, 199, 189, 186, 164, 153, 152, 122, 109, 107, 148, 133, 121, 127, 111, 98, 106, 89, 76, 90, 74, 61, 82, 66, 53, 83, 67, 54, 85, 72, 60, 85, 72, 60, 130, 117, 106, 200, 187, 177, 223, 210, 200, 215, 201, 193, 207, 192, 187, 205, 190, 183, 221, 207, 196, 231, 218, 203, 222, 209, 190, 222, 210, 188, 223, 211, 188, 209, 197, 175, 194, 182, 163, 188, 176, 158, 216, 203, 187, 217, 205, 189, 201, 191, 176, 199, 189, 176, 210, 199, 190, 216, 205, 199, 221, 210, 206, 217, 206, 204, 161, 149, 148, 157, 145, 143, 132, 120, 106, 99, 87, 71, 94, 82, 66, 92, 80, 64, 74, 62, 46, 69, 57, 42, 88, 76, 65, 92, 80, 68, 89, 77, 65, 103, 91, 79, 144, 132, 120, 198, 186, 175, 227, 213, 206, 223, 209, 201, 196, 182, 171, 214, 200, 186, 223, 210, 193, 217, 205, 186, 214, 203, 182, 204, 193, 174, 202, 191, 173, 210, 199, 183, 219, 207, 194, 215, 204, 191, 202, 194, 183, 202, 193, 185, 210, 201, 196, 220, 209, 203, 222, 211, 207, 209, 198, 196, 156, 145, 144, 148, 136, 135, 125, 115, 107, 100, 90, 81, 76, 66, 57, 78, 68, 59, 84, 75, 65, 73, 63, 55, 60, 47, 47, 98, 84, 83, 117, 104, 102, 113, 100, 96, 85, 72, 66, 109, 96, 90, 184, 171, 162, 241, 227, 217, 227, 213, 202, 217, 203, 189, 218, 205, 188, 220, 208, 191, 229, 218, 201, 225, 214, 196, 221, 209, 194, 216, 204, 191, 213, 202, 190, 209, 198, 188, 210, 202, 195, 187, 180, 174, 198, 191, 187, 215, 204, 198, 220, 209, 205, 213, 202, 200, 156, 144, 144, 111, 99, 99, 115, 105, 106, 100, 90, 91, 72, 62, 63, 77, 67, 68, 84, 75, 75, 84, 73, 76, 107, 95, 104, 110, 97, 106, 100, 88, 94, 102, 90, 93, 93, 82, 82, 102, 90, 88, 121, 107, 98, 131, 117, 105, 199, 185, 173, 224, 210, 197, 218, 204, 189, 220, 208, 192, 227, 218, 201, 224, 215, 200, 216, 206, 194, 218, 208, 198, 216, 206, 197, 199, 190, 182, 207, 199, 194, 194, 186, 182, 207, 199, 196, 213, 202, 196, 216, 205, 200, 221, 210, 208, 171, 160, 159, 87, 75, 76, 99, 87, 91, 103, 91, 95, 90, 78, 82, 101, 90, 94, 105, 93, 97, 110, 98, 104, 98, 87, 96, 67, 56, 64, 83, 72, 77, 49, 40, 40, 77, 68, 65, 118, 108, 102, 125, 112, 99, 132, 118, 105, 134, 120, 107, 151, 137, 124, 195, 181, 169, 231, 218, 205, 230, 222, 208, 214, 206, 194, 215, 207, 196, 216, 207, 198, 226, 217, 210, 216, 207, 201, 221, 211, 206, 220, 210, 205, 203, 193, 188, 218, 207, 201, 222, 211, 207, 222, 211, 208, 194, 183, 182, 98, 86, 86, 60, 47, 47, 62, 48, 48, 52, 38, 38, 51, 37, 37, 62, 48, 48, 60, 47, 47, 76, 65, 66, 74, 64, 63, 62, 54, 48, 82, 74, 62, 105, 98, 82, 103, 95, 78, 78, 65, 54, 111, 97, 84, 110, 96, 83, 113, 99, 87, 105, 91, 80, 145, 132, 121, 213, 205, 194, 220, 212, 201, 223, 215, 205, 233, 225, 218, 225, 217, 212, 222, 213, 208, 215, 202, 196, 223, 209, 202, 222, 208, 201, 215, 204, 198, 202, 191, 187, 207, 196, 193, 216, 205, 204, 151, 139, 137, 76, 61, 54, 60, 46, 37, 42, 27, 18, 51, 36, 26, 69, 55, 45, 72, 58, 49, 73, 65, 56, 72, 64, 52, 86, 78, 62, 100, 92, 72, 90, 84, 59, 90, 83, 59, 108, 97, 79, 106, 93, 77, 99, 86, 71, 97, 84, 71, 80, 66, 55, 51, 38, 29, 77, 69, 59, 169, 160, 151, 213, 204, 197, 205, 196, 189, 215, 206, 203, 211, 200, 196, 197, 181, 174, 201, 185, 177, 208, 192, 183, 215, 204, 198, 201, 190, 184, 194, 183, 178, 199, 188, 183, 196, 184, 179, 114, 99, 89, 83, 67, 52, 79, 65, 45, 88, 74, 52, 93, 78, 58, 88, 74, 59, 87, 76, 66, 105, 91, 79, 114, 98, 81, 93, 77, 59, 87, 74, 56, 68, 59, 39, 78, 70, 45, 92, 82, 58, 105, 95, 75, 104, 93, 79, 99, 87, 77, 107, 95, 87, 98, 84, 79, 161, 148, 143, 212, 198, 195, 216, 202, 198, 211, 197, 194, 218, 204, 200, 194, 179, 171, 186, 172, 163, 168, 154, 145, 216, 205, 199, 206, 195, 189, 200, 189, 183, 215, 204, 198, 222, 210, 204, 195, 179, 171, 112, 96, 82, 103, 88, 67, 105, 90, 68, 111, 96, 76, 102, 88, 72, 139, 127, 118, 144, 128, 115, 147, 129, 110, 146, 128, 109, 140, 125, 107, 112, 101, 82, 97, 86, 61, 105, 93, 70, 125, 112, 94, 151, 137, 124, 159, 145, 135, 144, 130, 123, 128, 113, 109, 138, 123, 119, 145, 130, 126, 160, 145, 141, 200, 185, 180, 221, 206, 201, 209, 194, 187, 211, 197, 190, 204, 189, 182, 218, 207, 201, 211, 200, 194, 216, 205, 199, 215, 204, 198, 213, 201, 195, 224, 207, 201, 188, 171, 161, 136, 120, 104, 119, 103, 85, 127, 111, 95, 126, 112, 98, 139, 127, 116, 156, 141, 125, 158, 140, 120, 168, 151, 128, 150, 136, 114, 136, 124, 104, 129, 114, 92, 110, 94, 74, 114, 98, 82, 163, 146, 134, 183, 165, 157, 188, 171, 164, 178, 163, 158, 161, 146, 141, 124, 109, 104, 107, 92, 87, 117, 102, 97, 150, 135, 130, 186, 171, 167, 210, 195, 191, 230, 215, 211, 220, 209, 203, 214, 203, 197, 214, 203, 197, 214, 203, 197, 216, 204, 198, 221, 206, 202, 227, 212, 203, 215, 201, 186, 166, 152, 136, 156, 141, 128, 132, 118, 107, 113, 102, 89, 152, 137, 120, 165, 147, 125, 154, 137, 112, 154, 140, 118, 147, 135, 115, 131, 114, 96, 128, 109, 94, 153, 134, 120, 163, 144, 133, 175, 155, 147, 197, 177, 171, 200, 184, 178, 195, 180, 173, 197, 182, 175, 181, 166, 159, 166, 151, 144, 147, 132, 127, 127, 111, 110, 127, 111, 110, 149, 134, 133, 215, 204, 198, 214, 203, 197, 213, 202, 196, 212, 201, 195, 220, 208, 203, 225, 211, 207, 217, 203, 195, 227, 214, 200, 235, 223, 207, 215, 202, 188, 181, 169, 159, 140, 128, 116, 149, 134, 117, 160, 143, 121, 162, 145, 121, 166, 152, 130, 170, 158, 138, 191, 172, 158, 203, 183, 171, 213, 193, 181, 204, 184, 175, 206, 186, 179, 220, 201, 194, 213, 197, 189, 202, 188, 179, 198, 183, 175, 209, 194, 186, 208, 193, 185, 219, 204, 197, 213, 197, 197, 175, 159, 159, 142, 125, 126, 209, 198, 192, 173, 162, 156, 142, 131, 125, 173, 162, 156, 210, 199, 193, 215, 204, 198, 220, 209, 198, 228, 218, 201, 230, 220, 202, 230, 221, 204, 228, 218, 204, 218, 207, 197, 176, 160, 147, 142, 124, 105, 171, 153, 133, 227, 212, 193, 221, 208, 192, 220, 202, 191, 220, 202, 191, 194, 176, 165, 183, 164, 154, 190, 171, 162, 206, 188, 179, 212, 197, 188, 201, 187, 178, 188, 174, 165, 198, 184, 175, 174, 160, 151, 186, 171, 163, 201, 186, 183, 210, 194, 192, 217, 201, 199, 204, 193, 187, 154, 143, 137, 147, 136, 130, 192, 181, 175, 215, 204, 198, 220, 210, 201, 216, 207, 193, 215, 207, 186, 221, 213, 191, 212, 204, 183, 208, 199, 183, 207, 195, 189, 216, 199, 191, 152, 133, 120, 165, 146, 131, 215, 200, 186, 210, 197, 186, 210, 195, 186, 216, 200, 191, 213, 197, 188, 217, 201, 191, 215, 199, 189, 215, 200, 189, 211, 197, 186, 216, 202, 192, 212, 198, 187, 217, 203, 193, 203, 189, 178, 155, 141, 132, 191, 176, 170, 204, 189, 183, 208, 193, 187, 218, 207, 201, 223, 212, 205, 229, 218, 212, 207, 196, 190, 198, 187, 180, 215, 205, 193, 219, 211, 193, 221, 213, 189, 221, 214, 187, 202, 195, 171, 219, 210, 193, 222, 209, 206, 196, 179, 174, 137, 117, 108, 166, 147, 137, 217, 201, 192, 208, 196, 188, 208, 196, 188, 209, 197, 188, 212, 199, 190, 209, 197, 187, 214, 202, 190, 216, 204, 192, 216, 202, 191, 206, 192, 181, 186, 172, 161, 205, 191, 180, 218, 204, 193, 195, 181, 170, 185, 171, 163, 208, 194, 186, 196, 182, 174, 226, 212, 203, 221, 208, 198, 213, 202, 191, 202, 193, 179, 180, 172, 157, 195, 185, 166, 217, 207, 185, 228, 217, 193, 223, 211, 186, 215, 202, 179, 217, 203, 185, 201, 186, 183, 136, 117, 115, 123, 103, 98, 180, 160, 153, 219, 200, 193, 218, 201, 194, 215, 202, 195, 212, 199, 192, 210, 197, 190, 200, 187, 179, 208, 195, 187, 216, 202, 194, 215, 200, 191, 212, 196, 188, 211, 195, 187, 214, 199, 190, 211, 195, 186, 206, 191, 182, 192, 177, 169, 191, 175, 168, 187, 171, 166, 228, 211, 199, 223, 210, 194, 223, 211, 195, 213, 206, 185, 197, 190, 168, 211, 200, 177, 217, 204, 182, 227, 212, 192, 208, 191, 172, 210, 191, 173, 205, 186, 172, 152, 132, 131, 175, 154, 154, 166, 146, 144, 194, 174, 170, 193, 172, 167, 175, 155, 149, 170, 154, 149, 159, 144, 139, 161, 146, 141, 140, 125, 120, 142, 127, 122, 148, 132, 127, 142, 126, 120, 144, 127, 121, 166, 149, 143, 156, 140, 134, 147, 131, 125, 154, 137, 131, 137, 120, 115, 104, 87, 84, 110, 93, 93, 226, 209, 197, 215, 201, 186, 205, 194, 177, 193, 185, 165, 210, 203, 181, 217, 205, 185, 217, 202, 184, 217, 200, 186, 213, 195, 184, 195, 174, 167, 138, 115, 112, 108, 84, 87, 162, 138, 141, 118, 97, 98, 113, 94, 92, 105, 88, 83, 87, 71, 65, 88, 73, 68, 87, 73, 67, 94, 80, 74, 105, 91, 85, 127, 113, 108, 146, 132, 127, 155, 142, 138, 166, 153, 149, 185, 172, 168, 190, 177, 173, 178, 165, 162, 193, 181, 177, 202, 189, 187, 185, 171, 171, 186, 173, 174, 200, 184, 173, 196, 182, 167, 210, 199, 182, 218, 209, 189, 219, 209, 189, 198, 185, 167, 183, 167, 152, 185, 167, 158, 150, 129, 128, 133, 108, 114, 63, 36, 45, 116, 88, 96, 120, 94, 99, 85, 63, 65, 92, 75, 74, 104, 92, 88, 147, 136, 131, 164, 152, 146, 178, 165, 159, 185, 172, 166, 192, 179, 173, 210, 197, 191, 200, 188, 183, 188, 179, 177, 207, 198, 197, 225, 216, 215, 223, 214, 213, 226, 218, 216, 226, 217, 216, 224, 215, 215, 227, 217, 219, 227, 218, 220, 192, 179, 166, 204, 191, 175, 218, 205, 189, 219, 208, 189, 221, 209, 190, 215, 199, 183, 186, 168, 157, 114, 94, 91, 63, 39, 45, 95, 68, 82, 97, 68, 85, 152, 121, 132, 121, 95, 101, 127, 107, 109, 169, 155, 154, 212, 204, 199, 237, 230, 223, 248, 236, 230, 234, 221, 215, 207, 194, 188, 214, 202, 196, 220, 208, 202, 226, 215, 210, 234, 228, 227, 244, 238, 238, 246, 241, 240, 231, 225, 225, 226, 221, 220, 215, 209, 209, 205, 200, 202, 225, 219, 221, 212, 206, 208, 212, 201, 188, 219, 207, 192, 210, 197, 181, 219, 206, 188, 218, 204, 185, 190, 172, 158, 122, 103, 93, 93, 72, 69, 81, 56, 62, 102, 74, 87, 138, 108, 124, 130, 102, 109, 148, 123, 127, 201, 183, 182, 238, 225, 222, 237, 228, 221, 231, 224, 215, 230, 220, 214, 226, 215, 209, 213, 203, 196, 224, 213, 207, 228, 217, 211, 227, 218, 212, 233, 229, 226, 242, 238, 236, 249, 245, 243, 252, 247, 246, 243, 239, 237, 237, 233, 231, 231, 226, 227, 226, 221, 222, 235, 230, 230, 230, 220, 207, 242, 231, 215, 232, 218, 202, 228, 213, 195, 228, 213, 194, 216, 197, 184, 172, 152, 142, 159, 136, 131, 160, 134, 136, 155, 127, 133, 140, 112, 120, 174, 152, 153, 227, 208, 206, 241, 225, 220, 235, 223, 215, 234, 224, 214, 237, 229, 218, 238, 229, 221, 232, 223, 216, 233, 224, 217, 229, 220, 213, 230, 221, 214, 234, 225, 219, 243, 237, 232, 247, 242, 237, 247, 242, 237, 240, 235, 230, 235, 230, 225, 234, 229, 225, 229, 223, 222, 216, 210, 208, 213, 207, 203, 241, 232, 218, 244, 232, 217, 234, 221, 205, 215, 198, 181, 209, 192, 174, 210, 191, 177, 204, 183, 171, 201, 178, 169, 179, 153, 148, 152, 123, 120, 177, 151, 148, 226, 210, 204, 234, 220, 212, 235, 222, 212, 221, 209, 197, 227, 215, 201, 237, 226, 213, 229, 220, 213, 228, 219, 212, 241, 232, 225, 235, 226, 219, 224, 216, 208, 228, 219, 212, 247, 240, 232, 245, 238, 230, 241, 234, 226, 229, 222, 214, 232, 224, 217, 235, 228, 221, 230, 222, 219, 220, 213, 208, 223, 216, 208], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387600}, {\"format\": \"raw\", \"value\": [154, 145, 135, 152, 144, 135, 157, 146, 136, 152, 138, 125, 131, 100, 76, 171, 125, 86, 164, 112, 67, 154, 92, 49, 141, 111, 85, 112, 140, 137, 101, 155, 160, 106, 158, 158, 99, 135, 134, 112, 144, 146, 136, 192, 195, 139, 209, 211, 132, 200, 201, 114, 183, 182, 115, 182, 180, 115, 176, 175, 117, 172, 173, 112, 164, 166, 85, 138, 145, 80, 130, 139, 87, 134, 134, 66, 107, 96, 42, 80, 59, 40, 73, 49, 34, 60, 36, 33, 57, 31, 31, 58, 29, 30, 58, 32, 157, 148, 138, 155, 147, 138, 160, 149, 139, 154, 139, 126, 134, 103, 80, 175, 128, 93, 166, 114, 71, 161, 99, 54, 153, 125, 95, 124, 153, 145, 120, 172, 180, 127, 185, 190, 132, 185, 189, 148, 195, 206, 140, 198, 214, 152, 209, 220, 148, 199, 204, 122, 179, 184, 119, 177, 184, 126, 181, 191, 151, 201, 212, 143, 195, 201, 106, 161, 169, 99, 153, 162, 99, 150, 152, 78, 123, 116, 53, 95, 79, 44, 83, 65, 35, 68, 48, 28, 58, 36, 25, 55, 29, 24, 52, 30, 157, 147, 137, 155, 147, 137, 159, 148, 138, 152, 138, 124, 133, 103, 81, 174, 128, 95, 163, 113, 71, 160, 100, 55, 157, 131, 99, 117, 145, 134, 114, 157, 164, 119, 175, 179, 127, 188, 191, 153, 206, 218, 151, 204, 224, 167, 216, 229, 161, 208, 212, 138, 195, 203, 142, 203, 212, 144, 201, 213, 153, 205, 216, 131, 185, 192, 101, 158, 165, 100, 158, 164, 99, 154, 157, 82, 132, 128, 69, 116, 107, 54, 101, 87, 38, 82, 65, 30, 68, 49, 28, 60, 38, 24, 50, 30, 157, 148, 138, 155, 147, 138, 159, 149, 139, 152, 137, 123, 135, 105, 83, 177, 133, 99, 163, 114, 72, 159, 100, 54, 148, 124, 92, 104, 132, 121, 102, 139, 144, 102, 154, 156, 115, 176, 177, 148, 200, 209, 157, 208, 223, 168, 221, 229, 159, 219, 221, 142, 212, 216, 146, 219, 222, 141, 207, 208, 131, 188, 189, 113, 170, 173, 96, 156, 160, 95, 157, 159, 90, 151, 150, 74, 131, 127, 67, 120, 113, 51, 106, 95, 34, 90, 73, 36, 85, 64, 35, 69, 48, 29, 54, 33, 157, 148, 138, 155, 147, 138, 160, 149, 139, 150, 135, 122, 135, 106, 82, 181, 138, 100, 168, 120, 75, 166, 109, 63, 143, 119, 89, 95, 124, 117, 103, 143, 149, 112, 164, 169, 125, 183, 188, 148, 201, 209, 154, 211, 219, 149, 215, 217, 139, 213, 212, 123, 205, 204, 133, 214, 208, 131, 200, 184, 130, 187, 170, 122, 180, 177, 106, 170, 168, 95, 161, 157, 84, 150, 145, 73, 135, 130, 62, 120, 114, 46, 108, 97, 35, 102, 83, 38, 96, 72, 31, 68, 46, 27, 52, 30, 157, 148, 138, 155, 147, 137, 160, 150, 139, 149, 134, 121, 135, 106, 80, 184, 142, 100, 173, 126, 79, 176, 118, 72, 149, 125, 98, 100, 130, 127, 111, 159, 170, 122, 180, 190, 126, 187, 197, 134, 194, 204, 133, 203, 208, 135, 213, 212, 135, 215, 213, 118, 202, 198, 124, 205, 191, 114, 178, 149, 99, 151, 119, 107, 165, 153, 93, 159, 151, 84, 154, 144, 83, 152, 141, 76, 141, 133, 66, 129, 122, 54, 122, 109, 45, 119, 98, 28, 91, 66, 24, 63, 39, 25, 50, 28, 159, 147, 139, 157, 146, 138, 158, 151, 139, 146, 134, 118, 138, 108, 81, 189, 147, 105, 178, 129, 80, 180, 120, 74, 152, 129, 105, 108, 144, 145, 114, 168, 177, 117, 179, 186, 116, 183, 187, 118, 187, 189, 115, 192, 190, 124, 199, 199, 130, 191, 196, 93, 151, 151, 98, 167, 150, 107, 172, 137, 71, 123, 78, 76, 132, 88, 76, 139, 117, 71, 142, 127, 67, 139, 121, 65, 130, 119, 66, 128, 120, 55, 128, 111, 45, 125, 100, 27, 88, 63, 19, 53, 30, 21, 44, 23, 160, 146, 140, 158, 145, 139, 157, 152, 138, 145, 133, 116, 141, 109, 84, 192, 149, 109, 180, 129, 81, 181, 122, 74, 153, 135, 110, 108, 151, 153, 111, 170, 175, 114, 174, 175, 107, 170, 169, 108, 171, 167, 98, 162, 156, 97, 150, 146, 83, 116, 118, 53, 90, 88, 68, 136, 115, 76, 155, 121, 65, 128, 80, 58, 113, 48, 64, 125, 90, 67, 137, 120, 61, 134, 114, 60, 126, 115, 61, 124, 114, 50, 126, 106, 43, 128, 99, 35, 96, 69, 23, 55, 33, 23, 47, 24, 160, 146, 140, 158, 145, 138, 157, 153, 138, 145, 133, 116, 143, 110, 85, 193, 149, 109, 182, 133, 87, 181, 127, 80, 151, 138, 111, 105, 154, 151, 104, 168, 169, 109, 166, 166, 99, 146, 145, 68, 105, 103, 53, 83, 80, 52, 69, 62, 59, 68, 59, 49, 85, 71, 46, 128, 99, 39, 134, 99, 49, 121, 79, 53, 109, 47, 55, 115, 76, 56, 125, 108, 56, 130, 114, 53, 123, 113, 55, 121, 108, 46, 125, 100, 37, 125, 93, 33, 99, 68, 24, 64, 38, 21, 48, 24, 160, 146, 140, 157, 145, 138, 157, 153, 138, 144, 133, 116, 145, 112, 87, 195, 150, 112, 184, 138, 93, 183, 134, 87, 149, 140, 111, 98, 149, 141, 100, 162, 159, 103, 151, 148, 66, 95, 94, 43, 54, 54, 56, 54, 54, 46, 39, 35, 43, 41, 32, 46, 82, 63, 37, 125, 88, 31, 127, 84, 43, 110, 63, 47, 100, 39, 46, 104, 61, 46, 112, 91, 50, 121, 108, 46, 118, 106, 47, 114, 96, 39, 120, 88, 37, 128, 90, 32, 103, 68, 19, 66, 35, 21, 54, 27, 160, 146, 140, 158, 145, 138, 157, 152, 138, 143, 131, 114, 148, 114, 89, 198, 154, 116, 185, 141, 97, 183, 135, 90, 147, 137, 107, 94, 140, 129, 97, 149, 143, 77, 110, 107, 44, 54, 55, 64, 55, 59, 85, 67, 71, 52, 38, 42, 25, 25, 25, 30, 65, 49, 36, 118, 77, 34, 116, 62, 45, 97, 42, 41, 90, 31, 36, 92, 44, 44, 105, 78, 48, 113, 100, 39, 107, 90, 39, 104, 77, 32, 110, 74, 35, 126, 84, 35, 108, 69, 22, 74, 39, 23, 60, 30, 160, 146, 140, 158, 145, 138, 157, 152, 138, 141, 130, 113, 150, 117, 92, 202, 160, 122, 185, 142, 100, 185, 136, 93, 147, 132, 103, 87, 123, 112, 61, 96, 90, 40, 55, 53, 48, 45, 49, 90, 75, 83, 118, 101, 109, 70, 60, 68, 26, 24, 30, 17, 43, 32, 34, 102, 63, 32, 101, 45, 43, 86, 28, 41, 89, 33, 35, 88, 35, 46, 100, 67, 50, 105, 90, 38, 96, 71, 38, 98, 63, 28, 103, 63, 29, 119, 73, 33, 107, 64, 20, 73, 36, 20, 61, 28, 160, 146, 140, 157, 145, 138, 157, 152, 138, 140, 128, 112, 152, 119, 93, 203, 161, 124, 185, 143, 101, 189, 139, 98, 148, 126, 99, 57, 80, 70, 29, 45, 41, 45, 45, 45, 52, 42, 48, 75, 62, 71, 102, 95, 104, 91, 85, 91, 53, 44, 47, 19, 31, 23, 23, 76, 44, 29, 92, 42, 38, 84, 32, 39, 88, 34, 37, 89, 32, 48, 96, 58, 51, 97, 77, 40, 90, 57, 40, 94, 53, 32, 103, 61, 27, 114, 65, 35, 107, 63, 26, 79, 40, 25, 69, 34, 159, 147, 139, 155, 146, 137, 158, 151, 138, 142, 127, 111, 154, 118, 93, 205, 158, 120, 184, 143, 102, 178, 139, 102, 122, 102, 82, 26, 31, 30, 39, 41, 48, 56, 51, 57, 42, 34, 37, 38, 31, 33, 52, 51, 53, 80, 80, 78, 80, 69, 68, 37, 33, 32, 18, 58, 37, 22, 81, 37, 36, 83, 32, 37, 87, 36, 36, 83, 31, 48, 89, 48, 49, 90, 59, 41, 88, 48, 38, 91, 49, 37, 98, 55, 35, 106, 58, 47, 103, 61, 31, 75, 40, 23, 58, 28, 158, 148, 137, 152, 148, 137, 158, 151, 138, 142, 124, 109, 155, 121, 98, 194, 152, 120, 139, 107, 75, 92, 70, 47, 49, 38, 29, 20, 16, 23, 67, 62, 79, 81, 74, 88, 36, 31, 37, 23, 18, 19, 26, 22, 21, 39, 41, 34, 77, 69, 66, 68, 58, 64, 29, 60, 48, 18, 72, 32, 36, 81, 29, 33, 83, 31, 33, 81, 32, 44, 84, 40, 48, 87, 46, 41, 87, 44, 38, 90, 48, 43, 91, 50, 45, 101, 53, 60, 100, 58, 43, 79, 44, 28, 55, 27, 158, 150, 137, 153, 150, 138, 157, 150, 136, 139, 124, 107, 137, 116, 96, 111, 90, 73, 41, 26, 17, 43, 34, 31, 29, 28, 30, 20, 21, 27, 78, 71, 84, 147, 136, 155, 69, 59, 78, 15, 5, 20, 25, 17, 23, 22, 21, 15, 41, 34, 29, 67, 61, 64, 38, 66, 54, 18, 65, 32, 36, 79, 33, 28, 84, 28, 30, 86, 30, 41, 88, 38, 45, 88, 42, 44, 87, 42, 45, 89, 48, 49, 89, 47, 48, 97, 48, 64, 101, 55, 67, 102, 59, 44, 69, 35, 158, 150, 137, 153, 149, 138, 158, 153, 140, 134, 123, 107, 64, 55, 40, 23, 19, 11, 24, 20, 24, 61, 59, 70, 53, 54, 61, 24, 26, 26, 58, 51, 56, 135, 122, 141, 124, 110, 140, 33, 19, 46, 34, 22, 35, 40, 37, 34, 44, 41, 35, 48, 50, 47, 42, 71, 58, 36, 78, 53, 39, 79, 43, 30, 86, 30, 28, 88, 29, 37, 90, 36, 44, 90, 41, 47, 89, 43, 51, 87, 44, 54, 85, 43, 53, 98, 49, 68, 103, 55, 80, 113, 65, 65, 89, 50, 157, 150, 139, 152, 148, 139, 133, 129, 119, 74, 67, 57, 22, 18, 7, 18, 18, 11, 40, 37, 42, 73, 69, 81, 49, 44, 49, 26, 21, 16, 55, 45, 47, 70, 57, 74, 107, 92, 122, 91, 77, 105, 73, 61, 75, 65, 63, 59, 55, 61, 51, 52, 67, 56, 57, 90, 74, 50, 89, 72, 41, 76, 54, 36, 81, 37, 33, 85, 34, 34, 87, 36, 41, 88, 41, 48, 88, 43, 55, 86, 43, 60, 87, 45, 54, 97, 50, 70, 103, 59, 90, 120, 75, 82, 104, 66, 143, 136, 128, 105, 100, 97, 55, 51, 48, 22, 19, 14, 23, 22, 16, 26, 25, 23, 51, 48, 50, 76, 70, 74, 51, 43, 44, 36, 27, 25, 59, 50, 52, 46, 36, 47, 44, 33, 51, 56, 45, 62, 52, 42, 51, 56, 56, 52, 62, 78, 63, 75, 105, 86, 66, 104, 87, 59, 97, 86, 54, 84, 76, 54, 77, 55, 43, 77, 45, 33, 79, 40, 42, 89, 46, 49, 89, 45, 52, 84, 40, 61, 89, 47, 59, 104, 62, 80, 112, 78, 85, 109, 76, 84, 100, 70, 78, 72, 69, 33, 28, 31, 23, 20, 24, 28, 27, 28, 34, 35, 37, 39, 39, 45, 59, 58, 59, 62, 60, 57, 52, 46, 49, 56, 48, 55, 54, 48, 53, 36, 30, 33, 30, 24, 26, 25, 20, 21, 27, 22, 23, 64, 68, 63, 95, 119, 100, 81, 122, 97, 65, 108, 88, 64, 103, 97, 63, 89, 93, 81, 81, 82, 62, 74, 63, 47, 83, 57, 50, 95, 57, 48, 89, 47, 52, 87, 42, 56, 89, 48, 67, 115, 79, 106, 138, 113, 105, 126, 106, 97, 104, 85, 33, 29, 30, 28, 24, 28, 30, 27, 32, 41, 39, 43, 57, 55, 62, 63, 62, 71, 60, 60, 63, 40, 40, 40, 45, 42, 47, 65, 60, 70, 45, 41, 46, 24, 21, 17, 25, 21, 16, 25, 22, 20, 25, 24, 21, 87, 96, 84, 121, 149, 124, 72, 116, 80, 52, 96, 66, 57, 92, 85, 83, 103, 115, 104, 99, 112, 73, 71, 72, 77, 101, 82, 77, 121, 84, 67, 99, 61, 68, 95, 55, 54, 89, 48, 65, 114, 81, 110, 143, 127, 145, 169, 160, 134, 138, 128, 50, 49, 52, 42, 40, 44, 36, 33, 37, 57, 52, 57, 74, 69, 74, 65, 61, 66, 45, 42, 47, 24, 22, 27, 38, 34, 40, 55, 50, 56, 33, 31, 31, 22, 19, 12, 27, 22, 19, 21, 18, 21, 27, 30, 22, 68, 84, 61, 77, 108, 69, 57, 97, 47, 48, 87, 44, 55, 81, 69, 91, 105, 123, 119, 118, 148, 92, 81, 103, 104, 116, 113, 109, 145, 124, 95, 111, 95, 86, 95, 71, 56, 92, 55, 60, 113, 84, 95, 141, 131, 130, 174, 170, 138, 161, 152, 65, 64, 70, 62, 60, 66, 52, 48, 55, 68, 62, 69, 69, 64, 69, 42, 39, 43, 28, 25, 29, 22, 20, 23, 31, 28, 32, 33, 30, 34, 28, 25, 28, 26, 22, 18, 27, 22, 21, 13, 13, 15, 30, 39, 26, 54, 79, 44, 54, 87, 38, 59, 90, 37, 70, 94, 53, 78, 95, 82, 85, 97, 115, 123, 124, 172, 124, 111, 155, 121, 124, 147, 108, 131, 138, 111, 113, 127, 97, 99, 93, 66, 94, 70, 73, 113, 101, 93, 135, 135, 88, 144, 142, 96, 152, 142, 67, 66, 72, 69, 67, 74, 59, 55, 62, 57, 52, 59, 51, 48, 53, 30, 30, 31, 26, 24, 23, 24, 21, 20, 30, 29, 29, 28, 27, 30, 26, 22, 28, 34, 29, 29, 25, 22, 21, 9, 12, 10, 30, 44, 26, 58, 86, 45, 56, 87, 37, 61, 78, 34, 95, 100, 74, 106, 112, 106, 102, 111, 127, 119, 124, 160, 134, 126, 159, 123, 124, 139, 115, 127, 132, 121, 117, 129, 95, 99, 94, 70, 83, 77, 96, 91, 110, 101, 91, 118, 92, 107, 124, 80, 118, 127, 63, 61, 67, 59, 57, 64, 49, 45, 52, 43, 37, 44, 37, 34, 39, 32, 32, 31, 37, 32, 28, 45, 37, 33, 44, 40, 37, 29, 29, 31, 21, 18, 24, 39, 34, 35, 31, 28, 27, 6, 8, 7, 30, 42, 23, 62, 85, 46, 61, 81, 41, 71, 73, 48, 100, 91, 85, 125, 119, 127, 121, 125, 139, 119, 126, 139, 123, 122, 128, 122, 122, 116, 129, 132, 120, 119, 112, 107, 82, 88, 75, 95, 109, 110, 117, 110, 143, 114, 82, 123, 133, 95, 134, 137, 102, 148, 31, 31, 34, 46, 44, 48, 44, 41, 45, 43, 38, 42, 46, 42, 46, 52, 47, 47, 60, 50, 44, 69, 56, 48, 56, 47, 43, 31, 28, 31, 23, 21, 25, 32, 28, 26, 38, 32, 32, 15, 11, 13, 31, 36, 22, 66, 75, 42, 79, 82, 52, 99, 92, 79, 120, 107, 110, 123, 112, 121, 124, 120, 129, 122, 125, 131, 128, 128, 125, 131, 127, 117, 136, 128, 118, 131, 121, 116, 92, 93, 76, 86, 118, 111, 95, 149, 165, 74, 100, 123, 109, 79, 117, 166, 99, 161, 19, 19, 17, 31, 31, 29, 35, 32, 32, 37, 33, 33, 57, 52, 53, 62, 53, 53, 93, 77, 70, 142, 123, 114, 84, 70, 65, 34, 28, 30, 29, 28, 28, 26, 22, 17, 39, 30, 30, 27, 16, 23, 35, 29, 23, 76, 68, 40, 90, 77, 46, 101, 91, 77, 122, 113, 110, 126, 116, 113, 130, 119, 113, 143, 141, 133, 140, 141, 124, 143, 136, 115, 146, 133, 114, 132, 123, 108, 103, 100, 71, 75, 104, 92, 81, 148, 160, 67, 125, 134, 81, 96, 120, 130, 102, 154, 20, 20, 16, 23, 23, 19, 29, 27, 24, 31, 29, 26, 47, 44, 44, 66, 61, 62, 153, 143, 139, 197, 185, 180, 97, 87, 88, 35, 30, 37, 37, 36, 35, 25, 23, 16, 38, 30, 30, 47, 35, 42, 44, 32, 30, 77, 60, 38, 89, 71, 41, 84, 73, 54, 110, 102, 88, 125, 113, 97, 120, 106, 84, 131, 124, 97, 128, 124, 91, 125, 115, 78, 124, 108, 73, 110, 100, 66, 103, 95, 58, 87, 92, 76, 86, 115, 123, 79, 118, 124, 56, 99, 111, 86, 115, 145, 23, 21, 19, 21, 20, 17, 26, 26, 22, 29, 30, 27, 32, 34, 34, 69, 72, 73, 116, 119, 119, 104, 106, 107, 61, 61, 67, 24, 22, 32, 36, 34, 32, 34, 32, 28, 23, 22, 23, 40, 35, 38, 42, 34, 34, 58, 47, 36, 68, 57, 39, 74, 63, 48, 79, 68, 52, 85, 72, 55, 91, 77, 56, 91, 78, 53, 93, 80, 51, 103, 86, 56, 113, 93, 60, 113, 93, 60, 121, 100, 68, 112, 97, 73, 108, 107, 94, 95, 112, 106, 62, 100, 103, 71, 114, 128, 24, 21, 21, 20, 18, 15, 28, 26, 23, 31, 31, 27, 23, 23, 20, 37, 35, 32, 44, 36, 34, 53, 41, 39, 59, 47, 45, 37, 27, 24, 38, 29, 24, 42, 37, 34, 16, 15, 17, 25, 25, 29, 27, 26, 28, 26, 24, 21, 28, 26, 19, 33, 31, 23, 33, 30, 21, 39, 35, 26, 50, 45, 35, 57, 47, 32, 61, 49, 32, 70, 57, 38, 92, 76, 56, 116, 99, 77, 116, 94, 70, 118, 96, 70, 111, 98, 76, 102, 103, 88, 91, 108, 102, 77, 101, 104, 24, 20, 21, 22, 18, 18, 34, 29, 26, 39, 33, 27, 36, 28, 19, 48, 32, 22, 70, 39, 31, 91, 51, 41, 95, 59, 42, 85, 57, 33, 81, 55, 40, 69, 49, 41, 30, 19, 16, 28, 23, 23, 28, 25, 25, 18, 16, 13, 19, 18, 13, 13, 13, 9, 14, 14, 11, 14, 16, 13, 20, 21, 18, 27, 25, 19, 31, 27, 20, 35, 29, 22, 47, 40, 32, 68, 61, 51, 75, 60, 47, 83, 64, 47, 84, 67, 49, 105, 95, 79, 118, 117, 105, 96, 99, 95, 23, 18, 18, 27, 23, 22, 31, 23, 19, 46, 33, 23, 74, 56, 38, 74, 47, 28, 89, 45, 30, 101, 46, 29, 104, 54, 25, 107, 64, 26, 112, 67, 39, 107, 67, 47, 68, 39, 25, 64, 42, 31, 69, 51, 39, 56, 40, 26, 61, 47, 33, 49, 38, 26, 35, 27, 18, 25, 20, 13, 20, 17, 13, 18, 18, 17, 17, 18, 18, 20, 20, 21, 21, 22, 22, 23, 23, 23, 29, 26, 25, 35, 27, 23, 47, 36, 28, 67, 57, 47, 83, 78, 69, 77, 74, 69], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387664}, {\"format\": \"raw\", \"value\": [55, 75, 42, 51, 76, 37, 57, 83, 48, 56, 83, 49, 51, 77, 51, 54, 79, 56, 53, 79, 52, 51, 77, 49, 53, 80, 49, 53, 79, 53, 51, 76, 55, 59, 81, 56, 66, 84, 65, 65, 79, 60, 72, 86, 59, 79, 96, 61, 72, 93, 61, 62, 85, 60, 61, 85, 60, 64, 90, 55, 69, 93, 57, 82, 102, 67, 70, 89, 59, 65, 83, 62, 62, 78, 56, 63, 76, 53, 73, 85, 62, 68, 81, 62, 63, 75, 59, 64, 77, 55, 66, 81, 57, 55, 71, 57, 66, 87, 46, 62, 87, 44, 53, 80, 41, 54, 82, 46, 52, 78, 52, 52, 77, 54, 51, 77, 50, 50, 76, 49, 52, 78, 48, 55, 81, 55, 47, 71, 51, 59, 78, 53, 69, 87, 63, 62, 79, 56, 68, 84, 59, 62, 78, 54, 59, 78, 52, 51, 74, 45, 59, 85, 54, 55, 83, 48, 50, 75, 42, 57, 78, 49, 63, 85, 59, 59, 85, 59, 51, 70, 48, 61, 70, 54, 66, 74, 60, 60, 72, 59, 63, 76, 58, 61, 75, 48, 65, 83, 54, 57, 78, 55, 59, 80, 36, 58, 83, 40, 55, 81, 45, 56, 83, 49, 47, 73, 47, 51, 76, 53, 49, 75, 49, 53, 79, 52, 62, 89, 58, 57, 83, 57, 52, 75, 56, 62, 78, 54, 79, 96, 67, 65, 85, 55, 65, 84, 60, 61, 77, 57, 53, 72, 49, 58, 82, 54, 60, 85, 55, 56, 80, 47, 54, 74, 48, 47, 64, 43, 47, 65, 47, 49, 74, 53, 60, 81, 62, 75, 88, 71, 76, 86, 73, 64, 76, 63, 61, 74, 52, 61, 75, 49, 66, 82, 57, 58, 78, 55, 62, 83, 42, 61, 85, 46, 52, 77, 46, 60, 86, 53, 55, 81, 54, 51, 76, 53, 52, 78, 51, 57, 84, 56, 57, 84, 53, 51, 77, 51, 63, 86, 67, 76, 89, 67, 78, 94, 61, 74, 96, 62, 79, 101, 76, 84, 100, 78, 76, 95, 73, 63, 85, 63, 70, 91, 68, 90, 106, 79, 98, 110, 90, 85, 92, 80, 75, 84, 76, 78, 97, 87, 63, 83, 68, 60, 81, 59, 65, 83, 62, 70, 83, 64, 69, 83, 57, 66, 80, 57, 63, 76, 60, 54, 68, 51, 64, 83, 47, 61, 84, 46, 53, 78, 43, 67, 92, 52, 74, 98, 65, 63, 86, 55, 62, 87, 51, 57, 88, 57, 62, 92, 60, 58, 81, 54, 63, 80, 63, 72, 83, 67, 66, 80, 56, 74, 93, 64, 82, 99, 76, 120, 131, 122, 128, 141, 135, 121, 131, 128, 161, 166, 164, 183, 185, 179, 191, 191, 188, 196, 194, 195, 194, 191, 196, 184, 186, 190, 113, 126, 118, 52, 76, 55, 53, 78, 53, 75, 91, 70, 71, 88, 62, 64, 80, 55, 56, 70, 51, 47, 58, 44, 63, 81, 45, 62, 83, 45, 64, 88, 53, 64, 86, 51, 65, 86, 54, 64, 85, 51, 62, 87, 44, 56, 87, 49, 66, 92, 56, 75, 93, 66, 76, 87, 72, 71, 82, 66, 73, 84, 67, 88, 101, 81, 125, 134, 119, 178, 180, 184, 174, 182, 187, 174, 180, 188, 186, 187, 197, 178, 181, 190, 177, 181, 190, 189, 193, 201, 191, 193, 203, 177, 177, 187, 155, 163, 162, 81, 100, 85, 53, 76, 53, 61, 79, 55, 65, 84, 57, 68, 87, 57, 62, 79, 53, 60, 74, 54, 64, 81, 43, 66, 87, 50, 55, 77, 48, 46, 66, 44, 52, 71, 48, 69, 90, 60, 64, 87, 49, 68, 92, 51, 72, 93, 53, 69, 83, 56, 76, 86, 71, 85, 97, 77, 98, 109, 91, 136, 145, 132, 180, 183, 177, 189, 183, 188, 150, 158, 162, 144, 159, 165, 147, 161, 170, 134, 151, 160, 133, 151, 160, 138, 156, 165, 142, 158, 167, 131, 142, 150, 149, 161, 162, 145, 159, 151, 95, 110, 93, 62, 81, 53, 58, 77, 48, 62, 82, 48, 59, 77, 46, 66, 82, 55, 74, 91, 55, 67, 89, 50, 53, 76, 44, 51, 71, 48, 55, 75, 49, 60, 80, 52, 51, 72, 43, 62, 82, 49, 74, 92, 58, 64, 80, 53, 67, 80, 63, 77, 90, 72, 123, 132, 118, 171, 174, 166, 184, 181, 178, 182, 176, 177, 132, 141, 143, 125, 144, 150, 125, 145, 155, 115, 138, 145, 116, 139, 146, 121, 144, 151, 129, 150, 157, 120, 137, 144, 129, 144, 148, 148, 161, 162, 123, 137, 128, 70, 88, 64, 56, 74, 47, 64, 83, 52, 60, 80, 49, 64, 84, 54, 73, 89, 58, 70, 92, 49, 67, 92, 49, 64, 86, 51, 61, 83, 46, 59, 79, 48, 43, 61, 44, 51, 70, 55, 60, 81, 57, 56, 79, 52, 70, 91, 72, 83, 96, 85, 126, 133, 124, 173, 172, 164, 159, 153, 146, 167, 166, 162, 126, 137, 138, 122, 140, 149, 115, 132, 144, 111, 128, 132, 106, 123, 127, 107, 124, 127, 118, 134, 140, 120, 135, 144, 118, 133, 141, 126, 142, 148, 110, 127, 124, 57, 74, 58, 46, 63, 44, 59, 76, 54, 59, 79, 53, 59, 81, 52, 66, 80, 55, 55, 73, 41, 64, 85, 52, 62, 82, 53, 72, 93, 59, 70, 91, 55, 58, 78, 51, 56, 76, 60, 56, 78, 55, 58, 83, 51, 65, 89, 60, 79, 93, 85, 135, 137, 132, 165, 162, 154, 131, 133, 122, 134, 143, 137, 121, 135, 136, 102, 117, 126, 66, 79, 91, 95, 110, 113, 103, 115, 118, 90, 103, 106, 61, 75, 79, 106, 117, 126, 115, 128, 139, 114, 131, 141, 101, 120, 119, 57, 76, 57, 46, 66, 41, 48, 68, 42, 50, 70, 46, 52, 72, 51, 70, 81, 56, 57, 70, 49, 61, 75, 57, 62, 78, 62, 66, 84, 61, 75, 94, 59, 76, 98, 57, 58, 80, 54, 60, 83, 55, 71, 95, 57, 73, 98, 60, 83, 104, 87, 136, 137, 129, 170, 166, 157, 119, 128, 117, 111, 127, 122, 112, 126, 127, 71, 82, 91, 49, 62, 72, 77, 95, 100, 67, 78, 86, 87, 101, 108, 66, 82, 87, 92, 102, 109, 112, 123, 135, 109, 124, 133, 99, 119, 111, 68, 91, 60, 64, 88, 50, 52, 75, 41, 48, 70, 44, 51, 69, 49, 89, 102, 65, 84, 100, 64, 80, 97, 63, 70, 88, 61, 56, 74, 49, 58, 76, 49, 64, 84, 57, 52, 75, 53, 54, 79, 54, 60, 84, 54, 63, 90, 57, 67, 97, 69, 115, 124, 106, 174, 170, 159, 144, 145, 135, 109, 122, 119, 110, 124, 125, 96, 109, 116, 92, 107, 118, 67, 83, 95, 30, 41, 54, 69, 82, 95, 111, 127, 136, 104, 114, 121, 106, 117, 123, 105, 122, 118, 91, 111, 90, 71, 92, 56, 64, 85, 48, 60, 79, 53, 55, 73, 50, 69, 87, 56, 92, 105, 63, 90, 107, 63, 81, 99, 56, 72, 91, 59, 56, 74, 50, 46, 62, 45, 46, 63, 50, 46, 66, 51, 50, 70, 53, 52, 72, 53, 48, 71, 48, 66, 92, 66, 118, 128, 108, 188, 183, 169, 170, 164, 154, 113, 121, 119, 109, 121, 123, 117, 131, 138, 111, 128, 139, 61, 77, 91, 32, 42, 58, 51, 64, 79, 110, 126, 136, 106, 116, 121, 99, 111, 113, 98, 116, 105, 74, 94, 68, 72, 90, 55, 63, 81, 48, 64, 80, 59, 66, 81, 61, 80, 96, 61, 79, 91, 58, 73, 90, 51, 73, 91, 52, 57, 75, 48, 58, 75, 55, 61, 78, 65, 56, 71, 63, 69, 80, 71, 86, 96, 86, 107, 117, 108, 114, 124, 115, 145, 152, 145, 185, 185, 176, 211, 201, 189, 180, 168, 157, 123, 128, 126, 102, 113, 116, 106, 123, 130, 102, 123, 131, 59, 77, 85, 41, 52, 63, 51, 64, 74, 95, 112, 117, 103, 113, 114, 101, 113, 117, 107, 124, 120, 79, 97, 81, 70, 85, 59, 64, 80, 51, 63, 78, 56, 65, 77, 59, 70, 82, 59, 117, 124, 103, 83, 95, 68, 78, 95, 62, 69, 87, 62, 81, 95, 78, 97, 107, 98, 116, 124, 120, 160, 162, 160, 189, 190, 190, 199, 201, 201, 199, 199, 202, 208, 201, 209, 212, 202, 204, 217, 205, 195, 179, 168, 156, 120, 125, 124, 104, 115, 118, 100, 116, 122, 84, 103, 109, 69, 85, 87, 76, 86, 90, 76, 88, 92, 87, 102, 104, 100, 111, 111, 103, 116, 121, 113, 129, 133, 88, 105, 97, 73, 88, 67, 76, 92, 63, 81, 97, 67, 78, 90, 69, 69, 77, 65, 175, 170, 163, 118, 123, 108, 88, 104, 76, 90, 106, 80, 150, 155, 141, 184, 180, 179, 195, 191, 197, 194, 193, 200, 195, 195, 201, 198, 197, 202, 203, 200, 206, 208, 203, 209, 217, 206, 207, 217, 205, 198, 159, 156, 145, 109, 117, 118, 104, 114, 116, 99, 110, 113, 95, 106, 108, 93, 103, 103, 98, 107, 106, 100, 110, 109, 96, 106, 107, 94, 105, 107, 103, 118, 120, 113, 131, 136, 91, 112, 97, 71, 89, 63, 78, 98, 61, 73, 93, 53, 69, 84, 56, 65, 74, 61, 171, 168, 170, 167, 171, 166, 141, 150, 132, 143, 146, 133, 198, 194, 190, 188, 185, 190, 168, 173, 181, 155, 164, 171, 171, 173, 179, 202, 195, 201, 215, 205, 210, 205, 199, 202, 217, 205, 206, 212, 201, 195, 162, 162, 153, 109, 119, 120, 102, 112, 114, 98, 108, 109, 101, 111, 112, 101, 109, 109, 98, 107, 106, 106, 115, 114, 93, 102, 104, 91, 103, 104, 104, 120, 122, 114, 132, 137, 88, 109, 91, 71, 91, 60, 74, 94, 56, 58, 78, 42, 53, 69, 44, 61, 73, 56, 146, 151, 159, 161, 167, 169, 183, 182, 175, 200, 190, 189, 195, 185, 190, 169, 170, 177, 143, 160, 166, 135, 155, 159, 170, 173, 178, 222, 210, 214, 217, 204, 204, 199, 189, 190, 219, 206, 207, 200, 192, 187, 159, 161, 154, 112, 121, 123, 102, 112, 114, 99, 109, 111, 100, 110, 112, 98, 107, 107, 99, 108, 107, 98, 107, 106, 94, 103, 105, 96, 108, 109, 106, 122, 124, 111, 129, 134, 74, 95, 77, 55, 75, 43, 64, 84, 48, 67, 86, 56, 67, 83, 61, 70, 84, 63, 128, 140, 147, 135, 144, 146, 183, 177, 173, 208, 194, 197, 185, 174, 180, 156, 158, 163, 129, 149, 152, 125, 146, 150, 176, 176, 181, 232, 219, 219, 208, 199, 192, 200, 189, 186, 218, 204, 203, 183, 176, 172, 146, 151, 145, 112, 121, 123, 102, 112, 114, 100, 110, 112, 100, 110, 111, 96, 105, 104, 100, 109, 108, 94, 103, 102, 92, 101, 103, 100, 112, 114, 107, 123, 125, 106, 125, 129, 60, 80, 64, 45, 64, 38, 55, 74, 41, 68, 88, 56, 66, 84, 58, 62, 80, 54, 115, 132, 136, 125, 135, 134, 198, 189, 184, 210, 198, 197, 175, 167, 169, 146, 149, 149, 124, 141, 139, 124, 142, 147, 179, 176, 182, 220, 209, 206, 201, 196, 186, 201, 189, 185, 212, 197, 196, 169, 163, 160, 136, 142, 139, 110, 120, 122, 102, 112, 114, 100, 110, 112, 100, 109, 111, 93, 102, 102, 93, 102, 102, 91, 100, 100, 92, 101, 102, 102, 114, 115, 108, 124, 127, 104, 123, 127, 57, 77, 64, 51, 68, 50, 62, 81, 52, 54, 74, 40, 56, 76, 45, 60, 80, 53, 119, 131, 138, 128, 133, 133, 204, 195, 186, 215, 203, 197, 167, 164, 164, 136, 143, 145, 119, 131, 131, 120, 139, 142, 154, 161, 163, 200, 194, 193, 200, 192, 189, 191, 182, 179, 200, 190, 186, 161, 160, 156, 125, 135, 135, 107, 120, 122, 101, 114, 115, 97, 110, 111, 97, 109, 111, 93, 103, 105, 90, 100, 101, 90, 100, 102, 96, 105, 105, 104, 114, 112, 110, 127, 133, 101, 121, 123, 54, 74, 59, 48, 67, 48, 59, 78, 57, 59, 80, 47, 63, 85, 51, 51, 71, 54, 121, 131, 136, 128, 130, 129, 196, 187, 176, 202, 191, 183, 154, 155, 155, 127, 137, 139, 113, 125, 127, 113, 131, 134, 130, 142, 144, 185, 184, 184, 191, 182, 181, 179, 174, 172, 197, 192, 186, 153, 155, 150, 120, 132, 133, 108, 123, 124, 100, 114, 115, 92, 106, 107, 91, 105, 106, 94, 104, 106, 93, 103, 105, 92, 102, 104, 99, 108, 109, 103, 114, 117, 112, 130, 137, 96, 117, 111, 55, 75, 53, 55, 74, 51, 58, 77, 55, 61, 82, 49, 62, 86, 49, 55, 77, 53, 99, 111, 109, 119, 122, 117, 189, 180, 169, 182, 175, 167, 136, 141, 141, 116, 131, 134, 105, 120, 122, 105, 122, 124, 119, 134, 138, 173, 178, 178, 176, 172, 168, 160, 162, 159, 191, 192, 186, 151, 155, 153, 118, 130, 132, 111, 125, 127, 101, 115, 116, 93, 108, 109, 90, 103, 105, 95, 105, 107, 97, 107, 109, 98, 108, 110, 102, 112, 116, 107, 120, 128, 112, 133, 135, 88, 109, 94, 59, 77, 49, 53, 74, 44, 55, 76, 44, 53, 75, 38, 55, 78, 39, 61, 84, 50, 62, 75, 66, 106, 110, 101, 191, 184, 170, 162, 159, 152, 120, 130, 132, 106, 125, 130, 99, 118, 120, 98, 113, 113, 111, 129, 135, 165, 176, 176, 170, 172, 163, 147, 157, 153, 174, 180, 175, 144, 151, 150, 120, 134, 138, 112, 126, 128, 102, 116, 117, 97, 111, 112, 92, 105, 106, 96, 107, 108, 102, 112, 115, 104, 114, 115, 107, 117, 122, 109, 125, 133, 104, 125, 121, 73, 92, 73, 55, 71, 42, 65, 86, 49, 68, 91, 49, 67, 89, 49, 63, 85, 47, 50, 72, 39, 50, 63, 50, 101, 105, 93, 192, 184, 171, 151, 150, 143, 112, 125, 126, 97, 120, 125, 95, 115, 118, 90, 103, 103, 99, 119, 125, 137, 151, 152, 157, 162, 152, 139, 155, 150, 142, 154, 149, 125, 135, 135, 120, 133, 138, 108, 122, 124, 102, 116, 117, 99, 114, 115, 94, 107, 109, 100, 110, 112, 108, 118, 120, 110, 120, 122, 110, 121, 125, 108, 127, 129, 82, 104, 95, 47, 64, 46, 50, 64, 39, 59, 81, 41, 64, 88, 40, 60, 83, 41, 50, 71, 39, 41, 61, 38, 53, 64, 44, 132, 131, 118, 199, 189, 179, 153, 148, 142, 106, 118, 114, 93, 115, 114, 91, 110, 112, 87, 99, 100, 95, 109, 112, 117, 129, 131, 136, 145, 143, 126, 144, 147, 112, 132, 134, 110, 127, 129, 108, 121, 125, 100, 114, 118, 98, 113, 117, 98, 112, 116, 94, 109, 111, 99, 112, 113, 107, 119, 122, 109, 120, 127, 108, 121, 128, 104, 123, 123, 77, 97, 85, 47, 62, 45, 42, 55, 37, 43, 59, 28, 59, 77, 35, 51, 67, 35, 51, 65, 47, 52, 64, 50, 68, 77, 55, 162, 159, 145, 187, 177, 168, 148, 143, 136, 102, 112, 105, 86, 106, 102, 83, 101, 102, 86, 97, 99, 96, 105, 107, 113, 122, 124, 116, 127, 130, 109, 127, 135, 99, 123, 128, 97, 117, 120, 91, 103, 106, 87, 100, 105, 82, 96, 101, 83, 96, 101, 90, 104, 107, 97, 111, 112, 102, 116, 118, 107, 120, 127, 111, 125, 134, 104, 121, 123, 68, 85, 71, 50, 66, 43, 60, 73, 50, 68, 81, 50, 75, 90, 49, 69, 83, 52, 63, 73, 60, 64, 71, 64, 74, 84, 62, 143, 144, 129, 154, 149, 139, 133, 133, 125, 94, 103, 97, 77, 94, 91, 75, 93, 94, 75, 86, 88, 97, 107, 109, 104, 114, 116, 97, 108, 111, 97, 113, 120, 97, 119, 122, 92, 110, 111, 77, 88, 90, 71, 83, 85, 73, 85, 87, 69, 81, 83, 79, 91, 93, 92, 106, 107, 99, 113, 114, 108, 121, 124, 113, 126, 132, 97, 112, 112, 59, 75, 56, 63, 78, 47, 77, 91, 58, 87, 102, 62, 82, 98, 53, 73, 88, 50, 74, 85, 61, 70, 79, 62, 66, 77, 55, 113, 117, 101, 121, 123, 110, 106, 113, 102, 83, 91, 85, 69, 81, 80, 73, 90, 92, 60, 72, 74, 71, 81, 83, 92, 102, 104, 85, 96, 99, 92, 107, 112, 94, 114, 115, 89, 105, 105, 63, 71, 72, 57, 66, 67, 69, 78, 80, 67, 77, 78, 73, 84, 85, 87, 101, 102, 97, 112, 112, 104, 118, 117, 104, 118, 116, 85, 100, 89, 71, 86, 59, 68, 81, 45, 67, 80, 43, 66, 81, 39, 70, 86, 43, 72, 87, 49, 83, 96, 61, 78, 90, 52, 64, 75, 53, 84, 91, 74, 79, 86, 71, 66, 78, 66, 66, 73, 67, 53, 62, 62, 71, 87, 89, 67, 78, 80, 49, 59, 61, 68, 78, 80, 67, 77, 80, 82, 95, 99, 86, 104, 104, 81, 96, 94, 55, 61, 60, 43, 51, 51, 65, 73, 73, 71, 79, 79, 71, 80, 81, 78, 92, 94, 90, 105, 104, 88, 103, 98, 73, 89, 77, 70, 85, 59, 77, 91, 56, 74, 85, 50, 64, 75, 40, 60, 74, 34, 55, 70, 33, 57, 71, 37, 72, 85, 50, 67, 79, 43, 62, 73, 50, 58, 69, 48, 53, 66, 46, 46, 62, 44, 44, 56, 43, 39, 51, 45, 58, 74, 72, 84, 97, 98, 68, 79, 81, 46, 55, 56, 44, 53, 53, 62, 74, 76, 73, 86, 88, 79, 89, 89, 62, 67, 64, 41, 48, 47, 66, 74, 73, 76, 84, 82, 77, 85, 84, 84, 93, 94, 88, 99, 99, 84, 97, 95, 41, 54, 46, 48, 60, 39, 57, 66, 42, 66, 72, 44, 78, 86, 50, 80, 90, 48, 66, 78, 42, 58, 70, 39, 53, 63, 37, 53, 63, 39, 56, 67, 43, 57, 71, 47, 57, 73, 47, 48, 65, 40, 45, 63, 42, 45, 62, 48, 49, 64, 57, 79, 93, 94, 81, 93, 94, 47, 57, 56, 30, 38, 35, 45, 56, 56, 67, 76, 81, 83, 89, 91, 59, 64, 59, 39, 48, 45, 66, 75, 72, 73, 83, 79, 77, 85, 83, 78, 83, 84, 87, 94, 96, 110, 120, 125, 78, 89, 90, 48, 55, 47, 56, 60, 51, 81, 84, 60, 95, 100, 59, 93, 100, 53, 80, 88, 50, 68, 79, 49, 60, 69, 44, 66, 76, 49], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387728}, {\"format\": \"raw\", \"value\": [64, 52, 37, 85, 60, 40, 92, 66, 47, 90, 65, 45, 147, 121, 99, 222, 194, 172, 224, 197, 175, 227, 201, 178, 227, 205, 181, 229, 207, 183, 232, 212, 183, 237, 214, 186, 224, 201, 174, 197, 186, 163, 239, 236, 227, 249, 245, 236, 248, 244, 236, 250, 243, 235, 249, 243, 233, 233, 213, 193, 192, 162, 125, 178, 149, 108, 170, 143, 101, 151, 124, 89, 166, 141, 117, 178, 152, 129, 156, 128, 100, 196, 167, 140, 171, 148, 128, 160, 129, 97, 180, 146, 117, 175, 145, 125, 72, 54, 40, 93, 65, 46, 98, 69, 50, 93, 66, 46, 148, 121, 99, 225, 197, 175, 228, 200, 177, 230, 204, 181, 230, 207, 183, 233, 210, 186, 236, 215, 187, 242, 218, 190, 226, 203, 175, 198, 188, 164, 244, 241, 231, 254, 248, 239, 252, 246, 238, 253, 246, 237, 251, 245, 234, 235, 213, 192, 196, 168, 130, 179, 155, 109, 178, 148, 103, 180, 150, 111, 185, 156, 130, 170, 140, 118, 150, 118, 90, 192, 162, 133, 172, 143, 121, 162, 131, 105, 193, 162, 136, 169, 134, 112, 70, 53, 38, 88, 62, 43, 94, 67, 48, 93, 65, 47, 147, 119, 98, 221, 193, 172, 224, 196, 175, 227, 202, 178, 228, 205, 181, 230, 208, 183, 233, 213, 184, 239, 215, 187, 221, 201, 174, 202, 193, 172, 241, 237, 227, 248, 243, 234, 248, 242, 235, 250, 244, 237, 248, 243, 234, 229, 207, 184, 206, 177, 142, 225, 203, 160, 232, 203, 158, 232, 195, 153, 217, 174, 136, 198, 155, 118, 193, 156, 123, 215, 183, 155, 199, 165, 130, 200, 162, 125, 199, 172, 143, 162, 125, 103, 70, 53, 37, 92, 63, 45, 98, 70, 49, 97, 69, 49, 150, 120, 99, 223, 195, 173, 225, 199, 177, 229, 204, 180, 228, 207, 182, 232, 211, 185, 236, 216, 188, 242, 219, 190, 216, 197, 174, 207, 196, 182, 231, 223, 212, 222, 217, 206, 209, 204, 192, 213, 207, 193, 233, 223, 207, 226, 202, 178, 200, 170, 136, 216, 178, 139, 221, 179, 136, 181, 146, 113, 191, 152, 115, 187, 145, 102, 197, 157, 118, 221, 189, 159, 200, 164, 122, 189, 146, 108, 189, 139, 115, 159, 97, 77, 70, 52, 36, 90, 62, 44, 95, 67, 47, 97, 69, 49, 116, 93, 77, 152, 135, 120, 161, 146, 131, 183, 168, 153, 208, 193, 175, 204, 190, 171, 190, 178, 157, 188, 171, 149, 160, 145, 129, 140, 131, 120, 159, 151, 140, 157, 150, 136, 144, 133, 116, 143, 129, 108, 195, 176, 153, 221, 193, 167, 184, 155, 125, 189, 151, 121, 186, 143, 112, 139, 110, 88, 144, 112, 81, 167, 128, 83, 179, 141, 101, 192, 156, 123, 176, 140, 98, 141, 97, 70, 144, 74, 57, 141, 61, 41, 62, 48, 34, 78, 56, 39, 84, 60, 43, 80, 59, 44, 70, 57, 46, 103, 92, 77, 141, 128, 110, 150, 138, 123, 161, 153, 139, 180, 163, 148, 180, 161, 142, 186, 163, 143, 142, 125, 110, 102, 96, 81, 126, 119, 104, 148, 138, 117, 158, 144, 123, 137, 120, 100, 155, 133, 113, 216, 186, 160, 157, 122, 91, 134, 99, 72, 135, 100, 74, 158, 125, 97, 129, 92, 59, 142, 102, 58, 138, 105, 63, 137, 101, 62, 122, 85, 50, 120, 83, 53, 145, 102, 76, 144, 99, 76, 52, 41, 31, 62, 47, 32, 69, 54, 38, 55, 43, 32, 67, 57, 46, 142, 128, 107, 189, 168, 143, 173, 156, 132, 146, 133, 117, 200, 173, 153, 218, 188, 166, 229, 201, 178, 152, 132, 114, 123, 115, 95, 161, 153, 133, 174, 164, 138, 187, 173, 145, 173, 156, 131, 140, 120, 98, 197, 168, 143, 175, 140, 115, 140, 105, 80, 136, 98, 73, 145, 109, 80, 125, 92, 63, 127, 92, 58, 117, 88, 56, 112, 81, 50, 88, 55, 32, 134, 104, 71, 171, 138, 105, 163, 132, 105, 59, 47, 36, 66, 50, 35, 58, 46, 34, 43, 36, 28, 77, 68, 54, 123, 112, 94, 124, 111, 94, 118, 107, 92, 108, 99, 87, 114, 102, 88, 127, 116, 100, 134, 122, 104, 95, 85, 69, 133, 126, 104, 136, 129, 111, 164, 150, 128, 199, 181, 155, 197, 176, 152, 165, 145, 123, 166, 140, 117, 220, 183, 161, 206, 170, 150, 192, 159, 135, 180, 148, 124, 170, 142, 119, 164, 135, 112, 157, 130, 105, 149, 114, 92, 105, 65, 46, 125, 94, 65, 131, 104, 77, 142, 114, 89, 101, 88, 70, 133, 116, 99, 84, 75, 65, 25, 24, 19, 58, 54, 46, 51, 48, 42, 45, 42, 36, 61, 58, 50, 76, 71, 61, 48, 43, 37, 52, 47, 40, 35, 35, 25, 31, 30, 19, 57, 53, 40, 62, 56, 46, 124, 112, 97, 195, 175, 148, 202, 164, 135, 195, 160, 135, 151, 128, 103, 203, 171, 151, 226, 188, 170, 210, 178, 155, 200, 171, 149, 190, 162, 140, 185, 156, 134, 181, 158, 138, 185, 133, 111, 182, 64, 43, 160, 75, 52, 133, 86, 70, 125, 94, 78, 71, 63, 45, 123, 115, 94, 134, 129, 113, 84, 81, 70, 60, 56, 47, 43, 39, 31, 33, 31, 22, 45, 43, 35, 72, 66, 56, 36, 33, 23, 40, 36, 26, 25, 25, 17, 19, 20, 10, 21, 19, 12, 23, 22, 15, 59, 39, 24, 110, 81, 58, 142, 124, 106, 136, 112, 93, 136, 117, 100, 162, 143, 125, 217, 189, 173, 205, 172, 151, 194, 166, 144, 182, 155, 134, 180, 152, 129, 176, 156, 135, 197, 115, 91, 217, 53, 33, 205, 45, 29, 214, 47, 33, 207, 69, 57, 49, 42, 28, 69, 64, 43, 101, 94, 74, 143, 135, 119, 137, 129, 115, 76, 71, 58, 36, 36, 31, 51, 50, 46, 69, 65, 55, 19, 20, 10, 21, 21, 12, 22, 22, 14, 30, 25, 17, 50, 41, 28, 52, 38, 23, 52, 32, 20, 50, 40, 32, 102, 93, 81, 117, 103, 85, 126, 112, 96, 143, 124, 104, 202, 174, 154, 205, 175, 153, 189, 163, 140, 181, 154, 131, 179, 154, 131, 182, 137, 114, 213, 76, 55, 222, 53, 35, 221, 46, 29, 220, 35, 22, 224, 39, 26, 56, 49, 36, 62, 55, 36, 63, 56, 38, 74, 67, 52, 121, 114, 100, 150, 143, 128, 141, 131, 118, 139, 132, 123, 99, 94, 84, 55, 52, 47, 57, 52, 47, 66, 59, 51, 75, 66, 57, 97, 87, 71, 122, 110, 92, 139, 125, 113, 159, 146, 135, 185, 171, 157, 200, 189, 173, 212, 195, 173, 230, 211, 186, 239, 216, 191, 232, 208, 184, 202, 180, 156, 182, 156, 132, 173, 148, 124, 180, 111, 87, 217, 62, 42, 228, 56, 37, 234, 57, 42, 232, 50, 36, 213, 37, 24, 45, 40, 30, 56, 50, 37, 59, 51, 37, 58, 50, 38, 73, 66, 52, 108, 101, 85, 115, 106, 91, 110, 101, 90, 145, 138, 128, 143, 136, 127, 160, 154, 147, 172, 163, 153, 177, 166, 154, 193, 181, 166, 205, 194, 178, 211, 198, 182, 211, 199, 181, 217, 207, 189, 219, 209, 192, 224, 212, 193, 235, 220, 197, 232, 213, 186, 231, 209, 183, 233, 212, 188, 218, 197, 174, 180, 162, 141, 169, 107, 87, 201, 58, 44, 219, 54, 39, 222, 51, 34, 233, 53, 37, 229, 56, 40, 23, 21, 15, 46, 41, 31, 58, 50, 38, 55, 48, 37, 60, 53, 41, 72, 66, 52, 90, 81, 65, 93, 83, 66, 152, 145, 132, 190, 182, 173, 195, 191, 185, 207, 200, 188, 210, 202, 185, 213, 204, 186, 217, 206, 189, 224, 213, 195, 230, 220, 202, 235, 223, 203, 222, 209, 189, 204, 190, 174, 200, 188, 177, 203, 188, 172, 185, 166, 146, 198, 177, 154, 224, 202, 178, 228, 210, 187, 197, 171, 152, 184, 113, 101, 194, 83, 75, 210, 62, 48, 218, 49, 35, 224, 51, 34, 33, 30, 22, 46, 41, 31, 61, 54, 41, 51, 46, 35, 44, 41, 33, 57, 52, 41, 83, 74, 57, 99, 88, 70, 121, 113, 97, 153, 146, 135, 163, 159, 150, 158, 153, 144, 180, 175, 161, 211, 204, 186, 219, 210, 191, 220, 210, 191, 222, 210, 191, 224, 211, 191, 212, 198, 180, 185, 168, 153, 159, 144, 131, 179, 165, 152, 164, 148, 136, 150, 129, 114, 170, 149, 130, 196, 173, 152, 223, 202, 180, 213, 197, 180, 189, 162, 151, 190, 123, 115, 181, 74, 65, 160, 36, 26, 54, 48, 39, 50, 45, 36, 58, 51, 39, 53, 47, 36, 38, 35, 28, 37, 34, 27, 65, 58, 45, 84, 75, 58, 91, 83, 67, 108, 101, 88, 138, 131, 119, 141, 136, 129, 131, 127, 122, 153, 149, 140, 194, 186, 173, 212, 201, 187, 214, 202, 187, 213, 202, 185, 214, 201, 185, 211, 196, 181, 188, 170, 156, 184, 167, 151, 158, 143, 132, 144, 126, 115, 156, 138, 124, 161, 140, 124, 209, 183, 165, 217, 191, 173, 217, 194, 177, 196, 175, 162, 156, 132, 123, 95, 65, 59, 62, 55, 44, 55, 51, 42, 50, 43, 32, 61, 52, 40, 44, 40, 32, 33, 30, 24, 54, 47, 36, 71, 63, 48, 77, 69, 55, 86, 78, 66, 100, 93, 80, 132, 125, 112, 141, 136, 127, 123, 120, 114, 139, 135, 131, 180, 171, 165, 200, 190, 180, 202, 192, 181, 203, 193, 179, 204, 193, 179, 207, 193, 181, 192, 179, 167, 153, 142, 129, 162, 149, 135, 190, 172, 160, 182, 164, 150, 197, 179, 164, 200, 179, 166, 200, 178, 162, 202, 179, 162, 182, 163, 148, 122, 106, 95, 67, 56, 43, 41, 37, 31, 28, 24, 18, 62, 54, 40, 50, 46, 34, 33, 32, 25, 52, 46, 36, 67, 59, 45, 68, 61, 47, 75, 68, 54, 80, 75, 61, 92, 86, 71, 123, 116, 102, 145, 139, 128, 139, 134, 130, 157, 154, 153, 182, 175, 171, 191, 180, 172, 196, 186, 174, 192, 184, 172, 192, 183, 172, 185, 177, 165, 177, 169, 156, 186, 177, 164, 192, 180, 167, 187, 173, 161, 182, 168, 157, 187, 172, 161, 186, 171, 156, 185, 167, 147, 161, 141, 124, 115, 94, 81, 82, 69, 53, 28, 26, 19, 9, 9, 7, 40, 35, 25, 48, 42, 31, 32, 31, 24, 53, 48, 37, 67, 59, 45, 65, 58, 44, 70, 63, 48, 75, 69, 55, 80, 73, 60, 90, 84, 71, 115, 108, 96, 143, 136, 127, 151, 147, 142, 170, 167, 166, 184, 177, 174, 183, 173, 165, 191, 181, 173, 188, 180, 173, 187, 178, 169, 186, 178, 167, 184, 176, 164, 187, 178, 166, 187, 174, 164, 178, 164, 154, 177, 162, 149, 175, 158, 141, 166, 145, 125, 133, 111, 93, 122, 103, 90, 102, 89, 69, 67, 57, 40, 42, 36, 27, 30, 27, 20, 42, 37, 29, 42, 40, 31, 49, 45, 34, 66, 59, 47, 64, 57, 44, 71, 64, 49, 78, 71, 57, 73, 66, 52, 82, 76, 64, 94, 88, 77, 109, 102, 92, 135, 128, 120, 156, 151, 146, 149, 147, 147, 139, 135, 131, 149, 139, 132, 177, 168, 161, 184, 176, 168, 180, 172, 161, 176, 168, 155, 174, 166, 150, 169, 158, 143, 165, 152, 139, 165, 151, 137, 154, 135, 116, 135, 113, 95, 114, 93, 74, 88, 76, 64, 112, 101, 83, 96, 82, 62, 71, 58, 43, 48, 40, 31, 29, 25, 19, 43, 40, 31, 52, 48, 37, 62, 57, 46, 63, 58, 46, 53, 49, 40, 55, 51, 43, 80, 75, 64, 81, 74, 61, 87, 80, 69, 94, 89, 79, 110, 103, 96, 133, 126, 117, 141, 138, 131, 103, 102, 101, 87, 81, 83, 123, 112, 104, 165, 156, 144, 165, 157, 145, 152, 143, 128, 147, 136, 120, 148, 134, 118, 151, 137, 121, 150, 138, 124, 132, 114, 96, 104, 86, 70, 110, 83, 66, 50, 38, 29, 115, 107, 96, 108, 100, 81, 81, 69, 52, 62, 49, 35, 33, 27, 17, 25, 22, 15, 55, 50, 39, 60, 55, 43, 55, 51, 42, 21, 19, 15, 9, 9, 5, 41, 39, 34, 79, 74, 63, 71, 63, 53, 78, 74, 64, 106, 101, 92, 115, 111, 103, 129, 124, 114, 135, 130, 122, 115, 107, 101, 110, 99, 84, 121, 109, 93, 138, 128, 118, 133, 123, 109, 127, 115, 99, 126, 113, 98, 125, 112, 95, 116, 105, 91, 120, 108, 90, 110, 89, 71, 128, 90, 73, 67, 53, 42, 111, 102, 96, 115, 107, 93, 102, 92, 73, 76, 62, 45, 53, 43, 30, 24, 20, 12, 30, 28, 20, 60, 55, 43, 51, 47, 35, 15, 15, 10, 10, 12, 6, 12, 12, 8, 56, 54, 46, 82, 76, 65, 69, 63, 53, 77, 73, 64, 112, 107, 100, 121, 116, 110, 114, 107, 98, 104, 93, 80, 113, 102, 83, 108, 97, 82, 113, 104, 94, 122, 115, 100, 100, 93, 80, 85, 77, 65, 122, 109, 93, 125, 111, 96, 111, 96, 79, 108, 82, 66, 137, 110, 84, 121, 98, 77, 109, 100, 92, 112, 104, 95, 119, 110, 94, 98, 85, 67, 69, 56, 41, 44, 36, 25, 20, 17, 10, 36, 30, 21, 49, 44, 34, 19, 20, 14, 20, 21, 13, 13, 14, 9, 31, 31, 26, 74, 68, 59, 77, 71, 60, 71, 66, 57, 76, 71, 64, 103, 99, 93, 92, 86, 78, 105, 95, 82, 117, 106, 90, 101, 93, 79, 107, 99, 86, 119, 110, 94, 95, 86, 74, 80, 73, 62, 115, 101, 85, 107, 89, 72, 105, 86, 67, 110, 84, 64, 139, 110, 83, 135, 107, 82, 107, 99, 87, 107, 98, 90, 118, 109, 97, 115, 106, 89, 85, 74, 57, 59, 49, 34, 35, 28, 19, 19, 14, 7, 30, 26, 20, 25, 24, 19, 38, 37, 28, 27, 26, 18, 19, 19, 15, 55, 50, 45, 72, 64, 54, 71, 66, 57, 68, 62, 54, 64, 62, 52, 64, 63, 54, 112, 104, 93, 130, 119, 107, 100, 91, 79, 107, 96, 83, 107, 97, 82, 85, 75, 65, 78, 69, 58, 104, 90, 73, 109, 91, 72, 118, 96, 76, 127, 99, 80, 137, 107, 82, 135, 108, 80, 105, 98, 84, 105, 97, 87, 108, 100, 92, 121, 113, 100, 106, 98, 81, 76, 66, 49, 53, 44, 33, 29, 24, 17, 16, 14, 8, 27, 26, 21, 55, 51, 41, 45, 39, 29, 19, 19, 13, 42, 39, 34, 62, 53, 45, 60, 55, 46, 63, 58, 50, 55, 53, 43, 48, 49, 41, 89, 82, 71, 104, 91, 78, 98, 85, 72, 94, 80, 64, 80, 71, 57, 86, 75, 61, 109, 95, 78, 109, 94, 78, 91, 76, 60, 108, 86, 68, 128, 103, 83, 130, 103, 82, 130, 101, 78, 104, 96, 84, 105, 96, 87, 105, 96, 89, 115, 106, 96, 124, 116, 103, 103, 93, 77, 71, 62, 46, 48, 41, 30, 24, 20, 13, 29, 28, 24, 67, 62, 54, 49, 41, 31, 25, 22, 16, 28, 29, 22, 54, 47, 37, 55, 39, 31, 56, 46, 39, 54, 49, 42, 47, 45, 38, 80, 69, 56, 98, 81, 64, 99, 81, 62, 94, 78, 62, 76, 64, 52, 101, 88, 71, 96, 86, 70, 74, 63, 52, 55, 44, 35, 67, 55, 44, 88, 74, 61, 106, 87, 70, 119, 93, 74, 102, 94, 84, 104, 96, 85, 105, 97, 88, 108, 99, 91, 125, 116, 107, 128, 119, 105, 94, 85, 67, 65, 55, 41, 37, 31, 21, 30, 28, 23, 79, 74, 67, 56, 48, 37, 28, 25, 18, 17, 19, 13, 49, 43, 35, 53, 36, 28, 51, 32, 24, 50, 34, 26, 59, 50, 41, 97, 81, 66, 97, 78, 61, 87, 73, 58, 74, 63, 52, 62, 52, 44, 71, 60, 49, 53, 45, 36, 44, 34, 28, 52, 41, 32, 55, 46, 38, 58, 49, 41, 70, 58, 48, 88, 72, 60, 100, 90, 82, 102, 94, 84, 105, 96, 88, 104, 95, 88, 112, 103, 95, 135, 127, 116, 120, 112, 97, 84, 74, 57, 54, 46, 32, 29, 26, 19, 69, 65, 58, 62, 56, 45, 27, 25, 18, 12, 13, 7, 39, 36, 28, 51, 45, 35, 48, 38, 29, 49, 35, 28, 58, 49, 41, 69, 58, 49, 59, 50, 42, 56, 50, 40, 50, 44, 35, 43, 36, 28, 38, 29, 22, 37, 28, 22, 43, 34, 28, 53, 43, 36, 56, 47, 39, 54, 45, 38, 54, 45, 38, 58, 49, 42, 96, 87, 80, 98, 90, 82, 102, 94, 86, 103, 94, 87, 102, 93, 86, 119, 110, 103, 135, 127, 115, 110, 102, 84, 78, 67, 51, 38, 32, 21, 41, 39, 33, 58, 54, 45, 25, 24, 17, 9, 10, 4, 23, 22, 14, 40, 37, 28, 41, 38, 29, 42, 39, 30, 45, 41, 32, 38, 34, 26, 34, 32, 25, 33, 30, 22, 29, 25, 16, 30, 23, 14, 33, 24, 17, 39, 31, 24, 46, 38, 31, 50, 41, 34, 52, 43, 36, 54, 45, 38, 53, 44, 37, 50, 42, 35, 93, 85, 77, 96, 87, 80, 101, 92, 85, 104, 95, 88, 103, 94, 87, 102, 93, 86, 129, 121, 110, 135, 127, 112, 99, 88, 72, 63, 54, 38, 27, 25, 17, 29, 29, 23, 20, 19, 12, 11, 11, 4, 10, 11, 5, 17, 17, 11, 22, 22, 15, 24, 24, 16, 23, 23, 16, 21, 21, 14, 19, 19, 12, 21, 18, 11, 25, 19, 11, 32, 24, 17, 40, 32, 25, 44, 37, 29, 46, 38, 32, 47, 38, 32, 48, 40, 32, 51, 42, 35, 53, 43, 36, 49, 41, 33, 84, 78, 70, 91, 83, 76, 96, 87, 80, 98, 89, 83, 100, 91, 84, 97, 88, 82, 110, 101, 93, 138, 129, 118, 117, 108, 93, 83, 75, 60, 47, 43, 32, 14, 15, 9, 14, 15, 9, 10, 12, 6, 10, 11, 5, 12, 13, 7, 13, 14, 7, 13, 14, 8, 15, 15, 9, 19, 17, 10, 22, 19, 11, 27, 23, 16, 35, 29, 24, 40, 34, 29, 45, 38, 33, 45, 39, 33, 42, 36, 32, 42, 36, 31, 42, 37, 29, 49, 40, 33, 51, 42, 35, 50, 41, 34], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387792}, {\"format\": \"raw\", \"value\": [124, 126, 113, 124, 126, 113, 133, 132, 119, 58, 51, 53, 9, 5, 8, 8, 5, 5, 10, 2, 5, 17, 6, 10, 79, 74, 63, 132, 132, 117, 130, 128, 115, 132, 129, 116, 137, 131, 119, 135, 129, 117, 132, 126, 114, 132, 126, 114, 129, 127, 114, 129, 127, 114, 130, 128, 115, 130, 128, 115, 130, 127, 117, 127, 124, 115, 79, 73, 69, 13, 9, 18, 7, 7, 11, 6, 5, 10, 6, 6, 11, 39, 40, 32, 122, 124, 112, 124, 125, 119, 121, 121, 114, 118, 118, 108, 123, 125, 111, 124, 125, 113, 131, 130, 117, 62, 56, 54, 7, 2, 5, 10, 6, 7, 8, 3, 5, 8, 2, 5, 71, 68, 57, 133, 132, 117, 129, 127, 114, 131, 128, 115, 135, 129, 117, 134, 128, 116, 131, 125, 113, 131, 125, 113, 128, 126, 113, 128, 126, 113, 130, 128, 115, 130, 128, 115, 129, 126, 116, 126, 123, 114, 105, 100, 94, 26, 23, 28, 11, 11, 16, 8, 7, 15, 7, 7, 14, 42, 43, 34, 119, 121, 109, 123, 124, 118, 120, 120, 114, 118, 118, 108, 123, 125, 111, 123, 124, 112, 129, 128, 115, 74, 69, 61, 16, 12, 12, 10, 6, 7, 21, 20, 20, 38, 39, 40, 79, 80, 67, 129, 127, 113, 128, 126, 113, 130, 127, 114, 134, 128, 116, 133, 127, 115, 130, 124, 112, 130, 124, 112, 127, 125, 112, 127, 125, 112, 128, 126, 113, 129, 127, 114, 128, 125, 115, 125, 122, 113, 132, 127, 119, 33, 30, 33, 5, 5, 6, 6, 6, 9, 5, 4, 9, 41, 43, 34, 121, 123, 111, 122, 123, 117, 119, 120, 113, 118, 118, 108, 122, 124, 110, 122, 124, 112, 127, 126, 114, 118, 113, 101, 36, 32, 31, 14, 9, 12, 31, 32, 32, 48, 56, 55, 79, 83, 68, 129, 127, 112, 127, 124, 111, 127, 124, 111, 129, 123, 110, 129, 123, 110, 129, 122, 110, 131, 125, 113, 127, 125, 112, 126, 125, 112, 128, 126, 113, 128, 126, 113, 128, 125, 115, 124, 121, 112, 117, 112, 103, 67, 64, 66, 50, 51, 47, 43, 44, 38, 29, 29, 28, 47, 48, 39, 119, 121, 109, 121, 122, 116, 119, 119, 112, 119, 118, 108, 122, 124, 111, 123, 123, 111, 126, 125, 112, 111, 107, 96, 38, 35, 32, 28, 22, 23, 25, 23, 22, 29, 31, 31, 74, 73, 64, 128, 125, 113, 132, 132, 118, 140, 138, 126, 147, 142, 133, 144, 140, 130, 136, 133, 121, 124, 120, 109, 124, 122, 110, 127, 122, 110, 127, 124, 113, 127, 125, 113, 126, 124, 113, 123, 120, 110, 130, 125, 115, 145, 143, 139, 145, 145, 136, 135, 135, 123, 121, 121, 115, 106, 107, 99, 121, 122, 113, 121, 122, 116, 117, 118, 111, 117, 117, 109, 118, 120, 109, 125, 123, 111, 123, 121, 109, 131, 128, 120, 115, 112, 105, 120, 116, 111, 119, 114, 111, 103, 95, 96, 105, 97, 97, 130, 127, 119, 176, 178, 166, 205, 206, 196, 217, 218, 213, 219, 220, 215, 203, 206, 198, 165, 164, 157, 126, 125, 114, 131, 121, 112, 124, 119, 111, 124, 121, 112, 124, 122, 110, 120, 118, 105, 119, 117, 106, 119, 116, 107, 114, 111, 102, 118, 115, 105, 125, 124, 116, 122, 123, 117, 122, 123, 117, 120, 121, 115, 116, 117, 111, 115, 116, 110, 121, 122, 111, 122, 123, 113, 119, 118, 108, 132, 133, 121, 133, 133, 121, 135, 138, 131, 128, 133, 130, 102, 110, 107, 70, 72, 69, 137, 133, 128, 200, 201, 197, 156, 157, 152, 148, 149, 144, 167, 169, 164, 219, 221, 220, 169, 166, 166, 114, 112, 103, 130, 123, 115, 122, 118, 109, 123, 120, 110, 122, 120, 108, 120, 118, 105, 115, 113, 102, 119, 116, 107, 119, 116, 107, 119, 116, 107, 121, 120, 112, 117, 118, 112, 120, 121, 115, 121, 122, 116, 117, 118, 112, 114, 115, 109, 120, 122, 111, 124, 125, 117, 133, 134, 127, 129, 130, 121, 130, 132, 121, 102, 109, 103, 75, 85, 82, 53, 68, 63, 32, 41, 35, 159, 155, 153, 160, 160, 163, 48, 49, 50, 46, 49, 44, 47, 51, 46, 66, 67, 69, 56, 53, 56, 76, 73, 68, 119, 116, 110, 122, 119, 111, 122, 119, 109, 120, 118, 106, 119, 117, 104, 116, 113, 103, 117, 114, 105, 118, 115, 106, 120, 117, 108, 123, 121, 113, 119, 120, 114, 116, 117, 111, 119, 120, 114, 117, 118, 112, 114, 115, 109, 128, 130, 119, 164, 167, 161, 203, 205, 200, 227, 229, 226, 181, 183, 181, 85, 91, 90, 55, 64, 63, 54, 66, 63, 34, 41, 36, 181, 180, 177, 154, 154, 156, 81, 82, 82, 102, 108, 102, 91, 97, 91, 64, 66, 65, 16, 13, 13, 54, 50, 48, 100, 102, 97, 116, 114, 106, 120, 117, 108, 119, 117, 105, 119, 117, 104, 118, 115, 105, 115, 112, 103, 115, 112, 103, 118, 115, 106, 120, 118, 110, 117, 118, 112, 119, 120, 113, 116, 117, 111, 115, 116, 110, 112, 113, 107, 132, 134, 124, 196, 200, 195, 194, 199, 195, 165, 169, 174, 84, 86, 95, 49, 53, 58, 24, 28, 31, 20, 22, 24, 37, 38, 35, 194, 195, 189, 141, 141, 138, 54, 57, 53, 78, 88, 80, 89, 98, 90, 95, 98, 90, 49, 47, 41, 33, 29, 28, 72, 77, 72, 104, 102, 94, 119, 116, 107, 120, 117, 105, 117, 115, 102, 115, 112, 102, 114, 111, 101, 114, 111, 102, 117, 114, 105, 118, 117, 109, 114, 115, 110, 114, 115, 109, 112, 113, 107, 113, 114, 108, 112, 113, 107, 102, 105, 102, 118, 123, 123, 183, 188, 189, 139, 141, 146, 49, 50, 57, 11, 10, 16, 2, 1, 6, 11, 10, 12, 63, 62, 60, 199, 200, 197, 146, 140, 137, 39, 27, 22, 26, 26, 22, 37, 38, 33, 50, 52, 46, 50, 50, 46, 26, 18, 20, 42, 44, 42, 74, 77, 73, 102, 104, 100, 115, 117, 110, 127, 130, 121, 120, 120, 114, 116, 114, 110, 106, 105, 98, 110, 109, 100, 118, 117, 108, 115, 116, 108, 113, 113, 106, 112, 110, 105, 114, 113, 106, 112, 113, 104, 127, 133, 133, 111, 117, 121, 152, 158, 161, 202, 205, 208, 179, 181, 184, 128, 128, 132, 72, 71, 76, 28, 28, 30, 82, 82, 82, 203, 203, 205, 145, 137, 135, 56, 37, 30, 18, 13, 10, 14, 10, 9, 11, 8, 9, 15, 13, 14, 22, 14, 14, 15, 14, 16, 40, 44, 44, 58, 62, 62, 81, 87, 83, 132, 138, 133, 196, 198, 196, 189, 189, 189, 156, 157, 153, 113, 114, 106, 118, 119, 111, 114, 115, 107, 116, 116, 109, 119, 115, 110, 115, 113, 106, 112, 114, 103, 200, 208, 206, 211, 221, 222, 210, 219, 220, 214, 220, 222, 219, 224, 227, 227, 228, 232, 217, 217, 222, 179, 179, 182, 171, 171, 172, 197, 199, 200, 133, 129, 127, 52, 40, 35, 12, 11, 10, 10, 9, 9, 13, 6, 10, 18, 11, 13, 71, 68, 63, 78, 78, 83, 31, 35, 35, 41, 45, 44, 55, 59, 57, 57, 61, 59, 178, 180, 180, 212, 212, 214, 215, 217, 215, 186, 188, 184, 128, 129, 125, 112, 112, 107, 118, 118, 113, 118, 115, 110, 117, 115, 109, 114, 115, 105, 189, 199, 197, 190, 202, 202, 197, 209, 209, 209, 218, 219, 214, 221, 223, 215, 220, 223, 223, 227, 230, 233, 237, 240, 238, 242, 244, 228, 232, 233, 210, 210, 208, 169, 163, 161, 110, 110, 110, 62, 60, 62, 32, 26, 32, 21, 16, 21, 131, 132, 129, 214, 213, 217, 25, 28, 29, 18, 22, 22, 23, 27, 26, 44, 48, 47, 178, 181, 183, 207, 210, 213, 208, 212, 214, 215, 219, 220, 198, 200, 200, 130, 130, 128, 113, 112, 109, 121, 118, 113, 118, 116, 109, 116, 118, 107, 174, 187, 184, 181, 195, 195, 186, 200, 199, 192, 204, 204, 199, 210, 211, 209, 217, 219, 209, 216, 218, 213, 219, 223, 217, 223, 228, 223, 229, 231, 225, 229, 228, 233, 233, 234, 229, 231, 233, 217, 219, 222, 195, 196, 201, 147, 149, 154, 105, 111, 112, 186, 187, 184, 134, 137, 136, 127, 131, 130, 143, 147, 148, 187, 191, 193, 215, 220, 224, 206, 212, 217, 208, 214, 219, 212, 218, 222, 219, 222, 225, 203, 203, 203, 143, 142, 141, 118, 115, 110, 121, 119, 113, 118, 119, 109, 156, 172, 168, 164, 180, 180, 169, 185, 184, 180, 192, 193, 187, 199, 200, 206, 216, 217, 212, 221, 223, 204, 212, 216, 204, 212, 217, 204, 212, 214, 202, 209, 207, 175, 180, 183, 202, 207, 210, 214, 219, 222, 219, 229, 233, 121, 131, 136, 73, 83, 89, 135, 138, 130, 222, 225, 223, 232, 236, 236, 230, 234, 236, 230, 234, 237, 221, 227, 232, 218, 225, 231, 217, 224, 231, 217, 224, 232, 228, 232, 238, 240, 240, 242, 210, 210, 210, 143, 140, 136, 119, 116, 111, 117, 118, 109, 136, 157, 157, 146, 164, 168, 153, 171, 171, 170, 176, 181, 173, 182, 187, 154, 165, 167, 182, 192, 193, 200, 211, 212, 192, 203, 204, 194, 202, 202, 196, 206, 204, 182, 194, 197, 196, 205, 209, 204, 213, 219, 151, 163, 175, 68, 82, 88, 113, 131, 131, 208, 212, 214, 208, 211, 216, 206, 211, 216, 200, 209, 208, 206, 215, 217, 204, 214, 216, 203, 212, 214, 199, 207, 213, 203, 210, 221, 202, 208, 215, 206, 210, 212, 236, 240, 242, 208, 209, 211, 132, 125, 130, 117, 116, 114, 122, 143, 143, 133, 147, 152, 153, 157, 161, 143, 154, 156, 81, 86, 91, 23, 24, 29, 46, 48, 52, 150, 156, 158, 179, 190, 189, 182, 190, 189, 189, 199, 198, 192, 205, 208, 191, 201, 206, 184, 194, 200, 96, 108, 120, 91, 105, 111, 176, 193, 192, 199, 204, 207, 200, 205, 211, 196, 202, 208, 193, 203, 201, 193, 203, 204, 187, 197, 199, 178, 189, 189, 173, 181, 186, 149, 154, 164, 61, 65, 72, 48, 52, 55, 162, 166, 168, 245, 247, 249, 198, 193, 199, 106, 105, 105, 108, 127, 127, 105, 114, 118, 126, 115, 122, 109, 125, 122, 12, 12, 16, 18, 10, 17, 13, 6, 13, 49, 48, 51, 160, 169, 166, 164, 173, 170, 171, 181, 179, 172, 185, 188, 178, 187, 192, 134, 143, 149, 77, 90, 99, 144, 158, 161, 183, 198, 197, 190, 197, 199, 185, 193, 198, 181, 190, 195, 174, 185, 183, 180, 190, 191, 182, 192, 194, 163, 173, 174, 157, 163, 167, 61, 63, 70, 11, 13, 19, 12, 16, 19, 50, 53, 56, 229, 232, 234, 245, 246, 249, 112, 113, 114, 96, 112, 113, 74, 81, 84, 86, 77, 80, 73, 84, 80, 15, 13, 15, 22, 14, 20, 23, 14, 22, 21, 16, 19, 116, 121, 118, 146, 156, 151, 152, 162, 160, 156, 169, 172, 160, 169, 174, 101, 111, 117, 107, 120, 127, 164, 178, 178, 168, 180, 181, 170, 179, 180, 168, 180, 183, 164, 176, 180, 157, 168, 166, 133, 143, 144, 116, 126, 128, 143, 153, 154, 128, 133, 136, 26, 26, 31, 24, 26, 30, 30, 34, 37, 26, 29, 32, 170, 173, 176, 230, 237, 239, 196, 199, 201, 88, 102, 104, 90, 98, 98, 119, 123, 119, 54, 55, 53, 9, 8, 8, 39, 37, 40, 33, 30, 36, 18, 13, 15, 76, 80, 75, 139, 150, 143, 141, 151, 150, 145, 158, 161, 145, 154, 160, 117, 127, 133, 134, 148, 152, 145, 159, 158, 147, 157, 158, 149, 161, 161, 146, 160, 163, 145, 159, 162, 150, 162, 159, 154, 164, 165, 78, 88, 90, 108, 118, 119, 105, 110, 112, 20, 19, 22, 49, 50, 53, 54, 58, 61, 34, 37, 40, 110, 114, 117, 211, 223, 224, 223, 231, 234, 87, 99, 102, 83, 94, 97, 116, 125, 118, 43, 39, 38, 38, 38, 37, 48, 49, 49, 37, 37, 40, 29, 25, 27, 49, 49, 47, 135, 148, 141, 135, 146, 143, 131, 143, 143, 135, 144, 147, 134, 143, 147, 131, 143, 147, 129, 142, 142, 130, 139, 141, 125, 138, 139, 120, 134, 137, 119, 134, 137, 126, 137, 137, 149, 158, 161, 98, 106, 110, 123, 133, 134, 76, 80, 81, 28, 28, 29, 38, 39, 41, 38, 42, 45, 26, 28, 32, 76, 81, 84, 199, 211, 211, 219, 217, 222, 83, 93, 95, 75, 89, 98, 109, 112, 107, 32, 32, 30, 55, 55, 55, 76, 77, 74, 47, 47, 47, 32, 28, 29, 40, 35, 37, 132, 145, 141, 133, 144, 139, 129, 140, 136, 120, 130, 129, 113, 122, 122, 108, 117, 122, 102, 112, 117, 99, 110, 114, 94, 105, 109, 89, 103, 106, 88, 103, 106, 97, 107, 112, 119, 128, 133, 79, 86, 92, 136, 146, 145, 61, 62, 61, 55, 58, 57, 46, 49, 50, 55, 59, 62, 36, 36, 40, 58, 63, 66, 186, 194, 195, 148, 136, 140, 71, 80, 83, 79, 90, 98, 104, 109, 104, 30, 30, 30, 36, 36, 37, 67, 67, 65, 45, 45, 45, 28, 26, 27, 33, 28, 30, 124, 135, 131, 130, 141, 138, 142, 153, 151, 146, 156, 157, 152, 162, 163, 151, 161, 165, 151, 161, 165, 153, 162, 167, 153, 162, 167, 153, 165, 169, 156, 169, 172, 163, 173, 178, 172, 181, 185, 98, 106, 111, 140, 150, 149, 55, 56, 56, 71, 75, 74, 84, 88, 88, 67, 71, 74, 56, 56, 61, 53, 58, 60, 175, 187, 187, 181, 185, 184, 59, 65, 68, 77, 86, 92, 99, 105, 102, 29, 30, 29, 38, 38, 38, 55, 55, 52, 57, 57, 57, 32, 32, 32, 28, 24, 25, 117, 126, 124, 119, 129, 129, 108, 118, 119, 112, 121, 125, 122, 131, 135, 133, 142, 147, 144, 153, 158, 153, 160, 165, 163, 169, 175, 168, 178, 183, 173, 183, 188, 177, 187, 191, 177, 186, 191, 121, 129, 134, 127, 136, 136, 45, 46, 46, 50, 53, 52, 76, 80, 80, 45, 49, 52, 39, 40, 44, 55, 60, 63, 168, 183, 181, 190, 204, 199, 34, 36, 41, 71, 79, 82, 87, 94, 92, 29, 30, 29, 71, 71, 70, 82, 83, 80, 60, 60, 60, 53, 55, 54, 25, 22, 23, 110, 115, 116, 109, 118, 121, 76, 85, 89, 64, 73, 80, 59, 68, 75, 57, 66, 71, 60, 68, 73, 58, 61, 68, 57, 60, 67, 56, 63, 69, 59, 66, 72, 62, 71, 76, 71, 80, 85, 87, 95, 100, 108, 117, 117, 37, 38, 37, 36, 40, 39, 99, 103, 103, 61, 65, 68, 26, 26, 30, 56, 61, 63, 169, 183, 182, 163, 176, 171, 8, 9, 13, 34, 38, 42, 51, 59, 58, 23, 26, 26, 86, 86, 86, 105, 106, 103, 62, 62, 62, 55, 59, 58, 24, 21, 22, 96, 99, 101, 98, 107, 112, 78, 87, 93, 62, 71, 80, 62, 71, 79, 64, 73, 78, 65, 73, 79, 71, 72, 79, 67, 67, 75, 60, 64, 70, 59, 64, 70, 58, 66, 71, 62, 71, 76, 71, 78, 84, 83, 93, 92, 23, 25, 24, 61, 65, 64, 98, 102, 102, 80, 84, 87, 33, 34, 38, 45, 50, 52, 95, 108, 107, 82, 86, 85, 3, 3, 4, 4, 5, 6, 8, 11, 11, 14, 15, 16, 88, 88, 86, 47, 48, 46, 47, 48, 44, 31, 32, 30, 21, 20, 20, 78, 81, 82, 78, 84, 88, 68, 73, 78, 61, 64, 70, 60, 64, 69, 61, 65, 69, 63, 67, 71, 65, 68, 72, 60, 62, 67, 55, 58, 65, 54, 57, 64, 55, 61, 65, 59, 65, 68, 59, 65, 69, 52, 58, 60, 11, 13, 14, 69, 70, 70, 56, 57, 59, 49, 52, 58, 33, 34, 39, 11, 13, 13, 29, 33, 33, 42, 42, 42, 4, 4, 4, 5, 5, 4, 1, 1, 1, 8, 8, 9, 114, 115, 112, 43, 43, 44, 51, 51, 49, 30, 30, 29, 11, 11, 11, 32, 33, 34, 29, 32, 35, 25, 27, 30, 22, 21, 24, 22, 21, 25, 20, 19, 23, 19, 18, 22, 17, 20, 22, 14, 17, 20, 13, 16, 22, 11, 13, 19, 15, 17, 21, 16, 19, 21, 15, 17, 20, 11, 14, 17, 4, 5, 6, 44, 44, 44, 119, 119, 122, 56, 59, 65, 13, 15, 20, 6, 5, 5, 38, 37, 37, 54, 54, 54, 3, 3, 3, 5, 5, 5, 3, 4, 4, 9, 9, 11, 57, 58, 56, 92, 91, 95, 81, 80, 85, 27, 26, 28, 7, 7, 7, 4, 4, 4, 1, 1, 3, 1, 1, 2, 1, 1, 2, 2, 1, 3, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 2, 2, 2, 6, 1, 0, 5, 1, 2, 4, 1, 1, 2, 1, 1, 2, 0, 0, 0, 3, 3, 3, 11, 11, 11, 59, 59, 61, 34, 34, 39, 14, 15, 18, 29, 29, 29, 50, 50, 50, 52, 52, 52, 3, 3, 3, 1, 1, 1, 0, 0, 0, 2, 2, 4, 4, 5, 4, 48, 47, 52, 44, 43, 49, 6, 6, 8, 4, 4, 4, 6, 6, 6, 9, 9, 9, 12, 11, 11, 16, 12, 13, 18, 14, 15, 20, 16, 17, 28, 25, 26, 27, 27, 27, 25, 25, 25, 20, 20, 22, 27, 27, 29, 35, 35, 35, 36, 36, 36, 34, 34, 34, 24, 24, 24, 14, 14, 14, 16, 15, 15, 14, 14, 15, 30, 29, 32, 51, 51, 53, 61, 61, 61, 66, 66, 66, 63, 63, 63, 42, 42, 42, 32, 32, 32, 26, 26, 27, 20, 20, 21, 18, 18, 17, 17, 16, 18, 17, 17, 17, 42, 42, 42, 37, 37, 37, 35, 34, 33, 35, 32, 30, 36, 33, 31, 44, 37, 37, 47, 40, 39, 54, 47, 47, 63, 56, 55, 58, 55, 53, 51, 49, 47, 40, 37, 38, 50, 47, 48, 57, 55, 53, 61, 59, 57, 67, 65, 63, 71, 69, 66, 57, 56, 54, 53, 53, 53, 56, 55, 55, 56, 54, 55, 51, 49, 49, 51, 51, 51, 49, 49, 49, 53, 53, 53], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387856}, {\"format\": \"raw\", \"value\": [241, 241, 241, 238, 238, 238, 240, 240, 240, 242, 242, 242, 243, 243, 243, 242, 242, 242, 242, 242, 242, 243, 243, 243, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 246, 246, 246, 247, 247, 247, 246, 246, 246, 246, 246, 246, 246, 246, 246, 245, 245, 245, 245, 245, 245, 243, 243, 243, 243, 243, 243, 246, 246, 246, 246, 246, 246, 242, 242, 242, 244, 244, 244, 245, 245, 245, 246, 246, 246, 246, 246, 246, 246, 246, 246, 246, 246, 246, 247, 247, 247, 248, 248, 248, 248, 248, 248, 249, 249, 249, 248, 248, 248, 249, 249, 249, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 246, 246, 246, 246, 246, 246, 245, 245, 245, 245, 245, 245, 245, 245, 245, 243, 243, 243, 245, 245, 245, 250, 250, 250, 247, 247, 247, 247, 247, 247, 248, 248, 248, 248, 248, 248, 248, 248, 248, 249, 249, 249, 249, 249, 249, 250, 250, 250, 250, 250, 250, 249, 249, 249, 250, 250, 250, 250, 250, 250, 251, 251, 251, 250, 250, 250, 250, 250, 250, 250, 250, 250, 249, 249, 249, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 249, 249, 249, 249, 249, 249, 248, 248, 248, 248, 248, 248, 248, 248, 248, 247, 247, 247, 247, 247, 247, 247, 247, 247, 245, 245, 245, 248, 248, 248, 252, 252, 252, 248, 248, 248, 249, 249, 249, 250, 250, 250, 250, 250, 250, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 250, 250, 250, 251, 251, 251, 250, 250, 250, 250, 250, 250, 250, 250, 250, 249, 249, 249, 249, 249, 249, 249, 249, 249, 248, 248, 248, 248, 248, 248, 247, 247, 247, 246, 246, 246, 245, 245, 245, 245, 245, 245, 244, 244, 244, 243, 243, 243, 242, 242, 242, 242, 242, 242, 241, 241, 241, 239, 239, 239, 242, 242, 242, 247, 247, 247, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 243, 243, 243, 243, 243, 243, 244, 244, 244, 243, 243, 243, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 243, 243, 243, 243, 243, 243, 243, 243, 243, 243, 243, 243, 242, 242, 242, 242, 242, 242, 242, 242, 242, 242, 242, 242, 241, 241, 241, 241, 241, 241, 240, 240, 240, 240, 240, 240, 239, 239, 239, 243, 243, 243, 243, 243, 243, 239, 239, 239, 240, 240, 240, 242, 242, 242, 242, 242, 242, 243, 243, 243, 243, 243, 243, 243, 243, 243, 244, 244, 244, 244, 244, 244, 245, 245, 245, 246, 246, 246, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 246, 246, 246, 247, 247, 247, 247, 247, 247, 248, 248, 248, 248, 248, 248, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 245, 245, 245, 244, 244, 244, 242, 242, 242, 245, 245, 245, 249, 249, 249, 246, 246, 246, 246, 246, 246, 247, 247, 247, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 249, 249, 249, 249, 249, 249, 250, 250, 250, 250, 250, 250, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 247, 247, 247, 246, 246, 246, 246, 246, 246, 244, 244, 244, 246, 246, 246, 250, 250, 250, 247, 247, 247, 248, 248, 248, 248, 248, 248, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 251, 251, 251, 251, 251, 251, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 250, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 248, 248, 248, 246, 246, 246, 245, 245, 245, 244, 244, 244, 247, 247, 247, 251, 251, 251, 248, 248, 248, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 250, 250, 250, 251, 251, 251, 250, 250, 250, 250, 250, 250, 250, 250, 250, 251, 251, 251, 251, 251, 251, 250, 250, 250, 250, 250, 250, 249, 249, 249, 249, 249, 249, 248, 248, 248, 248, 248, 248, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 246, 246, 246, 245, 245, 245, 245, 245, 245, 244, 244, 244, 243, 243, 243, 243, 243, 243, 243, 243, 243, 245, 245, 245, 246, 246, 246, 243, 243, 243, 244, 244, 244, 245, 245, 245, 246, 246, 246, 247, 246, 247, 248, 247, 247, 248, 248, 248, 248, 249, 249, 249, 250, 249, 250, 250, 250, 250, 250, 250, 251, 251, 251, 251, 251, 251, 251, 251, 251, 252, 252, 252, 252, 252, 252, 252, 252, 252, 251, 251, 251, 250, 250, 250, 249, 249, 249, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 248, 247, 247, 247, 248, 248, 248, 247, 247, 247, 249, 249, 249, 250, 250, 250, 247, 247, 247, 248, 248, 248, 249, 250, 249, 250, 251, 250, 252, 251, 252, 253, 252, 252, 252, 253, 253, 250, 254, 253, 252, 254, 253, 254, 254, 254, 255, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 254, 255, 254, 254, 254, 253, 252, 253, 252, 251, 252, 252, 251, 251, 252, 251, 251, 251, 250, 251, 250, 250, 250, 249, 250, 249, 250, 250, 250, 250, 250, 250, 248, 248, 248, 247, 247, 247, 248, 248, 248, 247, 247, 247, 249, 249, 249, 252, 252, 252, 249, 249, 249, 250, 250, 250, 252, 252, 252, 254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 252, 252, 252, 247, 247, 247, 245, 245, 245, 242, 242, 242, 242, 242, 242, 246, 247, 247, 253, 252, 253, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 253, 252, 252, 253, 252, 252, 252, 252, 252, 251, 251, 251, 251, 251, 251, 250, 250, 250, 249, 249, 249, 248, 248, 248, 248, 248, 248, 247, 247, 247, 249, 249, 249, 253, 253, 253, 251, 251, 251, 251, 251, 251, 253, 253, 253, 254, 254, 254, 252, 253, 253, 240, 243, 242, 228, 229, 229, 223, 219, 222, 217, 215, 218, 214, 217, 218, 219, 224, 224, 220, 222, 221, 220, 221, 221, 218, 220, 219, 212, 213, 213, 199, 199, 201, 185, 184, 186, 180, 179, 182, 189, 188, 190, 219, 221, 222, 251, 254, 253, 253, 254, 254, 251, 251, 251, 250, 250, 250, 249, 249, 249, 247, 247, 247, 246, 246, 246, 245, 245, 245, 243, 243, 243, 243, 243, 243, 244, 244, 244, 252, 252, 252, 250, 250, 250, 252, 252, 252, 252, 251, 251, 253, 253, 253, 182, 185, 184, 106, 114, 112, 94, 100, 100, 109, 110, 113, 109, 112, 115, 126, 132, 134, 124, 131, 132, 203, 206, 205, 203, 206, 205, 135, 138, 137, 110, 113, 112, 113, 118, 119, 80, 85, 87, 77, 82, 84, 110, 115, 117, 90, 98, 96, 152, 159, 157, 245, 248, 247, 255, 255, 255, 252, 251, 252, 251, 251, 251, 250, 250, 250, 249, 249, 249, 247, 247, 247, 246, 246, 246, 245, 245, 245, 248, 248, 248, 253, 253, 253, 251, 251, 251, 253, 253, 253, 255, 254, 255, 232, 232, 232, 84, 89, 87, 44, 55, 51, 113, 126, 123, 125, 137, 138, 121, 132, 133, 126, 137, 138, 29, 38, 39, 160, 166, 164, 185, 190, 188, 102, 107, 105, 35, 40, 39, 83, 94, 94, 119, 133, 133, 123, 137, 137, 154, 167, 168, 130, 143, 140, 77, 88, 84, 138, 143, 142, 223, 222, 223, 247, 246, 246, 255, 255, 255, 253, 253, 253, 252, 252, 252, 251, 251, 251, 249, 249, 249, 247, 247, 247, 250, 250, 250, 255, 255, 255, 252, 253, 253, 252, 254, 254, 251, 252, 253, 131, 132, 133, 18, 23, 23, 37, 45, 43, 102, 114, 114, 53, 69, 71, 44, 59, 60, 63, 78, 77, 21, 35, 33, 170, 183, 181, 198, 209, 207, 158, 165, 163, 77, 81, 80, 83, 91, 91, 130, 139, 141, 146, 155, 158, 160, 169, 172, 160, 168, 170, 146, 152, 152, 73, 76, 77, 137, 137, 139, 229, 229, 230, 252, 252, 252, 254, 254, 254, 254, 254, 254, 252, 252, 252, 250, 250, 250, 248, 248, 248, 250, 250, 250, 255, 255, 255, 251, 253, 253, 255, 255, 255, 215, 217, 218, 100, 104, 105, 85, 89, 90, 94, 97, 98, 98, 104, 104, 89, 96, 95, 80, 75, 72, 46, 27, 24, 50, 26, 23, 144, 128, 130, 194, 185, 187, 204, 203, 203, 186, 192, 190, 192, 194, 195, 197, 198, 201, 201, 202, 207, 205, 206, 212, 203, 203, 209, 210, 211, 215, 147, 148, 152, 122, 123, 127, 218, 219, 221, 228, 228, 228, 240, 240, 240, 251, 251, 251, 252, 252, 252, 249, 249, 249, 245, 245, 245, 247, 247, 247, 255, 255, 255, 255, 254, 255, 225, 219, 222, 165, 164, 166, 182, 186, 188, 173, 177, 179, 183, 187, 189, 194, 199, 198, 194, 192, 187, 144, 118, 114, 89, 33, 31, 110, 40, 39, 92, 35, 41, 114, 77, 82, 204, 192, 194, 220, 227, 226, 199, 203, 204, 190, 191, 194, 189, 190, 195, 182, 182, 189, 187, 188, 193, 196, 197, 201, 181, 182, 186, 169, 170, 174, 200, 201, 204, 205, 206, 207, 228, 229, 230, 228, 229, 230, 241, 241, 242, 249, 249, 249, 245, 245, 245, 246, 246, 246, 255, 255, 255, 255, 254, 255, 191, 182, 185, 137, 134, 139, 165, 169, 173, 160, 163, 168, 158, 161, 165, 165, 169, 173, 163, 161, 165, 130, 114, 116, 125, 93, 93, 127, 84, 83, 107, 69, 68, 121, 95, 95, 202, 192, 192, 199, 200, 201, 180, 182, 184, 163, 164, 167, 157, 158, 163, 153, 153, 160, 158, 159, 164, 165, 166, 170, 169, 170, 174, 175, 176, 180, 173, 174, 178, 189, 190, 192, 178, 180, 182, 113, 115, 117, 190, 191, 193, 255, 255, 255, 252, 252, 252, 252, 252, 252, 255, 255, 255, 253, 253, 253, 195, 192, 193, 162, 161, 166, 162, 165, 171, 162, 165, 172, 160, 163, 169, 181, 184, 191, 187, 189, 197, 179, 181, 187, 165, 166, 170, 143, 144, 144, 136, 134, 129, 152, 150, 147, 143, 143, 142, 91, 92, 92, 103, 104, 106, 156, 157, 160, 148, 149, 153, 149, 149, 156, 153, 154, 159, 156, 157, 161, 160, 161, 165, 163, 163, 168, 164, 166, 170, 164, 167, 170, 106, 110, 113, 59, 63, 66, 126, 129, 131, 252, 253, 253, 254, 254, 254, 254, 254, 254, 255, 255, 255, 246, 249, 249, 186, 190, 190, 177, 180, 184, 181, 184, 190, 181, 183, 190, 190, 192, 199, 202, 205, 210, 203, 207, 210, 195, 198, 202, 173, 176, 182, 152, 156, 162, 145, 149, 150, 134, 138, 139, 79, 83, 82, 80, 85, 83, 70, 73, 73, 123, 124, 126, 162, 163, 167, 158, 159, 165, 163, 164, 169, 166, 167, 171, 168, 170, 173, 168, 170, 173, 166, 169, 172, 138, 143, 147, 87, 91, 95, 90, 94, 98, 118, 121, 124, 241, 241, 241, 255, 255, 255, 255, 255, 255, 255, 255, 255, 237, 239, 239, 143, 145, 147, 125, 127, 130, 134, 136, 140, 139, 140, 145, 145, 147, 151, 158, 160, 163, 177, 178, 180, 174, 176, 178, 161, 162, 165, 154, 155, 159, 141, 142, 145, 110, 112, 112, 62, 64, 63, 95, 98, 94, 92, 94, 92, 104, 106, 106, 174, 175, 178, 173, 174, 179, 174, 177, 180, 175, 179, 180, 176, 179, 181, 177, 181, 182, 176, 180, 182, 132, 137, 139, 89, 91, 94, 118, 118, 121, 127, 127, 130, 238, 238, 237, 255, 255, 255, 255, 255, 255, 255, 255, 255, 225, 226, 225, 74, 76, 74, 58, 60, 59, 63, 64, 65, 66, 68, 68, 70, 72, 72, 83, 85, 85, 102, 104, 103, 91, 93, 91, 77, 79, 77, 141, 143, 143, 146, 147, 150, 95, 96, 97, 58, 60, 58, 115, 117, 113, 111, 113, 111, 98, 100, 100, 151, 152, 154, 150, 151, 155, 145, 148, 151, 142, 146, 147, 143, 147, 148, 147, 151, 152, 155, 160, 160, 125, 130, 127, 95, 98, 96, 126, 126, 125, 132, 132, 131, 228, 229, 229, 244, 244, 245, 244, 244, 244, 255, 255, 254, 232, 234, 231, 87, 89, 86, 53, 56, 53, 53, 55, 52, 51, 53, 50, 50, 52, 49, 56, 58, 55, 64, 66, 63, 49, 51, 48, 29, 31, 28, 98, 100, 99, 155, 156, 159, 77, 79, 80, 62, 64, 62, 118, 120, 116, 106, 108, 106, 94, 95, 95, 141, 142, 145, 145, 146, 151, 145, 148, 152, 144, 148, 151, 144, 148, 151, 146, 149, 153, 134, 139, 139, 85, 90, 87, 89, 92, 88, 99, 100, 98, 136, 137, 136, 196, 197, 201, 201, 202, 206, 202, 203, 207, 222, 224, 224, 221, 223, 223, 131, 132, 133, 19, 21, 20, 23, 24, 23, 21, 22, 21, 40, 42, 41, 103, 105, 104, 117, 119, 119, 104, 106, 106, 84, 85, 85, 108, 109, 111, 139, 140, 143, 44, 46, 46, 55, 57, 55, 93, 95, 92, 88, 90, 88, 57, 59, 59, 83, 84, 87, 101, 102, 106, 103, 105, 110, 108, 111, 117, 111, 114, 120, 121, 124, 129, 103, 107, 109, 30, 35, 34, 63, 65, 66, 118, 118, 119, 153, 153, 155, 169, 171, 178, 168, 170, 177, 170, 172, 179, 183, 184, 190, 182, 182, 189, 164, 164, 171, 53, 54, 58, 5, 6, 9, 2, 3, 7, 62, 63, 66, 141, 142, 147, 142, 142, 148, 133, 134, 140, 124, 125, 131, 117, 117, 123, 97, 98, 101, 30, 32, 32, 30, 32, 30, 80, 82, 79, 87, 89, 87, 56, 58, 59, 75, 76, 79, 95, 96, 100, 103, 105, 111, 111, 114, 120, 118, 121, 128, 126, 129, 136, 130, 134, 139, 120, 124, 129, 125, 126, 133, 148, 148, 154, 163, 163, 171, 162, 165, 173, 160, 163, 172, 162, 165, 174, 170, 172, 179, 160, 162, 169, 144, 146, 153, 108, 109, 115, 60, 61, 66, 57, 58, 63, 80, 81, 86, 96, 97, 102, 94, 96, 103, 89, 91, 98, 87, 89, 96, 89, 91, 98, 94, 97, 99, 91, 94, 95, 91, 94, 94, 116, 119, 119, 136, 138, 143, 145, 147, 155, 152, 153, 162, 155, 157, 166, 163, 165, 172, 166, 168, 174, 165, 167, 173, 165, 167, 173, 163, 166, 173, 161, 164, 173, 161, 163, 173, 161, 162, 172, 158, 159, 169, 155, 159, 168, 153, 157, 166, 155, 159, 168, 164, 167, 172, 160, 163, 168, 154, 157, 162, 154, 156, 161, 154, 155, 160, 154, 155, 160, 151, 152, 157, 148, 150, 155, 148, 151, 156, 149, 152, 157, 152, 155, 160, 157, 160, 165, 158, 161, 166, 158, 161, 166, 159, 162, 167, 159, 162, 168, 160, 163, 173, 161, 164, 175, 161, 164, 175, 161, 164, 175, 165, 167, 174, 164, 165, 170, 162, 163, 168, 162, 163, 168, 160, 162, 169, 157, 160, 169, 156, 159, 167, 156, 159, 167, 156, 159, 167, 157, 160, 168, 156, 159, 168, 158, 161, 170, 159, 162, 167, 157, 160, 165, 158, 161, 166, 160, 162, 167, 163, 164, 169, 163, 164, 169, 163, 164, 169, 162, 164, 169, 159, 162, 167, 156, 159, 164, 160, 163, 167, 160, 163, 169, 161, 164, 172, 161, 164, 173, 161, 164, 173, 162, 165, 174, 163, 166, 174, 163, 166, 175, 163, 166, 175, 161, 164, 173, 165, 167, 174, 163, 164, 169, 162, 163, 168, 165, 166, 171, 165, 167, 173, 163, 166, 173, 162, 165, 172, 162, 165, 172, 159, 162, 169, 157, 160, 167, 158, 161, 168, 161, 164, 171, 165, 168, 173, 163, 166, 171, 163, 166, 171, 164, 166, 171, 165, 166, 171, 166, 167, 172, 168, 169, 174, 166, 168, 173, 162, 165, 170, 160, 163, 168, 161, 164, 169, 162, 165, 170, 162, 165, 173, 162, 165, 174, 162, 165, 174, 162, 165, 173, 161, 164, 172, 162, 165, 172, 163, 166, 173, 161, 164, 172, 163, 165, 171, 164, 165, 170, 165, 166, 171, 166, 167, 172, 166, 167, 172, 162, 165, 170, 160, 163, 169, 159, 162, 167, 158, 161, 167, 157, 160, 165, 157, 160, 165, 160, 163, 168, 154, 157, 163, 152, 155, 160, 154, 157, 162, 154, 155, 161, 154, 155, 160, 155, 156, 161, 153, 154, 159, 151, 153, 158, 149, 152, 157, 151, 154, 159, 154, 157, 162, 150, 153, 158, 148, 152, 157, 149, 152, 158, 148, 151, 157, 146, 150, 155, 148, 151, 157, 146, 149, 155, 146, 149, 155, 146, 149, 155, 147, 149, 155, 152, 152, 158, 148, 149, 154, 148, 149, 154, 145, 147, 152, 145, 148, 152, 149, 152, 156, 148, 151, 155, 147, 150, 154, 147, 151, 155, 145, 149, 152, 147, 151, 155, 54, 56, 60, 53, 55, 59, 54, 56, 60, 55, 56, 60, 55, 56, 59, 55, 55, 59, 71, 71, 75, 74, 75, 79, 73, 75, 78, 70, 72, 75, 54, 56, 60, 69, 71, 74, 71, 73, 75, 71, 74, 75, 66, 69, 70, 63, 66, 68, 64, 66, 70, 70, 72, 76, 67, 69, 73, 67, 69, 72, 62, 64, 67, 55, 55, 59, 64, 64, 68, 67, 68, 71, 72, 73, 77, 65, 68, 70, 51, 53, 55, 53, 55, 58, 50, 53, 55, 51, 53, 56, 51, 53, 55, 52, 54, 56], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387920}, {\"format\": \"raw\", \"value\": [45, 65, 92, 72, 95, 110, 106, 132, 129, 106, 132, 129, 109, 134, 131, 111, 137, 134, 111, 139, 135, 115, 145, 142, 91, 112, 107, 85, 100, 96, 92, 113, 110, 84, 102, 99, 116, 141, 138, 122, 148, 145, 122, 148, 145, 123, 148, 145, 122, 148, 145, 122, 148, 145, 122, 148, 145, 122, 148, 145, 122, 148, 145, 123, 148, 144, 123, 147, 144, 123, 147, 143, 122, 150, 146, 108, 104, 113, 93, 45, 73, 72, 38, 64, 41, 23, 43, 23, 18, 24, 36, 31, 20, 52, 44, 29, 46, 67, 96, 76, 100, 113, 110, 136, 133, 109, 135, 133, 111, 138, 135, 111, 139, 136, 109, 136, 133, 116, 146, 142, 77, 92, 89, 75, 80, 77, 104, 124, 118, 105, 125, 121, 125, 151, 148, 124, 151, 148, 125, 151, 148, 126, 152, 149, 126, 152, 149, 126, 152, 149, 126, 152, 149, 125, 151, 149, 126, 152, 148, 127, 152, 148, 126, 151, 147, 126, 151, 147, 124, 155, 150, 104, 102, 111, 75, 34, 63, 75, 41, 67, 73, 46, 73, 37, 24, 40, 19, 13, 21, 44, 36, 35, 48, 68, 97, 79, 103, 115, 110, 137, 133, 110, 136, 133, 112, 140, 137, 113, 142, 139, 102, 128, 126, 99, 126, 124, 78, 85, 81, 94, 94, 87, 95, 109, 104, 100, 118, 115, 127, 154, 151, 126, 152, 149, 127, 152, 149, 127, 153, 149, 127, 153, 150, 127, 153, 150, 127, 153, 150, 127, 152, 149, 127, 152, 149, 127, 152, 149, 127, 152, 148, 127, 151, 148, 125, 154, 149, 107, 110, 116, 91, 62, 83, 101, 71, 95, 99, 75, 99, 67, 50, 70, 41, 33, 51, 57, 48, 52, 51, 72, 99, 83, 109, 118, 111, 139, 135, 111, 140, 136, 114, 143, 140, 120, 147, 146, 108, 134, 133, 90, 116, 113, 92, 92, 84, 112, 103, 91, 93, 98, 93, 106, 121, 120, 127, 154, 150, 128, 155, 151, 130, 154, 151, 130, 155, 152, 131, 156, 153, 131, 156, 153, 130, 155, 152, 130, 155, 152, 129, 154, 151, 130, 154, 152, 129, 154, 151, 129, 154, 151, 126, 151, 147, 123, 134, 134, 124, 121, 126, 125, 121, 128, 123, 118, 127, 106, 103, 113, 94, 94, 104, 100, 99, 104, 53, 75, 99, 87, 114, 119, 112, 141, 137, 113, 142, 138, 115, 145, 141, 114, 142, 141, 105, 132, 131, 85, 109, 106, 84, 79, 70, 127, 115, 100, 115, 101, 91, 106, 86, 88, 112, 114, 113, 128, 153, 149, 133, 157, 156, 134, 156, 154, 134, 158, 155, 134, 157, 155, 133, 157, 154, 132, 157, 154, 132, 156, 154, 133, 157, 155, 131, 157, 154, 132, 155, 155, 129, 153, 151, 128, 147, 145, 128, 142, 140, 126, 140, 139, 125, 137, 138, 119, 131, 131, 117, 129, 129, 122, 133, 133, 53, 76, 101, 90, 118, 124, 112, 143, 138, 113, 144, 139, 114, 145, 142, 108, 137, 135, 101, 130, 128, 83, 106, 104, 73, 65, 58, 127, 116, 102, 139, 125, 113, 115, 62, 66, 110, 64, 73, 128, 145, 144, 137, 163, 162, 137, 160, 157, 139, 161, 159, 138, 161, 158, 137, 161, 158, 135, 160, 157, 134, 159, 156, 127, 147, 142, 112, 125, 117, 124, 141, 136, 127, 148, 145, 122, 143, 138, 122, 140, 134, 123, 143, 139, 120, 146, 144, 117, 144, 141, 117, 142, 139, 117, 143, 139, 52, 75, 102, 95, 123, 131, 113, 143, 139, 113, 144, 141, 115, 145, 143, 105, 134, 132, 101, 131, 129, 85, 109, 108, 65, 58, 53, 111, 101, 93, 141, 134, 124, 122, 91, 86, 115, 69, 76, 131, 146, 145, 136, 163, 161, 136, 162, 158, 137, 164, 160, 138, 164, 160, 137, 163, 161, 137, 162, 160, 113, 127, 121, 96, 92, 83, 83, 73, 64, 91, 88, 80, 113, 120, 111, 100, 103, 98, 97, 96, 87, 115, 123, 115, 117, 140, 136, 112, 138, 133, 114, 140, 135, 114, 142, 139, 46, 69, 95, 99, 127, 135, 115, 145, 142, 114, 143, 141, 115, 145, 143, 104, 134, 132, 100, 131, 129, 87, 112, 111, 64, 58, 53, 95, 83, 75, 121, 113, 102, 108, 96, 82, 115, 97, 92, 153, 159, 158, 160, 173, 172, 153, 166, 165, 151, 165, 165, 141, 157, 156, 136, 157, 154, 123, 139, 136, 71, 65, 59, 71, 57, 48, 84, 72, 63, 69, 59, 53, 108, 104, 99, 145, 142, 142, 121, 113, 108, 105, 100, 92, 98, 99, 91, 90, 91, 84, 85, 85, 80, 92, 96, 89, 39, 61, 87, 95, 124, 131, 117, 147, 144, 114, 144, 142, 116, 146, 144, 114, 144, 142, 113, 143, 142, 97, 123, 122, 64, 59, 55, 83, 72, 62, 108, 100, 88, 106, 94, 82, 93, 80, 72, 122, 117, 110, 170, 166, 162, 188, 186, 184, 187, 187, 184, 165, 164, 161, 163, 162, 160, 116, 114, 111, 66, 50, 41, 74, 58, 47, 73, 61, 52, 70, 60, 53, 79, 71, 64, 146, 143, 136, 195, 197, 194, 144, 142, 140, 101, 92, 87, 98, 88, 80, 64, 53, 47, 83, 70, 59, 43, 64, 89, 94, 123, 130, 116, 147, 144, 114, 144, 142, 117, 146, 144, 117, 148, 146, 118, 148, 145, 83, 102, 99, 55, 49, 44, 78, 67, 58, 87, 79, 70, 87, 76, 67, 85, 75, 66, 79, 68, 59, 93, 84, 76, 164, 161, 156, 198, 197, 194, 186, 184, 180, 164, 160, 156, 110, 104, 98, 94, 78, 62, 101, 83, 65, 91, 75, 64, 81, 70, 61, 89, 78, 66, 140, 133, 120, 209, 211, 206, 194, 195, 194, 139, 133, 129, 120, 111, 102, 86, 75, 67, 104, 87, 70, 45, 65, 89, 93, 118, 125, 115, 142, 138, 115, 144, 141, 119, 149, 146, 118, 150, 147, 87, 106, 104, 37, 37, 36, 52, 44, 39, 79, 70, 63, 93, 85, 78, 94, 86, 78, 101, 91, 80, 91, 81, 71, 84, 73, 63, 123, 116, 108, 171, 170, 166, 153, 151, 146, 128, 125, 119, 89, 84, 78, 77, 63, 50, 102, 83, 65, 108, 93, 78, 100, 89, 77, 91, 79, 66, 138, 131, 120, 213, 212, 206, 215, 215, 212, 184, 181, 176, 149, 140, 128, 135, 121, 106, 131, 112, 89, 48, 61, 82, 90, 94, 92, 101, 107, 96, 97, 107, 99, 102, 119, 112, 93, 108, 103, 57, 57, 54, 47, 39, 36, 72, 65, 60, 89, 84, 79, 111, 103, 95, 118, 117, 104, 107, 109, 88, 120, 111, 97, 111, 101, 89, 109, 99, 87, 131, 127, 121, 95, 90, 83, 89, 81, 74, 92, 84, 75, 66, 57, 49, 75, 61, 51, 92, 79, 68, 110, 100, 90, 110, 100, 91, 162, 159, 152, 203, 205, 199, 202, 203, 198, 196, 195, 192, 179, 173, 166, 165, 154, 140, 137, 121, 103, 48, 55, 68, 89, 82, 75, 110, 101, 92, 103, 94, 86, 84, 78, 71, 66, 59, 52, 66, 57, 49, 69, 60, 54, 102, 97, 94, 137, 139, 137, 150, 142, 136, 132, 142, 117, 93, 135, 97, 119, 112, 100, 107, 95, 84, 130, 116, 102, 155, 151, 144, 115, 110, 100, 106, 98, 89, 120, 111, 99, 121, 113, 102, 115, 106, 95, 124, 116, 105, 150, 147, 140, 144, 142, 136, 163, 162, 154, 149, 146, 136, 144, 140, 131, 182, 182, 177, 219, 221, 220, 204, 201, 197, 147, 138, 132, 52, 61, 65, 73, 66, 61, 125, 120, 113, 127, 124, 121, 104, 97, 92, 81, 71, 63, 79, 72, 64, 80, 74, 67, 123, 121, 117, 193, 198, 196, 193, 190, 186, 132, 130, 111, 101, 113, 87, 119, 111, 100, 125, 113, 99, 171, 158, 142, 185, 184, 177, 154, 150, 143, 130, 120, 107, 135, 126, 112, 158, 156, 147, 168, 164, 154, 180, 178, 169, 182, 183, 176, 145, 142, 131, 132, 125, 111, 121, 110, 95, 128, 120, 104, 195, 195, 187, 243, 245, 242, 236, 238, 238, 172, 166, 164, 79, 97, 95, 50, 44, 41, 109, 98, 86, 136, 126, 116, 120, 112, 102, 86, 78, 69, 74, 67, 61, 83, 75, 69, 130, 120, 112, 182, 181, 177, 211, 213, 212, 170, 165, 160, 131, 119, 111, 135, 128, 117, 156, 145, 130, 194, 186, 174, 198, 199, 194, 179, 179, 174, 144, 136, 126, 129, 116, 99, 159, 154, 142, 183, 183, 177, 190, 191, 185, 156, 152, 141, 125, 116, 101, 111, 100, 85, 127, 113, 96, 158, 150, 131, 222, 222, 216, 247, 247, 245, 241, 244, 245, 186, 178, 172, 106, 135, 133, 54, 63, 63, 58, 50, 46, 116, 103, 96, 114, 104, 96, 82, 72, 63, 71, 63, 57, 104, 100, 95, 140, 137, 121, 149, 140, 127, 182, 180, 176, 198, 196, 193, 192, 188, 184, 175, 170, 164, 167, 159, 148, 198, 196, 188, 193, 194, 188, 162, 161, 155, 149, 140, 132, 135, 120, 104, 157, 147, 131, 192, 191, 183, 159, 155, 146, 107, 96, 84, 97, 85, 71, 92, 79, 65, 120, 106, 87, 179, 171, 154, 241, 241, 237, 249, 249, 247, 243, 245, 248, 185, 174, 163, 114, 146, 145, 99, 124, 122, 50, 55, 54, 59, 50, 47, 87, 75, 66, 71, 62, 52, 81, 67, 61, 91, 100, 80, 72, 135, 93, 88, 83, 64, 146, 137, 135, 199, 186, 185, 203, 185, 181, 217, 213, 210, 207, 205, 201, 188, 184, 176, 155, 145, 133, 105, 91, 82, 132, 117, 102, 161, 154, 142, 169, 166, 156, 169, 166, 156, 115, 104, 90, 72, 59, 50, 71, 59, 51, 88, 77, 63, 114, 101, 82, 180, 172, 157, 244, 244, 240, 243, 244, 243, 215, 213, 213, 152, 135, 121, 113, 143, 141, 118, 148, 146, 95, 119, 116, 47, 54, 52, 54, 48, 44, 63, 55, 46, 85, 72, 62, 109, 105, 85, 88, 115, 85, 110, 99, 85, 152, 145, 143, 193, 177, 176, 206, 178, 173, 215, 208, 204, 197, 198, 194, 157, 147, 133, 108, 89, 74, 93, 72, 56, 124, 104, 81, 156, 147, 135, 169, 167, 159, 117, 109, 99, 77, 63, 51, 62, 50, 43, 73, 63, 54, 93, 82, 69, 110, 98, 81, 169, 163, 150, 237, 240, 237, 226, 227, 229, 147, 134, 127, 116, 93, 71, 114, 143, 141, 116, 144, 143, 118, 148, 145, 89, 113, 109, 55, 57, 55, 65, 55, 47, 80, 70, 60, 110, 102, 90, 114, 105, 95, 127, 118, 109, 173, 172, 169, 208, 203, 203, 201, 178, 177, 194, 174, 173, 169, 165, 157, 129, 115, 95, 91, 69, 52, 97, 75, 57, 110, 86, 62, 114, 95, 76, 123, 111, 94, 90, 77, 64, 66, 51, 42, 56, 43, 37, 73, 63, 52, 104, 94, 80, 113, 102, 87, 161, 157, 146, 211, 214, 214, 175, 173, 172, 110, 91, 77, 112, 87, 60, 112, 141, 139, 113, 142, 140, 117, 146, 145, 113, 144, 141, 66, 75, 74, 57, 47, 41, 77, 66, 57, 95, 84, 74, 107, 97, 87, 141, 134, 124, 174, 172, 169, 206, 210, 210, 193, 181, 181, 188, 167, 168, 153, 142, 135, 104, 84, 65, 80, 59, 42, 95, 72, 53, 105, 81, 58, 97, 75, 53, 92, 74, 56, 86, 71, 58, 73, 59, 51, 66, 54, 46, 74, 63, 53, 103, 93, 81, 109, 99, 89, 135, 131, 121, 148, 148, 143, 130, 125, 119, 102, 85, 72, 104, 79, 56, 108, 137, 135, 109, 138, 136, 112, 140, 138, 114, 143, 140, 70, 84, 83, 42, 35, 32, 82, 69, 59, 100, 87, 75, 128, 118, 106, 168, 161, 150, 176, 176, 170, 183, 183, 181, 179, 171, 170, 173, 165, 163, 120, 108, 97, 90, 69, 51, 74, 53, 39, 89, 66, 48, 106, 83, 58, 96, 74, 52, 81, 64, 48, 76, 63, 53, 74, 61, 51, 81, 69, 59, 89, 78, 66, 94, 85, 73, 100, 92, 83, 120, 115, 106, 136, 134, 124, 121, 116, 109, 91, 76, 69, 85, 64, 48, 102, 131, 130, 104, 133, 132, 106, 136, 134, 110, 143, 140, 83, 106, 104, 37, 36, 35, 64, 52, 46, 100, 85, 74, 149, 136, 123, 181, 175, 164, 190, 190, 184, 194, 195, 191, 180, 179, 174, 126, 120, 111, 93, 78, 63, 95, 76, 57, 73, 53, 40, 83, 61, 45, 100, 78, 55, 93, 71, 50, 79, 62, 46, 67, 54, 46, 73, 61, 51, 90, 80, 67, 100, 90, 77, 104, 95, 81, 130, 124, 109, 131, 126, 115, 125, 121, 113, 113, 106, 98, 79, 64, 57, 78, 58, 43, 97, 93, 100, 94, 104, 107, 94, 111, 111, 96, 118, 117, 91, 115, 114, 44, 53, 53, 49, 45, 45, 98, 91, 85, 159, 154, 146, 202, 203, 196, 209, 211, 206, 210, 213, 208, 164, 161, 153, 93, 80, 66, 96, 80, 63, 104, 88, 69, 75, 56, 43, 81, 61, 47, 99, 79, 58, 98, 76, 54, 87, 70, 53, 68, 55, 48, 45, 34, 31, 59, 51, 43, 86, 77, 66, 120, 111, 97, 147, 143, 127, 144, 138, 126, 101, 91, 85, 100, 91, 82, 88, 75, 63, 80, 58, 43, 124, 76, 96, 115, 66, 87, 115, 69, 89, 104, 69, 85, 80, 56, 68, 61, 45, 53, 53, 43, 47, 58, 52, 53, 107, 106, 107, 184, 185, 184, 202, 204, 200, 196, 198, 192, 131, 122, 114, 86, 70, 56, 97, 83, 68, 104, 90, 72, 78, 59, 47, 81, 63, 51, 99, 83, 65, 105, 87, 66, 88, 72, 57, 69, 58, 51, 48, 35, 31, 42, 30, 26, 58, 47, 40, 105, 96, 86, 119, 112, 104, 135, 129, 117, 127, 120, 110, 89, 79, 72, 96, 85, 74, 74, 55, 43, 118, 60, 81, 142, 83, 106, 152, 96, 120, 153, 99, 122, 143, 91, 113, 131, 80, 100, 123, 62, 81, 113, 42, 65, 100, 38, 60, 130, 102, 112, 170, 170, 171, 163, 164, 162, 110, 100, 92, 82, 67, 54, 94, 81, 68, 98, 85, 72, 77, 61, 50, 82, 65, 54, 100, 86, 70, 103, 86, 67, 68, 53, 44, 54, 45, 40, 86, 77, 63, 85, 74, 62, 94, 85, 74, 80, 70, 64, 79, 68, 61, 139, 132, 117, 125, 120, 110, 91, 83, 77, 90, 79, 71, 71, 56, 47, 88, 91, 92, 124, 118, 121, 129, 94, 106, 140, 94, 110, 149, 143, 147, 152, 157, 159, 159, 158, 160, 155, 130, 138, 166, 102, 124, 164, 95, 121, 167, 156, 167, 163, 165, 172, 131, 132, 133, 86, 83, 78, 86, 77, 68, 89, 78, 68, 80, 68, 60, 77, 62, 53, 89, 75, 61, 102, 89, 76, 62, 52, 45, 61, 49, 42, 75, 64, 57, 76, 68, 60, 91, 85, 72, 96, 89, 76, 102, 94, 80, 118, 110, 96, 82, 73, 69, 91, 82, 76, 82, 71, 65, 66, 52, 46, 108, 120, 124, 135, 148, 151, 147, 158, 159, 142, 150, 150, 132, 140, 138, 133, 142, 138, 151, 163, 157, 163, 173, 169, 159, 150, 154, 160, 120, 136, 154, 141, 151, 165, 170, 177, 151, 156, 163, 127, 132, 136, 96, 94, 92, 80, 73, 67, 80, 71, 64, 80, 71, 65, 111, 107, 103, 151, 153, 153, 136, 140, 143, 115, 115, 112, 89, 85, 82, 67, 59, 55, 65, 54, 50, 64, 55, 51, 69, 62, 58, 67, 58, 54, 68, 59, 54, 91, 84, 77, 65, 56, 53, 53, 40, 36, 44, 42, 47, 84, 88, 95, 134, 143, 149, 163, 173, 176, 160, 172, 171, 159, 168, 167, 164, 169, 166, 174, 180, 178, 178, 184, 185, 181, 189, 188, 154, 156, 158, 150, 154, 161, 149, 155, 162, 136, 143, 147, 120, 123, 126, 95, 95, 96, 93, 95, 96, 122, 127, 131, 165, 174, 180, 174, 184, 193, 175, 184, 191, 178, 187, 191, 166, 173, 178, 136, 141, 142, 124, 123, 122, 107, 104, 100, 85, 79, 76, 70, 63, 58, 82, 74, 67, 81, 73, 68, 54, 46, 45, 46, 33, 31, 30, 32, 32, 21, 16, 20, 59, 57, 65, 117, 123, 127, 163, 173, 175, 207, 215, 217, 223, 231, 231, 215, 224, 223, 217, 226, 227, 213, 225, 225, 166, 174, 176, 144, 151, 156, 142, 150, 157, 125, 131, 138, 107, 110, 117, 96, 100, 105, 101, 109, 118, 131, 140, 148, 146, 155, 163, 133, 142, 151, 141, 149, 158, 152, 160, 167, 160, 167, 176, 163, 170, 177, 161, 168, 173, 149, 154, 158, 129, 132, 136, 112, 114, 117, 110, 109, 111, 90, 87, 88, 60, 56, 58, 55, 48, 46, 72, 91, 91, 43, 47, 49, 19, 13, 17, 37, 32, 36, 99, 98, 101, 180, 182, 185, 213, 222, 224, 193, 198, 202, 161, 166, 171, 138, 143, 147, 122, 126, 133, 134, 141, 149, 149, 158, 167, 128, 138, 146, 97, 107, 115, 83, 89, 97, 64, 67, 74, 128, 133, 132, 123, 125, 128, 72, 64, 72, 78, 76, 82, 85, 88, 93, 89, 91, 95, 95, 96, 103, 122, 126, 134, 122, 129, 138, 129, 137, 150, 129, 137, 152, 120, 126, 141, 102, 107, 119, 94, 98, 107, 109, 113, 116, 88, 113, 116, 83, 103, 104, 55, 64, 65, 35, 29, 30, 66, 47, 41, 100, 86, 86, 125, 130, 136, 87, 87, 94, 65, 65, 71, 68, 69, 74, 75, 77, 83, 79, 85, 89, 84, 94, 97, 80, 97, 97, 77, 95, 96, 76, 82, 89, 70, 70, 73, 140, 143, 142, 99, 99, 101, 89, 78, 80, 115, 111, 111, 121, 124, 121, 116, 116, 112, 104, 106, 105, 128, 136, 138, 137, 146, 154, 144, 154, 168, 147, 158, 176, 138, 148, 168, 125, 137, 151, 135, 146, 153, 145, 155, 159, 86, 110, 113, 89, 113, 114, 83, 105, 106, 70, 64, 60, 81, 52, 36, 94, 73, 67, 80, 79, 87, 31, 29, 34, 57, 61, 64, 66, 71, 74, 68, 76, 78, 66, 75, 77, 61, 70, 72, 58, 70, 68, 52, 63, 62, 53, 54, 61, 62, 64, 71, 79, 80, 86, 111, 116, 116, 148, 154, 151, 154, 160, 157, 173, 178, 173, 184, 188, 183, 148, 149, 148, 99, 97, 98, 93, 92, 96, 93, 92, 101, 113, 120, 132, 134, 145, 154, 158, 169, 176, 166, 177, 183, 157, 170, 178], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452387984}, {\"format\": \"raw\", \"value\": [160, 159, 154, 162, 161, 156, 169, 168, 163, 173, 172, 167, 177, 176, 171, 181, 180, 175, 177, 176, 171, 182, 181, 176, 184, 183, 178, 181, 180, 175, 183, 177, 176, 187, 178, 177, 185, 180, 171, 185, 183, 170, 182, 180, 170, 176, 173, 169, 176, 173, 170, 173, 170, 165, 168, 165, 161, 168, 165, 161, 170, 167, 163, 173, 170, 165, 173, 172, 167, 167, 167, 161, 162, 161, 156, 162, 161, 156, 163, 162, 157, 163, 163, 155, 162, 162, 152, 159, 159, 149, 158, 158, 149, 156, 156, 146, 171, 170, 163, 172, 172, 164, 175, 174, 167, 176, 176, 168, 177, 177, 170, 174, 173, 169, 169, 168, 164, 172, 171, 167, 174, 173, 169, 175, 174, 170, 174, 172, 169, 172, 169, 164, 173, 170, 160, 180, 177, 166, 180, 176, 169, 174, 170, 166, 164, 162, 156, 159, 160, 152, 160, 160, 152, 161, 161, 153, 164, 164, 156, 168, 169, 160, 175, 175, 164, 174, 174, 162, 168, 168, 157, 166, 166, 155, 164, 164, 153, 164, 163, 153, 165, 165, 154, 162, 162, 152, 156, 156, 146, 155, 154, 144, 173, 173, 163, 173, 173, 163, 173, 173, 164, 172, 172, 162, 170, 170, 162, 167, 167, 162, 166, 165, 160, 166, 165, 161, 166, 165, 160, 167, 166, 161, 162, 165, 157, 156, 159, 149, 160, 157, 148, 175, 169, 161, 179, 171, 167, 172, 166, 162, 165, 165, 156, 167, 169, 158, 168, 170, 159, 167, 168, 157, 169, 171, 160, 172, 173, 160, 176, 175, 159, 175, 174, 157, 166, 164, 148, 162, 160, 144, 163, 162, 145, 166, 164, 150, 171, 169, 158, 170, 168, 157, 157, 155, 144, 155, 153, 142, 165, 165, 155, 164, 164, 154, 169, 169, 159, 170, 170, 159, 169, 169, 160, 167, 166, 159, 167, 167, 160, 170, 169, 162, 170, 169, 162, 169, 169, 162, 159, 164, 152, 158, 164, 149, 171, 166, 159, 182, 168, 167, 184, 168, 169, 180, 168, 167, 172, 169, 159, 178, 177, 164, 172, 172, 159, 170, 170, 157, 174, 174, 161, 176, 175, 160, 185, 182, 163, 179, 177, 157, 168, 165, 145, 166, 163, 143, 171, 169, 149, 175, 172, 156, 180, 176, 164, 179, 175, 163, 170, 166, 154, 167, 162, 150, 161, 161, 149, 159, 160, 147, 164, 165, 153, 167, 167, 155, 167, 167, 155, 168, 168, 156, 172, 173, 161, 175, 175, 163, 176, 176, 164, 174, 174, 162, 162, 169, 151, 164, 171, 153, 185, 175, 169, 177, 153, 158, 148, 122, 129, 163, 143, 145, 168, 160, 150, 180, 177, 162, 178, 174, 160, 180, 176, 161, 185, 181, 167, 183, 179, 163, 192, 188, 168, 188, 184, 164, 180, 175, 155, 179, 175, 155, 179, 174, 154, 177, 172, 156, 179, 173, 161, 183, 177, 165, 181, 175, 163, 172, 166, 154, 165, 166, 152, 158, 159, 145, 161, 161, 147, 163, 163, 150, 164, 165, 150, 170, 171, 153, 179, 180, 162, 183, 184, 166, 181, 182, 164, 176, 178, 159, 171, 178, 156, 177, 182, 162, 192, 176, 173, 164, 132, 141, 133, 99, 110, 161, 134, 138, 181, 168, 158, 192, 185, 169, 196, 188, 172, 196, 189, 173, 202, 194, 178, 196, 189, 172, 194, 188, 170, 192, 187, 169, 186, 181, 162, 185, 180, 162, 179, 174, 156, 175, 169, 153, 180, 173, 160, 181, 175, 162, 177, 171, 157, 167, 161, 148, 168, 168, 153, 159, 159, 144, 161, 161, 146, 166, 166, 151, 170, 170, 153, 175, 174, 154, 184, 183, 162, 191, 189, 169, 195, 192, 172, 195, 191, 172, 193, 191, 171, 194, 193, 173, 198, 183, 176, 156, 118, 129, 161, 120, 133, 206, 184, 182, 203, 193, 180, 204, 194, 178, 205, 195, 180, 205, 195, 179, 208, 198, 182, 201, 192, 176, 193, 187, 169, 191, 185, 168, 189, 183, 166, 188, 182, 166, 181, 175, 160, 178, 171, 155, 183, 175, 160, 182, 173, 159, 178, 170, 156, 171, 163, 150, 174, 172, 156, 173, 170, 154, 176, 173, 157, 180, 177, 161, 183, 181, 163, 187, 183, 162, 192, 187, 166, 198, 191, 172, 207, 197, 179, 211, 199, 182, 213, 198, 182, 206, 200, 180, 202, 193, 178, 170, 128, 137, 179, 133, 146, 207, 195, 184, 202, 198, 179, 207, 197, 181, 207, 198, 182, 207, 197, 181, 208, 198, 182, 204, 196, 179, 197, 191, 172, 193, 187, 168, 195, 188, 171, 193, 187, 171, 188, 182, 168, 185, 175, 160, 185, 173, 157, 182, 170, 155, 181, 168, 156, 177, 165, 154, 180, 176, 159, 185, 181, 164, 191, 186, 170, 191, 186, 170, 192, 188, 170, 196, 190, 170, 194, 188, 167, 201, 192, 173, 208, 197, 179, 210, 196, 179, 213, 196, 181, 206, 201, 179, 201, 197, 177, 184, 144, 150, 177, 128, 141, 203, 187, 177, 205, 199, 181, 210, 201, 184, 209, 200, 183, 209, 200, 183, 206, 197, 181, 203, 195, 177, 197, 191, 171, 199, 192, 172, 201, 194, 176, 195, 188, 172, 190, 182, 168, 186, 176, 162, 184, 170, 156, 181, 167, 155, 184, 170, 160, 184, 169, 161, 182, 176, 161, 188, 181, 167, 196, 189, 174, 194, 188, 173, 195, 189, 173, 198, 191, 173, 194, 186, 168, 201, 193, 174, 209, 198, 179, 206, 194, 176, 204, 193, 175, 199, 198, 174, 198, 196, 173, 196, 162, 164, 171, 123, 136, 200, 173, 169, 210, 199, 183, 207, 198, 180, 205, 196, 178, 205, 196, 178, 201, 192, 175, 196, 188, 168, 193, 186, 165, 196, 189, 169, 196, 188, 170, 192, 185, 168, 191, 183, 168, 192, 181, 168, 193, 179, 167, 191, 177, 167, 196, 181, 173, 195, 180, 174, 186, 178, 166, 189, 181, 169, 195, 187, 174, 197, 189, 177, 198, 190, 176, 200, 190, 174, 196, 187, 170, 199, 191, 172, 204, 195, 174, 202, 192, 170, 196, 189, 169, 192, 193, 168, 198, 196, 170, 211, 184, 181, 169, 125, 138, 186, 148, 152, 209, 193, 179, 199, 191, 171, 197, 189, 169, 197, 188, 169, 197, 189, 169, 196, 188, 167, 191, 182, 160, 187, 178, 157, 190, 181, 162, 197, 187, 170, 200, 189, 173, 206, 193, 179, 211, 197, 185, 208, 194, 184, 204, 190, 182, 205, 190, 184, 185, 176, 166, 187, 178, 168, 191, 182, 172, 194, 185, 175, 195, 185, 175, 198, 185, 173, 196, 184, 169, 195, 186, 167, 195, 187, 165, 192, 185, 160, 189, 184, 162, 188, 187, 161, 191, 187, 160, 212, 193, 186, 173, 135, 148, 164, 120, 130, 207, 187, 175, 199, 192, 171, 199, 191, 170, 198, 190, 169, 204, 196, 175, 207, 198, 176, 199, 189, 165, 195, 184, 162, 205, 194, 173, 214, 203, 185, 209, 197, 180, 211, 198, 183, 216, 202, 188, 212, 198, 186, 205, 191, 181, 205, 191, 182, 184, 172, 164, 185, 173, 164, 187, 175, 166, 186, 175, 166, 188, 175, 167, 193, 178, 169, 194, 181, 168, 194, 183, 165, 189, 183, 159, 186, 181, 154, 193, 187, 164, 194, 187, 163, 189, 183, 154, 210, 199, 186, 189, 158, 168, 154, 106, 121, 208, 186, 174, 208, 201, 178, 203, 195, 173, 204, 196, 174, 212, 205, 182, 210, 201, 178, 208, 197, 173, 210, 198, 175, 210, 198, 177, 212, 200, 181, 205, 193, 175, 202, 190, 172, 208, 195, 176, 202, 189, 172, 198, 185, 170, 202, 189, 175, 187, 175, 166, 185, 172, 164, 184, 172, 163, 184, 172, 163, 187, 173, 165, 193, 177, 169, 197, 183, 171, 196, 186, 167, 190, 184, 160, 189, 185, 157, 198, 192, 168, 201, 190, 166, 200, 191, 162, 219, 212, 196, 211, 186, 194, 151, 105, 121, 188, 164, 154, 211, 203, 180, 209, 199, 177, 209, 200, 178, 210, 202, 179, 210, 201, 177, 212, 200, 176, 207, 195, 171, 206, 194, 172, 201, 188, 168, 196, 183, 165, 197, 185, 164, 196, 184, 161, 193, 181, 160, 195, 182, 163, 200, 186, 169, 200, 189, 180, 195, 184, 174, 189, 179, 168, 192, 182, 170, 197, 185, 173, 199, 185, 172, 205, 193, 174, 205, 196, 171, 202, 194, 168, 206, 200, 176, 212, 205, 180, 216, 205, 179, 222, 212, 188, 229, 220, 206, 225, 207, 207, 147, 119, 125, 167, 145, 137, 220, 202, 185, 215, 196, 177, 205, 188, 169, 197, 182, 163, 200, 186, 168, 205, 189, 171, 204, 188, 171, 204, 188, 171, 194, 178, 161, 193, 177, 162, 198, 184, 167, 193, 181, 161, 198, 184, 166, 198, 182, 166, 195, 178, 163, 199, 187, 177, 197, 185, 173, 192, 180, 166, 194, 183, 166, 207, 195, 178, 209, 196, 180, 212, 201, 179, 211, 202, 176, 214, 206, 183, 220, 211, 196, 214, 206, 191, 168, 160, 143, 125, 115, 104, 116, 105, 100, 141, 127, 129, 88, 72, 77, 103, 85, 81, 200, 179, 169, 200, 179, 165, 201, 181, 166, 204, 186, 170, 203, 186, 170, 205, 188, 173, 211, 193, 179, 209, 191, 177, 204, 186, 172, 203, 185, 171, 204, 189, 173, 208, 194, 178, 209, 194, 178, 205, 188, 174, 199, 180, 167, 197, 181, 168, 198, 182, 167, 196, 180, 164, 203, 188, 169, 208, 193, 175, 208, 195, 177, 209, 198, 180, 208, 199, 182, 219, 210, 199, 161, 153, 149, 77, 70, 71, 44, 38, 40, 34, 27, 31, 34, 24, 30, 57, 44, 54, 66, 53, 62, 43, 32, 34, 104, 92, 89, 183, 169, 162, 211, 195, 184, 211, 194, 179, 204, 186, 170, 207, 189, 175, 211, 193, 179, 211, 193, 179, 210, 193, 179, 212, 194, 180, 213, 197, 182, 215, 200, 185, 212, 195, 180, 212, 194, 180, 203, 183, 169, 198, 177, 163, 199, 179, 164, 204, 184, 166, 213, 193, 173, 212, 194, 174, 214, 200, 182, 213, 201, 186, 198, 188, 179, 152, 143, 143, 52, 44, 52, 22, 18, 29, 28, 25, 37, 28, 23, 33, 63, 54, 62, 156, 145, 151, 170, 158, 163, 86, 79, 84, 31, 27, 31, 76, 70, 70, 175, 164, 159, 208, 193, 181, 201, 182, 167, 203, 184, 170, 203, 185, 171, 208, 190, 176, 213, 195, 181, 220, 202, 188, 216, 199, 184, 211, 195, 180, 200, 182, 168, 197, 178, 164, 198, 176, 163, 196, 173, 159, 200, 178, 163, 206, 184, 166, 214, 192, 172, 215, 195, 175, 216, 201, 183, 205, 192, 181, 123, 113, 111, 51, 43, 51, 22, 18, 31, 19, 18, 30, 21, 21, 30, 25, 22, 27, 119, 112, 113, 165, 155, 150, 149, 138, 131, 112, 106, 109, 36, 34, 42, 34, 33, 40, 106, 100, 101, 198, 184, 177, 202, 184, 170, 203, 185, 171, 208, 190, 176, 212, 194, 180, 211, 193, 179, 213, 195, 181, 209, 191, 177, 205, 187, 173, 199, 180, 166, 201, 180, 167, 209, 185, 173, 204, 182, 170, 204, 182, 169, 206, 184, 169, 210, 189, 171, 211, 191, 173, 210, 194, 179, 173, 160, 152, 66, 56, 59, 28, 23, 32, 23, 23, 34, 17, 19, 28, 23, 24, 29, 32, 28, 29, 127, 118, 114, 157, 144, 134, 139, 124, 113, 128, 117, 118, 51, 47, 55, 34, 34, 44, 62, 59, 64, 151, 139, 135, 206, 188, 176, 205, 186, 173, 213, 194, 180, 212, 194, 180, 210, 192, 178, 210, 192, 178, 212, 194, 180, 210, 192, 178, 211, 191, 177, 211, 188, 175, 212, 187, 175, 208, 188, 179, 209, 189, 179, 204, 184, 172, 204, 184, 170, 208, 189, 174, 213, 197, 183, 155, 142, 137, 47, 38, 42, 34, 32, 39, 29, 31, 37, 23, 25, 32, 26, 25, 33, 42, 36, 41, 137, 124, 125, 153, 135, 132, 129, 107, 103, 131, 113, 113, 67, 57, 63, 28, 27, 38, 37, 35, 43, 80, 70, 70, 183, 165, 157, 204, 186, 173, 206, 188, 174, 213, 195, 181, 217, 199, 185, 213, 195, 181, 213, 194, 180, 209, 190, 176, 211, 190, 176, 213, 189, 177, 214, 187, 176, 202, 183, 175, 204, 186, 176, 200, 182, 170, 201, 183, 170, 208, 190, 175, 214, 198, 183, 184, 171, 166, 64, 57, 62, 35, 34, 42, 41, 44, 49, 35, 37, 45, 29, 27, 39, 48, 41, 50, 121, 108, 114, 147, 128, 131, 116, 94, 94, 126, 105, 103, 86, 73, 75, 28, 25, 35, 33, 32, 41, 47, 40, 41, 157, 142, 136, 210, 192, 179, 204, 186, 172, 213, 195, 181, 214, 196, 182, 210, 192, 178, 207, 188, 173, 202, 181, 166, 208, 185, 171, 212, 187, 175, 205, 179, 168, 200, 182, 170, 203, 185, 172, 205, 187, 174, 208, 190, 177, 210, 191, 176, 215, 199, 181, 193, 183, 175, 76, 73, 76, 39, 40, 50, 45, 44, 56, 44, 44, 56, 36, 36, 48, 37, 34, 42, 61, 52, 57, 103, 90, 92, 101, 84, 83, 118, 101, 96, 95, 83, 82, 30, 24, 32, 31, 28, 38, 44, 40, 44, 156, 145, 141, 211, 193, 181, 203, 184, 170, 211, 192, 178, 212, 193, 179, 209, 190, 176, 203, 182, 166, 204, 182, 164, 215, 192, 176, 209, 186, 172, 199, 175, 162, 203, 185, 171, 206, 188, 174, 213, 195, 181, 212, 194, 180, 214, 196, 180, 222, 204, 187, 188, 178, 168, 64, 61, 63, 41, 41, 51, 40, 38, 52, 42, 41, 53, 35, 36, 45, 34, 32, 39, 35, 29, 32, 62, 52, 53, 75, 62, 60, 103, 89, 83, 96, 85, 84, 30, 23, 31, 30, 26, 36, 54, 50, 54, 170, 160, 156, 208, 190, 177, 205, 186, 172, 211, 193, 179, 213, 194, 180, 209, 190, 176, 202, 181, 164, 209, 187, 168, 220, 198, 181, 217, 194, 180, 209, 186, 173, 207, 189, 175, 206, 188, 175, 212, 194, 180, 212, 194, 180, 215, 196, 181, 221, 203, 188, 174, 161, 152, 48, 42, 42, 40, 37, 45, 38, 36, 47, 38, 37, 48, 32, 31, 39, 33, 30, 36, 39, 33, 37, 46, 37, 38, 53, 41, 41, 93, 80, 76, 80, 70, 71, 31, 25, 34, 30, 26, 35, 60, 54, 58, 178, 167, 162, 213, 195, 182, 209, 190, 176, 206, 187, 173, 208, 189, 175, 207, 188, 174, 206, 186, 169, 208, 187, 169, 215, 193, 178, 220, 198, 184, 216, 194, 182, 205, 187, 173, 201, 183, 169, 205, 187, 173, 208, 190, 176, 209, 191, 177, 213, 195, 182, 171, 156, 147, 60, 50, 48, 41, 36, 41, 38, 36, 45, 38, 37, 46, 35, 33, 40, 33, 30, 36, 57, 52, 56, 51, 43, 46, 37, 27, 28, 70, 59, 57, 56, 48, 50, 36, 31, 40, 35, 30, 39, 66, 59, 62, 188, 175, 169, 216, 198, 185, 207, 188, 174, 200, 181, 167, 205, 186, 172, 206, 187, 173, 215, 195, 180, 208, 188, 171, 207, 187, 172, 212, 191, 178, 213, 191, 180, 197, 179, 165, 196, 178, 164, 200, 182, 168, 205, 187, 173, 202, 184, 171, 205, 186, 175, 193, 176, 167, 119, 106, 101, 48, 41, 42, 43, 42, 48, 57, 55, 62, 36, 33, 38, 32, 27, 32, 59, 54, 58, 42, 36, 39, 24, 16, 19, 38, 30, 29, 38, 32, 35, 42, 38, 47, 39, 34, 42, 64, 54, 56, 184, 169, 163, 210, 191, 178, 207, 188, 174, 206, 187, 173, 207, 188, 174, 212, 193, 179, 216, 198, 182, 208, 189, 173, 204, 186, 172, 202, 183, 171, 208, 189, 179, 187, 169, 155, 188, 170, 156, 199, 181, 167, 206, 188, 174, 201, 183, 170, 197, 179, 170, 201, 182, 173, 180, 162, 155, 72, 62, 60, 53, 51, 55, 119, 117, 122, 60, 55, 59, 25, 20, 24, 36, 31, 35, 22, 16, 21, 27, 21, 25, 39, 33, 33, 72, 67, 70, 71, 68, 78, 44, 37, 45, 73, 63, 63, 190, 174, 166, 211, 192, 179, 205, 186, 172, 211, 192, 178, 211, 192, 177, 215, 196, 182, 211, 193, 178, 202, 184, 170, 204, 186, 173, 198, 180, 169, 204, 185, 176, 190, 172, 158, 191, 173, 159, 200, 182, 168, 203, 185, 171, 200, 182, 170, 197, 179, 171, 196, 176, 167, 210, 191, 183, 139, 127, 123, 74, 70, 72, 165, 163, 167, 138, 131, 134, 53, 47, 50, 26, 21, 25, 21, 16, 21, 62, 57, 62, 82, 76, 77, 129, 125, 129, 96, 93, 102, 75, 68, 75, 133, 121, 120, 203, 186, 176, 218, 199, 186, 212, 192, 179, 212, 193, 179, 205, 186, 173, 203, 184, 170, 206, 187, 173, 202, 185, 171, 200, 183, 171, 197, 180, 170, 196, 178, 170, 200, 182, 168, 199, 181, 167, 196, 178, 164, 195, 178, 163, 199, 181, 168, 200, 179, 169, 197, 175, 165, 209, 190, 180, 194, 179, 172, 147, 137, 134, 168, 163, 163, 186, 179, 181, 115, 105, 108, 44, 40, 41, 25, 24, 23, 101, 95, 95, 131, 121, 118, 156, 150, 149, 116, 112, 115, 110, 102, 104, 199, 183, 178, 213, 189, 179, 213, 189, 178, 211, 190, 181, 203, 183, 175, 192, 172, 163, 190, 167, 157, 204, 183, 170, 208, 189, 175, 199, 180, 170, 198, 179, 172, 196, 177, 171, 199, 180, 168, 193, 175, 163, 192, 174, 162, 200, 182, 170, 207, 188, 176, 205, 183, 171, 209, 188, 177, 209, 189, 180, 208, 191, 183, 203, 187, 180, 160, 151, 149, 167, 158, 160, 146, 132, 134, 74, 69, 67, 43, 42, 38, 100, 88, 84, 152, 135, 130, 162, 149, 146, 144, 137, 136, 152, 142, 139, 218, 198, 191, 213, 185, 175, 204, 177, 168, 210, 187, 181, 206, 186, 182, 196, 174, 169, 197, 172, 163, 216, 192, 179, 213, 192, 178, 203, 181, 173, 204, 183, 179, 202, 182, 176, 187, 168, 161, 193, 175, 167, 198, 180, 172, 202, 183, 176, 206, 187, 179, 207, 186, 175, 213, 193, 183, 213, 194, 185, 209, 192, 185, 206, 190, 184, 185, 175, 172, 160, 147, 149, 142, 123, 125, 149, 138, 136, 158, 152, 147, 153, 137, 133, 145, 119, 118, 150, 129, 129, 166, 153, 152, 168, 156, 153, 207, 188, 181, 198, 171, 162, 200, 173, 164, 211, 189, 183, 202, 182, 178, 190, 169, 163, 202, 176, 168, 212, 188, 175, 210, 190, 176, 205, 184, 177, 198, 177, 174, 193, 172, 168], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452388048}, {\"format\": \"raw\", \"value\": [168, 151, 143, 145, 130, 124, 134, 134, 136, 178, 173, 170, 189, 191, 193, 186, 192, 196, 215, 221, 212, 231, 244, 226, 214, 229, 236, 184, 202, 213, 230, 223, 224, 229, 219, 221, 226, 239, 240, 234, 242, 242, 200, 188, 198, 155, 136, 136, 243, 251, 197, 230, 237, 199, 214, 221, 182, 211, 220, 143, 199, 199, 106, 195, 192, 82, 197, 186, 87, 206, 193, 56, 176, 196, 86, 161, 181, 152, 206, 207, 180, 223, 228, 207, 173, 183, 177, 222, 222, 189, 239, 239, 169, 229, 241, 92, 179, 159, 149, 154, 138, 132, 141, 142, 145, 189, 185, 181, 183, 185, 187, 209, 212, 217, 194, 190, 188, 226, 231, 222, 230, 246, 248, 223, 233, 235, 244, 244, 232, 238, 236, 223, 249, 253, 248, 201, 195, 196, 68, 41, 58, 160, 134, 140, 236, 246, 201, 214, 221, 205, 203, 212, 187, 209, 221, 142, 206, 207, 110, 195, 195, 70, 207, 200, 77, 202, 190, 80, 175, 186, 139, 174, 183, 186, 222, 222, 179, 217, 225, 186, 186, 197, 185, 223, 222, 196, 228, 227, 158, 229, 240, 99, 177, 154, 141, 152, 135, 129, 152, 154, 158, 206, 201, 197, 183, 186, 187, 202, 200, 206, 93, 64, 75, 112, 100, 99, 229, 233, 232, 255, 249, 253, 248, 255, 244, 241, 255, 239, 218, 205, 207, 70, 57, 62, 98, 66, 85, 213, 193, 194, 214, 227, 197, 191, 201, 197, 193, 206, 187, 212, 225, 157, 204, 204, 112, 187, 189, 47, 218, 217, 56, 212, 210, 71, 186, 197, 167, 196, 206, 181, 236, 241, 144, 207, 216, 167, 221, 233, 212, 229, 229, 198, 222, 222, 145, 234, 241, 124, 164, 139, 124, 151, 134, 128, 166, 169, 174, 208, 203, 199, 201, 204, 205, 159, 153, 162, 89, 35, 57, 61, 26, 35, 155, 142, 143, 231, 224, 230, 202, 187, 188, 169, 153, 152, 80, 67, 76, 65, 56, 67, 165, 136, 155, 200, 194, 185, 197, 213, 201, 186, 198, 196, 187, 203, 182, 201, 213, 162, 208, 206, 122, 198, 202, 48, 231, 236, 45, 217, 224, 57, 192, 209, 148, 207, 214, 187, 236, 236, 152, 206, 217, 162, 237, 249, 223, 244, 243, 205, 223, 226, 135, 239, 242, 154, 173, 132, 123, 163, 138, 135, 170, 171, 181, 172, 177, 179, 197, 199, 205, 131, 111, 120, 114, 62, 86, 116, 73, 93, 66, 49, 58, 97, 71, 77, 131, 68, 80, 120, 73, 79, 71, 49, 55, 164, 147, 156, 188, 158, 174, 222, 216, 187, 206, 214, 196, 180, 191, 182, 171, 186, 176, 176, 198, 153, 186, 201, 110, 200, 201, 43, 230, 229, 24, 221, 224, 94, 183, 205, 150, 203, 215, 209, 238, 234, 186, 228, 226, 177, 246, 252, 212, 241, 251, 206, 225, 242, 161, 248, 246, 182, 156, 109, 102, 172, 145, 145, 179, 184, 200, 158, 173, 181, 192, 191, 202, 118, 87, 98, 115, 71, 94, 104, 66, 88, 57, 40, 55, 58, 19, 26, 104, 55, 59, 125, 85, 86, 170, 109, 122, 179, 151, 159, 165, 131, 147, 213, 204, 165, 225, 233, 183, 184, 196, 165, 168, 182, 176, 169, 198, 150, 175, 204, 77, 208, 211, 27, 241, 236, 32, 227, 221, 115, 177, 195, 140, 201, 216, 168, 217, 224, 147, 213, 217, 172, 245, 247, 206, 243, 246, 198, 233, 234, 180, 246, 234, 166, 154, 111, 102, 163, 144, 145, 159, 173, 197, 147, 167, 182, 201, 199, 213, 114, 82, 98, 105, 67, 92, 105, 74, 97, 106, 87, 106, 137, 104, 114, 90, 56, 60, 97, 65, 68, 154, 93, 111, 103, 74, 83, 57, 27, 40, 170, 161, 125, 228, 242, 154, 193, 211, 149, 179, 195, 175, 171, 196, 165, 179, 200, 108, 217, 214, 72, 245, 237, 52, 236, 232, 69, 180, 193, 105, 198, 204, 141, 192, 200, 118, 173, 192, 141, 211, 216, 183, 217, 220, 161, 204, 204, 144, 229, 224, 130, 159, 119, 108, 166, 156, 158, 114, 134, 171, 120, 143, 171, 207, 210, 225, 114, 87, 105, 153, 124, 151, 180, 158, 182, 176, 155, 179, 190, 165, 177, 143, 86, 102, 89, 52, 61, 79, 66, 71, 86, 59, 67, 45, 12, 27, 144, 135, 98, 212, 230, 123, 195, 214, 141, 183, 203, 165, 169, 194, 166, 188, 205, 140, 224, 218, 93, 237, 235, 18, 231, 232, 42, 165, 179, 88, 174, 185, 100, 190, 192, 103, 173, 184, 127, 185, 199, 159, 188, 213, 146, 194, 221, 138, 229, 236, 145, 180, 142, 126, 172, 170, 171, 127, 147, 195, 137, 157, 195, 196, 205, 221, 137, 119, 140, 196, 175, 202, 170, 156, 182, 168, 146, 175, 184, 163, 178, 118, 74, 89, 94, 64, 75, 73, 56, 66, 86, 59, 67, 48, 15, 31, 124, 116, 77, 215, 233, 132, 199, 216, 154, 174, 196, 141, 157, 180, 154, 182, 204, 114, 226, 234, 32, 234, 234, 8, 221, 223, 66, 158, 177, 110, 183, 207, 91, 210, 237, 124, 189, 226, 140, 185, 209, 151, 174, 187, 141, 167, 161, 116, 173, 152, 115, 170, 141, 132, 142, 149, 163, 136, 155, 210, 160, 177, 224, 186, 196, 213, 139, 125, 142, 135, 112, 145, 139, 121, 152, 170, 143, 176, 152, 127, 148, 70, 52, 62, 66, 53, 61, 83, 50, 66, 91, 58, 67, 98, 67, 82, 170, 161, 129, 240, 249, 173, 207, 223, 166, 168, 196, 128, 167, 195, 170, 191, 211, 115, 238, 244, 22, 247, 242, 74, 231, 245, 86, 163, 194, 137, 165, 195, 134, 186, 159, 106, 148, 111, 73, 185, 103, 72, 172, 54, 52, 108, 22, 21, 81, 19, 27, 174, 158, 165, 117, 135, 172, 116, 134, 192, 122, 139, 193, 189, 196, 209, 159, 139, 150, 166, 133, 175, 171, 139, 176, 182, 151, 182, 141, 112, 139, 158, 138, 152, 53, 44, 54, 55, 39, 51, 96, 56, 65, 145, 128, 138, 194, 183, 165, 248, 242, 189, 220, 222, 167, 183, 197, 153, 182, 201, 172, 199, 212, 100, 240, 235, 65, 235, 229, 105, 197, 180, 86, 102, 80, 64, 82, 45, 57, 116, 23, 34, 122, 44, 52, 189, 62, 46, 199, 39, 39, 121, 30, 35, 141, 59, 62, 198, 183, 192, 111, 130, 165, 105, 122, 179, 96, 113, 167, 202, 209, 220, 213, 193, 204, 143, 112, 145, 163, 133, 158, 140, 111, 129, 162, 145, 152, 203, 191, 192, 119, 95, 101, 85, 47, 57, 108, 70, 75, 61, 65, 64, 180, 168, 154, 167, 143, 112, 140, 116, 98, 118, 90, 100, 84, 58, 85, 104, 88, 79, 107, 85, 70, 101, 62, 58, 111, 44, 67, 78, 12, 22, 116, 18, 32, 128, 60, 61, 203, 109, 83, 168, 52, 46, 163, 45, 59, 118, 70, 97, 180, 105, 106, 170, 159, 170, 145, 164, 199, 120, 135, 191, 105, 122, 177, 184, 192, 207, 184, 164, 173, 149, 118, 144, 135, 105, 127, 131, 103, 119, 88, 77, 69, 87, 73, 57, 154, 117, 109, 129, 71, 68, 100, 57, 59, 83, 89, 84, 193, 173, 168, 73, 45, 58, 86, 59, 80, 116, 81, 106, 92, 52, 70, 78, 47, 62, 74, 39, 82, 102, 38, 58, 114, 37, 51, 57, 36, 42, 119, 52, 60, 140, 95, 83, 165, 83, 59, 95, 17, 29, 121, 47, 72, 151, 82, 100, 154, 106, 138, 151, 142, 156, 166, 185, 220, 120, 134, 188, 114, 131, 186, 182, 189, 204, 176, 157, 165, 180, 150, 173, 125, 95, 123, 109, 77, 111, 75, 61, 73, 90, 68, 72, 120, 69, 72, 125, 54, 52, 127, 70, 72, 180, 158, 159, 156, 122, 128, 93, 66, 95, 104, 80, 109, 99, 68, 84, 94, 61, 70, 86, 50, 77, 113, 59, 94, 140, 56, 59, 169, 56, 34, 102, 38, 47, 138, 63, 76, 144, 68, 66, 88, 36, 32, 61, 18, 19, 118, 74, 90, 144, 78, 96, 90, 67, 107, 178, 172, 188, 142, 160, 198, 111, 125, 179, 105, 123, 176, 188, 195, 209, 187, 168, 173, 178, 150, 171, 144, 110, 148, 112, 78, 130, 111, 88, 135, 135, 102, 149, 151, 91, 126, 134, 59, 70, 164, 95, 100, 169, 119, 130, 117, 69, 84, 180, 147, 158, 134, 103, 117, 90, 52, 71, 108, 76, 92, 104, 72, 85, 153, 84, 72, 183, 95, 60, 182, 67, 48, 164, 34, 40, 159, 84, 82, 132, 42, 50, 97, 52, 62, 126, 89, 70, 157, 122, 125, 91, 69, 106, 49, 27, 40, 185, 187, 204, 138, 154, 202, 115, 139, 188, 132, 156, 197, 193, 195, 209, 193, 171, 162, 189, 171, 180, 206, 180, 203, 159, 134, 177, 114, 84, 131, 119, 84, 139, 118, 75, 111, 127, 72, 71, 148, 100, 101, 223, 199, 211, 176, 144, 155, 164, 132, 148, 121, 91, 108, 75, 45, 58, 78, 53, 55, 75, 43, 37, 204, 125, 88, 196, 106, 69, 184, 57, 48, 187, 56, 33, 157, 75, 58, 111, 26, 43, 133, 76, 82, 146, 101, 112, 140, 104, 128, 111, 79, 98, 80, 51, 61, 185, 188, 206, 142, 159, 204, 109, 134, 181, 124, 148, 188, 200, 206, 221, 245, 223, 216, 218, 198, 205, 218, 229, 234, 216, 200, 229, 149, 111, 166, 134, 103, 153, 109, 75, 106, 100, 50, 60, 98, 58, 48, 221, 223, 220, 160, 151, 153, 128, 100, 118, 107, 79, 97, 71, 44, 54, 52, 30, 38, 121, 70, 54, 227, 147, 102, 191, 91, 68, 215, 58, 45, 211, 96, 54, 181, 60, 48, 130, 52, 64, 154, 117, 114, 103, 67, 83, 118, 84, 110, 114, 80, 94, 147, 122, 133, 198, 200, 220, 155, 172, 213, 132, 156, 198, 153, 178, 217, 202, 213, 232, 239, 227, 226, 223, 214, 217, 164, 163, 170, 198, 189, 204, 197, 172, 213, 168, 143, 168, 203, 183, 191, 173, 126, 136, 178, 108, 99, 231, 219, 218, 150, 115, 127, 118, 82, 103, 65, 38, 55, 60, 33, 42, 55, 31, 45, 159, 84, 59, 221, 133, 85, 191, 76, 65, 210, 56, 30, 224, 86, 43, 213, 56, 52, 152, 101, 102, 158, 125, 122, 98, 54, 75, 92, 37, 68, 140, 69, 95, 112, 85, 96, 210, 212, 233, 172, 190, 226, 149, 172, 210, 156, 180, 220, 176, 192, 216, 229, 230, 232, 229, 223, 220, 202, 161, 172, 205, 190, 193, 189, 180, 191, 198, 180, 179, 224, 215, 202, 223, 207, 198, 224, 193, 181, 175, 177, 179, 123, 106, 119, 81, 51, 71, 58, 30, 47, 55, 28, 38, 63, 29, 34, 195, 106, 80, 211, 102, 64, 188, 56, 47, 198, 70, 33, 215, 56, 22, 187, 53, 50, 119, 94, 90, 106, 62, 63, 115, 57, 86, 120, 58, 90, 65, 33, 45, 23, 13, 18, 208, 210, 232, 177, 196, 228, 149, 171, 206, 138, 163, 204, 155, 176, 205, 223, 224, 232, 238, 212, 215, 200, 166, 169, 222, 192, 190, 206, 190, 191, 204, 190, 196, 204, 199, 197, 233, 240, 228, 175, 170, 169, 84, 73, 91, 116, 94, 115, 110, 81, 102, 80, 51, 69, 51, 26, 38, 115, 73, 65, 209, 119, 99, 208, 82, 58, 207, 55, 43, 211, 87, 56, 215, 85, 50, 139, 76, 63, 80, 52, 57, 111, 73, 71, 115, 65, 94, 108, 60, 86, 17, 12, 15, 12, 14, 15, 202, 211, 221, 176, 200, 226, 150, 177, 213, 172, 199, 234, 158, 172, 200, 173, 170, 172, 225, 191, 190, 238, 217, 213, 224, 199, 200, 238, 216, 218, 206, 175, 179, 194, 163, 170, 172, 160, 167, 78, 60, 74, 66, 41, 62, 83, 54, 76, 93, 72, 93, 74, 44, 56, 43, 12, 24, 154, 74, 50, 212, 84, 70, 195, 47, 36, 208, 59, 42, 225, 106, 75, 227, 160, 125, 119, 75, 78, 72, 36, 35, 80, 50, 54, 87, 64, 82, 51, 22, 37, 34, 17, 27, 48, 28, 36, 206, 218, 223, 169, 197, 222, 163, 193, 226, 186, 212, 236, 164, 176, 194, 171, 173, 166, 234, 209, 204, 234, 211, 208, 213, 191, 191, 168, 138, 141, 128, 76, 79, 124, 68, 79, 136, 103, 122, 83, 66, 82, 73, 57, 72, 74, 58, 74, 47, 38, 60, 78, 49, 60, 74, 35, 46, 180, 80, 53, 223, 93, 53, 202, 64, 45, 214, 93, 58, 228, 116, 75, 172, 116, 92, 117, 66, 79, 79, 48, 38, 68, 31, 42, 97, 60, 82, 20, 12, 16, 33, 20, 30, 46, 25, 33, 197, 207, 217, 171, 197, 227, 183, 210, 238, 187, 212, 221, 174, 190, 197, 180, 189, 180, 189, 174, 174, 198, 172, 172, 114, 77, 75, 78, 37, 40, 87, 40, 50, 186, 135, 152, 176, 144, 162, 95, 78, 94, 67, 49, 65, 94, 75, 92, 51, 46, 71, 64, 38, 52, 86, 43, 50, 200, 108, 79, 217, 121, 69, 211, 104, 73, 217, 128, 75, 217, 106, 63, 126, 52, 42, 114, 75, 81, 104, 64, 60, 105, 62, 73, 69, 31, 51, 13, 10, 13, 22, 7, 16, 18, 11, 14, 175, 185, 199, 167, 192, 227, 182, 205, 235, 191, 212, 216, 188, 206, 211, 173, 190, 185, 162, 155, 152, 161, 131, 132, 110, 68, 67, 69, 38, 38, 82, 55, 64, 191, 160, 177, 127, 107, 122, 85, 67, 83, 72, 54, 70, 102, 84, 101, 82, 76, 102, 54, 28, 42, 86, 43, 51, 202, 114, 80, 174, 82, 61, 192, 94, 65, 215, 136, 81, 232, 129, 92, 144, 77, 77, 88, 60, 62, 146, 93, 98, 136, 99, 109, 33, 29, 39, 31, 12, 21, 40, 16, 29, 31, 18, 24, 175, 184, 203, 150, 177, 214, 167, 186, 221, 184, 199, 211, 182, 200, 216, 169, 188, 197, 203, 199, 189, 206, 179, 180, 137, 95, 100, 77, 46, 48, 102, 77, 90, 151, 120, 144, 85, 63, 80, 66, 49, 65, 76, 58, 75, 68, 51, 68, 71, 62, 83, 86, 57, 69, 86, 48, 59, 210, 123, 97, 190, 82, 66, 198, 84, 58, 220, 125, 65, 226, 137, 89, 130, 91, 92, 63, 43, 42, 80, 49, 49, 95, 61, 69, 38, 26, 40, 39, 18, 27, 47, 19, 34, 44, 12, 24, 174, 182, 199, 144, 160, 209, 161, 178, 223, 192, 214, 225, 195, 217, 228, 200, 218, 225, 208, 197, 185, 223, 193, 191, 157, 122, 131, 109, 76, 87, 93, 61, 79, 141, 107, 130, 119, 91, 109, 116, 94, 107, 118, 96, 110, 80, 57, 72, 88, 71, 88, 122, 91, 102, 89, 47, 55, 192, 101, 86, 206, 103, 61, 197, 88, 54, 221, 122, 69, 185, 119, 82, 94, 66, 67, 73, 48, 47, 77, 56, 55, 76, 42, 52, 73, 44, 60, 39, 20, 28, 50, 20, 33, 62, 15, 32, 183, 183, 195, 134, 153, 205, 149, 172, 212, 164, 184, 191, 158, 172, 167, 153, 155, 152, 127, 104, 101, 155, 122, 121, 126, 97, 110, 82, 58, 74, 71, 47, 61, 122, 99, 113, 163, 138, 151, 186, 157, 167, 131, 101, 111, 118, 87, 97, 133, 103, 121, 111, 81, 92, 138, 86, 90, 181, 94, 76, 227, 128, 72, 223, 108, 65, 212, 116, 77, 133, 83, 79, 104, 66, 68, 105, 65, 66, 123, 80, 88, 76, 43, 55, 41, 21, 28, 37, 15, 22, 24, 17, 22, 48, 24, 33, 164, 158, 175, 99, 102, 140, 95, 91, 119, 67, 55, 68, 68, 52, 64, 60, 40, 54, 86, 58, 69, 108, 75, 88, 89, 58, 79, 102, 77, 94, 72, 48, 62, 121, 99, 111, 144, 118, 131, 204, 175, 185, 140, 111, 121, 105, 75, 85, 124, 93, 110, 134, 105, 117, 135, 86, 94, 123, 60, 53, 170, 82, 62, 175, 67, 61, 151, 72, 62, 120, 81, 80, 101, 62, 67, 108, 68, 73, 114, 79, 86, 88, 52, 65, 68, 33, 44, 33, 18, 24, 20, 20, 29, 28, 18, 22, 103, 93, 111, 124, 89, 119, 141, 110, 127, 97, 76, 88, 102, 81, 101, 118, 95, 118, 122, 91, 112, 97, 67, 88, 117, 87, 105, 105, 79, 94, 97, 74, 87, 135, 112, 125, 141, 116, 129, 196, 167, 177, 114, 84, 94, 152, 122, 132, 200, 168, 183, 171, 143, 156, 80, 38, 49, 102, 48, 63, 129, 74, 95, 72, 37, 58, 109, 49, 83, 100, 61, 73, 91, 51, 60, 115, 74, 83, 125, 93, 101, 91, 54, 67, 81, 40, 54, 26, 9, 17, 37, 10, 30, 42, 24, 32, 84, 56, 79, 143, 121, 132, 159, 135, 138, 124, 97, 113, 129, 108, 132, 179, 160, 180, 168, 136, 154, 124, 98, 114, 198, 169, 174, 119, 92, 100, 180, 156, 170, 177, 153, 166, 123, 97, 110, 190, 163, 173, 140, 109, 119, 131, 101, 111, 145, 111, 125, 98, 72, 85, 70, 36, 54, 133, 70, 89, 153, 91, 97, 79, 43, 47, 125, 53, 75, 83, 35, 51, 93, 53, 67, 95, 54, 68, 101, 63, 77, 80, 46, 57, 85, 55, 65, 49, 32, 38, 20, 14, 23, 36, 35, 37, 116, 90, 110, 152, 115, 127, 162, 128, 136, 144, 106, 126, 143, 115, 140, 146, 124, 139, 167, 137, 145, 148, 125, 132, 226, 199, 195, 143, 117, 125, 161, 137, 155, 163, 138, 155, 129, 104, 119, 107, 79, 90, 101, 72, 83, 138, 108, 121, 131, 98, 114, 93, 70, 84, 40, 11, 28, 89, 44, 64, 89, 55, 62, 97, 44, 63, 91, 54, 73, 77, 34, 51, 83, 42, 59, 73, 33, 49, 76, 32, 47, 70, 38, 49, 69, 51, 57, 102, 75, 84, 65, 48, 55, 85, 44, 58, 142, 141, 148, 144, 136, 143, 128, 132, 150, 145, 116, 118, 142, 124, 131, 122, 117, 116, 163, 150, 141, 124, 110, 112, 180, 164, 180, 124, 106, 128, 98, 69, 98, 119, 90, 113, 114, 100, 112, 73, 65, 64, 69, 55, 54, 106, 84, 100, 84, 71, 83, 79, 68, 88, 45, 24, 28, 66, 37, 42, 44, 33, 39, 85, 48, 63, 72, 38, 52, 77, 38, 48, 79, 37, 59, 81, 46, 61, 95, 55, 64, 56, 29, 38, 83, 57, 66, 131, 87, 102, 111, 69, 83, 107, 61, 77], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452388112}, {\"format\": \"raw\", \"value\": [46, 45, 50, 47, 45, 51, 45, 44, 49, 41, 40, 45, 35, 34, 39, 28, 27, 32, 22, 21, 25, 16, 15, 18, 12, 12, 14, 12, 11, 14, 10, 10, 13, 8, 8, 10, 5, 5, 7, 3, 2, 4, 2, 2, 3, 2, 2, 2, 3, 3, 3, 4, 4, 4, 3, 3, 3, 3, 3, 3, 4, 4, 4, 5, 5, 6, 4, 3, 7, 4, 3, 8, 4, 3, 8, 4, 3, 8, 4, 3, 8, 4, 3, 8, 4, 3, 8, 4, 3, 9, 4, 3, 11, 4, 3, 11, 40, 39, 44, 43, 42, 47, 43, 42, 47, 39, 38, 43, 35, 34, 39, 30, 29, 34, 34, 32, 34, 52, 49, 47, 54, 52, 48, 31, 29, 27, 11, 11, 9, 8, 8, 7, 5, 6, 5, 3, 4, 4, 2, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 6, 5, 5, 7, 5, 4, 7, 5, 5, 7, 5, 5, 7, 4, 4, 6, 4, 4, 6, 4, 4, 6, 4, 3, 9, 4, 3, 12, 5, 3, 12, 38, 37, 42, 41, 40, 45, 42, 41, 46, 40, 39, 44, 36, 35, 40, 37, 36, 40, 62, 57, 58, 101, 91, 84, 119, 108, 101, 108, 100, 94, 59, 52, 49, 18, 14, 12, 9, 6, 6, 8, 6, 6, 5, 5, 5, 3, 3, 3, 2, 2, 2, 2, 2, 2, 4, 4, 4, 5, 5, 5, 7, 7, 6, 7, 7, 7, 6, 6, 6, 6, 6, 7, 8, 8, 8, 6, 6, 6, 4, 4, 4, 3, 3, 4, 3, 4, 4, 4, 4, 6, 3, 3, 7, 2, 2, 6, 38, 37, 42, 41, 40, 46, 43, 42, 47, 41, 40, 46, 38, 37, 42, 41, 40, 44, 72, 65, 64, 107, 91, 85, 123, 105, 97, 139, 123, 116, 135, 122, 117, 77, 66, 64, 21, 14, 13, 9, 5, 5, 7, 5, 7, 5, 5, 6, 4, 4, 5, 4, 5, 6, 5, 6, 7, 6, 6, 7, 8, 8, 9, 8, 8, 9, 8, 7, 7, 9, 9, 8, 9, 9, 9, 6, 7, 6, 5, 5, 4, 6, 5, 5, 7, 5, 4, 5, 3, 2, 7, 5, 2, 31, 29, 26, 36, 37, 42, 39, 39, 46, 40, 39, 48, 41, 40, 47, 38, 36, 41, 41, 39, 40, 72, 65, 63, 109, 95, 90, 129, 113, 105, 143, 126, 115, 154, 137, 125, 143, 130, 119, 84, 75, 66, 26, 21, 15, 12, 8, 6, 9, 6, 6, 2, 1, 1, 0, 0, 0, 0, 0, 0, 2, 3, 3, 7, 5, 6, 7, 4, 6, 8, 5, 7, 6, 8, 7, 3, 9, 6, 2, 9, 5, 3, 8, 4, 5, 4, 2, 13, 5, 5, 38, 26, 21, 87, 75, 64, 129, 119, 108, 34, 36, 41, 37, 37, 45, 39, 37, 47, 39, 38, 45, 37, 35, 40, 38, 35, 37, 65, 57, 54, 102, 88, 81, 124, 107, 96, 145, 126, 111, 162, 141, 123, 164, 143, 124, 154, 133, 114, 122, 102, 84, 106, 87, 70, 97, 80, 64, 77, 65, 50, 68, 60, 46, 61, 55, 42, 47, 41, 29, 46, 39, 29, 54, 44, 36, 52, 44, 37, 38, 34, 26, 23, 23, 14, 13, 15, 6, 16, 15, 8, 35, 29, 23, 73, 61, 56, 121, 106, 95, 160, 146, 133, 167, 157, 147, 35, 37, 41, 37, 37, 45, 39, 37, 47, 39, 37, 45, 38, 35, 40, 38, 35, 36, 62, 53, 48, 103, 86, 73, 132, 112, 95, 156, 134, 116, 173, 148, 128, 187, 159, 136, 194, 162, 137, 195, 161, 135, 192, 160, 132, 191, 163, 133, 197, 173, 144, 205, 186, 157, 186, 169, 141, 165, 147, 122, 170, 150, 126, 173, 150, 126, 169, 143, 116, 152, 127, 99, 128, 106, 78, 108, 86, 60, 108, 85, 61, 130, 105, 83, 155, 129, 108, 169, 148, 133, 178, 164, 153, 176, 167, 161, 35, 37, 41, 37, 36, 44, 39, 37, 47, 40, 39, 46, 41, 39, 44, 47, 44, 46, 83, 73, 65, 129, 109, 89, 153, 131, 108, 163, 141, 121, 160, 135, 116, 158, 130, 109, 183, 150, 127, 196, 160, 135, 204, 171, 145, 194, 166, 139, 205, 179, 150, 211, 187, 156, 187, 162, 130, 198, 170, 137, 199, 166, 134, 194, 158, 124, 199, 163, 125, 199, 164, 125, 196, 162, 124, 191, 157, 122, 180, 147, 114, 171, 140, 109, 175, 146, 117, 180, 160, 143, 187, 175, 167, 180, 172, 168, 37, 38, 43, 38, 39, 46, 39, 40, 48, 42, 40, 46, 50, 44, 44, 76, 66, 60, 108, 92, 78, 109, 85, 65, 96, 71, 52, 109, 85, 69, 141, 120, 104, 155, 134, 117, 180, 155, 136, 200, 169, 149, 210, 184, 162, 218, 196, 175, 229, 206, 185, 207, 183, 161, 167, 140, 117, 161, 130, 104, 166, 132, 104, 182, 147, 116, 196, 163, 129, 199, 167, 131, 198, 165, 131, 198, 165, 133, 197, 167, 137, 196, 169, 141, 193, 170, 145, 183, 169, 154, 182, 174, 166, 179, 172, 166, 38, 39, 44, 37, 39, 46, 37, 38, 43, 46, 41, 40, 74, 59, 48, 124, 100, 79, 139, 111, 86, 96, 66, 44, 73, 37, 20, 106, 67, 53, 149, 114, 100, 173, 147, 128, 191, 166, 145, 197, 168, 146, 208, 182, 157, 210, 187, 163, 191, 166, 146, 134, 107, 90, 82, 54, 38, 80, 52, 35, 105, 76, 55, 128, 97, 70, 174, 141, 110, 195, 160, 126, 193, 155, 120, 193, 155, 120, 194, 159, 126, 199, 168, 138, 198, 171, 145, 169, 149, 131, 154, 137, 124, 163, 145, 134, 42, 42, 49, 43, 43, 47, 48, 44, 42, 62, 51, 42, 85, 63, 46, 113, 82, 58, 137, 108, 80, 142, 114, 88, 122, 80, 63, 131, 74, 64, 138, 83, 73, 142, 99, 84, 169, 137, 116, 187, 160, 135, 190, 161, 131, 164, 133, 101, 160, 128, 97, 147, 114, 83, 144, 110, 78, 155, 120, 85, 176, 141, 103, 169, 134, 95, 184, 148, 111, 199, 161, 125, 195, 157, 120, 191, 153, 116, 196, 159, 123, 195, 160, 125, 190, 156, 124, 169, 135, 112, 140, 106, 89, 148, 113, 97, 42, 42, 50, 50, 48, 48, 71, 64, 56, 95, 81, 67, 98, 77, 58, 117, 90, 70, 140, 118, 100, 167, 153, 139, 182, 154, 150, 166, 123, 127, 188, 146, 152, 215, 186, 186, 220, 203, 196, 211, 197, 185, 202, 178, 155, 193, 161, 131, 184, 151, 119, 177, 144, 107, 170, 137, 97, 174, 140, 98, 183, 148, 106, 186, 151, 111, 187, 153, 116, 197, 163, 127, 205, 172, 137, 196, 163, 128, 192, 158, 122, 200, 165, 128, 198, 162, 124, 192, 159, 127, 191, 159, 131, 189, 158, 129, 53, 50, 59, 65, 61, 59, 90, 83, 72, 106, 96, 81, 119, 105, 92, 149, 133, 123, 158, 144, 138, 162, 152, 149, 169, 151, 154, 152, 128, 136, 171, 152, 160, 203, 194, 197, 216, 210, 209, 205, 195, 192, 201, 181, 171, 209, 184, 167, 213, 187, 164, 203, 177, 147, 191, 164, 129, 182, 154, 118, 185, 156, 121, 191, 162, 128, 198, 169, 135, 215, 188, 156, 234, 208, 177, 226, 201, 170, 196, 169, 136, 194, 162, 126, 203, 168, 130, 198, 164, 128, 197, 166, 132, 204, 175, 142, 58, 57, 63, 78, 72, 69, 104, 93, 83, 117, 104, 90, 130, 116, 104, 141, 127, 120, 140, 125, 120, 128, 110, 107, 117, 96, 96, 122, 102, 103, 139, 122, 123, 156, 143, 143, 182, 168, 167, 192, 174, 173, 191, 172, 164, 196, 177, 163, 218, 200, 183, 225, 208, 186, 218, 200, 177, 204, 186, 161, 188, 167, 140, 179, 155, 127, 181, 155, 124, 183, 157, 127, 197, 173, 144, 225, 201, 172, 222, 197, 168, 190, 163, 132, 180, 151, 119, 188, 156, 120, 196, 161, 125, 198, 163, 129, 72, 73, 76, 86, 78, 74, 99, 83, 73, 107, 86, 73, 112, 91, 78, 111, 93, 80, 106, 88, 81, 113, 95, 92, 143, 125, 124, 172, 155, 154, 180, 164, 164, 171, 154, 155, 156, 141, 142, 157, 142, 143, 167, 153, 144, 180, 168, 154, 194, 183, 170, 216, 207, 194, 231, 223, 207, 232, 220, 202, 210, 196, 174, 190, 171, 146, 186, 163, 135, 181, 156, 127, 170, 145, 115, 187, 161, 131, 218, 190, 161, 217, 189, 159, 197, 168, 138, 188, 156, 121, 189, 155, 117, 186, 152, 115, 55, 54, 55, 71, 62, 57, 87, 69, 58, 96, 75, 60, 96, 74, 59, 94, 74, 61, 93, 76, 67, 117, 103, 99, 154, 141, 139, 176, 165, 163, 200, 190, 190, 212, 204, 206, 196, 190, 193, 167, 162, 165, 150, 145, 142, 160, 156, 148, 164, 162, 155, 191, 189, 181, 226, 223, 213, 238, 232, 217, 221, 212, 193, 205, 190, 168, 193, 173, 148, 192, 169, 143, 190, 166, 138, 177, 150, 120, 181, 151, 119, 197, 164, 130, 209, 175, 139, 207, 173, 136, 200, 167, 129, 189, 156, 119, 48, 46, 46, 73, 62, 56, 87, 68, 56, 91, 68, 52, 94, 71, 55, 101, 79, 65, 113, 95, 84, 129, 115, 105, 141, 130, 122, 155, 146, 140, 182, 176, 172, 198, 195, 193, 206, 206, 206, 210, 211, 213, 204, 205, 203, 211, 212, 208, 206, 208, 204, 211, 213, 208, 239, 239, 230, 247, 242, 228, 230, 219, 201, 214, 198, 176, 192, 169, 144, 180, 155, 127, 184, 157, 127, 183, 154, 122, 174, 142, 109, 167, 133, 98, 171, 136, 100, 177, 144, 108, 193, 161, 124, 191, 160, 124, 51, 47, 48, 65, 53, 46, 78, 59, 45, 88, 63, 47, 92, 67, 51, 98, 75, 60, 111, 92, 77, 122, 106, 90, 127, 113, 99, 131, 121, 108, 145, 137, 128, 158, 155, 148, 162, 162, 157, 175, 177, 174, 192, 194, 191, 214, 215, 212, 219, 221, 217, 226, 227, 220, 237, 234, 224, 237, 229, 213, 226, 213, 192, 212, 193, 167, 193, 166, 136, 180, 150, 119, 180, 150, 118, 184, 154, 122, 191, 161, 128, 192, 162, 130, 190, 159, 127, 186, 156, 122, 194, 164, 129, 193, 163, 129, 52, 48, 51, 64, 54, 49, 82, 65, 53, 95, 72, 56, 97, 71, 56, 95, 69, 56, 99, 75, 62, 105, 87, 72, 112, 96, 82, 120, 106, 93, 124, 114, 102, 131, 123, 112, 141, 135, 126, 152, 148, 139, 170, 169, 161, 180, 180, 171, 192, 189, 177, 207, 200, 185, 215, 204, 186, 213, 200, 179, 204, 190, 168, 203, 188, 164, 205, 187, 160, 209, 189, 162, 209, 187, 160, 209, 187, 160, 211, 188, 160, 209, 184, 157, 204, 178, 151, 198, 172, 143, 195, 168, 138, 186, 159, 130, 55, 51, 56, 62, 53, 50, 78, 63, 51, 98, 76, 61, 108, 83, 66, 110, 82, 69, 106, 80, 66, 102, 79, 64, 108, 87, 71, 116, 97, 82, 119, 103, 88, 124, 111, 96, 132, 121, 106, 152, 142, 128, 169, 162, 147, 172, 165, 149, 187, 176, 158, 185, 172, 151, 194, 179, 156, 213, 200, 178, 215, 203, 184, 222, 212, 192, 229, 217, 194, 229, 216, 192, 224, 209, 184, 221, 203, 179, 219, 199, 173, 211, 188, 162, 203, 180, 154, 196, 171, 145, 193, 167, 140, 187, 160, 133, 54, 50, 53, 60, 52, 46, 68, 53, 39, 84, 63, 45, 102, 77, 58, 111, 84, 68, 110, 82, 66, 110, 84, 65, 120, 94, 74, 124, 101, 82, 126, 106, 87, 127, 110, 91, 122, 105, 87, 122, 106, 89, 122, 108, 90, 139, 124, 106, 148, 132, 111, 138, 121, 98, 160, 143, 121, 175, 161, 141, 182, 170, 153, 208, 198, 180, 222, 209, 187, 221, 206, 182, 210, 194, 170, 201, 182, 158, 200, 179, 153, 200, 178, 151, 200, 176, 150, 197, 171, 144, 197, 169, 141, 190, 161, 134, 52, 49, 50, 62, 54, 46, 68, 54, 38, 77, 56, 36, 91, 66, 45, 101, 74, 56, 103, 76, 59, 110, 84, 65, 126, 101, 82, 137, 114, 94, 139, 119, 100, 141, 123, 105, 138, 122, 104, 131, 116, 99, 129, 115, 98, 141, 126, 108, 135, 117, 96, 127, 107, 84, 147, 126, 103, 140, 119, 98, 149, 132, 112, 181, 167, 146, 183, 169, 147, 183, 169, 145, 190, 175, 150, 193, 175, 150, 197, 177, 151, 196, 173, 147, 199, 175, 149, 199, 172, 143, 194, 164, 132, 187, 157, 125, 54, 51, 50, 68, 59, 49, 78, 63, 45, 86, 64, 43, 94, 68, 47, 99, 72, 53, 102, 76, 59, 110, 87, 71, 128, 107, 90, 145, 126, 108, 151, 134, 116, 153, 137, 121, 156, 142, 125, 158, 145, 129, 161, 149, 135, 173, 160, 145, 173, 156, 138, 153, 133, 111, 157, 135, 111, 153, 129, 104, 158, 136, 111, 157, 137, 113, 164, 148, 124, 186, 171, 147, 205, 188, 163, 209, 190, 165, 207, 186, 160, 204, 181, 154, 196, 171, 144, 184, 156, 123, 188, 158, 120, 193, 162, 124, 57, 53, 50, 83, 71, 56, 92, 72, 50, 93, 66, 46, 93, 64, 46, 103, 75, 55, 113, 88, 68, 113, 92, 75, 122, 102, 85, 138, 119, 99, 154, 137, 115, 179, 163, 141, 187, 171, 151, 177, 162, 145, 164, 148, 133, 174, 158, 142, 190, 176, 160, 190, 177, 158, 194, 180, 158, 179, 163, 136, 174, 156, 125, 169, 148, 117, 177, 154, 126, 178, 155, 127, 182, 157, 129, 189, 163, 135, 194, 167, 137, 190, 162, 132, 180, 151, 120, 191, 158, 124, 202, 166, 130, 196, 159, 122, 50, 45, 41, 77, 64, 46, 87, 65, 42, 97, 67, 47, 107, 75, 57, 113, 84, 62, 115, 87, 63, 120, 92, 70, 137, 110, 87, 159, 135, 110, 177, 157, 131, 193, 176, 152, 202, 187, 167, 196, 181, 165, 185, 172, 154, 184, 170, 151, 188, 175, 156, 208, 195, 175, 193, 179, 156, 196, 177, 150, 199, 175, 144, 198, 171, 137, 192, 162, 129, 186, 155, 122, 181, 149, 116, 177, 144, 110, 174, 140, 105, 180, 145, 110, 192, 157, 121, 202, 163, 126, 201, 160, 122, 196, 154, 116, 47, 40, 35, 87, 73, 54, 104, 80, 56, 113, 82, 61, 119, 86, 66, 122, 91, 67, 129, 97, 70, 138, 103, 75, 142, 108, 80, 150, 120, 90, 169, 144, 115, 190, 170, 143, 198, 181, 159, 199, 183, 165, 204, 190, 168, 211, 197, 174, 207, 193, 170, 194, 178, 154, 185, 166, 141, 203, 178, 149, 198, 167, 134, 199, 165, 130, 202, 167, 131, 197, 161, 124, 192, 154, 117, 195, 157, 118, 202, 163, 123, 208, 168, 127, 205, 164, 123, 190, 148, 107, 179, 137, 95, 180, 138, 96, 67, 59, 52, 106, 89, 69, 117, 91, 66, 117, 84, 62, 120, 85, 64, 131, 98, 73, 136, 103, 74, 138, 101, 73, 141, 105, 75, 153, 119, 87, 167, 137, 103, 181, 154, 122, 187, 161, 133, 196, 171, 145, 211, 188, 163, 201, 180, 156, 187, 167, 143, 205, 186, 160, 194, 173, 144, 190, 165, 132, 195, 165, 129, 201, 168, 130, 208, 172, 135, 211, 175, 138, 208, 170, 133, 198, 159, 121, 187, 147, 108, 187, 146, 106, 196, 155, 114, 196, 157, 116, 197, 159, 118, 200, 163, 123, 71, 63, 54, 113, 97, 77, 130, 105, 81, 134, 103, 81, 144, 113, 91, 151, 122, 97, 150, 122, 94, 152, 121, 93, 161, 129, 99, 173, 142, 110, 182, 151, 117, 188, 157, 124, 187, 157, 125, 183, 153, 123, 189, 161, 135, 193, 167, 143, 188, 164, 138, 213, 189, 163, 206, 182, 153, 196, 172, 139, 199, 173, 136, 211, 181, 144, 217, 183, 148, 217, 181, 147, 210, 174, 138, 197, 161, 123, 195, 158, 119, 200, 163, 121, 202, 164, 123, 201, 165, 125, 205, 171, 132, 219, 186, 148, 60, 56, 42, 101, 88, 70, 119, 97, 76, 135, 109, 85, 148, 124, 98, 147, 126, 99, 153, 132, 105, 166, 142, 116, 174, 149, 122, 180, 155, 128, 185, 159, 133, 193, 167, 141, 206, 180, 154, 191, 165, 139, 185, 163, 138, 208, 187, 163, 186, 165, 140, 221, 199, 173, 222, 199, 172, 193, 169, 141, 207, 182, 153, 227, 200, 170, 227, 195, 165, 226, 192, 160, 224, 190, 155, 221, 188, 150, 214, 181, 141, 213, 181, 138, 221, 189, 144, 217, 186, 145, 212, 181, 144, 208, 177, 141, 60, 55, 41, 83, 69, 52, 94, 72, 49, 111, 83, 56, 120, 90, 61, 132, 103, 73, 153, 126, 96, 163, 136, 109, 164, 137, 111, 175, 148, 122, 188, 161, 135, 195, 168, 142, 202, 176, 150, 189, 162, 136, 184, 157, 130, 199, 171, 143, 166, 137, 108, 189, 160, 130, 232, 202, 170, 219, 187, 156, 176, 144, 112, 196, 164, 130, 221, 188, 153, 223, 190, 154, 219, 186, 148, 214, 181, 141, 211, 179, 137, 209, 177, 133, 211, 179, 134, 205, 171, 130, 191, 155, 118, 175, 140, 103, 52, 46, 36, 77, 66, 52, 87, 70, 51, 92, 71, 48, 95, 71, 47, 110, 84, 60, 135, 108, 83, 151, 122, 95, 152, 122, 96, 149, 119, 92, 151, 121, 95, 170, 140, 113, 188, 158, 132, 192, 162, 136, 182, 150, 121, 172, 138, 108, 169, 135, 104, 162, 127, 95, 176, 140, 106, 194, 157, 122, 180, 143, 108, 154, 117, 82, 173, 137, 102, 188, 153, 117, 193, 158, 121, 180, 146, 108, 168, 133, 95, 169, 134, 95, 173, 139, 99, 175, 139, 102, 171, 132, 97, 154, 116, 81, 41, 38, 36, 52, 49, 43, 49, 45, 36, 35, 30, 21, 35, 27, 19, 37, 28, 22, 46, 35, 29, 70, 57, 49, 75, 62, 53, 73, 60, 52, 79, 66, 58, 84, 70, 61, 88, 75, 65, 89, 75, 67, 90, 75, 65, 81, 65, 53, 84, 68, 57, 82, 66, 54, 76, 58, 46, 78, 59, 44, 81, 62, 48, 83, 63, 49, 78, 60, 48, 78, 59, 48, 69, 51, 40, 58, 40, 30, 50, 32, 22, 60, 42, 31, 86, 68, 55, 95, 77, 64, 87, 69, 59, 87, 69, 58], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452388176}, {\"format\": \"raw\", \"value\": [60, 35, 18, 63, 49, 38, 66, 56, 44, 64, 51, 35, 62, 53, 36, 68, 60, 42, 64, 53, 34, 58, 45, 24, 55, 40, 17, 56, 36, 16, 59, 36, 18, 61, 38, 20, 64, 41, 23, 71, 47, 30, 78, 52, 36, 86, 64, 46, 81, 63, 41, 77, 54, 31, 73, 41, 18, 82, 50, 17, 56, 29, 5, 33, 13, 4, 14, 5, 4, 2, 0, 2, 31, 27, 21, 94, 86, 67, 128, 116, 88, 139, 121, 91, 145, 124, 96, 148, 128, 101, 146, 129, 101, 151, 133, 104, 61, 37, 20, 65, 51, 40, 67, 56, 44, 66, 53, 37, 58, 53, 38, 61, 59, 43, 66, 61, 43, 69, 62, 42, 65, 55, 35, 67, 48, 30, 67, 45, 28, 71, 49, 32, 87, 65, 48, 98, 76, 59, 93, 74, 64, 86, 73, 63, 76, 67, 53, 66, 52, 37, 62, 39, 24, 66, 41, 15, 45, 23, 2, 31, 13, 5, 10, 0, 0, 22, 17, 15, 95, 84, 66, 125, 109, 84, 134, 117, 93, 142, 123, 97, 146, 126, 96, 143, 125, 96, 145, 128, 100, 146, 129, 101, 70, 46, 30, 69, 55, 43, 61, 51, 39, 59, 46, 31, 59, 51, 38, 63, 56, 45, 66, 57, 43, 72, 60, 45, 77, 63, 47, 76, 63, 50, 70, 57, 46, 84, 70, 60, 98, 85, 75, 102, 89, 79, 98, 87, 83, 95, 89, 86, 85, 82, 74, 52, 46, 36, 44, 29, 20, 59, 37, 26, 48, 26, 16, 26, 9, 5, 16, 5, 1, 70, 61, 44, 124, 108, 76, 134, 113, 83, 138, 117, 94, 139, 118, 95, 142, 124, 93, 141, 123, 92, 140, 123, 95, 140, 123, 95, 74, 55, 37, 66, 54, 42, 50, 40, 28, 55, 42, 26, 66, 53, 40, 69, 57, 45, 70, 57, 44, 71, 57, 44, 75, 61, 47, 85, 75, 61, 94, 86, 73, 105, 98, 86, 100, 95, 85, 105, 101, 92, 105, 100, 96, 98, 94, 92, 88, 86, 82, 73, 70, 65, 53, 46, 42, 52, 39, 36, 60, 45, 43, 38, 23, 22, 70, 56, 45, 120, 107, 81, 130, 113, 80, 138, 119, 89, 139, 120, 94, 137, 119, 93, 138, 120, 91, 137, 120, 91, 138, 121, 93, 141, 124, 95, 73, 56, 38, 65, 55, 42, 51, 41, 29, 59, 45, 30, 68, 55, 40, 67, 56, 41, 79, 67, 53, 104, 92, 78, 92, 81, 66, 82, 72, 57, 72, 63, 49, 97, 92, 79, 107, 105, 94, 96, 96, 87, 109, 107, 102, 103, 99, 96, 86, 81, 78, 74, 70, 67, 71, 67, 64, 53, 46, 44, 51, 42, 41, 52, 40, 39, 79, 65, 54, 118, 103, 80, 136, 120, 92, 133, 116, 88, 136, 120, 91, 135, 119, 90, 135, 118, 90, 135, 118, 90, 131, 114, 86, 133, 115, 87, 71, 54, 35, 62, 52, 40, 51, 41, 29, 54, 41, 25, 64, 51, 36, 83, 71, 57, 109, 97, 83, 109, 97, 83, 90, 78, 64, 68, 57, 45, 49, 40, 30, 83, 77, 69, 111, 108, 102, 113, 112, 107, 105, 102, 99, 88, 84, 81, 66, 62, 59, 56, 52, 49, 54, 50, 47, 59, 54, 53, 63, 56, 58, 53, 44, 45, 40, 30, 21, 83, 71, 50, 135, 121, 93, 140, 123, 95, 137, 120, 92, 136, 119, 91, 134, 117, 89, 133, 116, 88, 132, 115, 87, 131, 114, 86, 62, 44, 25, 50, 40, 27, 51, 41, 28, 55, 42, 26, 60, 47, 32, 92, 80, 66, 111, 99, 85, 86, 74, 59, 71, 59, 45, 64, 53, 43, 66, 56, 49, 93, 86, 81, 119, 115, 112, 127, 125, 123, 103, 100, 97, 61, 57, 54, 34, 30, 27, 21, 17, 14, 21, 17, 14, 25, 22, 23, 51, 47, 53, 68, 61, 65, 51, 43, 36, 70, 62, 42, 122, 108, 81, 138, 121, 92, 139, 122, 94, 132, 115, 87, 131, 114, 86, 133, 116, 88, 130, 113, 85, 132, 114, 86, 93, 81, 73, 71, 62, 56, 59, 49, 42, 61, 49, 39, 65, 55, 43, 92, 83, 71, 86, 76, 66, 41, 31, 23, 38, 28, 20, 41, 33, 26, 73, 67, 60, 119, 114, 109, 144, 141, 136, 134, 132, 128, 90, 87, 83, 29, 25, 23, 11, 8, 6, 10, 6, 6, 11, 7, 8, 8, 7, 7, 14, 13, 16, 21, 17, 21, 32, 26, 23, 59, 52, 38, 106, 92, 68, 130, 111, 84, 134, 115, 88, 130, 112, 84, 128, 110, 82, 129, 111, 85, 126, 108, 83, 125, 107, 81, 100, 97, 98, 98, 91, 91, 90, 81, 78, 92, 82, 78, 91, 86, 79, 71, 69, 63, 38, 35, 32, 30, 27, 26, 30, 26, 28, 34, 30, 27, 80, 77, 71, 113, 110, 104, 134, 131, 125, 148, 145, 139, 125, 122, 118, 57, 53, 51, 25, 21, 21, 11, 7, 9, 5, 1, 6, 5, 4, 4, 6, 6, 6, 7, 5, 9, 25, 20, 20, 53, 46, 37, 103, 89, 67, 136, 116, 89, 133, 113, 86, 130, 110, 83, 130, 110, 83, 128, 110, 82, 126, 109, 81, 122, 105, 76, 97, 96, 96, 91, 87, 86, 100, 93, 90, 114, 108, 102, 112, 111, 107, 46, 48, 46, 26, 27, 28, 26, 27, 31, 18, 18, 24, 36, 34, 34, 53, 49, 46, 65, 61, 59, 96, 93, 90, 134, 130, 128, 108, 104, 102, 42, 38, 36, 14, 10, 11, 8, 4, 6, 9, 5, 9, 26, 26, 25, 32, 33, 32, 29, 26, 30, 24, 19, 19, 43, 36, 28, 109, 94, 72, 127, 107, 79, 126, 106, 79, 129, 109, 82, 128, 108, 81, 127, 110, 77, 125, 109, 74, 116, 99, 67, 129, 132, 131, 122, 122, 119, 132, 130, 125, 131, 127, 121, 91, 89, 82, 53, 52, 47, 34, 32, 30, 14, 12, 12, 24, 21, 23, 40, 37, 38, 43, 39, 40, 41, 37, 38, 62, 58, 59, 79, 74, 75, 51, 47, 46, 13, 9, 7, 7, 3, 3, 7, 2, 5, 23, 18, 24, 33, 33, 32, 30, 31, 30, 36, 34, 38, 22, 17, 17, 39, 32, 23, 113, 98, 76, 130, 110, 82, 126, 106, 80, 122, 102, 75, 114, 94, 67, 109, 91, 60, 111, 94, 63, 116, 99, 72, 155, 159, 155, 157, 159, 153, 151, 151, 143, 117, 115, 105, 83, 76, 67, 74, 65, 58, 60, 52, 48, 43, 35, 33, 58, 51, 51, 64, 59, 62, 45, 41, 45, 34, 30, 34, 28, 23, 27, 18, 13, 17, 11, 9, 9, 5, 4, 3, 11, 9, 9, 21, 19, 21, 32, 30, 33, 32, 32, 30, 13, 12, 12, 13, 9, 14, 25, 18, 19, 47, 39, 31, 114, 97, 75, 123, 102, 72, 124, 104, 74, 122, 103, 73, 120, 101, 75, 114, 97, 73, 110, 94, 71, 89, 73, 54, 171, 175, 166, 172, 174, 164, 160, 161, 148, 125, 122, 109, 101, 92, 85, 75, 65, 62, 68, 60, 59, 61, 56, 57, 72, 68, 70, 84, 80, 85, 46, 41, 46, 30, 25, 30, 26, 21, 26, 20, 15, 20, 6, 5, 7, 5, 5, 5, 25, 25, 25, 42, 42, 42, 30, 30, 30, 32, 31, 29, 18, 15, 16, 14, 8, 13, 29, 19, 21, 47, 36, 29, 119, 99, 78, 125, 102, 71, 110, 91, 56, 108, 91, 59, 114, 97, 74, 100, 85, 70, 53, 41, 31, 36, 24, 13, 173, 177, 171, 169, 171, 163, 138, 138, 128, 103, 101, 90, 82, 75, 68, 73, 65, 61, 70, 65, 63, 53, 50, 50, 47, 46, 47, 51, 48, 50, 36, 31, 33, 18, 14, 16, 21, 16, 18, 18, 13, 15, 8, 5, 6, 6, 4, 5, 14, 12, 13, 27, 25, 25, 38, 36, 36, 38, 37, 35, 24, 21, 22, 26, 19, 25, 26, 16, 18, 50, 39, 32, 97, 79, 62, 119, 98, 71, 118, 100, 70, 112, 97, 70, 99, 84, 66, 43, 29, 23, 13, 0, 0, 23, 10, 8, 169, 171, 169, 154, 155, 150, 113, 113, 106, 87, 84, 77, 77, 73, 66, 92, 89, 83, 91, 89, 86, 68, 69, 68, 54, 57, 57, 38, 37, 36, 41, 37, 36, 41, 37, 36, 25, 21, 20, 22, 18, 17, 22, 16, 18, 20, 15, 16, 18, 13, 15, 42, 35, 37, 81, 76, 77, 54, 51, 50, 24, 21, 22, 20, 13, 19, 37, 27, 29, 77, 66, 59, 92, 75, 62, 98, 79, 59, 113, 96, 72, 99, 85, 64, 46, 33, 23, 10, 0, 0, 13, 0, 0, 13, 0, 0, 170, 172, 171, 151, 151, 147, 107, 106, 100, 92, 88, 82, 76, 74, 68, 80, 79, 74, 98, 99, 95, 81, 84, 82, 55, 59, 58, 50, 47, 45, 70, 65, 62, 85, 82, 78, 72, 68, 65, 43, 39, 37, 24, 18, 20, 31, 20, 25, 35, 24, 28, 59, 50, 53, 67, 58, 60, 21, 17, 16, 10, 9, 10, 31, 26, 31, 59, 50, 51, 89, 79, 72, 96, 82, 70, 90, 74, 59, 94, 81, 63, 94, 84, 70, 78, 70, 63, 71, 63, 59, 63, 54, 50, 56, 46, 42, 168, 168, 165, 131, 130, 124, 108, 104, 95, 122, 116, 107, 99, 96, 91, 71, 70, 68, 85, 83, 81, 109, 108, 106, 64, 63, 60, 69, 62, 60, 156, 152, 148, 175, 176, 172, 143, 141, 139, 118, 111, 112, 90, 88, 88, 68, 56, 59, 45, 34, 36, 30, 36, 31, 25, 26, 22, 28, 27, 25, 39, 41, 42, 93, 90, 95, 111, 106, 106, 96, 88, 79, 93, 82, 70, 99, 89, 78, 128, 122, 114, 157, 157, 152, 155, 159, 158, 156, 160, 159, 156, 159, 157, 156, 159, 157, 171, 172, 168, 128, 127, 121, 126, 122, 113, 135, 128, 119, 121, 115, 110, 108, 104, 100, 114, 109, 105, 97, 93, 89, 87, 83, 79, 123, 121, 119, 189, 191, 187, 216, 219, 214, 217, 213, 209, 200, 185, 184, 176, 156, 155, 156, 129, 129, 111, 97, 94, 78, 89, 79, 109, 114, 107, 145, 142, 136, 138, 135, 132, 128, 123, 125, 126, 120, 120, 121, 115, 106, 116, 107, 94, 110, 100, 89, 131, 125, 118, 169, 169, 166, 165, 169, 169, 159, 164, 164, 160, 164, 163, 162, 166, 165, 182, 182, 179, 130, 129, 123, 131, 126, 118, 131, 124, 115, 120, 112, 105, 109, 101, 95, 108, 100, 93, 104, 96, 89, 124, 116, 111, 169, 165, 167, 207, 205, 209, 221, 215, 215, 214, 193, 193, 210, 172, 174, 212, 147, 151, 183, 110, 114, 174, 130, 129, 159, 148, 141, 156, 140, 138, 166, 150, 142, 143, 134, 125, 120, 111, 110, 122, 114, 113, 123, 118, 111, 118, 109, 97, 119, 109, 99, 122, 117, 110, 164, 164, 161, 173, 177, 177, 169, 174, 173, 166, 170, 169, 167, 171, 170, 159, 159, 156, 127, 125, 119, 145, 140, 132, 138, 131, 122, 118, 109, 101, 110, 101, 93, 101, 91, 83, 118, 108, 99, 146, 136, 128, 174, 163, 166, 203, 189, 197, 206, 183, 188, 205, 164, 169, 223, 162, 167, 215, 132, 134, 166, 86, 86, 189, 149, 143, 197, 193, 181, 182, 171, 164, 173, 155, 143, 158, 144, 133, 140, 128, 125, 127, 118, 116, 106, 101, 95, 108, 101, 89, 125, 116, 104, 121, 116, 108, 157, 158, 154, 176, 179, 179, 172, 177, 176, 171, 175, 174, 173, 177, 176, 136, 134, 129, 134, 125, 117, 136, 126, 120, 115, 108, 106, 113, 109, 106, 105, 100, 96, 117, 110, 104, 121, 112, 104, 126, 114, 106, 148, 124, 117, 181, 148, 149, 210, 169, 178, 224, 172, 181, 222, 159, 162, 201, 136, 134, 193, 148, 145, 198, 184, 178, 192, 193, 182, 174, 168, 153, 160, 150, 139, 163, 154, 147, 145, 137, 132, 117, 110, 105, 83, 76, 70, 107, 101, 86, 113, 108, 90, 110, 108, 95, 157, 157, 151, 176, 177, 176, 173, 176, 176, 173, 177, 176, 175, 179, 178, 125, 122, 114, 131, 121, 111, 114, 103, 96, 79, 72, 69, 88, 87, 86, 101, 99, 97, 123, 118, 114, 122, 114, 108, 112, 102, 94, 156, 125, 119, 209, 163, 164, 222, 170, 178, 217, 161, 169, 204, 150, 152, 204, 166, 166, 214, 195, 196, 204, 197, 197, 178, 174, 172, 128, 119, 114, 126, 118, 114, 154, 149, 146, 134, 129, 125, 128, 123, 119, 117, 112, 107, 111, 105, 94, 86, 81, 67, 71, 69, 58, 148, 148, 142, 186, 187, 184, 177, 180, 179, 175, 179, 178, 176, 180, 179, 102, 100, 88, 101, 92, 77, 115, 104, 93, 106, 100, 94, 103, 103, 103, 110, 111, 112, 127, 125, 123, 136, 132, 129, 128, 120, 116, 155, 124, 124, 209, 161, 163, 212, 160, 162, 204, 157, 157, 211, 177, 177, 218, 205, 206, 222, 214, 216, 210, 198, 199, 180, 169, 171, 136, 130, 132, 94, 92, 92, 115, 113, 112, 130, 129, 127, 170, 169, 167, 158, 157, 155, 102, 97, 93, 63, 56, 51, 33, 30, 25, 108, 108, 103, 190, 191, 187, 190, 193, 191, 187, 191, 190, 187, 191, 190, 122, 121, 106, 84, 75, 58, 91, 81, 66, 131, 125, 116, 194, 195, 195, 210, 213, 216, 192, 193, 194, 169, 167, 166, 147, 142, 139, 146, 122, 123, 186, 145, 145, 196, 152, 146, 210, 178, 170, 209, 196, 190, 204, 197, 198, 205, 187, 187, 187, 160, 157, 182, 163, 160, 210, 210, 209, 194, 198, 198, 198, 199, 199, 210, 210, 211, 210, 210, 211, 177, 177, 178, 107, 101, 103, 62, 54, 55, 33, 30, 28, 87, 87, 82, 185, 187, 182, 196, 200, 197, 193, 197, 196, 197, 201, 200, 182, 183, 172, 125, 123, 107, 66, 61, 41, 99, 95, 76, 208, 206, 202, 247, 246, 249, 247, 245, 246, 238, 236, 236, 224, 220, 219, 186, 170, 168, 155, 125, 122, 165, 128, 122, 198, 164, 155, 183, 158, 147, 175, 138, 133, 168, 124, 122, 124, 88, 86, 146, 126, 124, 232, 228, 228, 247, 248, 249, 251, 251, 252, 246, 246, 247, 232, 232, 233, 202, 203, 203, 130, 125, 123, 85, 78, 75, 49, 46, 41, 79, 79, 73, 165, 166, 159, 199, 203, 199, 198, 202, 201, 200, 204, 203, 203, 204, 198, 188, 187, 180, 144, 140, 132, 133, 126, 119, 216, 214, 215, 242, 242, 247, 240, 240, 245, 243, 243, 248, 240, 239, 243, 210, 190, 186, 165, 128, 121, 168, 124, 118, 175, 130, 121, 172, 131, 119, 162, 120, 112, 134, 96, 91, 77, 52, 48, 86, 76, 74, 214, 214, 212, 241, 242, 241, 243, 243, 243, 244, 244, 244, 217, 217, 216, 143, 142, 142, 99, 94, 92, 81, 75, 70, 91, 88, 82, 103, 103, 96, 141, 143, 136, 199, 203, 199, 207, 211, 211, 206, 210, 209, 206, 206, 203, 208, 206, 206, 208, 202, 205, 172, 164, 169, 184, 182, 188, 226, 227, 232, 235, 236, 241, 238, 239, 245, 216, 214, 219, 180, 156, 149, 185, 144, 134, 191, 145, 138, 183, 139, 132, 168, 134, 124, 111, 89, 83, 75, 61, 56, 48, 40, 36, 57, 56, 52, 200, 204, 200, 234, 236, 235, 235, 235, 235, 236, 236, 236, 220, 220, 220, 118, 118, 118, 59, 54, 54, 58, 51, 51, 75, 71, 70, 89, 89, 86, 143, 144, 141, 205, 208, 206, 209, 213, 212, 212, 216, 215, 206, 206, 206, 207, 206, 202, 204, 200, 193, 131, 124, 117, 104, 96, 93, 176, 168, 166, 209, 202, 200, 187, 180, 178, 162, 153, 151, 129, 111, 103, 125, 99, 90, 98, 70, 66, 90, 67, 65, 75, 62, 60, 36, 30, 29, 40, 35, 35, 33, 29, 28, 64, 62, 59, 204, 203, 199, 233, 232, 231, 222, 222, 222, 225, 225, 225, 229, 229, 229, 161, 161, 161, 54, 48, 50, 36, 28, 31, 36, 32, 33, 61, 60, 60, 140, 141, 141, 212, 215, 214, 207, 212, 210, 209, 213, 212, 210, 210, 210, 211, 210, 207, 209, 207, 201, 178, 175, 167, 122, 113, 101, 101, 89, 76, 111, 100, 87, 102, 90, 77, 164, 153, 140, 148, 141, 134, 45, 39, 35, 20, 13, 12, 12, 8, 8, 20, 19, 19, 28, 24, 21, 60, 52, 49, 119, 112, 108, 145, 140, 136, 219, 214, 211, 227, 224, 225, 221, 221, 224, 213, 212, 216, 200, 200, 203, 166, 165, 169, 51, 49, 52, 34, 31, 33, 43, 41, 43, 48, 47, 48, 141, 141, 142, 216, 219, 221, 208, 211, 215, 208, 212, 215, 213, 213, 213, 211, 211, 211, 210, 211, 211, 210, 209, 209, 195, 192, 183, 161, 157, 144, 156, 152, 140, 183, 178, 166, 205, 201, 190, 169, 168, 164, 106, 107, 107, 94, 94, 94, 90, 91, 91, 87, 87, 87, 118, 117, 116, 174, 172, 170, 195, 190, 186, 155, 147, 140, 178, 169, 161, 189, 186, 183, 181, 181, 181, 170, 170, 170, 177, 177, 176, 178, 178, 178, 143, 144, 144, 157, 157, 157, 157, 157, 157, 121, 121, 121, 170, 170, 170, 213, 215, 219, 207, 210, 216, 211, 215, 220, 221, 221, 221, 221, 221, 221, 222, 222, 222, 218, 218, 218, 218, 220, 219, 216, 219, 217, 215, 217, 216, 216, 218, 217, 219, 221, 220, 221, 222, 221, 217, 217, 217, 214, 214, 214, 212, 211, 211, 213, 213, 214, 217, 222, 227, 219, 225, 229, 213, 212, 211, 164, 156, 150, 136, 124, 114, 135, 131, 123, 155, 156, 150, 189, 189, 184, 218, 219, 213, 220, 221, 216, 220, 221, 218, 217, 217, 217, 214, 214, 214, 213, 213, 213, 219, 219, 219, 219, 221, 223, 217, 221, 223, 222, 226, 228, 218, 218, 218, 216, 216, 216, 216, 216, 216, 214, 214, 214, 216, 216, 216, 221, 221, 221, 220, 220, 220, 218, 219, 219, 223, 223, 223, 225, 225, 225, 225, 225, 225, 224, 224, 224, 225, 225, 226, 228, 228, 228, 223, 226, 229, 220, 223, 226, 220, 221, 221, 218, 216, 214, 210, 206, 203, 204, 203, 201, 220, 220, 219, 226, 226, 225, 226, 226, 226, 226, 226, 225, 225, 225, 225, 226, 226, 226, 227, 227, 227, 227, 227, 227, 227, 227, 227, 224, 226, 225, 219, 223, 222, 221, 225, 224], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452388240}], \"selected_variable\": {\"name\": [\"<SArray>\"], \"dtype\": \"Image\", \"view_component\": \"Images\", \"view_file\": \"sarray\", \"descriptives\": {\"rows\": 2005}, \"type\": \"SArray\", \"view_components\": [\"Images\"]}}, e);\n",
       "                });\n",
       "            })();\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "image_train['image'].show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#Train a classifier on the raw image pixels\n",
    "\n",
    "We first start by training a classifier on just the raw pixels of the image."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "PROGRESS: Creating a validation set from 5 percent of training data. This may take a while.\n",
      "          You can set ``validation_set=None`` to disable validation tracking.\n",
      "\n",
      "PROGRESS: Logistic regression:\n",
      "PROGRESS: --------------------------------------------------------\n",
      "PROGRESS: Number of examples          : 1914\n",
      "PROGRESS: Number of classes           : 4\n",
      "PROGRESS: Number of feature columns   : 1\n",
      "PROGRESS: Number of unpacked features : 3072\n",
      "PROGRESS: Number of coefficients    : 9219\n",
      "PROGRESS: Starting L-BFGS\n",
      "PROGRESS: --------------------------------------------------------\n",
      "PROGRESS: +-----------+----------+-----------+--------------+-------------------+---------------------+\n",
      "PROGRESS: | Iteration | Passes   | Step size | Elapsed Time | Training-accuracy | Validation-accuracy |\n",
      "PROGRESS: +-----------+----------+-----------+--------------+-------------------+---------------------+\n",
      "PROGRESS: | 1         | 6        | 0.000009  | 8.901348     | 0.274817          | 0.219780            |\n",
      "PROGRESS: | 2         | 9        | 5.000000  | 11.510837    | 0.427377          | 0.406593            |\n",
      "PROGRESS: | 3         | 10       | 5.000000  | 12.567608    | 0.405956          | 0.428571            |\n",
      "PROGRESS: | 4         | 12       | 1.000000  | 16.285468    | 0.432602          | 0.461538            |\n",
      "PROGRESS: | 5         | 13       | 1.000000  | 18.896629    | 0.448798          | 0.461538            |\n",
      "PROGRESS: | 6         | 14       | 1.000000  | 20.046345    | 0.459770          | 0.439560            |\n",
      "PROGRESS: | 7         | 15       | 1.000000  | 21.066622    | 0.485371          | 0.483516            |\n",
      "PROGRESS: | 8         | 16       | 1.000000  | 22.079217    | 0.367816          | 0.307692            |\n",
      "PROGRESS: | 9         | 18       | 1.000000  | 24.204190    | 0.493730          | 0.494505            |\n",
      "PROGRESS: | 10        | 19       | 1.000000  | 26.974843    | 0.511494          | 0.505495            |\n",
      "PROGRESS: +-----------+----------+-----------+--------------+-------------------+---------------------+\n"
     ]
    }
   ],
   "source": [
    "raw_pixel_model = graphlab.logistic_classifier.create(image_train,target='label',\n",
    "                                              features=['image_array'])"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#Make a prediction with the simple model based on raw pixels"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "application/javascript": [
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//cdnjs.cloudflare.com/ajax/libs/font-awesome/4.1.0/css/font-awesome.min.css\"\n",
       "}));\n",
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//dato.com/files/canvas/1.6.1/css/canvas.css\"\n",
       "}));\n",
       "\n",
       "            (function(){\n",
       "\n",
       "                var e = null;\n",
       "                if (typeof element == 'undefined') {\n",
       "                    var scripts = document.getElementsByTagName('script');\n",
       "                    var thisScriptTag = scripts[scripts.length-1];\n",
       "                    var parentDiv = thisScriptTag.parentNode;\n",
       "                    e = document.createElement('div');\n",
       "                    parentDiv.appendChild(e);\n",
       "                } else {\n",
       "                    e = element[0];\n",
       "                }\n",
       "\n",
       "                if (typeof requirejs !== 'undefined') {\n",
       "                    // disable load timeout; ipython_app.js is large and can take a while to load.\n",
       "                    requirejs.config({waitSeconds: 0});\n",
       "                }\n",
       "\n",
       "                require(['//dato.com/files/canvas/1.6.1/js/ipython_app.js'], function(IPythonApp){\n",
       "                    var app = new IPythonApp();\n",
       "                    app.attachView('sarray','Images', {\"ipython\": true, \"rows\": [{\"format\": \"raw\", \"value\": [158, 112, 49, 159, 111, 47, 165, 116, 51, 166, 118, 53, 160, 112, 46, 156, 109, 41, 162, 115, 47, 159, 113, 45, 158, 111, 44, 159, 113, 41, 161, 116, 41, 160, 111, 52, 161, 111, 49, 166, 117, 41, 169, 117, 45, 170, 119, 44, 167, 117, 40, 162, 113, 38, 160, 111, 39, 160, 112, 43, 156, 109, 44, 149, 107, 45, 150, 107, 45, 148, 106, 43, 149, 107, 44, 143, 101, 39, 140, 98, 43, 141, 97, 41, 143, 97, 38, 137, 95, 36, 126, 91, 36, 116, 85, 33, 152, 112, 51, 151, 110, 40, 159, 114, 45, 166, 116, 56, 162, 112, 49, 160, 113, 43, 164, 117, 47, 162, 114, 45, 163, 116, 46, 156, 110, 38, 155, 111, 41, 159, 110, 54, 163, 113, 52, 170, 119, 41, 171, 117, 40, 171, 115, 33, 169, 115, 30, 160, 111, 33, 154, 112, 41, 151, 115, 50, 145, 110, 53, 139, 104, 55, 140, 102, 52, 141, 100, 48, 149, 105, 50, 147, 102, 46, 145, 102, 45, 142, 97, 38, 143, 98, 34, 136, 95, 31, 125, 91, 32, 119, 88, 34, 151, 110, 47, 151, 109, 33, 158, 111, 36, 167, 111, 48, 160, 106, 42, 163, 115, 44, 165, 117, 45, 165, 117, 45, 163, 115, 43, 162, 115, 43, 158, 114, 48, 157, 109, 57, 161, 111, 51, 166, 115, 38, 167, 114, 37, 169, 113, 35, 170, 116, 39, 159, 114, 47, 145, 111, 54, 121, 96, 49, 110, 90, 52, 98, 78, 50, 101, 77, 47, 114, 85, 50, 120, 86, 48, 134, 96, 55, 143, 103, 51, 140, 99, 39, 142, 99, 35, 139, 98, 34, 130, 95, 34, 120, 89, 33, 155, 107, 40, 155, 110, 32, 160, 109, 31, 174, 112, 44, 167, 110, 43, 167, 117, 46, 169, 120, 48, 169, 119, 48, 165, 115, 44, 165, 117, 45, 167, 123, 57, 191, 146, 95, 177, 130, 75, 157, 111, 41, 162, 115, 47, 164, 114, 54, 158, 112, 58, 149, 111, 67, 104, 80, 47, 103, 87, 65, 98, 90, 76, 92, 90, 84, 80, 75, 66, 74, 63, 50, 86, 70, 52, 83, 62, 39, 113, 85, 45, 132, 98, 46, 140, 102, 43, 140, 101, 39, 136, 99, 39, 127, 94, 36, 155, 107, 41, 156, 114, 48, 161, 115, 49, 170, 114, 47, 169, 114, 43, 163, 113, 40, 169, 120, 47, 166, 116, 44, 164, 113, 41, 164, 116, 42, 173, 128, 59, 246, 214, 164, 195, 156, 107, 151, 114, 56, 146, 111, 60, 142, 108, 71, 111, 80, 50, 78, 53, 31, 85, 69, 56, 113, 103, 98, 112, 110, 111, 106, 114, 118, 97, 102, 105, 93, 94, 93, 74, 72, 67, 84, 78, 70, 85, 73, 47, 105, 83, 45, 128, 96, 48, 138, 101, 46, 133, 94, 36, 129, 93, 36, 148, 109, 54, 133, 104, 64, 130, 100, 57, 147, 112, 53, 161, 115, 44, 165, 113, 39, 167, 116, 41, 167, 115, 41, 163, 111, 37, 165, 116, 39, 163, 118, 42, 180, 138, 85, 157, 122, 78, 128, 102, 58, 97, 75, 43, 66, 50, 31, 69, 58, 43, 66, 56, 45, 89, 83, 76, 118, 113, 110, 122, 121, 120, 119, 122, 122, 114, 116, 116, 94, 96, 96, 99, 100, 97, 91, 91, 86, 58, 58, 47, 67, 58, 37, 108, 84, 49, 140, 105, 58, 138, 98, 44, 134, 95, 40, 127, 100, 57, 109, 95, 80, 47, 37, 17, 88, 74, 28, 153, 117, 48, 170, 118, 43, 168, 115, 40, 170, 118, 43, 169, 117, 42, 166, 116, 37, 164, 120, 39, 147, 107, 52, 129, 98, 59, 127, 108, 75, 100, 87, 70, 68, 67, 57, 78, 83, 72, 72, 75, 64, 83, 84, 74, 132, 130, 121, 146, 142, 132, 124, 118, 108, 105, 99, 90, 107, 102, 94, 115, 111, 103, 85, 83, 77, 63, 71, 69, 46, 47, 39, 79, 61, 36, 132, 98, 58, 141, 99, 48, 134, 93, 39, 131, 115, 90, 99, 96, 92, 42, 43, 38, 70, 64, 41, 143, 111, 56, 167, 117, 42, 165, 114, 36, 168, 116, 39, 171, 119, 49, 161, 113, 51, 140, 109, 51, 120, 94, 49, 130, 110, 77, 144, 131, 107, 116, 106, 93, 88, 87, 79, 91, 95, 88, 85, 88, 82, 77, 77, 69, 124, 118, 107, 163, 153, 140, 136, 124, 112, 102, 93, 81, 106, 98, 88, 100, 93, 84, 85, 81, 74, 54, 60, 58, 49, 53, 49, 57, 47, 32, 107, 83, 50, 138, 103, 51, 136, 97, 39, 170, 161, 144, 103, 105, 105, 54, 58, 59, 124, 121, 113, 153, 124, 82, 161, 113, 43, 163, 117, 41, 166, 122, 50, 165, 121, 66, 174, 135, 95, 113, 89, 59, 125, 105, 78, 157, 141, 121, 156, 143, 128, 121, 111, 101, 86, 80, 74, 82, 81, 77, 84, 85, 82, 80, 78, 73, 81, 71, 61, 138, 125, 112, 146, 135, 123, 113, 103, 93, 87, 79, 70, 83, 77, 69, 86, 82, 76, 71, 73, 67, 56, 57, 53, 40, 35, 27, 74, 59, 35, 133, 106, 59, 137, 103, 45, 180, 176, 163, 134, 139, 143, 94, 100, 105, 154, 154, 149, 174, 149, 112, 158, 116, 51, 156, 116, 47, 153, 118, 60, 207, 180, 146, 237, 214, 198, 207, 180, 166, 156, 131, 119, 174, 153, 145, 148, 131, 125, 125, 110, 107, 93, 85, 79, 86, 84, 79, 74, 74, 71, 59, 57, 53, 76, 68, 58, 137, 125, 112, 143, 133, 122, 133, 124, 114, 106, 98, 89, 86, 81, 74, 87, 85, 78, 84, 85, 78, 75, 76, 71, 50, 49, 43, 40, 30, 15, 95, 75, 44, 132, 103, 57, 183, 183, 175, 108, 116, 122, 142, 151, 158, 165, 169, 168, 177, 156, 122, 155, 112, 50, 159, 118, 51, 122, 89, 47, 213, 197, 179, 237, 224, 226, 220, 191, 188, 164, 135, 131, 183, 159, 155, 156, 137, 132, 125, 108, 104, 120, 111, 104, 78, 76, 69, 80, 80, 77, 45, 44, 40, 91, 85, 77, 175, 165, 154, 157, 147, 137, 155, 147, 138, 107, 100, 92, 87, 83, 77, 103, 102, 96, 88, 88, 79, 78, 79, 73, 59, 59, 59, 41, 36, 33, 59, 46, 31, 104, 81, 46, 188, 191, 189, 100, 108, 116, 135, 144, 153, 170, 175, 178, 187, 167, 136, 166, 120, 59, 173, 123, 55, 134, 93, 44, 117, 95, 80, 194, 182, 188, 199, 171, 164, 170, 142, 133, 185, 161, 151, 189, 171, 159, 134, 119, 106, 117, 107, 95, 102, 98, 89, 84, 84, 79, 38, 38, 34, 125, 121, 113, 210, 201, 192, 160, 152, 142, 146, 139, 130, 93, 89, 82, 83, 80, 75, 94, 93, 88, 104, 104, 94, 85, 87, 81, 73, 75, 78, 55, 53, 55, 62, 55, 48, 76, 56, 26, 189, 194, 194, 90, 96, 105, 127, 134, 144, 175, 180, 185, 174, 156, 133, 166, 123, 68, 178, 123, 53, 159, 109, 47, 97, 68, 44, 168, 154, 152, 168, 144, 126, 137, 114, 94, 186, 166, 148, 216, 202, 183, 160, 149, 129, 123, 113, 98, 120, 114, 105, 115, 114, 109, 50, 50, 47, 150, 147, 140, 194, 187, 178, 155, 149, 140, 123, 118, 111, 91, 88, 83, 84, 83, 79, 84, 84, 80, 95, 95, 85, 86, 87, 81, 84, 87, 89, 73, 73, 73, 79, 74, 64, 73, 55, 24, 189, 192, 193, 93, 95, 103, 152, 154, 163, 185, 188, 192, 119, 110, 98, 136, 106, 66, 173, 124, 58, 167, 116, 50, 103, 72, 39, 147, 132, 120, 145, 125, 103, 167, 149, 127, 189, 174, 155, 226, 216, 200, 180, 172, 157, 141, 131, 117, 126, 117, 107, 117, 114, 109, 71, 71, 68, 154, 152, 147, 186, 181, 174, 149, 144, 136, 114, 110, 104, 87, 85, 80, 80, 80, 76, 72, 73, 70, 80, 80, 72, 99, 100, 94, 100, 101, 99, 90, 88, 81, 97, 89, 69, 94, 73, 34, 194, 196, 196, 108, 107, 112, 168, 167, 172, 186, 186, 188, 105, 109, 109, 99, 89, 67, 156, 119, 62, 167, 122, 55, 100, 74, 34, 115, 106, 88, 138, 123, 103, 198, 185, 169, 190, 180, 169, 172, 165, 159, 145, 140, 140, 154, 143, 134, 146, 136, 125, 103, 100, 95, 71, 71, 70, 152, 152, 149, 179, 175, 170, 137, 133, 127, 130, 128, 122, 110, 109, 105, 85, 86, 83, 91, 93, 91, 95, 96, 90, 109, 110, 104, 115, 116, 111, 100, 96, 80, 97, 85, 53, 117, 95, 47, 197, 197, 197, 132, 129, 136, 172, 167, 174, 184, 178, 181, 130, 137, 142, 78, 83, 77, 140, 120, 88, 155, 125, 77, 115, 94, 52, 130, 120, 93, 143, 131, 116, 230, 221, 211, 242, 236, 230, 145, 138, 137, 135, 130, 130, 131, 121, 112, 121, 112, 101, 108, 104, 95, 95, 88, 75, 144, 134, 118, 168, 159, 146, 152, 147, 138, 112, 108, 101, 87, 85, 80, 71, 72, 68, 87, 88, 87, 105, 104, 99, 112, 109, 99, 120, 110, 93, 103, 86, 54, 121, 96, 48, 136, 104, 48, 203, 203, 204, 146, 146, 160, 168, 164, 178, 191, 182, 188, 168, 170, 172, 78, 86, 90, 126, 125, 126, 138, 126, 113, 138, 121, 82, 96, 80, 37, 154, 143, 133, 173, 163, 155, 162, 152, 141, 140, 132, 117, 113, 106, 88, 113, 106, 90, 101, 101, 92, 105, 101, 87, 112, 90, 58, 171, 143, 104, 156, 138, 109, 148, 141, 126, 135, 130, 118, 109, 105, 97, 78, 76, 72, 79, 79, 77, 94, 93, 94, 101, 91, 82, 107, 83, 55, 125, 88, 45, 151, 108, 55, 144, 104, 46, 214, 215, 215, 163, 166, 180, 164, 167, 184, 183, 184, 194, 176, 182, 186, 94, 102, 105, 96, 96, 102, 156, 149, 145, 148, 137, 111, 106, 93, 61, 129, 116, 105, 118, 105, 95, 114, 102, 89, 116, 105, 89, 102, 91, 73, 115, 110, 98, 86, 91, 88, 101, 103, 95, 144, 128, 102, 118, 96, 64, 68, 56, 32, 128, 120, 105, 133, 126, 115, 75, 69, 61, 60, 56, 51, 58, 56, 53, 71, 70, 65, 102, 93, 78, 116, 94, 64, 143, 112, 68, 150, 116, 64, 140, 110, 54, 212, 211, 205, 178, 184, 192, 167, 175, 189, 173, 181, 193, 176, 184, 188, 124, 131, 133, 86, 88, 96, 141, 139, 143, 153, 148, 141, 135, 128, 111, 104, 90, 80, 77, 64, 55, 134, 121, 108, 124, 111, 96, 129, 117, 100, 147, 143, 133, 85, 92, 93, 92, 96, 93, 150, 139, 120, 132, 117, 93, 117, 109, 92, 107, 99, 86, 75, 68, 58, 64, 59, 52, 44, 41, 39, 65, 62, 60, 86, 69, 40, 133, 105, 59, 155, 119, 62, 160, 120, 54, 154, 115, 45, 151, 111, 46, 199, 192, 180, 187, 189, 187, 171, 176, 181, 174, 179, 185, 177, 182, 184, 144, 149, 152, 86, 90, 99, 119, 121, 132, 122, 124, 130, 137, 136, 135, 144, 134, 126, 70, 59, 51, 129, 118, 108, 108, 97, 86, 145, 134, 123, 184, 176, 168, 116, 118, 118, 73, 75, 73, 131, 119, 103, 137, 124, 105, 134, 129, 118, 89, 86, 78, 51, 49, 44, 52, 51, 50, 47, 49, 52, 90, 90, 93, 121, 91, 60, 163, 118, 68, 171, 121, 64, 164, 113, 52, 158, 111, 50, 149, 107, 46, 165, 156, 146, 195, 193, 187, 179, 178, 175, 177, 173, 172, 181, 181, 180, 152, 157, 160, 99, 103, 111, 131, 135, 146, 171, 175, 185, 103, 105, 111, 93, 90, 87, 80, 77, 73, 93, 90, 86, 122, 118, 116, 178, 173, 173, 191, 182, 177, 150, 148, 148, 100, 100, 101, 89, 78, 66, 87, 77, 63, 60, 61, 57, 46, 52, 54, 38, 46, 51, 24, 33, 41, 46, 57, 69, 60, 71, 83, 108, 100, 75, 144, 125, 82, 144, 123, 76, 128, 109, 61, 127, 113, 69, 120, 105, 63, 117, 120, 124, 195, 200, 200, 177, 178, 176, 178, 169, 168, 181, 179, 179, 138, 144, 147, 83, 87, 91, 150, 153, 159, 245, 247, 250, 219, 222, 225, 133, 140, 144, 134, 141, 147, 149, 156, 164, 176, 182, 192, 190, 196, 208, 194, 192, 197, 168, 172, 181, 125, 133, 143, 110, 109, 109, 61, 62, 62, 35, 49, 58, 34, 54, 68, 49, 70, 87, 58, 81, 102, 61, 85, 110, 58, 84, 111, 69, 99, 122, 72, 101, 119, 78, 104, 120, 69, 96, 112, 59, 92, 112, 55, 90, 115, 79, 105, 133, 175, 197, 213, 174, 183, 192, 176, 172, 177, 177, 177, 182, 140, 146, 150, 109, 112, 113, 211, 211, 209, 253, 252, 247, 252, 253, 252, 208, 224, 232, 124, 143, 157, 114, 132, 149, 124, 141, 162, 116, 133, 156, 122, 133, 152, 104, 124, 148, 68, 93, 119, 68, 87, 104, 60, 82, 101, 52, 84, 111, 50, 84, 110, 51, 85, 115, 56, 93, 125, 56, 94, 131, 51, 91, 130, 43, 96, 135, 51, 104, 141, 59, 108, 142, 48, 97, 132, 43, 97, 137, 42, 95, 132, 41, 89, 135, 96, 137, 168, 144, 168, 188, 168, 174, 188, 178, 182, 192, 165, 170, 174, 165, 166, 164, 246, 245, 237, 253, 251, 241, 227, 231, 228, 110, 136, 153, 60, 88, 111, 53, 80, 105, 49, 76, 105, 49, 75, 107, 48, 72, 101, 45, 79, 115, 42, 81, 120, 46, 81, 113, 42, 82, 116, 38, 86, 125, 46, 90, 125, 46, 89, 126, 43, 87, 128, 42, 89, 132, 46, 93, 139, 46, 94, 137, 50, 96, 137, 55, 96, 135, 53, 94, 134, 51, 95, 139, 45, 90, 133, 29, 91, 141, 29, 87, 130, 59, 102, 134, 131, 153, 176, 166, 179, 191, 132, 136, 137, 194, 189, 181, 254, 250, 242, 241, 245, 245, 141, 159, 175, 61, 94, 127, 50, 84, 118, 50, 84, 119, 51, 85, 121, 49, 83, 120, 50, 84, 116, 47, 86, 117, 42, 84, 117, 39, 82, 115, 34, 79, 113, 35, 83, 120, 39, 86, 125, 38, 85, 125, 42, 89, 130, 45, 92, 134, 56, 103, 145, 62, 103, 142, 59, 101, 142, 56, 102, 146, 50, 99, 144, 46, 94, 140, 51, 103, 149, 48, 111, 162, 30, 94, 140, 34, 85, 124, 73, 106, 136, 128, 148, 167, 128, 136, 143, 215, 213, 209, 255, 253, 249, 187, 198, 205, 66, 93, 118, 54, 91, 128, 50, 88, 125, 52, 90, 127, 52, 90, 127, 46, 83, 121, 45, 82, 115, 43, 82, 113, 41, 81, 112, 36, 80, 113, 39, 83, 117, 40, 86, 123, 40, 89, 131, 43, 92, 134, 46, 95, 138, 59, 108, 150, 62, 110, 152, 64, 109, 147, 59, 108, 149, 54, 108, 154, 50, 105, 152, 70, 123, 167, 83, 137, 182, 52, 114, 165, 35, 99, 147, 31, 86, 130, 41, 83, 122, 66, 95, 126, 128, 145, 164, 224, 229, 234, 240, 245, 247, 124, 143, 153, 58, 92, 114, 49, 87, 123, 56, 94, 131, 54, 92, 129, 44, 82, 119, 44, 82, 119, 47, 83, 119, 46, 84, 119, 43, 83, 119, 43, 86, 123, 44, 88, 127, 44, 90, 131, 45, 97, 141, 54, 106, 150, 58, 110, 154, 54, 105, 150, 46, 97, 141, 43, 95, 140, 36, 91, 138, 51, 108, 158, 73, 130, 178, 85, 138, 182, 76, 125, 169, 50, 110, 162, 35, 98, 149, 29, 89, 138, 35, 86, 133, 44, 83, 126, 78, 106, 138, 202, 219, 233, 211, 228, 234, 97, 126, 140, 65, 104, 126, 54, 94, 129, 48, 87, 124, 58, 97, 133, 48, 87, 123, 40, 80, 116, 45, 82, 119, 47, 84, 122, 48, 87, 126, 47, 89, 130, 46, 89, 132, 51, 97, 140, 39, 92, 138, 39, 93, 139, 48, 102, 148, 47, 101, 147, 39, 93, 139, 28, 85, 133, 40, 101, 153, 67, 129, 182, 67, 126, 176, 46, 98, 142, 51, 96, 139, 50, 108, 161, 35, 97, 147, 32, 92, 143, 33, 88, 141, 41, 88, 138, 46, 84, 125, 104, 133, 159, 170, 197, 211, 64, 100, 119, 54, 97, 121, 52, 94, 128, 53, 95, 130, 61, 103, 139, 58, 100, 135, 54, 96, 131, 45, 83, 120, 42, 79, 118, 41, 80, 120, 46, 88, 130, 49, 92, 135, 46, 92, 136, 42, 95, 139, 40, 93, 138, 39, 92, 136, 37, 90, 135, 40, 93, 138, 44, 102, 151, 63, 125, 178, 47, 110, 164, 31, 90, 140, 15, 60, 103, 51, 93, 136, 68, 124, 177, 42, 100, 148, 31, 88, 137, 38, 91, 146, 37, 87, 139, 43, 89, 132, 42, 79, 113, 71, 107, 133, 49, 89, 114, 31, 77, 105, 27, 71, 105, 38, 82, 117, 49, 93, 128, 56, 100, 135, 58, 102, 137, 53, 92, 128, 56, 94, 131, 60, 99, 137, 57, 99, 139, 53, 97, 138, 50, 95, 137, 45, 94, 136, 39, 88, 131, 33, 83, 125, 42, 91, 133, 62, 112, 154, 79, 132, 179, 73, 131, 181, 56, 116, 168, 38, 97, 146, 13, 64, 108, 40, 85, 127, 61, 116, 168, 49, 102, 148, 35, 85, 132, 43, 91, 143, 39, 90, 139, 42, 92, 134, 44, 88, 125, 40, 81, 112, 42, 85, 115, 27, 72, 104, 23, 67, 102, 30, 74, 109, 27, 71, 106, 29, 73, 108, 36, 80, 115, 47, 86, 120, 56, 95, 128, 62, 101, 135, 66, 109, 144, 75, 119, 156, 69, 113, 152, 49, 95, 134, 43, 88, 127, 43, 88, 127, 60, 105, 144, 85, 130, 170, 109, 156, 197, 93, 145, 190, 60, 115, 164, 26, 82, 130, 29, 82, 126, 20, 64, 107, 54, 107, 160, 56, 105, 149, 45, 89, 132, 43, 86, 134, 40, 89, 134, 40, 92, 132, 40, 87, 123, 38, 81, 115, 36, 79, 114, 26, 69, 105, 22, 66, 101, 29, 73, 108, 25, 69, 104, 29, 73, 108, 19, 63, 98, 18, 58, 89, 32, 70, 100, 47, 87, 118, 61, 104, 137, 74, 119, 152, 66, 111, 145, 53, 96, 131, 52, 95, 130, 45, 87, 123, 67, 109, 145, 89, 131, 167, 105, 146, 182, 89, 135, 175, 48, 99, 145, 24, 77, 124, 34, 84, 129, 21, 67, 110], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284462138448}, {\"format\": \"raw\", \"value\": [160, 37, 13, 185, 49, 11, 209, 57, 14, 217, 58, 10, 230, 66, 9, 246, 78, 10, 249, 80, 5, 246, 81, 2, 248, 86, 3, 243, 82, 3, 230, 73, 1, 221, 66, 2, 218, 65, 4, 221, 67, 6, 216, 67, 5, 199, 56, 0, 188, 50, 1, 187, 50, 0, 184, 64, 35, 180, 115, 86, 166, 52, 22, 144, 56, 23, 121, 50, 29, 139, 39, 8, 106, 22, 13, 102, 34, 27, 102, 46, 39, 79, 36, 29, 94, 29, 19, 101, 18, 8, 91, 21, 6, 94, 19, 5, 225, 67, 13, 239, 72, 12, 242, 77, 10, 230, 68, 4, 232, 67, 7, 245, 74, 8, 243, 72, 3, 235, 66, 0, 237, 68, 4, 230, 64, 2, 216, 57, 1, 205, 52, 1, 201, 50, 2, 203, 54, 4, 200, 55, 4, 186, 46, 1, 175, 41, 1, 171, 42, 1, 161, 39, 16, 127, 41, 19, 142, 40, 7, 141, 35, 6, 122, 30, 6, 135, 33, 7, 118, 34, 33, 82, 46, 46, 37, 30, 23, 52, 27, 22, 95, 28, 19, 107, 21, 8, 97, 22, 4, 100, 18, 6, 252, 72, 7, 249, 68, 4, 241, 72, 3, 220, 62, 0, 217, 58, 4, 226, 61, 4, 223, 56, 1, 214, 49, 0, 213, 48, 4, 207, 45, 4, 195, 43, 4, 184, 40, 4, 179, 38, 4, 182, 42, 6, 179, 43, 5, 167, 38, 3, 159, 34, 4, 152, 35, 3, 148, 30, 12, 129, 28, 9, 128, 35, 4, 140, 33, 7, 128, 31, 6, 114, 34, 10, 87, 48, 40, 40, 34, 35, 4, 13, 13, 38, 14, 12, 99, 21, 15, 115, 20, 6, 105, 19, 3, 105, 17, 6, 233, 56, 1, 225, 54, 3, 222, 61, 8, 211, 60, 11, 211, 62, 18, 203, 48, 4, 200, 43, 3, 192, 36, 3, 187, 35, 5, 183, 35, 6, 174, 34, 8, 164, 32, 7, 160, 31, 8, 165, 33, 9, 160, 34, 6, 153, 32, 6, 145, 29, 7, 141, 30, 5, 140, 27, 10, 138, 29, 9, 125, 32, 4, 125, 28, 10, 127, 29, 16, 105, 37, 23, 59, 42, 30, 37, 18, 22, 26, 11, 17, 55, 15, 14, 112, 22, 15, 120, 19, 6, 112, 16, 5, 109, 17, 8, 207, 57, 12, 195, 57, 19, 207, 66, 29, 201, 59, 26, 190, 52, 23, 180, 36, 6, 179, 32, 7, 171, 27, 8, 163, 28, 7, 159, 29, 8, 153, 28, 9, 146, 26, 8, 145, 26, 9, 151, 26, 10, 147, 28, 7, 141, 30, 8, 135, 28, 9, 136, 28, 7, 131, 28, 8, 135, 28, 7, 129, 28, 8, 122, 48, 37, 132, 67, 64, 90, 42, 39, 58, 25, 16, 61, 18, 16, 48, 13, 14, 86, 25, 21, 117, 27, 14, 120, 31, 15, 114, 19, 13, 109, 17, 9, 182, 59, 24, 171, 58, 30, 170, 47, 22, 162, 33, 12, 153, 26, 9, 156, 26, 6, 159, 25, 9, 151, 22, 8, 144, 23, 5, 141, 25, 5, 140, 26, 9, 138, 25, 10, 139, 24, 11, 141, 24, 10, 138, 27, 7, 138, 31, 9, 135, 29, 10, 140, 30, 11, 134, 33, 11, 138, 30, 7, 140, 33, 20, 137, 93, 85, 102, 94, 93, 69, 60, 59, 75, 41, 34, 62, 27, 14, 67, 30, 19, 116, 44, 32, 129, 43, 23, 128, 45, 27, 112, 24, 16, 110, 19, 9, 141, 34, 12, 136, 28, 11, 136, 23, 10, 134, 20, 7, 136, 22, 8, 134, 23, 8, 140, 22, 10, 133, 21, 7, 135, 22, 6, 137, 22, 5, 139, 25, 10, 141, 26, 14, 143, 24, 13, 146, 25, 12, 142, 29, 10, 145, 35, 12, 145, 32, 9, 145, 31, 14, 138, 35, 14, 143, 30, 7, 142, 51, 37, 107, 89, 86, 47, 55, 60, 33, 37, 40, 72, 56, 53, 75, 40, 28, 108, 43, 28, 127, 45, 28, 132, 36, 20, 132, 30, 16, 111, 23, 6, 112, 21, 7, 118, 17, 3, 125, 17, 6, 128, 16, 6, 129, 18, 7, 136, 22, 11, 131, 23, 10, 138, 22, 12, 132, 22, 9, 136, 24, 9, 140, 23, 8, 144, 26, 12, 147, 27, 14, 150, 25, 14, 158, 27, 18, 154, 29, 16, 153, 39, 19, 146, 40, 16, 149, 45, 21, 147, 51, 26, 148, 48, 22, 128, 65, 49, 66, 64, 62, 13, 18, 20, 17, 11, 10, 80, 34, 30, 117, 37, 26, 128, 31, 16, 122, 32, 13, 123, 25, 9, 128, 22, 8, 114, 22, 4, 112, 21, 7, 115, 17, 7, 126, 18, 10, 132, 18, 9, 133, 18, 8, 139, 21, 11, 135, 22, 10, 143, 23, 14, 137, 23, 11, 139, 25, 13, 145, 24, 12, 149, 28, 14, 152, 30, 15, 148, 37, 19, 154, 56, 36, 163, 51, 34, 170, 59, 40, 158, 59, 36, 162, 58, 32, 157, 55, 34, 148, 54, 34, 115, 61, 51, 44, 40, 43, 14, 17, 15, 30, 16, 9, 105, 26, 20, 139, 25, 12, 136, 24, 9, 126, 27, 10, 119, 26, 8, 122, 23, 8, 116, 21, 8, 111, 20, 8, 118, 19, 12, 128, 18, 12, 136, 18, 11, 136, 18, 8, 141, 21, 12, 136, 20, 10, 145, 22, 14, 141, 24, 13, 141, 24, 14, 147, 25, 14, 154, 32, 20, 165, 49, 34, 157, 62, 39, 154, 76, 49, 162, 57, 40, 167, 52, 38, 155, 49, 32, 147, 46, 27, 145, 50, 39, 138, 58, 50, 99, 56, 54, 56, 49, 59, 46, 48, 52, 55, 44, 38, 109, 41, 35, 124, 35, 21, 122, 25, 11, 126, 25, 12, 115, 25, 6, 116, 24, 9, 117, 20, 11, 110, 20, 10, 125, 20, 12, 132, 18, 11, 139, 19, 11, 137, 18, 9, 142, 21, 12, 136, 21, 10, 144, 21, 13, 140, 23, 13, 139, 25, 13, 144, 25, 16, 150, 36, 27, 153, 53, 40, 131, 49, 32, 139, 66, 50, 144, 62, 50, 152, 74, 63, 166, 104, 88, 186, 137, 119, 211, 166, 161, 214, 184, 180, 128, 124, 121, 92, 104, 113, 69, 75, 84, 42, 33, 34, 85, 56, 50, 95, 61, 49, 99, 38, 29, 115, 25, 17, 112, 24, 9, 111, 25, 10, 113, 18, 12, 107, 19, 10, 133, 21, 9, 137, 18, 10, 142, 20, 14, 138, 19, 11, 141, 24, 14, 136, 24, 12, 142, 22, 13, 138, 24, 12, 137, 25, 12, 143, 29, 18, 136, 31, 24, 132, 48, 39, 142, 85, 77, 182, 151, 147, 201, 178, 175, 203, 190, 186, 210, 205, 200, 206, 205, 200, 207, 202, 210, 192, 197, 202, 162, 178, 177, 189, 208, 213, 146, 152, 158, 42, 22, 28, 27, 24, 19, 40, 37, 34, 103, 70, 70, 114, 40, 37, 109, 21, 10, 106, 22, 9, 108, 17, 11, 104, 17, 9, 140, 20, 8, 139, 20, 10, 143, 22, 15, 139, 21, 13, 143, 24, 16, 140, 24, 14, 138, 25, 13, 137, 26, 14, 135, 25, 12, 133, 32, 24, 144, 66, 62, 164, 112, 108, 171, 144, 142, 160, 155, 162, 137, 140, 147, 115, 117, 125, 106, 100, 110, 93, 88, 94, 75, 71, 84, 59, 61, 74, 111, 117, 126, 220, 232, 241, 201, 213, 215, 95, 78, 84, 13, 15, 12, 7, 10, 9, 62, 50, 52, 116, 70, 73, 99, 26, 25, 101, 21, 13, 105, 17, 9, 100, 16, 8, 144, 20, 11, 138, 22, 11, 143, 25, 15, 140, 22, 14, 146, 23, 17, 146, 23, 16, 130, 25, 12, 135, 26, 14, 130, 26, 20, 145, 72, 68, 140, 103, 103, 110, 91, 93, 94, 80, 86, 92, 86, 95, 49, 52, 61, 19, 18, 25, 29, 17, 22, 50, 34, 35, 25, 15, 17, 18, 16, 23, 120, 124, 137, 209, 221, 235, 210, 224, 235, 157, 155, 167, 38, 36, 42, 6, 7, 7, 19, 22, 23, 68, 59, 66, 69, 33, 40, 82, 19, 17, 99, 18, 9, 95, 16, 7, 145, 24, 15, 139, 23, 13, 146, 27, 18, 142, 22, 14, 144, 24, 16, 142, 25, 18, 121, 19, 11, 128, 21, 18, 133, 55, 54, 127, 85, 83, 84, 58, 59, 68, 41, 46, 86, 61, 68, 82, 78, 83, 46, 50, 55, 22, 24, 27, 19, 11, 12, 50, 43, 39, 30, 30, 28, 65, 73, 76, 175, 191, 200, 201, 216, 232, 205, 209, 231, 203, 205, 224, 102, 103, 115, 16, 14, 22, 18, 16, 19, 22, 23, 26, 35, 27, 31, 56, 22, 22, 79, 20, 13, 88, 18, 8, 143, 26, 16, 139, 22, 13, 148, 26, 19, 144, 23, 14, 138, 25, 14, 132, 37, 30, 139, 60, 57, 131, 52, 55, 117, 76, 79, 66, 52, 53, 72, 56, 57, 86, 59, 60, 106, 80, 82, 78, 77, 78, 40, 46, 50, 34, 38, 41, 36, 35, 35, 70, 73, 71, 115, 124, 124, 182, 196, 200, 203, 223, 231, 197, 216, 230, 205, 217, 236, 195, 210, 221, 108, 118, 126, 61, 57, 68, 37, 21, 26, 18, 14, 14, 24, 31, 32, 79, 71, 73, 100, 62, 63, 83, 17, 9, 142, 25, 17, 139, 20, 14, 147, 25, 19, 144, 23, 17, 133, 33, 24, 114, 53, 47, 132, 96, 93, 121, 92, 92, 81, 73, 79, 89, 93, 98, 60, 62, 60, 69, 66, 61, 85, 81, 76, 68, 71, 71, 83, 90, 94, 155, 162, 166, 192, 196, 198, 219, 223, 226, 237, 245, 250, 235, 245, 252, 215, 227, 237, 215, 228, 240, 211, 222, 231, 114, 121, 124, 48, 37, 42, 93, 59, 74, 53, 17, 28, 20, 9, 12, 65, 72, 76, 139, 140, 149, 143, 117, 126, 84, 19, 17, 143, 25, 18, 141, 21, 16, 142, 24, 18, 137, 26, 21, 116, 40, 36, 69, 44, 42, 58, 53, 56, 67, 69, 72, 81, 88, 96, 75, 82, 88, 29, 37, 36, 28, 41, 36, 36, 49, 45, 25, 32, 34, 140, 148, 154, 242, 251, 255, 236, 246, 250, 235, 242, 249, 227, 233, 244, 220, 226, 237, 219, 225, 237, 223, 226, 238, 149, 139, 150, 58, 31, 39, 57, 11, 21, 84, 25, 46, 78, 40, 59, 78, 67, 77, 133, 133, 142, 161, 162, 174, 167, 151, 163, 91, 34, 38, 143, 22, 17, 140, 19, 16, 136, 22, 16, 134, 38, 34, 141, 93, 92, 71, 70, 73, 45, 46, 60, 52, 54, 66, 67, 75, 84, 33, 38, 44, 23, 24, 28, 22, 27, 33, 47, 56, 62, 41, 49, 55, 155, 163, 174, 217, 227, 240, 199, 214, 225, 190, 205, 217, 191, 203, 217, 208, 218, 231, 220, 229, 239, 223, 228, 238, 173, 163, 177, 103, 74, 86, 93, 57, 69, 115, 90, 106, 135, 128, 146, 149, 149, 164, 152, 151, 164, 148, 150, 161, 165, 160, 169, 89, 51, 55, 143, 19, 13, 140, 15, 10, 126, 38, 32, 181, 124, 125, 189, 175, 180, 76, 90, 98, 33, 36, 53, 43, 42, 56, 57, 63, 72, 21, 23, 28, 16, 11, 14, 23, 21, 27, 57, 64, 73, 66, 79, 89, 158, 170, 185, 194, 208, 224, 182, 199, 213, 179, 197, 213, 196, 211, 228, 201, 214, 227, 194, 206, 215, 206, 217, 225, 222, 227, 242, 179, 177, 192, 151, 152, 165, 156, 168, 180, 149, 167, 181, 151, 162, 176, 150, 154, 166, 146, 151, 159, 136, 136, 141, 66, 42, 42, 140, 18, 12, 133, 10, 7, 154, 101, 101, 234, 220, 229, 181, 190, 201, 90, 111, 123, 38, 47, 62, 42, 46, 57, 52, 57, 65, 11, 10, 15, 11, 9, 9, 11, 14, 15, 20, 31, 38, 49, 66, 79, 160, 177, 191, 186, 204, 218, 176, 194, 208, 185, 202, 219, 185, 198, 216, 115, 124, 138, 69, 79, 88, 90, 102, 109, 161, 172, 184, 196, 211, 228, 183, 200, 218, 170, 184, 201, 160, 177, 191, 153, 169, 181, 147, 156, 166, 136, 140, 147, 77, 74, 77, 38, 17, 14, 130, 14, 13, 128, 20, 24, 163, 132, 139, 163, 165, 179, 139, 150, 162, 106, 128, 141, 45, 55, 69, 46, 52, 61, 28, 30, 35, 3, 3, 4, 9, 10, 11, 15, 22, 27, 30, 45, 54, 54, 72, 86, 162, 180, 194, 180, 198, 212, 172, 190, 204, 190, 205, 219, 113, 123, 136, 21, 25, 36, 20, 26, 32, 21, 30, 34, 48, 56, 64, 149, 163, 177, 187, 202, 221, 171, 184, 204, 142, 158, 173, 133, 147, 159, 128, 136, 144, 67, 68, 73, 21, 13, 15, 39, 17, 13, 124, 10, 9, 132, 35, 39, 103, 83, 91, 26, 33, 49, 72, 83, 96, 108, 130, 143, 52, 62, 76, 48, 53, 62, 18, 19, 21, 7, 7, 7, 11, 16, 21, 59, 72, 81, 90, 108, 121, 99, 117, 131, 165, 183, 197, 176, 194, 208, 177, 195, 209, 169, 183, 193, 42, 47, 56, 29, 30, 38, 47, 49, 55, 38, 43, 46, 14, 20, 25, 70, 79, 89, 149, 161, 178, 136, 148, 169, 117, 132, 149, 117, 129, 141, 60, 64, 72, 14, 10, 14, 21, 9, 8, 48, 24, 20, 121, 10, 5, 124, 33, 34, 73, 55, 59, 30, 35, 48, 59, 70, 83, 114, 136, 149, 68, 78, 92, 31, 36, 45, 13, 15, 15, 14, 17, 19, 24, 34, 42, 72, 88, 100, 79, 97, 111, 108, 126, 140, 187, 205, 219, 187, 205, 219, 191, 208, 222, 139, 152, 160, 27, 32, 38, 43, 43, 51, 30, 32, 37, 27, 31, 35, 28, 32, 36, 27, 31, 39, 108, 117, 130, 132, 145, 164, 123, 138, 155, 89, 99, 110, 22, 23, 29, 21, 12, 12, 42, 25, 22, 59, 33, 30, 109, 10, 7, 102, 21, 23, 71, 54, 58, 63, 65, 77, 60, 71, 84, 113, 136, 148, 77, 87, 101, 28, 33, 42, 16, 21, 22, 31, 39, 43, 48, 63, 74, 71, 87, 101, 70, 86, 100, 136, 154, 168, 189, 207, 221, 179, 197, 211, 180, 198, 212, 116, 129, 137, 31, 37, 43, 54, 56, 64, 53, 55, 63, 41, 44, 52, 27, 28, 35, 14, 15, 21, 72, 77, 86, 133, 147, 162, 124, 139, 154, 60, 67, 78, 18, 14, 19, 34, 20, 18, 50, 28, 24, 59, 31, 28, 87, 7, 9, 81, 14, 21, 61, 47, 55, 60, 62, 76, 58, 69, 82, 105, 128, 140, 75, 86, 101, 21, 28, 37, 20, 30, 33, 46, 60, 67, 76, 94, 108, 96, 111, 127, 97, 111, 126, 145, 162, 176, 164, 182, 195, 163, 180, 194, 170, 188, 201, 113, 127, 135, 32, 41, 48, 57, 60, 70, 71, 75, 86, 49, 53, 65, 37, 35, 46, 17, 15, 21, 41, 44, 50, 108, 122, 131, 96, 111, 123, 33, 38, 49, 12, 7, 11, 29, 13, 10, 40, 16, 11, 50, 22, 20, 73, 11, 11, 73, 17, 23, 64, 39, 49, 60, 59, 73, 57, 70, 87, 95, 117, 132, 87, 104, 120, 47, 61, 75, 61, 81, 93, 98, 121, 134, 137, 159, 177, 165, 183, 200, 169, 185, 200, 176, 195, 207, 183, 201, 212, 182, 199, 213, 182, 198, 214, 124, 136, 148, 34, 42, 53, 54, 60, 72, 96, 102, 113, 92, 98, 110, 51, 52, 64, 27, 28, 34, 17, 21, 24, 70, 79, 85, 59, 69, 76, 12, 16, 22, 6, 3, 7, 18, 7, 9, 29, 12, 13, 40, 22, 22, 73, 19, 15, 73, 20, 22, 69, 29, 37, 78, 67, 78, 65, 73, 87, 89, 103, 115, 69, 85, 96, 47, 60, 72, 52, 69, 82, 60, 80, 93, 74, 91, 105, 86, 100, 114, 91, 104, 119, 96, 113, 125, 98, 113, 126, 96, 109, 123, 98, 109, 124, 83, 89, 102, 32, 37, 48, 60, 65, 76, 59, 64, 75, 62, 66, 78, 29, 31, 41, 20, 23, 27, 4, 8, 9, 17, 20, 24, 10, 14, 16, 3, 5, 6, 7, 6, 8, 10, 6, 10, 17, 11, 15, 33, 24, 25, 75, 23, 21, 83, 28, 31, 72, 29, 35, 54, 37, 43, 45, 44, 50, 39, 44, 48, 15, 22, 25, 4, 7, 12, 3, 10, 14, 2, 10, 14, 5, 12, 17, 7, 12, 17, 7, 13, 20, 8, 16, 24, 10, 17, 26, 11, 16, 25, 11, 15, 24, 13, 15, 20, 8, 9, 13, 66, 67, 74, 67, 68, 78, 47, 48, 59, 56, 56, 65, 15, 16, 18, 2, 4, 3, 2, 3, 5, 1, 3, 4, 3, 4, 3, 6, 6, 5, 10, 9, 9, 15, 14, 13, 32, 25, 26, 80, 33, 33, 89, 37, 40, 81, 39, 44, 47, 32, 37, 21, 23, 30, 10, 18, 23, 16, 25, 30, 25, 32, 37, 14, 23, 28, 10, 21, 25, 14, 23, 28, 14, 23, 28, 14, 23, 27, 14, 21, 24, 14, 19, 23, 12, 15, 19, 10, 11, 15, 9, 10, 9, 6, 7, 6, 23, 24, 28, 62, 62, 71, 72, 71, 83, 42, 41, 47, 7, 8, 8, 3, 4, 2, 4, 5, 5, 5, 5, 5, 5, 6, 4, 7, 9, 6, 11, 14, 11, 21, 24, 21, 33, 29, 28, 73, 35, 37, 79, 37, 41, 73, 41, 48, 55, 50, 59, 46, 60, 73, 47, 67, 79, 59, 81, 92, 58, 77, 89, 26, 44, 56, 17, 36, 47, 25, 45, 56, 28, 48, 59, 31, 49, 57, 32, 44, 48, 29, 39, 43, 28, 35, 40, 24, 29, 35, 21, 27, 27, 16, 21, 21, 12, 16, 21, 20, 23, 33, 22, 25, 37, 8, 10, 16, 6, 9, 8, 8, 11, 8, 7, 9, 9, 8, 10, 10, 8, 11, 10, 11, 14, 13, 15, 20, 18, 27, 31, 29, 31, 30, 28, 69, 42, 44, 72, 42, 49, 76, 59, 70, 78, 87, 101, 88, 109, 128, 83, 111, 128, 72, 102, 118, 56, 82, 99, 32, 55, 71, 38, 62, 78, 43, 69, 84, 42, 71, 85, 47, 74, 87, 51, 72, 83, 50, 70, 81, 49, 67, 79, 44, 59, 71, 38, 51, 60, 30, 43, 49, 28, 41, 49, 34, 47, 58, 34, 44, 56, 19, 24, 32, 12, 18, 19, 14, 20, 19, 16, 22, 24, 15, 21, 24, 13, 19, 21, 18, 22, 25, 26, 28, 31, 30, 32, 34, 29, 30, 28], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452292368}, {\"format\": \"raw\", \"value\": [23, 19, 23, 19, 21, 28, 21, 16, 19, 65, 47, 40, 164, 131, 113, 188, 147, 115, 183, 147, 109, 178, 142, 116, 170, 135, 113, 172, 137, 103, 186, 144, 106, 186, 142, 105, 184, 141, 105, 183, 140, 105, 182, 140, 105, 183, 143, 107, 180, 140, 106, 164, 126, 99, 127, 96, 76, 92, 73, 58, 107, 95, 84, 110, 93, 86, 153, 130, 114, 194, 164, 137, 195, 155, 124, 201, 156, 125, 197, 155, 124, 198, 157, 125, 201, 158, 127, 200, 155, 125, 199, 152, 122, 197, 151, 120, 23, 20, 24, 19, 20, 27, 21, 17, 20, 46, 31, 26, 153, 122, 106, 202, 161, 130, 191, 155, 118, 178, 146, 124, 164, 138, 125, 158, 136, 114, 169, 139, 109, 183, 149, 117, 186, 152, 120, 184, 150, 118, 180, 146, 114, 178, 151, 121, 180, 159, 133, 173, 150, 131, 138, 117, 106, 86, 73, 68, 74, 65, 62, 106, 88, 81, 180, 156, 140, 206, 175, 150, 207, 168, 138, 213, 169, 140, 208, 171, 137, 206, 173, 136, 207, 172, 136, 205, 168, 133, 204, 164, 129, 202, 163, 128, 23, 20, 24, 20, 20, 26, 23, 20, 23, 31, 21, 18, 127, 102, 88, 200, 162, 131, 185, 151, 116, 168, 140, 123, 159, 141, 139, 158, 149, 141, 154, 136, 116, 162, 139, 116, 178, 154, 129, 178, 153, 127, 179, 152, 125, 178, 159, 132, 181, 166, 142, 190, 171, 154, 182, 161, 152, 125, 109, 105, 71, 58, 55, 114, 97, 89, 197, 177, 159, 209, 183, 158, 213, 179, 151, 216, 178, 151, 213, 177, 146, 211, 178, 142, 212, 177, 142, 211, 173, 139, 208, 169, 136, 206, 166, 132, 23, 20, 24, 21, 20, 25, 24, 21, 25, 23, 17, 18, 99, 79, 69, 189, 153, 124, 175, 140, 106, 160, 130, 115, 168, 151, 156, 168, 164, 166, 166, 157, 146, 149, 135, 120, 170, 153, 137, 186, 166, 148, 191, 169, 149, 195, 176, 151, 195, 176, 150, 200, 175, 156, 188, 161, 148, 141, 118, 109, 99, 82, 74, 146, 133, 122, 210, 196, 177, 214, 195, 169, 213, 189, 161, 212, 183, 157, 212, 180, 152, 213, 179, 149, 217, 179, 150, 217, 177, 148, 215, 173, 145, 214, 171, 142, 25, 21, 25, 23, 20, 24, 23, 21, 25, 21, 19, 23, 72, 56, 51, 170, 137, 109, 165, 130, 96, 151, 119, 104, 175, 156, 161, 183, 178, 184, 185, 179, 178, 155, 146, 141, 146, 132, 124, 157, 139, 128, 169, 148, 134, 188, 167, 147, 197, 175, 151, 196, 169, 150, 178, 152, 137, 141, 120, 108, 121, 109, 96, 172, 167, 152, 211, 206, 183, 219, 210, 181, 221, 209, 179, 217, 201, 174, 217, 195, 168, 217, 191, 164, 214, 186, 160, 212, 182, 156, 209, 177, 152, 206, 172, 147, 26, 22, 26, 27, 22, 26, 26, 23, 27, 23, 22, 28, 49, 38, 35, 143, 115, 89, 164, 130, 95, 154, 120, 102, 169, 146, 150, 194, 185, 193, 200, 195, 199, 166, 158, 159, 130, 118, 116, 125, 108, 102, 128, 107, 98, 151, 132, 118, 165, 146, 130, 165, 143, 131, 148, 129, 119, 143, 132, 122, 147, 143, 132, 182, 183, 167, 188, 190, 166, 201, 199, 170, 212, 207, 178, 217, 209, 183, 213, 204, 179, 219, 209, 183, 220, 209, 183, 215, 202, 177, 215, 199, 175, 211, 194, 169, 30, 24, 26, 26, 19, 22, 27, 21, 25, 25, 20, 26, 37, 30, 29, 125, 113, 92, 180, 161, 128, 171, 148, 123, 169, 151, 147, 197, 186, 195, 202, 194, 199, 179, 170, 171, 139, 128, 126, 113, 98, 94, 122, 105, 99, 130, 113, 106, 119, 104, 96, 133, 116, 109, 122, 107, 101, 140, 128, 122, 185, 178, 172, 203, 202, 192, 191, 192, 170, 201, 197, 176, 215, 206, 195, 218, 207, 196, 215, 209, 197, 219, 215, 202, 220, 216, 197, 218, 214, 191, 220, 215, 191, 224, 218, 194, 94, 88, 77, 48, 41, 33, 31, 24, 17, 36, 29, 25, 100, 96, 88, 175, 174, 154, 193, 186, 155, 168, 156, 126, 163, 149, 140, 192, 181, 190, 198, 189, 193, 195, 186, 185, 174, 164, 163, 145, 132, 129, 142, 129, 123, 132, 118, 113, 106, 92, 88, 121, 107, 103, 122, 108, 104, 139, 124, 121, 192, 180, 177, 209, 204, 198, 189, 187, 165, 213, 206, 189, 242, 230, 228, 237, 224, 219, 239, 231, 224, 232, 228, 218, 208, 205, 186, 213, 211, 187, 222, 220, 196, 229, 226, 205, 180, 177, 149, 158, 153, 128, 114, 109, 86, 122, 117, 96, 177, 175, 155, 190, 189, 167, 190, 183, 153, 160, 147, 119, 133, 120, 111, 173, 161, 168, 197, 188, 191, 200, 192, 191, 194, 184, 183, 185, 173, 170, 167, 154, 148, 146, 131, 127, 129, 115, 112, 129, 115, 112, 133, 119, 116, 141, 127, 124, 177, 166, 163, 201, 197, 187, 189, 188, 162, 220, 216, 193, 241, 233, 223, 235, 226, 213, 232, 227, 207, 213, 211, 187, 189, 188, 157, 199, 198, 166, 225, 224, 196, 234, 232, 210, 197, 194, 161, 192, 188, 158, 178, 175, 146, 186, 182, 155, 193, 191, 167, 195, 194, 169, 197, 190, 159, 157, 144, 117, 128, 115, 104, 163, 152, 155, 185, 177, 179, 191, 182, 181, 193, 183, 182, 195, 182, 180, 178, 164, 159, 151, 138, 135, 114, 102, 100, 129, 118, 116, 131, 119, 117, 134, 123, 121, 170, 160, 158, 194, 189, 178, 208, 208, 178, 234, 233, 204, 236, 232, 216, 240, 235, 214, 235, 234, 203, 201, 203, 167, 185, 187, 147, 187, 189, 150, 208, 209, 176, 235, 235, 207, 202, 199, 170, 196, 192, 165, 187, 183, 158, 192, 187, 165, 200, 198, 175, 205, 205, 176, 197, 191, 160, 151, 138, 112, 149, 136, 123, 175, 165, 164, 184, 176, 177, 189, 181, 180, 193, 184, 182, 187, 175, 172, 168, 154, 149, 136, 124, 121, 117, 107, 106, 128, 118, 116, 128, 119, 117, 129, 120, 118, 167, 158, 156, 181, 176, 166, 205, 205, 175, 240, 240, 209, 243, 243, 222, 243, 244, 216, 238, 242, 205, 206, 212, 169, 186, 192, 145, 187, 192, 147, 193, 198, 159, 221, 224, 186, 205, 201, 172, 205, 201, 174, 197, 193, 169, 192, 187, 166, 203, 201, 176, 208, 209, 176, 194, 188, 157, 160, 146, 122, 168, 155, 141, 191, 182, 177, 193, 185, 185, 191, 183, 182, 193, 183, 182, 172, 159, 157, 146, 132, 127, 119, 107, 104, 124, 115, 115, 142, 133, 132, 133, 124, 123, 135, 126, 125, 167, 158, 159, 176, 170, 164, 191, 189, 163, 234, 235, 206, 243, 246, 224, 241, 246, 217, 236, 242, 205, 215, 222, 181, 186, 194, 146, 184, 192, 142, 185, 192, 147, 196, 202, 156, 206, 203, 167, 204, 201, 167, 200, 197, 165, 193, 189, 160, 197, 196, 165, 199, 198, 164, 191, 183, 153, 180, 165, 143, 172, 159, 145, 179, 170, 163, 183, 176, 174, 173, 165, 164, 174, 164, 163, 174, 162, 159, 152, 138, 133, 131, 120, 118, 141, 133, 134, 166, 159, 159, 142, 135, 135, 154, 146, 146, 169, 161, 163, 172, 165, 163, 191, 189, 168, 230, 231, 205, 240, 244, 223, 241, 248, 220, 239, 247, 214, 228, 234, 199, 200, 208, 163, 186, 195, 144, 184, 193, 144, 192, 199, 152, 210, 208, 169, 202, 202, 162, 198, 196, 160, 191, 185, 155, 201, 193, 163, 180, 167, 136, 177, 156, 131, 202, 185, 164, 171, 161, 146, 154, 145, 136, 142, 135, 132, 142, 135, 133, 168, 161, 159, 168, 158, 158, 147, 137, 135, 156, 143, 146, 175, 164, 167, 169, 164, 162, 150, 149, 144, 164, 162, 158, 158, 153, 152, 160, 157, 152, 197, 195, 176, 230, 228, 203, 241, 242, 215, 241, 247, 216, 244, 249, 221, 242, 245, 218, 226, 232, 197, 191, 199, 159, 195, 204, 162, 215, 222, 182, 211, 210, 174, 201, 204, 164, 199, 197, 162, 192, 182, 157, 207, 191, 168, 170, 142, 120, 161, 125, 109, 215, 193, 178, 189, 181, 166, 186, 177, 167, 173, 166, 161, 172, 167, 163, 190, 184, 182, 177, 170, 171, 137, 130, 132, 127, 114, 120, 180, 165, 169, 174, 170, 163, 150, 152, 140, 160, 158, 149, 175, 171, 166, 176, 174, 164, 193, 189, 170, 236, 231, 204, 245, 242, 211, 242, 244, 213, 243, 245, 218, 251, 251, 228, 239, 242, 214, 201, 207, 176, 212, 221, 187, 225, 233, 199, 211, 212, 175, 196, 200, 160, 197, 197, 161, 193, 185, 159, 209, 189, 170, 181, 145, 132, 154, 112, 104, 217, 192, 183, 206, 199, 188, 197, 190, 182, 195, 189, 184, 185, 180, 176, 170, 164, 162, 173, 167, 168, 166, 160, 163, 152, 137, 141, 163, 146, 145, 184, 176, 165, 166, 162, 146, 152, 145, 133, 192, 184, 175, 181, 177, 165, 175, 168, 150, 204, 195, 169, 238, 232, 202, 243, 241, 212, 244, 245, 217, 247, 249, 221, 223, 228, 196, 213, 221, 186, 226, 236, 199, 226, 235, 199, 214, 216, 179, 194, 199, 159, 180, 182, 146, 181, 174, 148, 197, 176, 161, 196, 155, 151, 155, 110, 109, 198, 173, 168, 214, 208, 199, 192, 186, 181, 174, 168, 164, 183, 178, 174, 173, 168, 165, 161, 155, 156, 174, 167, 170, 178, 164, 166, 128, 110, 105, 164, 150, 136, 189, 177, 159, 147, 134, 119, 167, 154, 143, 180, 171, 158, 156, 144, 126, 118, 104, 80, 157, 145, 118, 215, 209, 183, 239, 238, 209, 235, 237, 205, 206, 210, 175, 214, 221, 183, 234, 243, 201, 228, 237, 197, 215, 219, 181, 198, 206, 164, 166, 169, 133, 163, 158, 131, 180, 163, 149, 202, 167, 165, 190, 149, 151, 185, 162, 159, 207, 202, 194, 210, 205, 199, 205, 200, 196, 214, 209, 205, 193, 188, 185, 174, 168, 168, 176, 170, 172, 173, 161, 162, 129, 112, 104, 137, 120, 105, 191, 173, 155, 153, 135, 119, 163, 147, 134, 200, 186, 173, 171, 155, 136, 135, 115, 92, 116, 98, 75, 144, 132, 111, 184, 178, 152, 193, 188, 158, 187, 185, 152, 210, 212, 176, 239, 243, 203, 235, 239, 200, 216, 221, 183, 205, 214, 172, 174, 179, 142, 164, 161, 133, 185, 175, 159, 203, 181, 176, 210, 179, 177, 194, 177, 170, 191, 189, 177, 211, 207, 197, 218, 212, 207, 226, 221, 217, 225, 220, 217, 203, 197, 198, 190, 184, 187, 179, 171, 170, 151, 139, 131, 121, 103, 90, 168, 149, 133, 158, 140, 126, 167, 151, 139, 194, 177, 162, 170, 148, 130, 172, 147, 126, 154, 131, 111, 131, 112, 96, 153, 138, 118, 169, 156, 132, 162, 151, 124, 184, 177, 146, 222, 217, 184, 236, 234, 199, 216, 223, 185, 208, 218, 176, 192, 198, 161, 180, 178, 149, 197, 194, 175, 202, 194, 183, 209, 190, 182, 210, 200, 188, 186, 186, 170, 189, 184, 170, 197, 191, 185, 204, 199, 194, 209, 203, 201, 213, 208, 208, 207, 200, 202, 181, 177, 175, 178, 171, 164, 149, 135, 123, 146, 127, 113, 175, 158, 145, 183, 168, 157, 174, 155, 140, 156, 131, 113, 171, 143, 123, 163, 137, 119, 148, 126, 112, 169, 148, 134, 180, 159, 142, 166, 147, 127, 160, 144, 121, 172, 158, 132, 204, 197, 166, 218, 225, 189, 213, 221, 183, 202, 208, 173, 182, 183, 155, 191, 191, 171, 203, 199, 186, 201, 190, 177, 202, 194, 178, 202, 198, 180, 195, 188, 172, 193, 190, 178, 192, 186, 177, 178, 171, 164, 198, 193, 188, 207, 198, 195, 199, 191, 189, 211, 207, 201, 203, 191, 182, 166, 148, 136, 187, 169, 157, 177, 160, 147, 155, 135, 120, 147, 123, 106, 166, 141, 124, 167, 142, 128, 171, 149, 138, 182, 159, 148, 175, 152, 138, 156, 135, 120, 156, 136, 119, 159, 140, 122, 167, 154, 130, 217, 222, 189, 215, 221, 188, 209, 214, 183, 186, 190, 161, 179, 179, 158, 200, 195, 183, 208, 200, 187, 200, 190, 176, 209, 198, 184, 215, 205, 191, 210, 209, 192, 186, 178, 164, 161, 151, 139, 182, 179, 166, 196, 182, 173, 194, 181, 177, 203, 197, 192, 207, 196, 188, 190, 174, 162, 185, 165, 150, 155, 134, 118, 142, 124, 107, 155, 137, 121, 166, 147, 133, 172, 153, 142, 179, 161, 150, 173, 153, 141, 159, 139, 125, 150, 131, 117, 158, 139, 124, 158, 139, 125, 143, 125, 108, 214, 219, 186, 213, 218, 186, 214, 219, 187, 192, 198, 166, 169, 170, 148, 197, 191, 180, 218, 210, 199, 217, 207, 197, 215, 203, 193, 217, 206, 195, 212, 207, 192, 195, 180, 168, 170, 156, 145, 179, 174, 159, 195, 180, 169, 191, 176, 170, 190, 182, 175, 192, 181, 172, 192, 176, 163, 170, 150, 134, 132, 111, 93, 142, 125, 108, 167, 150, 134, 170, 152, 139, 170, 152, 141, 179, 161, 151, 173, 154, 142, 157, 138, 124, 157, 138, 124, 147, 128, 114, 134, 115, 101, 125, 106, 91, 213, 218, 186, 209, 214, 181, 211, 217, 183, 202, 207, 172, 168, 170, 143, 193, 188, 176, 216, 210, 201, 222, 213, 207, 223, 212, 206, 222, 211, 203, 211, 199, 189, 205, 182, 175, 194, 174, 165, 194, 186, 171, 201, 186, 174, 198, 181, 172, 198, 186, 178, 196, 182, 171, 188, 171, 158, 153, 133, 117, 134, 114, 97, 155, 137, 120, 171, 154, 138, 167, 149, 136, 166, 148, 138, 189, 171, 161, 178, 159, 146, 165, 146, 132, 163, 144, 130, 142, 123, 109, 133, 115, 100, 137, 118, 104, 211, 216, 184, 206, 212, 178, 206, 212, 175, 202, 209, 169, 175, 179, 146, 191, 189, 170, 211, 207, 198, 213, 205, 202, 214, 205, 200, 216, 205, 197, 198, 177, 171, 171, 138, 136, 194, 167, 161, 206, 195, 180, 201, 187, 171, 201, 182, 170, 200, 185, 173, 197, 181, 168, 177, 158, 144, 150, 130, 115, 144, 125, 108, 158, 141, 124, 167, 150, 134, 157, 140, 126, 159, 141, 130, 181, 163, 153, 176, 157, 145, 168, 149, 135, 152, 133, 119, 150, 131, 117, 149, 130, 116, 144, 124, 111, 210, 215, 184, 204, 210, 176, 201, 208, 168, 193, 200, 157, 181, 187, 147, 188, 190, 162, 208, 206, 192, 210, 204, 200, 205, 198, 191, 206, 196, 185, 160, 131, 129, 122, 80, 82, 177, 145, 141, 208, 194, 179, 198, 184, 166, 194, 174, 159, 193, 174, 159, 184, 165, 150, 166, 147, 132, 150, 131, 116, 139, 120, 105, 156, 139, 122, 160, 143, 127, 153, 136, 122, 155, 137, 127, 160, 142, 132, 159, 140, 128, 155, 136, 122, 152, 133, 119, 152, 133, 119, 140, 121, 107, 131, 112, 98, 210, 215, 184, 202, 208, 172, 198, 205, 163, 187, 194, 148, 174, 181, 134, 178, 183, 146, 205, 205, 186, 214, 209, 202, 209, 204, 192, 203, 194, 178, 164, 129, 130, 131, 81, 88, 180, 142, 140, 202, 186, 172, 187, 171, 152, 182, 161, 144, 182, 161, 145, 169, 149, 132, 157, 137, 122, 139, 120, 105, 134, 115, 100, 153, 135, 119, 154, 137, 121, 144, 126, 112, 151, 133, 122, 141, 123, 113, 131, 112, 100, 141, 122, 108, 157, 138, 124, 155, 136, 122, 150, 131, 117, 147, 128, 114, 210, 214, 183, 200, 205, 169, 194, 200, 158, 181, 188, 142, 168, 176, 126, 168, 175, 132, 196, 198, 178, 215, 212, 204, 212, 208, 195, 199, 192, 175, 189, 160, 157, 184, 142, 144, 203, 170, 164, 185, 168, 152, 173, 155, 135, 172, 149, 131, 163, 141, 124, 155, 133, 116, 147, 127, 111, 118, 100, 84, 131, 113, 97, 148, 131, 115, 145, 128, 113, 141, 123, 109, 144, 126, 114, 132, 114, 102, 127, 108, 95, 133, 114, 100, 149, 130, 116, 163, 144, 130, 162, 144, 130, 156, 137, 123, 208, 210, 177, 194, 196, 161, 189, 192, 153, 180, 183, 142, 162, 169, 119, 158, 166, 122, 189, 192, 178, 211, 210, 204, 211, 209, 197, 197, 192, 180, 194, 182, 170, 199, 180, 168, 191, 171, 157, 172, 153, 135, 163, 141, 122, 164, 140, 123, 158, 134, 119, 147, 125, 109, 130, 111, 94, 109, 92, 75, 137, 120, 104, 144, 126, 111, 144, 126, 112, 145, 127, 113, 144, 126, 112, 132, 114, 100, 124, 105, 92, 134, 116, 102, 151, 133, 119, 162, 144, 130, 159, 141, 126, 147, 129, 115, 194, 196, 163, 177, 179, 144, 176, 179, 141, 181, 185, 145, 159, 166, 116, 143, 151, 107, 179, 181, 169, 205, 204, 200, 208, 205, 194, 199, 194, 183, 194, 186, 172, 190, 179, 163, 181, 166, 150, 165, 146, 129, 156, 133, 115, 161, 136, 121, 149, 126, 112, 136, 114, 100, 112, 93, 78, 114, 97, 81, 137, 120, 104, 133, 115, 101, 138, 120, 106, 146, 128, 114, 146, 128, 114, 131, 113, 99, 131, 113, 99, 144, 126, 112, 150, 132, 118, 149, 131, 117, 148, 130, 116, 141, 123, 110, 172, 177, 142, 157, 161, 126, 165, 170, 131, 178, 184, 143, 167, 174, 124, 133, 140, 95, 156, 156, 145, 199, 195, 192, 206, 201, 190, 199, 193, 183, 199, 191, 178, 194, 182, 168, 160, 145, 130, 133, 113, 98, 132, 108, 92, 139, 115, 101, 140, 118, 104, 126, 106, 92, 107, 89, 75, 126, 110, 95, 130, 114, 99, 129, 112, 97, 138, 120, 106, 149, 131, 116, 141, 123, 109, 140, 122, 108, 145, 127, 113, 142, 124, 110, 136, 117, 103, 140, 122, 108, 149, 130, 116, 152, 134, 119, 151, 157, 123, 134, 140, 104, 144, 151, 112, 155, 161, 120, 158, 166, 116, 125, 130, 87, 130, 128, 118, 183, 177, 174, 197, 191, 181, 191, 183, 174, 183, 175, 164, 165, 154, 141, 128, 112, 99, 103, 83, 69, 94, 71, 57, 105, 83, 70, 119, 99, 87, 112, 94, 81, 117, 101, 88, 124, 110, 96, 121, 108, 93, 125, 108, 94, 139, 121, 107, 143, 126, 112, 139, 121, 107, 140, 122, 108, 129, 111, 97, 125, 107, 93, 132, 115, 101, 149, 132, 118, 155, 137, 123, 150, 132, 118], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284462140240}], \"selected_variable\": {\"name\": [\"<SArray>\"], \"dtype\": \"Image\", \"view_component\": \"Images\", \"view_file\": \"sarray\", \"descriptives\": {\"rows\": 3}, \"type\": \"SArray\", \"view_components\": [\"Images\"]}}, e);\n",
       "                });\n",
       "            })();\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "image_test[0:3]['image'].show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "dtype: str\n",
       "Rows: 3\n",
       "['cat', 'automobile', 'cat']"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "image_test[0:3]['label']"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "dtype: str\n",
       "Rows: 3\n",
       "['bird', 'cat', 'bird']"
      ]
     },
     "execution_count": 8,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "raw_pixel_model.predict(image_test[0:3])"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The model makes wrong predictions for all three images."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#Evaluating raw pixel model on test data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "{'accuracy': 0.46925, 'confusion_matrix': Columns:\n",
       " \ttarget_label\tstr\n",
       " \tpredicted_label\tstr\n",
       " \tcount\tint\n",
       " \n",
       " Rows: 16\n",
       " \n",
       " Data:\n",
       " +--------------+-----------------+-------+\n",
       " | target_label | predicted_label | count |\n",
       " +--------------+-----------------+-------+\n",
       " |     bird     |       dog       |  175  |\n",
       " |     dog      |       cat       |  274  |\n",
       " |     cat      |       cat       |  373  |\n",
       " |     bird     |    automobile   |  140  |\n",
       " |  automobile  |    automobile   |  628  |\n",
       " |     dog      |    automobile   |  101  |\n",
       " |     dog      |       dog       |  406  |\n",
       " |     cat      |       dog       |  277  |\n",
       " |     bird     |       cat       |  215  |\n",
       " |  automobile  |       bird      |   86  |\n",
       " +--------------+-----------------+-------+\n",
       " [16 rows x 3 columns]\n",
       " Note: Only the head of the SFrame is printed.\n",
       " You can use print_rows(num_rows=m, num_columns=n) to print more rows and columns.}"
      ]
     },
     "execution_count": 9,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "raw_pixel_model.evaluate(image_test)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The accuracy of this model is poor, getting only about 46% accuracy."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#Can we improve the model using deep features\n",
    "\n",
    "We only have 2005 data points, so it is not possible to train a deep neural network effectively with so little data.  Instead, we will use transfer learning: using deep features trained on the full ImageNet dataset, we will train a simple model on this small dataset."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "2005"
      ]
     },
     "execution_count": 10,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "len(image_train)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "##Computing deep features for our images\n",
    "\n",
    "The two lines below allow us to compute deep features.  This computation takes a little while, so we have already computed them and saved the results as a column in the data you loaded. \n",
    "\n",
    "(Note that if you would like to compute such deep features and have a GPU on your machine, you should use the GPU enabled GraphLab Create, which will be significantly faster for this task.)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "#deep_learning_model = graphlab.load_model('http://s3.amazonaws.com/GraphLab-Datasets/deeplearning/imagenet_model_iter45')\n",
    "#image_train['deep_features'] = deep_learning_model.extract_features(image_train)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "As we can see, the column deep_features already contains the pre-computed deep features for this data. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div style=\"max-height:1000px;max-width:1500px;overflow:auto;\"><table frame=\"box\" rules=\"cols\">\n",
       "    <tr>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">id</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">image</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">label</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">deep_features</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">image_array</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">24</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">bird</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.242871761322,<br>1.09545373917, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[73.0, 77.0, 58.0, 71.0,<br>68.0, 50.0, 77.0, 69.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">33</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">cat</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.525087952614, 0.0,<br>0.0, 0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[7.0, 5.0, 8.0, 7.0, 5.0,<br>8.0, 5.0, 4.0, 6.0, 7.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">36</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">cat</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.566015958786, 0.0,<br>0.0, 0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[169.0, 122.0, 65.0,<br>131.0, 108.0, 75.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">70</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">dog</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[1.12979578972, 0.0, 0.0,<br>0.778194487095, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[154.0, 179.0, 152.0,<br>159.0, 183.0, 157.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">90</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">bird</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[1.71786928177, 0.0, 0.0,<br>0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[216.0, 195.0, 180.0,<br>201.0, 178.0, 160.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">97</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">automobile</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[1.57818555832, 0.0, 0.0,<br>0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[33.0, 44.0, 27.0, 29.0,<br>44.0, 31.0, 32.0, 45.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">107</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">dog</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.0, 0.0,<br>0.220677852631, 0.0,  ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[97.0, 51.0, 31.0, 104.0,<br>58.0, 38.0, 107.0, 61.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">121</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">bird</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.0, 0.23753464222, 0.0,<br>0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[93.0, 96.0, 88.0, 102.0,<br>106.0, 97.0, 117.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">136</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">automobile</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.0, 0.0, 0.0, 0.0, 0.0,<br>0.0, 7.5737862587, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[35.0, 59.0, 53.0, 36.0,<br>56.0, 56.0, 42.0, 62.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">138</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">bird</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.658935725689, 0.0,<br>0.0, 0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[205.0, 193.0, 195.0,<br>200.0, 187.0, 193.0, ...</td>\n",
       "    </tr>\n",
       "</table>\n",
       "[10 rows x 5 columns]<br/>\n",
       "</div>"
      ],
      "text/plain": [
       "Columns:\n",
       "\tid\tint\n",
       "\timage\tImage\n",
       "\tlabel\tstr\n",
       "\tdeep_features\tarray\n",
       "\timage_array\tarray\n",
       "\n",
       "Rows: 10\n",
       "\n",
       "Data:\n",
       "+-----+----------------------+------------+-------------------------------+\n",
       "|  id |        image         |   label    |         deep_features         |\n",
       "+-----+----------------------+------------+-------------------------------+\n",
       "|  24 | Height: 32 Width: 32 |    bird    | [0.242871761322, 1.0954537... |\n",
       "|  33 | Height: 32 Width: 32 |    cat     | [0.525087952614, 0.0, 0.0,... |\n",
       "|  36 | Height: 32 Width: 32 |    cat     | [0.566015958786, 0.0, 0.0,... |\n",
       "|  70 | Height: 32 Width: 32 |    dog     | [1.12979578972, 0.0, 0.0, ... |\n",
       "|  90 | Height: 32 Width: 32 |    bird    | [1.71786928177, 0.0, 0.0, ... |\n",
       "|  97 | Height: 32 Width: 32 | automobile | [1.57818555832, 0.0, 0.0, ... |\n",
       "| 107 | Height: 32 Width: 32 |    dog     | [0.0, 0.0, 0.220677852631,... |\n",
       "| 121 | Height: 32 Width: 32 |    bird    | [0.0, 0.23753464222, 0.0, ... |\n",
       "| 136 | Height: 32 Width: 32 | automobile | [0.0, 0.0, 0.0, 0.0, 0.0, ... |\n",
       "| 138 | Height: 32 Width: 32 |    bird    | [0.658935725689, 0.0, 0.0,... |\n",
       "+-----+----------------------+------------+-------------------------------+\n",
       "+-------------------------------+\n",
       "|          image_array          |\n",
       "+-------------------------------+\n",
       "| [73.0, 77.0, 58.0, 71.0, 6... |\n",
       "| [7.0, 5.0, 8.0, 7.0, 5.0, ... |\n",
       "| [169.0, 122.0, 65.0, 131.0... |\n",
       "| [154.0, 179.0, 152.0, 159.... |\n",
       "| [216.0, 195.0, 180.0, 201.... |\n",
       "| [33.0, 44.0, 27.0, 29.0, 4... |\n",
       "| [97.0, 51.0, 31.0, 104.0, ... |\n",
       "| [93.0, 96.0, 88.0, 102.0, ... |\n",
       "| [35.0, 59.0, 53.0, 36.0, 5... |\n",
       "| [205.0, 193.0, 195.0, 200.... |\n",
       "+-------------------------------+\n",
       "[10 rows x 5 columns]"
      ]
     },
     "execution_count": 11,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "image_train.head()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#Given the deep features, let's train a classifier"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "PROGRESS: Creating a validation set from 5 percent of training data. This may take a while.\n",
      "          You can set ``validation_set=None`` to disable validation tracking.\n",
      "\n",
      "PROGRESS: WARNING: Detected extremely low variance for feature(s) 'deep_features' because all entries are nearly the same.\n",
      "Proceeding with model training using all features. If the model does not provide results of adequate quality, exclude the above mentioned feature(s) from the input dataset.\n",
      "PROGRESS: Logistic regression:\n",
      "PROGRESS: --------------------------------------------------------\n",
      "PROGRESS: Number of examples          : 1907\n",
      "PROGRESS: Number of classes           : 4\n",
      "PROGRESS: Number of feature columns   : 1\n",
      "PROGRESS: Number of unpacked features : 4096\n",
      "PROGRESS: Number of coefficients    : 12291\n",
      "PROGRESS: Starting L-BFGS\n",
      "PROGRESS: --------------------------------------------------------\n",
      "PROGRESS: +-----------+----------+-----------+--------------+-------------------+---------------------+\n",
      "PROGRESS: | Iteration | Passes   | Step size | Elapsed Time | Training-accuracy | Validation-accuracy |\n",
      "PROGRESS: +-----------+----------+-----------+--------------+-------------------+---------------------+\n",
      "PROGRESS: | 1         | 5        | 0.000131  | 8.722927     | 0.738332          | 0.724490            |\n",
      "PROGRESS: | 2         | 9        | 0.250000  | 15.717168    | 0.759832          | 0.755102            |\n",
      "PROGRESS: | 3         | 10       | 0.250000  | 18.608909    | 0.766649          | 0.775510            |\n",
      "PROGRESS: | 4         | 11       | 0.250000  | 20.278396    | 0.771369          | 0.785714            |\n",
      "PROGRESS: | 5         | 12       | 0.250000  | 21.926598    | 0.774515          | 0.775510            |\n",
      "PROGRESS: | 6         | 13       | 0.250000  | 24.876189    | 0.789198          | 0.775510            |\n",
      "PROGRESS: | 7         | 14       | 0.250000  | 28.252849    | 0.799161          | 0.795918            |\n",
      "PROGRESS: | 8         | 15       | 0.250000  | 29.758930    | 0.817514          | 0.836735            |\n",
      "PROGRESS: | 9         | 16       | 0.250000  | 31.279928    | 0.845307          | 0.867347            |\n",
      "PROGRESS: | 10        | 17       | 0.250000  | 32.899500    | 0.859990          | 0.846939            |\n",
      "PROGRESS: +-----------+----------+-----------+--------------+-------------------+---------------------+\n"
     ]
    }
   ],
   "source": [
    "deep_features_model = graphlab.logistic_classifier.create(image_train,\n",
    "                                                         features=['deep_features'],\n",
    "                                                         target='label')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#Apply the deep features model to first few images of test set"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "application/javascript": [
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//cdnjs.cloudflare.com/ajax/libs/font-awesome/4.1.0/css/font-awesome.min.css\"\n",
       "}));\n",
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//dato.com/files/canvas/1.6.1/css/canvas.css\"\n",
       "}));\n",
       "\n",
       "            (function(){\n",
       "\n",
       "                var e = null;\n",
       "                if (typeof element == 'undefined') {\n",
       "                    var scripts = document.getElementsByTagName('script');\n",
       "                    var thisScriptTag = scripts[scripts.length-1];\n",
       "                    var parentDiv = thisScriptTag.parentNode;\n",
       "                    e = document.createElement('div');\n",
       "                    parentDiv.appendChild(e);\n",
       "                } else {\n",
       "                    e = element[0];\n",
       "                }\n",
       "\n",
       "                if (typeof requirejs !== 'undefined') {\n",
       "                    // disable load timeout; ipython_app.js is large and can take a while to load.\n",
       "                    requirejs.config({waitSeconds: 0});\n",
       "                }\n",
       "\n",
       "                require(['//dato.com/files/canvas/1.6.1/js/ipython_app.js'], function(IPythonApp){\n",
       "                    var app = new IPythonApp();\n",
       "                    app.attachView('sarray','Images', {\"ipython\": true, \"rows\": [{\"format\": \"raw\", \"value\": [158, 112, 49, 159, 111, 47, 165, 116, 51, 166, 118, 53, 160, 112, 46, 156, 109, 41, 162, 115, 47, 159, 113, 45, 158, 111, 44, 159, 113, 41, 161, 116, 41, 160, 111, 52, 161, 111, 49, 166, 117, 41, 169, 117, 45, 170, 119, 44, 167, 117, 40, 162, 113, 38, 160, 111, 39, 160, 112, 43, 156, 109, 44, 149, 107, 45, 150, 107, 45, 148, 106, 43, 149, 107, 44, 143, 101, 39, 140, 98, 43, 141, 97, 41, 143, 97, 38, 137, 95, 36, 126, 91, 36, 116, 85, 33, 152, 112, 51, 151, 110, 40, 159, 114, 45, 166, 116, 56, 162, 112, 49, 160, 113, 43, 164, 117, 47, 162, 114, 45, 163, 116, 46, 156, 110, 38, 155, 111, 41, 159, 110, 54, 163, 113, 52, 170, 119, 41, 171, 117, 40, 171, 115, 33, 169, 115, 30, 160, 111, 33, 154, 112, 41, 151, 115, 50, 145, 110, 53, 139, 104, 55, 140, 102, 52, 141, 100, 48, 149, 105, 50, 147, 102, 46, 145, 102, 45, 142, 97, 38, 143, 98, 34, 136, 95, 31, 125, 91, 32, 119, 88, 34, 151, 110, 47, 151, 109, 33, 158, 111, 36, 167, 111, 48, 160, 106, 42, 163, 115, 44, 165, 117, 45, 165, 117, 45, 163, 115, 43, 162, 115, 43, 158, 114, 48, 157, 109, 57, 161, 111, 51, 166, 115, 38, 167, 114, 37, 169, 113, 35, 170, 116, 39, 159, 114, 47, 145, 111, 54, 121, 96, 49, 110, 90, 52, 98, 78, 50, 101, 77, 47, 114, 85, 50, 120, 86, 48, 134, 96, 55, 143, 103, 51, 140, 99, 39, 142, 99, 35, 139, 98, 34, 130, 95, 34, 120, 89, 33, 155, 107, 40, 155, 110, 32, 160, 109, 31, 174, 112, 44, 167, 110, 43, 167, 117, 46, 169, 120, 48, 169, 119, 48, 165, 115, 44, 165, 117, 45, 167, 123, 57, 191, 146, 95, 177, 130, 75, 157, 111, 41, 162, 115, 47, 164, 114, 54, 158, 112, 58, 149, 111, 67, 104, 80, 47, 103, 87, 65, 98, 90, 76, 92, 90, 84, 80, 75, 66, 74, 63, 50, 86, 70, 52, 83, 62, 39, 113, 85, 45, 132, 98, 46, 140, 102, 43, 140, 101, 39, 136, 99, 39, 127, 94, 36, 155, 107, 41, 156, 114, 48, 161, 115, 49, 170, 114, 47, 169, 114, 43, 163, 113, 40, 169, 120, 47, 166, 116, 44, 164, 113, 41, 164, 116, 42, 173, 128, 59, 246, 214, 164, 195, 156, 107, 151, 114, 56, 146, 111, 60, 142, 108, 71, 111, 80, 50, 78, 53, 31, 85, 69, 56, 113, 103, 98, 112, 110, 111, 106, 114, 118, 97, 102, 105, 93, 94, 93, 74, 72, 67, 84, 78, 70, 85, 73, 47, 105, 83, 45, 128, 96, 48, 138, 101, 46, 133, 94, 36, 129, 93, 36, 148, 109, 54, 133, 104, 64, 130, 100, 57, 147, 112, 53, 161, 115, 44, 165, 113, 39, 167, 116, 41, 167, 115, 41, 163, 111, 37, 165, 116, 39, 163, 118, 42, 180, 138, 85, 157, 122, 78, 128, 102, 58, 97, 75, 43, 66, 50, 31, 69, 58, 43, 66, 56, 45, 89, 83, 76, 118, 113, 110, 122, 121, 120, 119, 122, 122, 114, 116, 116, 94, 96, 96, 99, 100, 97, 91, 91, 86, 58, 58, 47, 67, 58, 37, 108, 84, 49, 140, 105, 58, 138, 98, 44, 134, 95, 40, 127, 100, 57, 109, 95, 80, 47, 37, 17, 88, 74, 28, 153, 117, 48, 170, 118, 43, 168, 115, 40, 170, 118, 43, 169, 117, 42, 166, 116, 37, 164, 120, 39, 147, 107, 52, 129, 98, 59, 127, 108, 75, 100, 87, 70, 68, 67, 57, 78, 83, 72, 72, 75, 64, 83, 84, 74, 132, 130, 121, 146, 142, 132, 124, 118, 108, 105, 99, 90, 107, 102, 94, 115, 111, 103, 85, 83, 77, 63, 71, 69, 46, 47, 39, 79, 61, 36, 132, 98, 58, 141, 99, 48, 134, 93, 39, 131, 115, 90, 99, 96, 92, 42, 43, 38, 70, 64, 41, 143, 111, 56, 167, 117, 42, 165, 114, 36, 168, 116, 39, 171, 119, 49, 161, 113, 51, 140, 109, 51, 120, 94, 49, 130, 110, 77, 144, 131, 107, 116, 106, 93, 88, 87, 79, 91, 95, 88, 85, 88, 82, 77, 77, 69, 124, 118, 107, 163, 153, 140, 136, 124, 112, 102, 93, 81, 106, 98, 88, 100, 93, 84, 85, 81, 74, 54, 60, 58, 49, 53, 49, 57, 47, 32, 107, 83, 50, 138, 103, 51, 136, 97, 39, 170, 161, 144, 103, 105, 105, 54, 58, 59, 124, 121, 113, 153, 124, 82, 161, 113, 43, 163, 117, 41, 166, 122, 50, 165, 121, 66, 174, 135, 95, 113, 89, 59, 125, 105, 78, 157, 141, 121, 156, 143, 128, 121, 111, 101, 86, 80, 74, 82, 81, 77, 84, 85, 82, 80, 78, 73, 81, 71, 61, 138, 125, 112, 146, 135, 123, 113, 103, 93, 87, 79, 70, 83, 77, 69, 86, 82, 76, 71, 73, 67, 56, 57, 53, 40, 35, 27, 74, 59, 35, 133, 106, 59, 137, 103, 45, 180, 176, 163, 134, 139, 143, 94, 100, 105, 154, 154, 149, 174, 149, 112, 158, 116, 51, 156, 116, 47, 153, 118, 60, 207, 180, 146, 237, 214, 198, 207, 180, 166, 156, 131, 119, 174, 153, 145, 148, 131, 125, 125, 110, 107, 93, 85, 79, 86, 84, 79, 74, 74, 71, 59, 57, 53, 76, 68, 58, 137, 125, 112, 143, 133, 122, 133, 124, 114, 106, 98, 89, 86, 81, 74, 87, 85, 78, 84, 85, 78, 75, 76, 71, 50, 49, 43, 40, 30, 15, 95, 75, 44, 132, 103, 57, 183, 183, 175, 108, 116, 122, 142, 151, 158, 165, 169, 168, 177, 156, 122, 155, 112, 50, 159, 118, 51, 122, 89, 47, 213, 197, 179, 237, 224, 226, 220, 191, 188, 164, 135, 131, 183, 159, 155, 156, 137, 132, 125, 108, 104, 120, 111, 104, 78, 76, 69, 80, 80, 77, 45, 44, 40, 91, 85, 77, 175, 165, 154, 157, 147, 137, 155, 147, 138, 107, 100, 92, 87, 83, 77, 103, 102, 96, 88, 88, 79, 78, 79, 73, 59, 59, 59, 41, 36, 33, 59, 46, 31, 104, 81, 46, 188, 191, 189, 100, 108, 116, 135, 144, 153, 170, 175, 178, 187, 167, 136, 166, 120, 59, 173, 123, 55, 134, 93, 44, 117, 95, 80, 194, 182, 188, 199, 171, 164, 170, 142, 133, 185, 161, 151, 189, 171, 159, 134, 119, 106, 117, 107, 95, 102, 98, 89, 84, 84, 79, 38, 38, 34, 125, 121, 113, 210, 201, 192, 160, 152, 142, 146, 139, 130, 93, 89, 82, 83, 80, 75, 94, 93, 88, 104, 104, 94, 85, 87, 81, 73, 75, 78, 55, 53, 55, 62, 55, 48, 76, 56, 26, 189, 194, 194, 90, 96, 105, 127, 134, 144, 175, 180, 185, 174, 156, 133, 166, 123, 68, 178, 123, 53, 159, 109, 47, 97, 68, 44, 168, 154, 152, 168, 144, 126, 137, 114, 94, 186, 166, 148, 216, 202, 183, 160, 149, 129, 123, 113, 98, 120, 114, 105, 115, 114, 109, 50, 50, 47, 150, 147, 140, 194, 187, 178, 155, 149, 140, 123, 118, 111, 91, 88, 83, 84, 83, 79, 84, 84, 80, 95, 95, 85, 86, 87, 81, 84, 87, 89, 73, 73, 73, 79, 74, 64, 73, 55, 24, 189, 192, 193, 93, 95, 103, 152, 154, 163, 185, 188, 192, 119, 110, 98, 136, 106, 66, 173, 124, 58, 167, 116, 50, 103, 72, 39, 147, 132, 120, 145, 125, 103, 167, 149, 127, 189, 174, 155, 226, 216, 200, 180, 172, 157, 141, 131, 117, 126, 117, 107, 117, 114, 109, 71, 71, 68, 154, 152, 147, 186, 181, 174, 149, 144, 136, 114, 110, 104, 87, 85, 80, 80, 80, 76, 72, 73, 70, 80, 80, 72, 99, 100, 94, 100, 101, 99, 90, 88, 81, 97, 89, 69, 94, 73, 34, 194, 196, 196, 108, 107, 112, 168, 167, 172, 186, 186, 188, 105, 109, 109, 99, 89, 67, 156, 119, 62, 167, 122, 55, 100, 74, 34, 115, 106, 88, 138, 123, 103, 198, 185, 169, 190, 180, 169, 172, 165, 159, 145, 140, 140, 154, 143, 134, 146, 136, 125, 103, 100, 95, 71, 71, 70, 152, 152, 149, 179, 175, 170, 137, 133, 127, 130, 128, 122, 110, 109, 105, 85, 86, 83, 91, 93, 91, 95, 96, 90, 109, 110, 104, 115, 116, 111, 100, 96, 80, 97, 85, 53, 117, 95, 47, 197, 197, 197, 132, 129, 136, 172, 167, 174, 184, 178, 181, 130, 137, 142, 78, 83, 77, 140, 120, 88, 155, 125, 77, 115, 94, 52, 130, 120, 93, 143, 131, 116, 230, 221, 211, 242, 236, 230, 145, 138, 137, 135, 130, 130, 131, 121, 112, 121, 112, 101, 108, 104, 95, 95, 88, 75, 144, 134, 118, 168, 159, 146, 152, 147, 138, 112, 108, 101, 87, 85, 80, 71, 72, 68, 87, 88, 87, 105, 104, 99, 112, 109, 99, 120, 110, 93, 103, 86, 54, 121, 96, 48, 136, 104, 48, 203, 203, 204, 146, 146, 160, 168, 164, 178, 191, 182, 188, 168, 170, 172, 78, 86, 90, 126, 125, 126, 138, 126, 113, 138, 121, 82, 96, 80, 37, 154, 143, 133, 173, 163, 155, 162, 152, 141, 140, 132, 117, 113, 106, 88, 113, 106, 90, 101, 101, 92, 105, 101, 87, 112, 90, 58, 171, 143, 104, 156, 138, 109, 148, 141, 126, 135, 130, 118, 109, 105, 97, 78, 76, 72, 79, 79, 77, 94, 93, 94, 101, 91, 82, 107, 83, 55, 125, 88, 45, 151, 108, 55, 144, 104, 46, 214, 215, 215, 163, 166, 180, 164, 167, 184, 183, 184, 194, 176, 182, 186, 94, 102, 105, 96, 96, 102, 156, 149, 145, 148, 137, 111, 106, 93, 61, 129, 116, 105, 118, 105, 95, 114, 102, 89, 116, 105, 89, 102, 91, 73, 115, 110, 98, 86, 91, 88, 101, 103, 95, 144, 128, 102, 118, 96, 64, 68, 56, 32, 128, 120, 105, 133, 126, 115, 75, 69, 61, 60, 56, 51, 58, 56, 53, 71, 70, 65, 102, 93, 78, 116, 94, 64, 143, 112, 68, 150, 116, 64, 140, 110, 54, 212, 211, 205, 178, 184, 192, 167, 175, 189, 173, 181, 193, 176, 184, 188, 124, 131, 133, 86, 88, 96, 141, 139, 143, 153, 148, 141, 135, 128, 111, 104, 90, 80, 77, 64, 55, 134, 121, 108, 124, 111, 96, 129, 117, 100, 147, 143, 133, 85, 92, 93, 92, 96, 93, 150, 139, 120, 132, 117, 93, 117, 109, 92, 107, 99, 86, 75, 68, 58, 64, 59, 52, 44, 41, 39, 65, 62, 60, 86, 69, 40, 133, 105, 59, 155, 119, 62, 160, 120, 54, 154, 115, 45, 151, 111, 46, 199, 192, 180, 187, 189, 187, 171, 176, 181, 174, 179, 185, 177, 182, 184, 144, 149, 152, 86, 90, 99, 119, 121, 132, 122, 124, 130, 137, 136, 135, 144, 134, 126, 70, 59, 51, 129, 118, 108, 108, 97, 86, 145, 134, 123, 184, 176, 168, 116, 118, 118, 73, 75, 73, 131, 119, 103, 137, 124, 105, 134, 129, 118, 89, 86, 78, 51, 49, 44, 52, 51, 50, 47, 49, 52, 90, 90, 93, 121, 91, 60, 163, 118, 68, 171, 121, 64, 164, 113, 52, 158, 111, 50, 149, 107, 46, 165, 156, 146, 195, 193, 187, 179, 178, 175, 177, 173, 172, 181, 181, 180, 152, 157, 160, 99, 103, 111, 131, 135, 146, 171, 175, 185, 103, 105, 111, 93, 90, 87, 80, 77, 73, 93, 90, 86, 122, 118, 116, 178, 173, 173, 191, 182, 177, 150, 148, 148, 100, 100, 101, 89, 78, 66, 87, 77, 63, 60, 61, 57, 46, 52, 54, 38, 46, 51, 24, 33, 41, 46, 57, 69, 60, 71, 83, 108, 100, 75, 144, 125, 82, 144, 123, 76, 128, 109, 61, 127, 113, 69, 120, 105, 63, 117, 120, 124, 195, 200, 200, 177, 178, 176, 178, 169, 168, 181, 179, 179, 138, 144, 147, 83, 87, 91, 150, 153, 159, 245, 247, 250, 219, 222, 225, 133, 140, 144, 134, 141, 147, 149, 156, 164, 176, 182, 192, 190, 196, 208, 194, 192, 197, 168, 172, 181, 125, 133, 143, 110, 109, 109, 61, 62, 62, 35, 49, 58, 34, 54, 68, 49, 70, 87, 58, 81, 102, 61, 85, 110, 58, 84, 111, 69, 99, 122, 72, 101, 119, 78, 104, 120, 69, 96, 112, 59, 92, 112, 55, 90, 115, 79, 105, 133, 175, 197, 213, 174, 183, 192, 176, 172, 177, 177, 177, 182, 140, 146, 150, 109, 112, 113, 211, 211, 209, 253, 252, 247, 252, 253, 252, 208, 224, 232, 124, 143, 157, 114, 132, 149, 124, 141, 162, 116, 133, 156, 122, 133, 152, 104, 124, 148, 68, 93, 119, 68, 87, 104, 60, 82, 101, 52, 84, 111, 50, 84, 110, 51, 85, 115, 56, 93, 125, 56, 94, 131, 51, 91, 130, 43, 96, 135, 51, 104, 141, 59, 108, 142, 48, 97, 132, 43, 97, 137, 42, 95, 132, 41, 89, 135, 96, 137, 168, 144, 168, 188, 168, 174, 188, 178, 182, 192, 165, 170, 174, 165, 166, 164, 246, 245, 237, 253, 251, 241, 227, 231, 228, 110, 136, 153, 60, 88, 111, 53, 80, 105, 49, 76, 105, 49, 75, 107, 48, 72, 101, 45, 79, 115, 42, 81, 120, 46, 81, 113, 42, 82, 116, 38, 86, 125, 46, 90, 125, 46, 89, 126, 43, 87, 128, 42, 89, 132, 46, 93, 139, 46, 94, 137, 50, 96, 137, 55, 96, 135, 53, 94, 134, 51, 95, 139, 45, 90, 133, 29, 91, 141, 29, 87, 130, 59, 102, 134, 131, 153, 176, 166, 179, 191, 132, 136, 137, 194, 189, 181, 254, 250, 242, 241, 245, 245, 141, 159, 175, 61, 94, 127, 50, 84, 118, 50, 84, 119, 51, 85, 121, 49, 83, 120, 50, 84, 116, 47, 86, 117, 42, 84, 117, 39, 82, 115, 34, 79, 113, 35, 83, 120, 39, 86, 125, 38, 85, 125, 42, 89, 130, 45, 92, 134, 56, 103, 145, 62, 103, 142, 59, 101, 142, 56, 102, 146, 50, 99, 144, 46, 94, 140, 51, 103, 149, 48, 111, 162, 30, 94, 140, 34, 85, 124, 73, 106, 136, 128, 148, 167, 128, 136, 143, 215, 213, 209, 255, 253, 249, 187, 198, 205, 66, 93, 118, 54, 91, 128, 50, 88, 125, 52, 90, 127, 52, 90, 127, 46, 83, 121, 45, 82, 115, 43, 82, 113, 41, 81, 112, 36, 80, 113, 39, 83, 117, 40, 86, 123, 40, 89, 131, 43, 92, 134, 46, 95, 138, 59, 108, 150, 62, 110, 152, 64, 109, 147, 59, 108, 149, 54, 108, 154, 50, 105, 152, 70, 123, 167, 83, 137, 182, 52, 114, 165, 35, 99, 147, 31, 86, 130, 41, 83, 122, 66, 95, 126, 128, 145, 164, 224, 229, 234, 240, 245, 247, 124, 143, 153, 58, 92, 114, 49, 87, 123, 56, 94, 131, 54, 92, 129, 44, 82, 119, 44, 82, 119, 47, 83, 119, 46, 84, 119, 43, 83, 119, 43, 86, 123, 44, 88, 127, 44, 90, 131, 45, 97, 141, 54, 106, 150, 58, 110, 154, 54, 105, 150, 46, 97, 141, 43, 95, 140, 36, 91, 138, 51, 108, 158, 73, 130, 178, 85, 138, 182, 76, 125, 169, 50, 110, 162, 35, 98, 149, 29, 89, 138, 35, 86, 133, 44, 83, 126, 78, 106, 138, 202, 219, 233, 211, 228, 234, 97, 126, 140, 65, 104, 126, 54, 94, 129, 48, 87, 124, 58, 97, 133, 48, 87, 123, 40, 80, 116, 45, 82, 119, 47, 84, 122, 48, 87, 126, 47, 89, 130, 46, 89, 132, 51, 97, 140, 39, 92, 138, 39, 93, 139, 48, 102, 148, 47, 101, 147, 39, 93, 139, 28, 85, 133, 40, 101, 153, 67, 129, 182, 67, 126, 176, 46, 98, 142, 51, 96, 139, 50, 108, 161, 35, 97, 147, 32, 92, 143, 33, 88, 141, 41, 88, 138, 46, 84, 125, 104, 133, 159, 170, 197, 211, 64, 100, 119, 54, 97, 121, 52, 94, 128, 53, 95, 130, 61, 103, 139, 58, 100, 135, 54, 96, 131, 45, 83, 120, 42, 79, 118, 41, 80, 120, 46, 88, 130, 49, 92, 135, 46, 92, 136, 42, 95, 139, 40, 93, 138, 39, 92, 136, 37, 90, 135, 40, 93, 138, 44, 102, 151, 63, 125, 178, 47, 110, 164, 31, 90, 140, 15, 60, 103, 51, 93, 136, 68, 124, 177, 42, 100, 148, 31, 88, 137, 38, 91, 146, 37, 87, 139, 43, 89, 132, 42, 79, 113, 71, 107, 133, 49, 89, 114, 31, 77, 105, 27, 71, 105, 38, 82, 117, 49, 93, 128, 56, 100, 135, 58, 102, 137, 53, 92, 128, 56, 94, 131, 60, 99, 137, 57, 99, 139, 53, 97, 138, 50, 95, 137, 45, 94, 136, 39, 88, 131, 33, 83, 125, 42, 91, 133, 62, 112, 154, 79, 132, 179, 73, 131, 181, 56, 116, 168, 38, 97, 146, 13, 64, 108, 40, 85, 127, 61, 116, 168, 49, 102, 148, 35, 85, 132, 43, 91, 143, 39, 90, 139, 42, 92, 134, 44, 88, 125, 40, 81, 112, 42, 85, 115, 27, 72, 104, 23, 67, 102, 30, 74, 109, 27, 71, 106, 29, 73, 108, 36, 80, 115, 47, 86, 120, 56, 95, 128, 62, 101, 135, 66, 109, 144, 75, 119, 156, 69, 113, 152, 49, 95, 134, 43, 88, 127, 43, 88, 127, 60, 105, 144, 85, 130, 170, 109, 156, 197, 93, 145, 190, 60, 115, 164, 26, 82, 130, 29, 82, 126, 20, 64, 107, 54, 107, 160, 56, 105, 149, 45, 89, 132, 43, 86, 134, 40, 89, 134, 40, 92, 132, 40, 87, 123, 38, 81, 115, 36, 79, 114, 26, 69, 105, 22, 66, 101, 29, 73, 108, 25, 69, 104, 29, 73, 108, 19, 63, 98, 18, 58, 89, 32, 70, 100, 47, 87, 118, 61, 104, 137, 74, 119, 152, 66, 111, 145, 53, 96, 131, 52, 95, 130, 45, 87, 123, 67, 109, 145, 89, 131, 167, 105, 146, 182, 89, 135, 175, 48, 99, 145, 24, 77, 124, 34, 84, 129, 21, 67, 110], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284462321360}, {\"format\": \"raw\", \"value\": [160, 37, 13, 185, 49, 11, 209, 57, 14, 217, 58, 10, 230, 66, 9, 246, 78, 10, 249, 80, 5, 246, 81, 2, 248, 86, 3, 243, 82, 3, 230, 73, 1, 221, 66, 2, 218, 65, 4, 221, 67, 6, 216, 67, 5, 199, 56, 0, 188, 50, 1, 187, 50, 0, 184, 64, 35, 180, 115, 86, 166, 52, 22, 144, 56, 23, 121, 50, 29, 139, 39, 8, 106, 22, 13, 102, 34, 27, 102, 46, 39, 79, 36, 29, 94, 29, 19, 101, 18, 8, 91, 21, 6, 94, 19, 5, 225, 67, 13, 239, 72, 12, 242, 77, 10, 230, 68, 4, 232, 67, 7, 245, 74, 8, 243, 72, 3, 235, 66, 0, 237, 68, 4, 230, 64, 2, 216, 57, 1, 205, 52, 1, 201, 50, 2, 203, 54, 4, 200, 55, 4, 186, 46, 1, 175, 41, 1, 171, 42, 1, 161, 39, 16, 127, 41, 19, 142, 40, 7, 141, 35, 6, 122, 30, 6, 135, 33, 7, 118, 34, 33, 82, 46, 46, 37, 30, 23, 52, 27, 22, 95, 28, 19, 107, 21, 8, 97, 22, 4, 100, 18, 6, 252, 72, 7, 249, 68, 4, 241, 72, 3, 220, 62, 0, 217, 58, 4, 226, 61, 4, 223, 56, 1, 214, 49, 0, 213, 48, 4, 207, 45, 4, 195, 43, 4, 184, 40, 4, 179, 38, 4, 182, 42, 6, 179, 43, 5, 167, 38, 3, 159, 34, 4, 152, 35, 3, 148, 30, 12, 129, 28, 9, 128, 35, 4, 140, 33, 7, 128, 31, 6, 114, 34, 10, 87, 48, 40, 40, 34, 35, 4, 13, 13, 38, 14, 12, 99, 21, 15, 115, 20, 6, 105, 19, 3, 105, 17, 6, 233, 56, 1, 225, 54, 3, 222, 61, 8, 211, 60, 11, 211, 62, 18, 203, 48, 4, 200, 43, 3, 192, 36, 3, 187, 35, 5, 183, 35, 6, 174, 34, 8, 164, 32, 7, 160, 31, 8, 165, 33, 9, 160, 34, 6, 153, 32, 6, 145, 29, 7, 141, 30, 5, 140, 27, 10, 138, 29, 9, 125, 32, 4, 125, 28, 10, 127, 29, 16, 105, 37, 23, 59, 42, 30, 37, 18, 22, 26, 11, 17, 55, 15, 14, 112, 22, 15, 120, 19, 6, 112, 16, 5, 109, 17, 8, 207, 57, 12, 195, 57, 19, 207, 66, 29, 201, 59, 26, 190, 52, 23, 180, 36, 6, 179, 32, 7, 171, 27, 8, 163, 28, 7, 159, 29, 8, 153, 28, 9, 146, 26, 8, 145, 26, 9, 151, 26, 10, 147, 28, 7, 141, 30, 8, 135, 28, 9, 136, 28, 7, 131, 28, 8, 135, 28, 7, 129, 28, 8, 122, 48, 37, 132, 67, 64, 90, 42, 39, 58, 25, 16, 61, 18, 16, 48, 13, 14, 86, 25, 21, 117, 27, 14, 120, 31, 15, 114, 19, 13, 109, 17, 9, 182, 59, 24, 171, 58, 30, 170, 47, 22, 162, 33, 12, 153, 26, 9, 156, 26, 6, 159, 25, 9, 151, 22, 8, 144, 23, 5, 141, 25, 5, 140, 26, 9, 138, 25, 10, 139, 24, 11, 141, 24, 10, 138, 27, 7, 138, 31, 9, 135, 29, 10, 140, 30, 11, 134, 33, 11, 138, 30, 7, 140, 33, 20, 137, 93, 85, 102, 94, 93, 69, 60, 59, 75, 41, 34, 62, 27, 14, 67, 30, 19, 116, 44, 32, 129, 43, 23, 128, 45, 27, 112, 24, 16, 110, 19, 9, 141, 34, 12, 136, 28, 11, 136, 23, 10, 134, 20, 7, 136, 22, 8, 134, 23, 8, 140, 22, 10, 133, 21, 7, 135, 22, 6, 137, 22, 5, 139, 25, 10, 141, 26, 14, 143, 24, 13, 146, 25, 12, 142, 29, 10, 145, 35, 12, 145, 32, 9, 145, 31, 14, 138, 35, 14, 143, 30, 7, 142, 51, 37, 107, 89, 86, 47, 55, 60, 33, 37, 40, 72, 56, 53, 75, 40, 28, 108, 43, 28, 127, 45, 28, 132, 36, 20, 132, 30, 16, 111, 23, 6, 112, 21, 7, 118, 17, 3, 125, 17, 6, 128, 16, 6, 129, 18, 7, 136, 22, 11, 131, 23, 10, 138, 22, 12, 132, 22, 9, 136, 24, 9, 140, 23, 8, 144, 26, 12, 147, 27, 14, 150, 25, 14, 158, 27, 18, 154, 29, 16, 153, 39, 19, 146, 40, 16, 149, 45, 21, 147, 51, 26, 148, 48, 22, 128, 65, 49, 66, 64, 62, 13, 18, 20, 17, 11, 10, 80, 34, 30, 117, 37, 26, 128, 31, 16, 122, 32, 13, 123, 25, 9, 128, 22, 8, 114, 22, 4, 112, 21, 7, 115, 17, 7, 126, 18, 10, 132, 18, 9, 133, 18, 8, 139, 21, 11, 135, 22, 10, 143, 23, 14, 137, 23, 11, 139, 25, 13, 145, 24, 12, 149, 28, 14, 152, 30, 15, 148, 37, 19, 154, 56, 36, 163, 51, 34, 170, 59, 40, 158, 59, 36, 162, 58, 32, 157, 55, 34, 148, 54, 34, 115, 61, 51, 44, 40, 43, 14, 17, 15, 30, 16, 9, 105, 26, 20, 139, 25, 12, 136, 24, 9, 126, 27, 10, 119, 26, 8, 122, 23, 8, 116, 21, 8, 111, 20, 8, 118, 19, 12, 128, 18, 12, 136, 18, 11, 136, 18, 8, 141, 21, 12, 136, 20, 10, 145, 22, 14, 141, 24, 13, 141, 24, 14, 147, 25, 14, 154, 32, 20, 165, 49, 34, 157, 62, 39, 154, 76, 49, 162, 57, 40, 167, 52, 38, 155, 49, 32, 147, 46, 27, 145, 50, 39, 138, 58, 50, 99, 56, 54, 56, 49, 59, 46, 48, 52, 55, 44, 38, 109, 41, 35, 124, 35, 21, 122, 25, 11, 126, 25, 12, 115, 25, 6, 116, 24, 9, 117, 20, 11, 110, 20, 10, 125, 20, 12, 132, 18, 11, 139, 19, 11, 137, 18, 9, 142, 21, 12, 136, 21, 10, 144, 21, 13, 140, 23, 13, 139, 25, 13, 144, 25, 16, 150, 36, 27, 153, 53, 40, 131, 49, 32, 139, 66, 50, 144, 62, 50, 152, 74, 63, 166, 104, 88, 186, 137, 119, 211, 166, 161, 214, 184, 180, 128, 124, 121, 92, 104, 113, 69, 75, 84, 42, 33, 34, 85, 56, 50, 95, 61, 49, 99, 38, 29, 115, 25, 17, 112, 24, 9, 111, 25, 10, 113, 18, 12, 107, 19, 10, 133, 21, 9, 137, 18, 10, 142, 20, 14, 138, 19, 11, 141, 24, 14, 136, 24, 12, 142, 22, 13, 138, 24, 12, 137, 25, 12, 143, 29, 18, 136, 31, 24, 132, 48, 39, 142, 85, 77, 182, 151, 147, 201, 178, 175, 203, 190, 186, 210, 205, 200, 206, 205, 200, 207, 202, 210, 192, 197, 202, 162, 178, 177, 189, 208, 213, 146, 152, 158, 42, 22, 28, 27, 24, 19, 40, 37, 34, 103, 70, 70, 114, 40, 37, 109, 21, 10, 106, 22, 9, 108, 17, 11, 104, 17, 9, 140, 20, 8, 139, 20, 10, 143, 22, 15, 139, 21, 13, 143, 24, 16, 140, 24, 14, 138, 25, 13, 137, 26, 14, 135, 25, 12, 133, 32, 24, 144, 66, 62, 164, 112, 108, 171, 144, 142, 160, 155, 162, 137, 140, 147, 115, 117, 125, 106, 100, 110, 93, 88, 94, 75, 71, 84, 59, 61, 74, 111, 117, 126, 220, 232, 241, 201, 213, 215, 95, 78, 84, 13, 15, 12, 7, 10, 9, 62, 50, 52, 116, 70, 73, 99, 26, 25, 101, 21, 13, 105, 17, 9, 100, 16, 8, 144, 20, 11, 138, 22, 11, 143, 25, 15, 140, 22, 14, 146, 23, 17, 146, 23, 16, 130, 25, 12, 135, 26, 14, 130, 26, 20, 145, 72, 68, 140, 103, 103, 110, 91, 93, 94, 80, 86, 92, 86, 95, 49, 52, 61, 19, 18, 25, 29, 17, 22, 50, 34, 35, 25, 15, 17, 18, 16, 23, 120, 124, 137, 209, 221, 235, 210, 224, 235, 157, 155, 167, 38, 36, 42, 6, 7, 7, 19, 22, 23, 68, 59, 66, 69, 33, 40, 82, 19, 17, 99, 18, 9, 95, 16, 7, 145, 24, 15, 139, 23, 13, 146, 27, 18, 142, 22, 14, 144, 24, 16, 142, 25, 18, 121, 19, 11, 128, 21, 18, 133, 55, 54, 127, 85, 83, 84, 58, 59, 68, 41, 46, 86, 61, 68, 82, 78, 83, 46, 50, 55, 22, 24, 27, 19, 11, 12, 50, 43, 39, 30, 30, 28, 65, 73, 76, 175, 191, 200, 201, 216, 232, 205, 209, 231, 203, 205, 224, 102, 103, 115, 16, 14, 22, 18, 16, 19, 22, 23, 26, 35, 27, 31, 56, 22, 22, 79, 20, 13, 88, 18, 8, 143, 26, 16, 139, 22, 13, 148, 26, 19, 144, 23, 14, 138, 25, 14, 132, 37, 30, 139, 60, 57, 131, 52, 55, 117, 76, 79, 66, 52, 53, 72, 56, 57, 86, 59, 60, 106, 80, 82, 78, 77, 78, 40, 46, 50, 34, 38, 41, 36, 35, 35, 70, 73, 71, 115, 124, 124, 182, 196, 200, 203, 223, 231, 197, 216, 230, 205, 217, 236, 195, 210, 221, 108, 118, 126, 61, 57, 68, 37, 21, 26, 18, 14, 14, 24, 31, 32, 79, 71, 73, 100, 62, 63, 83, 17, 9, 142, 25, 17, 139, 20, 14, 147, 25, 19, 144, 23, 17, 133, 33, 24, 114, 53, 47, 132, 96, 93, 121, 92, 92, 81, 73, 79, 89, 93, 98, 60, 62, 60, 69, 66, 61, 85, 81, 76, 68, 71, 71, 83, 90, 94, 155, 162, 166, 192, 196, 198, 219, 223, 226, 237, 245, 250, 235, 245, 252, 215, 227, 237, 215, 228, 240, 211, 222, 231, 114, 121, 124, 48, 37, 42, 93, 59, 74, 53, 17, 28, 20, 9, 12, 65, 72, 76, 139, 140, 149, 143, 117, 126, 84, 19, 17, 143, 25, 18, 141, 21, 16, 142, 24, 18, 137, 26, 21, 116, 40, 36, 69, 44, 42, 58, 53, 56, 67, 69, 72, 81, 88, 96, 75, 82, 88, 29, 37, 36, 28, 41, 36, 36, 49, 45, 25, 32, 34, 140, 148, 154, 242, 251, 255, 236, 246, 250, 235, 242, 249, 227, 233, 244, 220, 226, 237, 219, 225, 237, 223, 226, 238, 149, 139, 150, 58, 31, 39, 57, 11, 21, 84, 25, 46, 78, 40, 59, 78, 67, 77, 133, 133, 142, 161, 162, 174, 167, 151, 163, 91, 34, 38, 143, 22, 17, 140, 19, 16, 136, 22, 16, 134, 38, 34, 141, 93, 92, 71, 70, 73, 45, 46, 60, 52, 54, 66, 67, 75, 84, 33, 38, 44, 23, 24, 28, 22, 27, 33, 47, 56, 62, 41, 49, 55, 155, 163, 174, 217, 227, 240, 199, 214, 225, 190, 205, 217, 191, 203, 217, 208, 218, 231, 220, 229, 239, 223, 228, 238, 173, 163, 177, 103, 74, 86, 93, 57, 69, 115, 90, 106, 135, 128, 146, 149, 149, 164, 152, 151, 164, 148, 150, 161, 165, 160, 169, 89, 51, 55, 143, 19, 13, 140, 15, 10, 126, 38, 32, 181, 124, 125, 189, 175, 180, 76, 90, 98, 33, 36, 53, 43, 42, 56, 57, 63, 72, 21, 23, 28, 16, 11, 14, 23, 21, 27, 57, 64, 73, 66, 79, 89, 158, 170, 185, 194, 208, 224, 182, 199, 213, 179, 197, 213, 196, 211, 228, 201, 214, 227, 194, 206, 215, 206, 217, 225, 222, 227, 242, 179, 177, 192, 151, 152, 165, 156, 168, 180, 149, 167, 181, 151, 162, 176, 150, 154, 166, 146, 151, 159, 136, 136, 141, 66, 42, 42, 140, 18, 12, 133, 10, 7, 154, 101, 101, 234, 220, 229, 181, 190, 201, 90, 111, 123, 38, 47, 62, 42, 46, 57, 52, 57, 65, 11, 10, 15, 11, 9, 9, 11, 14, 15, 20, 31, 38, 49, 66, 79, 160, 177, 191, 186, 204, 218, 176, 194, 208, 185, 202, 219, 185, 198, 216, 115, 124, 138, 69, 79, 88, 90, 102, 109, 161, 172, 184, 196, 211, 228, 183, 200, 218, 170, 184, 201, 160, 177, 191, 153, 169, 181, 147, 156, 166, 136, 140, 147, 77, 74, 77, 38, 17, 14, 130, 14, 13, 128, 20, 24, 163, 132, 139, 163, 165, 179, 139, 150, 162, 106, 128, 141, 45, 55, 69, 46, 52, 61, 28, 30, 35, 3, 3, 4, 9, 10, 11, 15, 22, 27, 30, 45, 54, 54, 72, 86, 162, 180, 194, 180, 198, 212, 172, 190, 204, 190, 205, 219, 113, 123, 136, 21, 25, 36, 20, 26, 32, 21, 30, 34, 48, 56, 64, 149, 163, 177, 187, 202, 221, 171, 184, 204, 142, 158, 173, 133, 147, 159, 128, 136, 144, 67, 68, 73, 21, 13, 15, 39, 17, 13, 124, 10, 9, 132, 35, 39, 103, 83, 91, 26, 33, 49, 72, 83, 96, 108, 130, 143, 52, 62, 76, 48, 53, 62, 18, 19, 21, 7, 7, 7, 11, 16, 21, 59, 72, 81, 90, 108, 121, 99, 117, 131, 165, 183, 197, 176, 194, 208, 177, 195, 209, 169, 183, 193, 42, 47, 56, 29, 30, 38, 47, 49, 55, 38, 43, 46, 14, 20, 25, 70, 79, 89, 149, 161, 178, 136, 148, 169, 117, 132, 149, 117, 129, 141, 60, 64, 72, 14, 10, 14, 21, 9, 8, 48, 24, 20, 121, 10, 5, 124, 33, 34, 73, 55, 59, 30, 35, 48, 59, 70, 83, 114, 136, 149, 68, 78, 92, 31, 36, 45, 13, 15, 15, 14, 17, 19, 24, 34, 42, 72, 88, 100, 79, 97, 111, 108, 126, 140, 187, 205, 219, 187, 205, 219, 191, 208, 222, 139, 152, 160, 27, 32, 38, 43, 43, 51, 30, 32, 37, 27, 31, 35, 28, 32, 36, 27, 31, 39, 108, 117, 130, 132, 145, 164, 123, 138, 155, 89, 99, 110, 22, 23, 29, 21, 12, 12, 42, 25, 22, 59, 33, 30, 109, 10, 7, 102, 21, 23, 71, 54, 58, 63, 65, 77, 60, 71, 84, 113, 136, 148, 77, 87, 101, 28, 33, 42, 16, 21, 22, 31, 39, 43, 48, 63, 74, 71, 87, 101, 70, 86, 100, 136, 154, 168, 189, 207, 221, 179, 197, 211, 180, 198, 212, 116, 129, 137, 31, 37, 43, 54, 56, 64, 53, 55, 63, 41, 44, 52, 27, 28, 35, 14, 15, 21, 72, 77, 86, 133, 147, 162, 124, 139, 154, 60, 67, 78, 18, 14, 19, 34, 20, 18, 50, 28, 24, 59, 31, 28, 87, 7, 9, 81, 14, 21, 61, 47, 55, 60, 62, 76, 58, 69, 82, 105, 128, 140, 75, 86, 101, 21, 28, 37, 20, 30, 33, 46, 60, 67, 76, 94, 108, 96, 111, 127, 97, 111, 126, 145, 162, 176, 164, 182, 195, 163, 180, 194, 170, 188, 201, 113, 127, 135, 32, 41, 48, 57, 60, 70, 71, 75, 86, 49, 53, 65, 37, 35, 46, 17, 15, 21, 41, 44, 50, 108, 122, 131, 96, 111, 123, 33, 38, 49, 12, 7, 11, 29, 13, 10, 40, 16, 11, 50, 22, 20, 73, 11, 11, 73, 17, 23, 64, 39, 49, 60, 59, 73, 57, 70, 87, 95, 117, 132, 87, 104, 120, 47, 61, 75, 61, 81, 93, 98, 121, 134, 137, 159, 177, 165, 183, 200, 169, 185, 200, 176, 195, 207, 183, 201, 212, 182, 199, 213, 182, 198, 214, 124, 136, 148, 34, 42, 53, 54, 60, 72, 96, 102, 113, 92, 98, 110, 51, 52, 64, 27, 28, 34, 17, 21, 24, 70, 79, 85, 59, 69, 76, 12, 16, 22, 6, 3, 7, 18, 7, 9, 29, 12, 13, 40, 22, 22, 73, 19, 15, 73, 20, 22, 69, 29, 37, 78, 67, 78, 65, 73, 87, 89, 103, 115, 69, 85, 96, 47, 60, 72, 52, 69, 82, 60, 80, 93, 74, 91, 105, 86, 100, 114, 91, 104, 119, 96, 113, 125, 98, 113, 126, 96, 109, 123, 98, 109, 124, 83, 89, 102, 32, 37, 48, 60, 65, 76, 59, 64, 75, 62, 66, 78, 29, 31, 41, 20, 23, 27, 4, 8, 9, 17, 20, 24, 10, 14, 16, 3, 5, 6, 7, 6, 8, 10, 6, 10, 17, 11, 15, 33, 24, 25, 75, 23, 21, 83, 28, 31, 72, 29, 35, 54, 37, 43, 45, 44, 50, 39, 44, 48, 15, 22, 25, 4, 7, 12, 3, 10, 14, 2, 10, 14, 5, 12, 17, 7, 12, 17, 7, 13, 20, 8, 16, 24, 10, 17, 26, 11, 16, 25, 11, 15, 24, 13, 15, 20, 8, 9, 13, 66, 67, 74, 67, 68, 78, 47, 48, 59, 56, 56, 65, 15, 16, 18, 2, 4, 3, 2, 3, 5, 1, 3, 4, 3, 4, 3, 6, 6, 5, 10, 9, 9, 15, 14, 13, 32, 25, 26, 80, 33, 33, 89, 37, 40, 81, 39, 44, 47, 32, 37, 21, 23, 30, 10, 18, 23, 16, 25, 30, 25, 32, 37, 14, 23, 28, 10, 21, 25, 14, 23, 28, 14, 23, 28, 14, 23, 27, 14, 21, 24, 14, 19, 23, 12, 15, 19, 10, 11, 15, 9, 10, 9, 6, 7, 6, 23, 24, 28, 62, 62, 71, 72, 71, 83, 42, 41, 47, 7, 8, 8, 3, 4, 2, 4, 5, 5, 5, 5, 5, 5, 6, 4, 7, 9, 6, 11, 14, 11, 21, 24, 21, 33, 29, 28, 73, 35, 37, 79, 37, 41, 73, 41, 48, 55, 50, 59, 46, 60, 73, 47, 67, 79, 59, 81, 92, 58, 77, 89, 26, 44, 56, 17, 36, 47, 25, 45, 56, 28, 48, 59, 31, 49, 57, 32, 44, 48, 29, 39, 43, 28, 35, 40, 24, 29, 35, 21, 27, 27, 16, 21, 21, 12, 16, 21, 20, 23, 33, 22, 25, 37, 8, 10, 16, 6, 9, 8, 8, 11, 8, 7, 9, 9, 8, 10, 10, 8, 11, 10, 11, 14, 13, 15, 20, 18, 27, 31, 29, 31, 30, 28, 69, 42, 44, 72, 42, 49, 76, 59, 70, 78, 87, 101, 88, 109, 128, 83, 111, 128, 72, 102, 118, 56, 82, 99, 32, 55, 71, 38, 62, 78, 43, 69, 84, 42, 71, 85, 47, 74, 87, 51, 72, 83, 50, 70, 81, 49, 67, 79, 44, 59, 71, 38, 51, 60, 30, 43, 49, 28, 41, 49, 34, 47, 58, 34, 44, 56, 19, 24, 32, 12, 18, 19, 14, 20, 19, 16, 22, 24, 15, 21, 24, 13, 19, 21, 18, 22, 25, 26, 28, 31, 30, 32, 34, 29, 30, 28], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284452962512}, {\"format\": \"raw\", \"value\": [23, 19, 23, 19, 21, 28, 21, 16, 19, 65, 47, 40, 164, 131, 113, 188, 147, 115, 183, 147, 109, 178, 142, 116, 170, 135, 113, 172, 137, 103, 186, 144, 106, 186, 142, 105, 184, 141, 105, 183, 140, 105, 182, 140, 105, 183, 143, 107, 180, 140, 106, 164, 126, 99, 127, 96, 76, 92, 73, 58, 107, 95, 84, 110, 93, 86, 153, 130, 114, 194, 164, 137, 195, 155, 124, 201, 156, 125, 197, 155, 124, 198, 157, 125, 201, 158, 127, 200, 155, 125, 199, 152, 122, 197, 151, 120, 23, 20, 24, 19, 20, 27, 21, 17, 20, 46, 31, 26, 153, 122, 106, 202, 161, 130, 191, 155, 118, 178, 146, 124, 164, 138, 125, 158, 136, 114, 169, 139, 109, 183, 149, 117, 186, 152, 120, 184, 150, 118, 180, 146, 114, 178, 151, 121, 180, 159, 133, 173, 150, 131, 138, 117, 106, 86, 73, 68, 74, 65, 62, 106, 88, 81, 180, 156, 140, 206, 175, 150, 207, 168, 138, 213, 169, 140, 208, 171, 137, 206, 173, 136, 207, 172, 136, 205, 168, 133, 204, 164, 129, 202, 163, 128, 23, 20, 24, 20, 20, 26, 23, 20, 23, 31, 21, 18, 127, 102, 88, 200, 162, 131, 185, 151, 116, 168, 140, 123, 159, 141, 139, 158, 149, 141, 154, 136, 116, 162, 139, 116, 178, 154, 129, 178, 153, 127, 179, 152, 125, 178, 159, 132, 181, 166, 142, 190, 171, 154, 182, 161, 152, 125, 109, 105, 71, 58, 55, 114, 97, 89, 197, 177, 159, 209, 183, 158, 213, 179, 151, 216, 178, 151, 213, 177, 146, 211, 178, 142, 212, 177, 142, 211, 173, 139, 208, 169, 136, 206, 166, 132, 23, 20, 24, 21, 20, 25, 24, 21, 25, 23, 17, 18, 99, 79, 69, 189, 153, 124, 175, 140, 106, 160, 130, 115, 168, 151, 156, 168, 164, 166, 166, 157, 146, 149, 135, 120, 170, 153, 137, 186, 166, 148, 191, 169, 149, 195, 176, 151, 195, 176, 150, 200, 175, 156, 188, 161, 148, 141, 118, 109, 99, 82, 74, 146, 133, 122, 210, 196, 177, 214, 195, 169, 213, 189, 161, 212, 183, 157, 212, 180, 152, 213, 179, 149, 217, 179, 150, 217, 177, 148, 215, 173, 145, 214, 171, 142, 25, 21, 25, 23, 20, 24, 23, 21, 25, 21, 19, 23, 72, 56, 51, 170, 137, 109, 165, 130, 96, 151, 119, 104, 175, 156, 161, 183, 178, 184, 185, 179, 178, 155, 146, 141, 146, 132, 124, 157, 139, 128, 169, 148, 134, 188, 167, 147, 197, 175, 151, 196, 169, 150, 178, 152, 137, 141, 120, 108, 121, 109, 96, 172, 167, 152, 211, 206, 183, 219, 210, 181, 221, 209, 179, 217, 201, 174, 217, 195, 168, 217, 191, 164, 214, 186, 160, 212, 182, 156, 209, 177, 152, 206, 172, 147, 26, 22, 26, 27, 22, 26, 26, 23, 27, 23, 22, 28, 49, 38, 35, 143, 115, 89, 164, 130, 95, 154, 120, 102, 169, 146, 150, 194, 185, 193, 200, 195, 199, 166, 158, 159, 130, 118, 116, 125, 108, 102, 128, 107, 98, 151, 132, 118, 165, 146, 130, 165, 143, 131, 148, 129, 119, 143, 132, 122, 147, 143, 132, 182, 183, 167, 188, 190, 166, 201, 199, 170, 212, 207, 178, 217, 209, 183, 213, 204, 179, 219, 209, 183, 220, 209, 183, 215, 202, 177, 215, 199, 175, 211, 194, 169, 30, 24, 26, 26, 19, 22, 27, 21, 25, 25, 20, 26, 37, 30, 29, 125, 113, 92, 180, 161, 128, 171, 148, 123, 169, 151, 147, 197, 186, 195, 202, 194, 199, 179, 170, 171, 139, 128, 126, 113, 98, 94, 122, 105, 99, 130, 113, 106, 119, 104, 96, 133, 116, 109, 122, 107, 101, 140, 128, 122, 185, 178, 172, 203, 202, 192, 191, 192, 170, 201, 197, 176, 215, 206, 195, 218, 207, 196, 215, 209, 197, 219, 215, 202, 220, 216, 197, 218, 214, 191, 220, 215, 191, 224, 218, 194, 94, 88, 77, 48, 41, 33, 31, 24, 17, 36, 29, 25, 100, 96, 88, 175, 174, 154, 193, 186, 155, 168, 156, 126, 163, 149, 140, 192, 181, 190, 198, 189, 193, 195, 186, 185, 174, 164, 163, 145, 132, 129, 142, 129, 123, 132, 118, 113, 106, 92, 88, 121, 107, 103, 122, 108, 104, 139, 124, 121, 192, 180, 177, 209, 204, 198, 189, 187, 165, 213, 206, 189, 242, 230, 228, 237, 224, 219, 239, 231, 224, 232, 228, 218, 208, 205, 186, 213, 211, 187, 222, 220, 196, 229, 226, 205, 180, 177, 149, 158, 153, 128, 114, 109, 86, 122, 117, 96, 177, 175, 155, 190, 189, 167, 190, 183, 153, 160, 147, 119, 133, 120, 111, 173, 161, 168, 197, 188, 191, 200, 192, 191, 194, 184, 183, 185, 173, 170, 167, 154, 148, 146, 131, 127, 129, 115, 112, 129, 115, 112, 133, 119, 116, 141, 127, 124, 177, 166, 163, 201, 197, 187, 189, 188, 162, 220, 216, 193, 241, 233, 223, 235, 226, 213, 232, 227, 207, 213, 211, 187, 189, 188, 157, 199, 198, 166, 225, 224, 196, 234, 232, 210, 197, 194, 161, 192, 188, 158, 178, 175, 146, 186, 182, 155, 193, 191, 167, 195, 194, 169, 197, 190, 159, 157, 144, 117, 128, 115, 104, 163, 152, 155, 185, 177, 179, 191, 182, 181, 193, 183, 182, 195, 182, 180, 178, 164, 159, 151, 138, 135, 114, 102, 100, 129, 118, 116, 131, 119, 117, 134, 123, 121, 170, 160, 158, 194, 189, 178, 208, 208, 178, 234, 233, 204, 236, 232, 216, 240, 235, 214, 235, 234, 203, 201, 203, 167, 185, 187, 147, 187, 189, 150, 208, 209, 176, 235, 235, 207, 202, 199, 170, 196, 192, 165, 187, 183, 158, 192, 187, 165, 200, 198, 175, 205, 205, 176, 197, 191, 160, 151, 138, 112, 149, 136, 123, 175, 165, 164, 184, 176, 177, 189, 181, 180, 193, 184, 182, 187, 175, 172, 168, 154, 149, 136, 124, 121, 117, 107, 106, 128, 118, 116, 128, 119, 117, 129, 120, 118, 167, 158, 156, 181, 176, 166, 205, 205, 175, 240, 240, 209, 243, 243, 222, 243, 244, 216, 238, 242, 205, 206, 212, 169, 186, 192, 145, 187, 192, 147, 193, 198, 159, 221, 224, 186, 205, 201, 172, 205, 201, 174, 197, 193, 169, 192, 187, 166, 203, 201, 176, 208, 209, 176, 194, 188, 157, 160, 146, 122, 168, 155, 141, 191, 182, 177, 193, 185, 185, 191, 183, 182, 193, 183, 182, 172, 159, 157, 146, 132, 127, 119, 107, 104, 124, 115, 115, 142, 133, 132, 133, 124, 123, 135, 126, 125, 167, 158, 159, 176, 170, 164, 191, 189, 163, 234, 235, 206, 243, 246, 224, 241, 246, 217, 236, 242, 205, 215, 222, 181, 186, 194, 146, 184, 192, 142, 185, 192, 147, 196, 202, 156, 206, 203, 167, 204, 201, 167, 200, 197, 165, 193, 189, 160, 197, 196, 165, 199, 198, 164, 191, 183, 153, 180, 165, 143, 172, 159, 145, 179, 170, 163, 183, 176, 174, 173, 165, 164, 174, 164, 163, 174, 162, 159, 152, 138, 133, 131, 120, 118, 141, 133, 134, 166, 159, 159, 142, 135, 135, 154, 146, 146, 169, 161, 163, 172, 165, 163, 191, 189, 168, 230, 231, 205, 240, 244, 223, 241, 248, 220, 239, 247, 214, 228, 234, 199, 200, 208, 163, 186, 195, 144, 184, 193, 144, 192, 199, 152, 210, 208, 169, 202, 202, 162, 198, 196, 160, 191, 185, 155, 201, 193, 163, 180, 167, 136, 177, 156, 131, 202, 185, 164, 171, 161, 146, 154, 145, 136, 142, 135, 132, 142, 135, 133, 168, 161, 159, 168, 158, 158, 147, 137, 135, 156, 143, 146, 175, 164, 167, 169, 164, 162, 150, 149, 144, 164, 162, 158, 158, 153, 152, 160, 157, 152, 197, 195, 176, 230, 228, 203, 241, 242, 215, 241, 247, 216, 244, 249, 221, 242, 245, 218, 226, 232, 197, 191, 199, 159, 195, 204, 162, 215, 222, 182, 211, 210, 174, 201, 204, 164, 199, 197, 162, 192, 182, 157, 207, 191, 168, 170, 142, 120, 161, 125, 109, 215, 193, 178, 189, 181, 166, 186, 177, 167, 173, 166, 161, 172, 167, 163, 190, 184, 182, 177, 170, 171, 137, 130, 132, 127, 114, 120, 180, 165, 169, 174, 170, 163, 150, 152, 140, 160, 158, 149, 175, 171, 166, 176, 174, 164, 193, 189, 170, 236, 231, 204, 245, 242, 211, 242, 244, 213, 243, 245, 218, 251, 251, 228, 239, 242, 214, 201, 207, 176, 212, 221, 187, 225, 233, 199, 211, 212, 175, 196, 200, 160, 197, 197, 161, 193, 185, 159, 209, 189, 170, 181, 145, 132, 154, 112, 104, 217, 192, 183, 206, 199, 188, 197, 190, 182, 195, 189, 184, 185, 180, 176, 170, 164, 162, 173, 167, 168, 166, 160, 163, 152, 137, 141, 163, 146, 145, 184, 176, 165, 166, 162, 146, 152, 145, 133, 192, 184, 175, 181, 177, 165, 175, 168, 150, 204, 195, 169, 238, 232, 202, 243, 241, 212, 244, 245, 217, 247, 249, 221, 223, 228, 196, 213, 221, 186, 226, 236, 199, 226, 235, 199, 214, 216, 179, 194, 199, 159, 180, 182, 146, 181, 174, 148, 197, 176, 161, 196, 155, 151, 155, 110, 109, 198, 173, 168, 214, 208, 199, 192, 186, 181, 174, 168, 164, 183, 178, 174, 173, 168, 165, 161, 155, 156, 174, 167, 170, 178, 164, 166, 128, 110, 105, 164, 150, 136, 189, 177, 159, 147, 134, 119, 167, 154, 143, 180, 171, 158, 156, 144, 126, 118, 104, 80, 157, 145, 118, 215, 209, 183, 239, 238, 209, 235, 237, 205, 206, 210, 175, 214, 221, 183, 234, 243, 201, 228, 237, 197, 215, 219, 181, 198, 206, 164, 166, 169, 133, 163, 158, 131, 180, 163, 149, 202, 167, 165, 190, 149, 151, 185, 162, 159, 207, 202, 194, 210, 205, 199, 205, 200, 196, 214, 209, 205, 193, 188, 185, 174, 168, 168, 176, 170, 172, 173, 161, 162, 129, 112, 104, 137, 120, 105, 191, 173, 155, 153, 135, 119, 163, 147, 134, 200, 186, 173, 171, 155, 136, 135, 115, 92, 116, 98, 75, 144, 132, 111, 184, 178, 152, 193, 188, 158, 187, 185, 152, 210, 212, 176, 239, 243, 203, 235, 239, 200, 216, 221, 183, 205, 214, 172, 174, 179, 142, 164, 161, 133, 185, 175, 159, 203, 181, 176, 210, 179, 177, 194, 177, 170, 191, 189, 177, 211, 207, 197, 218, 212, 207, 226, 221, 217, 225, 220, 217, 203, 197, 198, 190, 184, 187, 179, 171, 170, 151, 139, 131, 121, 103, 90, 168, 149, 133, 158, 140, 126, 167, 151, 139, 194, 177, 162, 170, 148, 130, 172, 147, 126, 154, 131, 111, 131, 112, 96, 153, 138, 118, 169, 156, 132, 162, 151, 124, 184, 177, 146, 222, 217, 184, 236, 234, 199, 216, 223, 185, 208, 218, 176, 192, 198, 161, 180, 178, 149, 197, 194, 175, 202, 194, 183, 209, 190, 182, 210, 200, 188, 186, 186, 170, 189, 184, 170, 197, 191, 185, 204, 199, 194, 209, 203, 201, 213, 208, 208, 207, 200, 202, 181, 177, 175, 178, 171, 164, 149, 135, 123, 146, 127, 113, 175, 158, 145, 183, 168, 157, 174, 155, 140, 156, 131, 113, 171, 143, 123, 163, 137, 119, 148, 126, 112, 169, 148, 134, 180, 159, 142, 166, 147, 127, 160, 144, 121, 172, 158, 132, 204, 197, 166, 218, 225, 189, 213, 221, 183, 202, 208, 173, 182, 183, 155, 191, 191, 171, 203, 199, 186, 201, 190, 177, 202, 194, 178, 202, 198, 180, 195, 188, 172, 193, 190, 178, 192, 186, 177, 178, 171, 164, 198, 193, 188, 207, 198, 195, 199, 191, 189, 211, 207, 201, 203, 191, 182, 166, 148, 136, 187, 169, 157, 177, 160, 147, 155, 135, 120, 147, 123, 106, 166, 141, 124, 167, 142, 128, 171, 149, 138, 182, 159, 148, 175, 152, 138, 156, 135, 120, 156, 136, 119, 159, 140, 122, 167, 154, 130, 217, 222, 189, 215, 221, 188, 209, 214, 183, 186, 190, 161, 179, 179, 158, 200, 195, 183, 208, 200, 187, 200, 190, 176, 209, 198, 184, 215, 205, 191, 210, 209, 192, 186, 178, 164, 161, 151, 139, 182, 179, 166, 196, 182, 173, 194, 181, 177, 203, 197, 192, 207, 196, 188, 190, 174, 162, 185, 165, 150, 155, 134, 118, 142, 124, 107, 155, 137, 121, 166, 147, 133, 172, 153, 142, 179, 161, 150, 173, 153, 141, 159, 139, 125, 150, 131, 117, 158, 139, 124, 158, 139, 125, 143, 125, 108, 214, 219, 186, 213, 218, 186, 214, 219, 187, 192, 198, 166, 169, 170, 148, 197, 191, 180, 218, 210, 199, 217, 207, 197, 215, 203, 193, 217, 206, 195, 212, 207, 192, 195, 180, 168, 170, 156, 145, 179, 174, 159, 195, 180, 169, 191, 176, 170, 190, 182, 175, 192, 181, 172, 192, 176, 163, 170, 150, 134, 132, 111, 93, 142, 125, 108, 167, 150, 134, 170, 152, 139, 170, 152, 141, 179, 161, 151, 173, 154, 142, 157, 138, 124, 157, 138, 124, 147, 128, 114, 134, 115, 101, 125, 106, 91, 213, 218, 186, 209, 214, 181, 211, 217, 183, 202, 207, 172, 168, 170, 143, 193, 188, 176, 216, 210, 201, 222, 213, 207, 223, 212, 206, 222, 211, 203, 211, 199, 189, 205, 182, 175, 194, 174, 165, 194, 186, 171, 201, 186, 174, 198, 181, 172, 198, 186, 178, 196, 182, 171, 188, 171, 158, 153, 133, 117, 134, 114, 97, 155, 137, 120, 171, 154, 138, 167, 149, 136, 166, 148, 138, 189, 171, 161, 178, 159, 146, 165, 146, 132, 163, 144, 130, 142, 123, 109, 133, 115, 100, 137, 118, 104, 211, 216, 184, 206, 212, 178, 206, 212, 175, 202, 209, 169, 175, 179, 146, 191, 189, 170, 211, 207, 198, 213, 205, 202, 214, 205, 200, 216, 205, 197, 198, 177, 171, 171, 138, 136, 194, 167, 161, 206, 195, 180, 201, 187, 171, 201, 182, 170, 200, 185, 173, 197, 181, 168, 177, 158, 144, 150, 130, 115, 144, 125, 108, 158, 141, 124, 167, 150, 134, 157, 140, 126, 159, 141, 130, 181, 163, 153, 176, 157, 145, 168, 149, 135, 152, 133, 119, 150, 131, 117, 149, 130, 116, 144, 124, 111, 210, 215, 184, 204, 210, 176, 201, 208, 168, 193, 200, 157, 181, 187, 147, 188, 190, 162, 208, 206, 192, 210, 204, 200, 205, 198, 191, 206, 196, 185, 160, 131, 129, 122, 80, 82, 177, 145, 141, 208, 194, 179, 198, 184, 166, 194, 174, 159, 193, 174, 159, 184, 165, 150, 166, 147, 132, 150, 131, 116, 139, 120, 105, 156, 139, 122, 160, 143, 127, 153, 136, 122, 155, 137, 127, 160, 142, 132, 159, 140, 128, 155, 136, 122, 152, 133, 119, 152, 133, 119, 140, 121, 107, 131, 112, 98, 210, 215, 184, 202, 208, 172, 198, 205, 163, 187, 194, 148, 174, 181, 134, 178, 183, 146, 205, 205, 186, 214, 209, 202, 209, 204, 192, 203, 194, 178, 164, 129, 130, 131, 81, 88, 180, 142, 140, 202, 186, 172, 187, 171, 152, 182, 161, 144, 182, 161, 145, 169, 149, 132, 157, 137, 122, 139, 120, 105, 134, 115, 100, 153, 135, 119, 154, 137, 121, 144, 126, 112, 151, 133, 122, 141, 123, 113, 131, 112, 100, 141, 122, 108, 157, 138, 124, 155, 136, 122, 150, 131, 117, 147, 128, 114, 210, 214, 183, 200, 205, 169, 194, 200, 158, 181, 188, 142, 168, 176, 126, 168, 175, 132, 196, 198, 178, 215, 212, 204, 212, 208, 195, 199, 192, 175, 189, 160, 157, 184, 142, 144, 203, 170, 164, 185, 168, 152, 173, 155, 135, 172, 149, 131, 163, 141, 124, 155, 133, 116, 147, 127, 111, 118, 100, 84, 131, 113, 97, 148, 131, 115, 145, 128, 113, 141, 123, 109, 144, 126, 114, 132, 114, 102, 127, 108, 95, 133, 114, 100, 149, 130, 116, 163, 144, 130, 162, 144, 130, 156, 137, 123, 208, 210, 177, 194, 196, 161, 189, 192, 153, 180, 183, 142, 162, 169, 119, 158, 166, 122, 189, 192, 178, 211, 210, 204, 211, 209, 197, 197, 192, 180, 194, 182, 170, 199, 180, 168, 191, 171, 157, 172, 153, 135, 163, 141, 122, 164, 140, 123, 158, 134, 119, 147, 125, 109, 130, 111, 94, 109, 92, 75, 137, 120, 104, 144, 126, 111, 144, 126, 112, 145, 127, 113, 144, 126, 112, 132, 114, 100, 124, 105, 92, 134, 116, 102, 151, 133, 119, 162, 144, 130, 159, 141, 126, 147, 129, 115, 194, 196, 163, 177, 179, 144, 176, 179, 141, 181, 185, 145, 159, 166, 116, 143, 151, 107, 179, 181, 169, 205, 204, 200, 208, 205, 194, 199, 194, 183, 194, 186, 172, 190, 179, 163, 181, 166, 150, 165, 146, 129, 156, 133, 115, 161, 136, 121, 149, 126, 112, 136, 114, 100, 112, 93, 78, 114, 97, 81, 137, 120, 104, 133, 115, 101, 138, 120, 106, 146, 128, 114, 146, 128, 114, 131, 113, 99, 131, 113, 99, 144, 126, 112, 150, 132, 118, 149, 131, 117, 148, 130, 116, 141, 123, 110, 172, 177, 142, 157, 161, 126, 165, 170, 131, 178, 184, 143, 167, 174, 124, 133, 140, 95, 156, 156, 145, 199, 195, 192, 206, 201, 190, 199, 193, 183, 199, 191, 178, 194, 182, 168, 160, 145, 130, 133, 113, 98, 132, 108, 92, 139, 115, 101, 140, 118, 104, 126, 106, 92, 107, 89, 75, 126, 110, 95, 130, 114, 99, 129, 112, 97, 138, 120, 106, 149, 131, 116, 141, 123, 109, 140, 122, 108, 145, 127, 113, 142, 124, 110, 136, 117, 103, 140, 122, 108, 149, 130, 116, 152, 134, 119, 151, 157, 123, 134, 140, 104, 144, 151, 112, 155, 161, 120, 158, 166, 116, 125, 130, 87, 130, 128, 118, 183, 177, 174, 197, 191, 181, 191, 183, 174, 183, 175, 164, 165, 154, 141, 128, 112, 99, 103, 83, 69, 94, 71, 57, 105, 83, 70, 119, 99, 87, 112, 94, 81, 117, 101, 88, 124, 110, 96, 121, 108, 93, 125, 108, 94, 139, 121, 107, 143, 126, 112, 139, 121, 107, 140, 122, 108, 129, 111, 97, 125, 107, 93, 132, 115, 101, 149, 132, 118, 155, 137, 123, 150, 132, 118], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284462321232}], \"selected_variable\": {\"name\": [\"<SArray>\"], \"dtype\": \"Image\", \"view_component\": \"Images\", \"view_file\": \"sarray\", \"descriptives\": {\"rows\": 3}, \"type\": \"SArray\", \"view_components\": [\"Images\"]}}, e);\n",
       "                });\n",
       "            })();\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "image_test[0:3]['image'].show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "dtype: str\n",
       "Rows: 3\n",
       "['cat', 'automobile', 'cat']"
      ]
     },
     "execution_count": 14,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "deep_features_model.predict(image_test[0:3])"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The classifier with deep features gets all of these images right!"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#Compute test_data accuracy of deep_features_model\n",
    "\n",
    "As we can see, deep features provide us with significantly better accuracy (about 78%)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "{'accuracy': 0.78475, 'confusion_matrix': Columns:\n",
       " \ttarget_label\tstr\n",
       " \tpredicted_label\tstr\n",
       " \tcount\tint\n",
       " \n",
       " Rows: 16\n",
       " \n",
       " Data:\n",
       " +--------------+-----------------+-------+\n",
       " | target_label | predicted_label | count |\n",
       " +--------------+-----------------+-------+\n",
       " |     dog      |    automobile   |   20  |\n",
       " |     bird     |       bird      |  801  |\n",
       " |  automobile  |       bird      |   27  |\n",
       " |     dog      |       bird      |   47  |\n",
       " |     cat      |    automobile   |   36  |\n",
       " |     cat      |       cat       |  661  |\n",
       " |     bird     |       cat       |  116  |\n",
       " |     cat      |       dog       |  222  |\n",
       " |     dog      |       dog       |  722  |\n",
       " |  automobile  |    automobile   |  955  |\n",
       " +--------------+-----------------+-------+\n",
       " [16 rows x 3 columns]\n",
       " Note: Only the head of the SFrame is printed.\n",
       " You can use print_rows(num_rows=m, num_columns=n) to print more rows and columns.}"
      ]
     },
     "execution_count": 15,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "deep_features_model.evaluate(image_test)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Programming assignment\n",
    "### 1. Computing summary statistics of the data."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div style=\"max-height:1000px;max-width:1500px;overflow:auto;\"><table frame=\"box\" rules=\"cols\">\n",
       "    <tr>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">id</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">image</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">label</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">deep_features</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">image_array</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">24</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">bird</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.242871761322,<br>1.09545373917, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[73.0, 77.0, 58.0, 71.0,<br>68.0, 50.0, 77.0, 69.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">33</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">cat</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.525087952614, 0.0,<br>0.0, 0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[7.0, 5.0, 8.0, 7.0, 5.0,<br>8.0, 5.0, 4.0, 6.0, 7.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">36</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">cat</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.566015958786, 0.0,<br>0.0, 0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[169.0, 122.0, 65.0,<br>131.0, 108.0, 75.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">70</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">dog</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[1.12979578972, 0.0, 0.0,<br>0.778194487095, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[154.0, 179.0, 152.0,<br>159.0, 183.0, 157.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">90</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">bird</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[1.71786928177, 0.0, 0.0,<br>0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[216.0, 195.0, 180.0,<br>201.0, 178.0, 160.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">97</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">automobile</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[1.57818555832, 0.0, 0.0,<br>0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[33.0, 44.0, 27.0, 29.0,<br>44.0, 31.0, 32.0, 45.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">107</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">dog</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.0, 0.0,<br>0.220677852631, 0.0,  ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[97.0, 51.0, 31.0, 104.0,<br>58.0, 38.0, 107.0, 61.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">121</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">bird</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.0, 0.23753464222, 0.0,<br>0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[93.0, 96.0, 88.0, 102.0,<br>106.0, 97.0, 117.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">136</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">automobile</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.0, 0.0, 0.0, 0.0, 0.0,<br>0.0, 7.5737862587, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[35.0, 59.0, 53.0, 36.0,<br>56.0, 56.0, 42.0, 62.0, ...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">138</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">Height: 32 Width: 32</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">bird</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[0.658935725689, 0.0,<br>0.0, 0.0, 0.0, 0.0, ...</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">[205.0, 193.0, 195.0,<br>200.0, 187.0, 193.0, ...</td>\n",
       "    </tr>\n",
       "</table>\n",
       "[10 rows x 5 columns]<br/>\n",
       "</div>"
      ],
      "text/plain": [
       "Columns:\n",
       "\tid\tint\n",
       "\timage\tImage\n",
       "\tlabel\tstr\n",
       "\tdeep_features\tarray\n",
       "\timage_array\tarray\n",
       "\n",
       "Rows: 10\n",
       "\n",
       "Data:\n",
       "+-----+----------------------+------------+-------------------------------+\n",
       "|  id |        image         |   label    |         deep_features         |\n",
       "+-----+----------------------+------------+-------------------------------+\n",
       "|  24 | Height: 32 Width: 32 |    bird    | [0.242871761322, 1.0954537... |\n",
       "|  33 | Height: 32 Width: 32 |    cat     | [0.525087952614, 0.0, 0.0,... |\n",
       "|  36 | Height: 32 Width: 32 |    cat     | [0.566015958786, 0.0, 0.0,... |\n",
       "|  70 | Height: 32 Width: 32 |    dog     | [1.12979578972, 0.0, 0.0, ... |\n",
       "|  90 | Height: 32 Width: 32 |    bird    | [1.71786928177, 0.0, 0.0, ... |\n",
       "|  97 | Height: 32 Width: 32 | automobile | [1.57818555832, 0.0, 0.0, ... |\n",
       "| 107 | Height: 32 Width: 32 |    dog     | [0.0, 0.0, 0.220677852631,... |\n",
       "| 121 | Height: 32 Width: 32 |    bird    | [0.0, 0.23753464222, 0.0, ... |\n",
       "| 136 | Height: 32 Width: 32 | automobile | [0.0, 0.0, 0.0, 0.0, 0.0, ... |\n",
       "| 138 | Height: 32 Width: 32 |    bird    | [0.658935725689, 0.0, 0.0,... |\n",
       "+-----+----------------------+------------+-------------------------------+\n",
       "+-------------------------------+\n",
       "|          image_array          |\n",
       "+-------------------------------+\n",
       "| [73.0, 77.0, 58.0, 71.0, 6... |\n",
       "| [7.0, 5.0, 8.0, 7.0, 5.0, ... |\n",
       "| [169.0, 122.0, 65.0, 131.0... |\n",
       "| [154.0, 179.0, 152.0, 159.... |\n",
       "| [216.0, 195.0, 180.0, 201.... |\n",
       "| [33.0, 44.0, 27.0, 29.0, 4... |\n",
       "| [97.0, 51.0, 31.0, 104.0, ... |\n",
       "| [93.0, 96.0, 88.0, 102.0, ... |\n",
       "| [35.0, 59.0, 53.0, 36.0, 5... |\n",
       "| [205.0, 193.0, 195.0, 200.... |\n",
       "+-------------------------------+\n",
       "[10 rows x 5 columns]"
      ]
     },
     "execution_count": 17,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "image_train.head()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 19,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "\n",
       "+------------------+-------+----------+\n",
       "|       item       | value | is exact |\n",
       "+------------------+-------+----------+\n",
       "|      Length      |  2005 |   Yes    |\n",
       "| # Missing Values |   0   |   Yes    |\n",
       "| # unique values  |   4   |    No    |\n",
       "+------------------+-------+----------+\n",
       "\n",
       "Most frequent items:\n",
       "+-------+------------+-----+-----+------+\n",
       "| value | automobile | cat | dog | bird |\n",
       "+-------+------------+-----+-----+------+\n",
       "| count |    509     | 509 | 509 | 478  |\n",
       "+-------+------------+-----+-----+------+\n"
      ]
     },
     "execution_count": 19,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "image_train['label'].sketch_summary()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### 2.  Creating category-specific image retrieval models."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 33,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "image_train_auto = image_train[image_train['label'] == 'automobile']\n",
    "#len(image_train_auto)\n",
    "#image_train_auto.head()\n",
    "\n",
    "image_train_bird = image_train[image_train['label'] == 'bird']\n",
    "#len(image_train_bird)\n",
    "#image_train_bird.head()\n",
    "\n",
    "image_train_cat = image_train[image_train['label'] == 'cat']\n",
    "#len(image_train_cat)\n",
    "#image_train_cat.head()\n",
    "\n",
    "image_train_dog = image_train[image_train['label'] == 'dog']\n",
    "#len(image_train_dog)\n",
    "#image_train_dog.head()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 34,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "PROGRESS: Starting brute force nearest neighbors model training.\n",
      "PROGRESS: Starting brute force nearest neighbors model training.\n",
      "PROGRESS: Starting brute force nearest neighbors model training.\n",
      "PROGRESS: Starting brute force nearest neighbors model training.\n"
     ]
    }
   ],
   "source": [
    "knn_model_auto = graphlab.nearest_neighbors.create(image_train_auto,features=['deep_features'],\n",
    "                                             label='id')\n",
    "knn_model_bird = graphlab.nearest_neighbors.create(image_train_bird,features=['deep_features'],\n",
    "                                             label='id')\n",
    "knn_model_cat = graphlab.nearest_neighbors.create(image_train_cat,features=['deep_features'],\n",
    "                                             label='id')\n",
    "knn_model_dog = graphlab.nearest_neighbors.create(image_train_dog,features=['deep_features'],\n",
    "                                             label='id')\n",
    "graphlab.canvas.set_target('ipynb')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 38,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "application/javascript": [
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//cdnjs.cloudflare.com/ajax/libs/font-awesome/4.1.0/css/font-awesome.min.css\"\n",
       "}));\n",
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//dato.com/files/canvas/1.6.1/css/canvas.css\"\n",
       "}));\n",
       "\n",
       "            (function(){\n",
       "\n",
       "                var e = null;\n",
       "                if (typeof element == 'undefined') {\n",
       "                    var scripts = document.getElementsByTagName('script');\n",
       "                    var thisScriptTag = scripts[scripts.length-1];\n",
       "                    var parentDiv = thisScriptTag.parentNode;\n",
       "                    e = document.createElement('div');\n",
       "                    parentDiv.appendChild(e);\n",
       "                } else {\n",
       "                    e = element[0];\n",
       "                }\n",
       "\n",
       "                if (typeof requirejs !== 'undefined') {\n",
       "                    // disable load timeout; ipython_app.js is large and can take a while to load.\n",
       "                    requirejs.config({waitSeconds: 0});\n",
       "                }\n",
       "\n",
       "                require(['//dato.com/files/canvas/1.6.1/js/ipython_app.js'], function(IPythonApp){\n",
       "                    var app = new IPythonApp();\n",
       "                    app.attachView('sarray','Images', {\"ipython\": true, \"rows\": [{\"format\": \"raw\", \"value\": [158, 112, 49, 159, 111, 47, 165, 116, 51, 166, 118, 53, 160, 112, 46, 156, 109, 41, 162, 115, 47, 159, 113, 45, 158, 111, 44, 159, 113, 41, 161, 116, 41, 160, 111, 52, 161, 111, 49, 166, 117, 41, 169, 117, 45, 170, 119, 44, 167, 117, 40, 162, 113, 38, 160, 111, 39, 160, 112, 43, 156, 109, 44, 149, 107, 45, 150, 107, 45, 148, 106, 43, 149, 107, 44, 143, 101, 39, 140, 98, 43, 141, 97, 41, 143, 97, 38, 137, 95, 36, 126, 91, 36, 116, 85, 33, 152, 112, 51, 151, 110, 40, 159, 114, 45, 166, 116, 56, 162, 112, 49, 160, 113, 43, 164, 117, 47, 162, 114, 45, 163, 116, 46, 156, 110, 38, 155, 111, 41, 159, 110, 54, 163, 113, 52, 170, 119, 41, 171, 117, 40, 171, 115, 33, 169, 115, 30, 160, 111, 33, 154, 112, 41, 151, 115, 50, 145, 110, 53, 139, 104, 55, 140, 102, 52, 141, 100, 48, 149, 105, 50, 147, 102, 46, 145, 102, 45, 142, 97, 38, 143, 98, 34, 136, 95, 31, 125, 91, 32, 119, 88, 34, 151, 110, 47, 151, 109, 33, 158, 111, 36, 167, 111, 48, 160, 106, 42, 163, 115, 44, 165, 117, 45, 165, 117, 45, 163, 115, 43, 162, 115, 43, 158, 114, 48, 157, 109, 57, 161, 111, 51, 166, 115, 38, 167, 114, 37, 169, 113, 35, 170, 116, 39, 159, 114, 47, 145, 111, 54, 121, 96, 49, 110, 90, 52, 98, 78, 50, 101, 77, 47, 114, 85, 50, 120, 86, 48, 134, 96, 55, 143, 103, 51, 140, 99, 39, 142, 99, 35, 139, 98, 34, 130, 95, 34, 120, 89, 33, 155, 107, 40, 155, 110, 32, 160, 109, 31, 174, 112, 44, 167, 110, 43, 167, 117, 46, 169, 120, 48, 169, 119, 48, 165, 115, 44, 165, 117, 45, 167, 123, 57, 191, 146, 95, 177, 130, 75, 157, 111, 41, 162, 115, 47, 164, 114, 54, 158, 112, 58, 149, 111, 67, 104, 80, 47, 103, 87, 65, 98, 90, 76, 92, 90, 84, 80, 75, 66, 74, 63, 50, 86, 70, 52, 83, 62, 39, 113, 85, 45, 132, 98, 46, 140, 102, 43, 140, 101, 39, 136, 99, 39, 127, 94, 36, 155, 107, 41, 156, 114, 48, 161, 115, 49, 170, 114, 47, 169, 114, 43, 163, 113, 40, 169, 120, 47, 166, 116, 44, 164, 113, 41, 164, 116, 42, 173, 128, 59, 246, 214, 164, 195, 156, 107, 151, 114, 56, 146, 111, 60, 142, 108, 71, 111, 80, 50, 78, 53, 31, 85, 69, 56, 113, 103, 98, 112, 110, 111, 106, 114, 118, 97, 102, 105, 93, 94, 93, 74, 72, 67, 84, 78, 70, 85, 73, 47, 105, 83, 45, 128, 96, 48, 138, 101, 46, 133, 94, 36, 129, 93, 36, 148, 109, 54, 133, 104, 64, 130, 100, 57, 147, 112, 53, 161, 115, 44, 165, 113, 39, 167, 116, 41, 167, 115, 41, 163, 111, 37, 165, 116, 39, 163, 118, 42, 180, 138, 85, 157, 122, 78, 128, 102, 58, 97, 75, 43, 66, 50, 31, 69, 58, 43, 66, 56, 45, 89, 83, 76, 118, 113, 110, 122, 121, 120, 119, 122, 122, 114, 116, 116, 94, 96, 96, 99, 100, 97, 91, 91, 86, 58, 58, 47, 67, 58, 37, 108, 84, 49, 140, 105, 58, 138, 98, 44, 134, 95, 40, 127, 100, 57, 109, 95, 80, 47, 37, 17, 88, 74, 28, 153, 117, 48, 170, 118, 43, 168, 115, 40, 170, 118, 43, 169, 117, 42, 166, 116, 37, 164, 120, 39, 147, 107, 52, 129, 98, 59, 127, 108, 75, 100, 87, 70, 68, 67, 57, 78, 83, 72, 72, 75, 64, 83, 84, 74, 132, 130, 121, 146, 142, 132, 124, 118, 108, 105, 99, 90, 107, 102, 94, 115, 111, 103, 85, 83, 77, 63, 71, 69, 46, 47, 39, 79, 61, 36, 132, 98, 58, 141, 99, 48, 134, 93, 39, 131, 115, 90, 99, 96, 92, 42, 43, 38, 70, 64, 41, 143, 111, 56, 167, 117, 42, 165, 114, 36, 168, 116, 39, 171, 119, 49, 161, 113, 51, 140, 109, 51, 120, 94, 49, 130, 110, 77, 144, 131, 107, 116, 106, 93, 88, 87, 79, 91, 95, 88, 85, 88, 82, 77, 77, 69, 124, 118, 107, 163, 153, 140, 136, 124, 112, 102, 93, 81, 106, 98, 88, 100, 93, 84, 85, 81, 74, 54, 60, 58, 49, 53, 49, 57, 47, 32, 107, 83, 50, 138, 103, 51, 136, 97, 39, 170, 161, 144, 103, 105, 105, 54, 58, 59, 124, 121, 113, 153, 124, 82, 161, 113, 43, 163, 117, 41, 166, 122, 50, 165, 121, 66, 174, 135, 95, 113, 89, 59, 125, 105, 78, 157, 141, 121, 156, 143, 128, 121, 111, 101, 86, 80, 74, 82, 81, 77, 84, 85, 82, 80, 78, 73, 81, 71, 61, 138, 125, 112, 146, 135, 123, 113, 103, 93, 87, 79, 70, 83, 77, 69, 86, 82, 76, 71, 73, 67, 56, 57, 53, 40, 35, 27, 74, 59, 35, 133, 106, 59, 137, 103, 45, 180, 176, 163, 134, 139, 143, 94, 100, 105, 154, 154, 149, 174, 149, 112, 158, 116, 51, 156, 116, 47, 153, 118, 60, 207, 180, 146, 237, 214, 198, 207, 180, 166, 156, 131, 119, 174, 153, 145, 148, 131, 125, 125, 110, 107, 93, 85, 79, 86, 84, 79, 74, 74, 71, 59, 57, 53, 76, 68, 58, 137, 125, 112, 143, 133, 122, 133, 124, 114, 106, 98, 89, 86, 81, 74, 87, 85, 78, 84, 85, 78, 75, 76, 71, 50, 49, 43, 40, 30, 15, 95, 75, 44, 132, 103, 57, 183, 183, 175, 108, 116, 122, 142, 151, 158, 165, 169, 168, 177, 156, 122, 155, 112, 50, 159, 118, 51, 122, 89, 47, 213, 197, 179, 237, 224, 226, 220, 191, 188, 164, 135, 131, 183, 159, 155, 156, 137, 132, 125, 108, 104, 120, 111, 104, 78, 76, 69, 80, 80, 77, 45, 44, 40, 91, 85, 77, 175, 165, 154, 157, 147, 137, 155, 147, 138, 107, 100, 92, 87, 83, 77, 103, 102, 96, 88, 88, 79, 78, 79, 73, 59, 59, 59, 41, 36, 33, 59, 46, 31, 104, 81, 46, 188, 191, 189, 100, 108, 116, 135, 144, 153, 170, 175, 178, 187, 167, 136, 166, 120, 59, 173, 123, 55, 134, 93, 44, 117, 95, 80, 194, 182, 188, 199, 171, 164, 170, 142, 133, 185, 161, 151, 189, 171, 159, 134, 119, 106, 117, 107, 95, 102, 98, 89, 84, 84, 79, 38, 38, 34, 125, 121, 113, 210, 201, 192, 160, 152, 142, 146, 139, 130, 93, 89, 82, 83, 80, 75, 94, 93, 88, 104, 104, 94, 85, 87, 81, 73, 75, 78, 55, 53, 55, 62, 55, 48, 76, 56, 26, 189, 194, 194, 90, 96, 105, 127, 134, 144, 175, 180, 185, 174, 156, 133, 166, 123, 68, 178, 123, 53, 159, 109, 47, 97, 68, 44, 168, 154, 152, 168, 144, 126, 137, 114, 94, 186, 166, 148, 216, 202, 183, 160, 149, 129, 123, 113, 98, 120, 114, 105, 115, 114, 109, 50, 50, 47, 150, 147, 140, 194, 187, 178, 155, 149, 140, 123, 118, 111, 91, 88, 83, 84, 83, 79, 84, 84, 80, 95, 95, 85, 86, 87, 81, 84, 87, 89, 73, 73, 73, 79, 74, 64, 73, 55, 24, 189, 192, 193, 93, 95, 103, 152, 154, 163, 185, 188, 192, 119, 110, 98, 136, 106, 66, 173, 124, 58, 167, 116, 50, 103, 72, 39, 147, 132, 120, 145, 125, 103, 167, 149, 127, 189, 174, 155, 226, 216, 200, 180, 172, 157, 141, 131, 117, 126, 117, 107, 117, 114, 109, 71, 71, 68, 154, 152, 147, 186, 181, 174, 149, 144, 136, 114, 110, 104, 87, 85, 80, 80, 80, 76, 72, 73, 70, 80, 80, 72, 99, 100, 94, 100, 101, 99, 90, 88, 81, 97, 89, 69, 94, 73, 34, 194, 196, 196, 108, 107, 112, 168, 167, 172, 186, 186, 188, 105, 109, 109, 99, 89, 67, 156, 119, 62, 167, 122, 55, 100, 74, 34, 115, 106, 88, 138, 123, 103, 198, 185, 169, 190, 180, 169, 172, 165, 159, 145, 140, 140, 154, 143, 134, 146, 136, 125, 103, 100, 95, 71, 71, 70, 152, 152, 149, 179, 175, 170, 137, 133, 127, 130, 128, 122, 110, 109, 105, 85, 86, 83, 91, 93, 91, 95, 96, 90, 109, 110, 104, 115, 116, 111, 100, 96, 80, 97, 85, 53, 117, 95, 47, 197, 197, 197, 132, 129, 136, 172, 167, 174, 184, 178, 181, 130, 137, 142, 78, 83, 77, 140, 120, 88, 155, 125, 77, 115, 94, 52, 130, 120, 93, 143, 131, 116, 230, 221, 211, 242, 236, 230, 145, 138, 137, 135, 130, 130, 131, 121, 112, 121, 112, 101, 108, 104, 95, 95, 88, 75, 144, 134, 118, 168, 159, 146, 152, 147, 138, 112, 108, 101, 87, 85, 80, 71, 72, 68, 87, 88, 87, 105, 104, 99, 112, 109, 99, 120, 110, 93, 103, 86, 54, 121, 96, 48, 136, 104, 48, 203, 203, 204, 146, 146, 160, 168, 164, 178, 191, 182, 188, 168, 170, 172, 78, 86, 90, 126, 125, 126, 138, 126, 113, 138, 121, 82, 96, 80, 37, 154, 143, 133, 173, 163, 155, 162, 152, 141, 140, 132, 117, 113, 106, 88, 113, 106, 90, 101, 101, 92, 105, 101, 87, 112, 90, 58, 171, 143, 104, 156, 138, 109, 148, 141, 126, 135, 130, 118, 109, 105, 97, 78, 76, 72, 79, 79, 77, 94, 93, 94, 101, 91, 82, 107, 83, 55, 125, 88, 45, 151, 108, 55, 144, 104, 46, 214, 215, 215, 163, 166, 180, 164, 167, 184, 183, 184, 194, 176, 182, 186, 94, 102, 105, 96, 96, 102, 156, 149, 145, 148, 137, 111, 106, 93, 61, 129, 116, 105, 118, 105, 95, 114, 102, 89, 116, 105, 89, 102, 91, 73, 115, 110, 98, 86, 91, 88, 101, 103, 95, 144, 128, 102, 118, 96, 64, 68, 56, 32, 128, 120, 105, 133, 126, 115, 75, 69, 61, 60, 56, 51, 58, 56, 53, 71, 70, 65, 102, 93, 78, 116, 94, 64, 143, 112, 68, 150, 116, 64, 140, 110, 54, 212, 211, 205, 178, 184, 192, 167, 175, 189, 173, 181, 193, 176, 184, 188, 124, 131, 133, 86, 88, 96, 141, 139, 143, 153, 148, 141, 135, 128, 111, 104, 90, 80, 77, 64, 55, 134, 121, 108, 124, 111, 96, 129, 117, 100, 147, 143, 133, 85, 92, 93, 92, 96, 93, 150, 139, 120, 132, 117, 93, 117, 109, 92, 107, 99, 86, 75, 68, 58, 64, 59, 52, 44, 41, 39, 65, 62, 60, 86, 69, 40, 133, 105, 59, 155, 119, 62, 160, 120, 54, 154, 115, 45, 151, 111, 46, 199, 192, 180, 187, 189, 187, 171, 176, 181, 174, 179, 185, 177, 182, 184, 144, 149, 152, 86, 90, 99, 119, 121, 132, 122, 124, 130, 137, 136, 135, 144, 134, 126, 70, 59, 51, 129, 118, 108, 108, 97, 86, 145, 134, 123, 184, 176, 168, 116, 118, 118, 73, 75, 73, 131, 119, 103, 137, 124, 105, 134, 129, 118, 89, 86, 78, 51, 49, 44, 52, 51, 50, 47, 49, 52, 90, 90, 93, 121, 91, 60, 163, 118, 68, 171, 121, 64, 164, 113, 52, 158, 111, 50, 149, 107, 46, 165, 156, 146, 195, 193, 187, 179, 178, 175, 177, 173, 172, 181, 181, 180, 152, 157, 160, 99, 103, 111, 131, 135, 146, 171, 175, 185, 103, 105, 111, 93, 90, 87, 80, 77, 73, 93, 90, 86, 122, 118, 116, 178, 173, 173, 191, 182, 177, 150, 148, 148, 100, 100, 101, 89, 78, 66, 87, 77, 63, 60, 61, 57, 46, 52, 54, 38, 46, 51, 24, 33, 41, 46, 57, 69, 60, 71, 83, 108, 100, 75, 144, 125, 82, 144, 123, 76, 128, 109, 61, 127, 113, 69, 120, 105, 63, 117, 120, 124, 195, 200, 200, 177, 178, 176, 178, 169, 168, 181, 179, 179, 138, 144, 147, 83, 87, 91, 150, 153, 159, 245, 247, 250, 219, 222, 225, 133, 140, 144, 134, 141, 147, 149, 156, 164, 176, 182, 192, 190, 196, 208, 194, 192, 197, 168, 172, 181, 125, 133, 143, 110, 109, 109, 61, 62, 62, 35, 49, 58, 34, 54, 68, 49, 70, 87, 58, 81, 102, 61, 85, 110, 58, 84, 111, 69, 99, 122, 72, 101, 119, 78, 104, 120, 69, 96, 112, 59, 92, 112, 55, 90, 115, 79, 105, 133, 175, 197, 213, 174, 183, 192, 176, 172, 177, 177, 177, 182, 140, 146, 150, 109, 112, 113, 211, 211, 209, 253, 252, 247, 252, 253, 252, 208, 224, 232, 124, 143, 157, 114, 132, 149, 124, 141, 162, 116, 133, 156, 122, 133, 152, 104, 124, 148, 68, 93, 119, 68, 87, 104, 60, 82, 101, 52, 84, 111, 50, 84, 110, 51, 85, 115, 56, 93, 125, 56, 94, 131, 51, 91, 130, 43, 96, 135, 51, 104, 141, 59, 108, 142, 48, 97, 132, 43, 97, 137, 42, 95, 132, 41, 89, 135, 96, 137, 168, 144, 168, 188, 168, 174, 188, 178, 182, 192, 165, 170, 174, 165, 166, 164, 246, 245, 237, 253, 251, 241, 227, 231, 228, 110, 136, 153, 60, 88, 111, 53, 80, 105, 49, 76, 105, 49, 75, 107, 48, 72, 101, 45, 79, 115, 42, 81, 120, 46, 81, 113, 42, 82, 116, 38, 86, 125, 46, 90, 125, 46, 89, 126, 43, 87, 128, 42, 89, 132, 46, 93, 139, 46, 94, 137, 50, 96, 137, 55, 96, 135, 53, 94, 134, 51, 95, 139, 45, 90, 133, 29, 91, 141, 29, 87, 130, 59, 102, 134, 131, 153, 176, 166, 179, 191, 132, 136, 137, 194, 189, 181, 254, 250, 242, 241, 245, 245, 141, 159, 175, 61, 94, 127, 50, 84, 118, 50, 84, 119, 51, 85, 121, 49, 83, 120, 50, 84, 116, 47, 86, 117, 42, 84, 117, 39, 82, 115, 34, 79, 113, 35, 83, 120, 39, 86, 125, 38, 85, 125, 42, 89, 130, 45, 92, 134, 56, 103, 145, 62, 103, 142, 59, 101, 142, 56, 102, 146, 50, 99, 144, 46, 94, 140, 51, 103, 149, 48, 111, 162, 30, 94, 140, 34, 85, 124, 73, 106, 136, 128, 148, 167, 128, 136, 143, 215, 213, 209, 255, 253, 249, 187, 198, 205, 66, 93, 118, 54, 91, 128, 50, 88, 125, 52, 90, 127, 52, 90, 127, 46, 83, 121, 45, 82, 115, 43, 82, 113, 41, 81, 112, 36, 80, 113, 39, 83, 117, 40, 86, 123, 40, 89, 131, 43, 92, 134, 46, 95, 138, 59, 108, 150, 62, 110, 152, 64, 109, 147, 59, 108, 149, 54, 108, 154, 50, 105, 152, 70, 123, 167, 83, 137, 182, 52, 114, 165, 35, 99, 147, 31, 86, 130, 41, 83, 122, 66, 95, 126, 128, 145, 164, 224, 229, 234, 240, 245, 247, 124, 143, 153, 58, 92, 114, 49, 87, 123, 56, 94, 131, 54, 92, 129, 44, 82, 119, 44, 82, 119, 47, 83, 119, 46, 84, 119, 43, 83, 119, 43, 86, 123, 44, 88, 127, 44, 90, 131, 45, 97, 141, 54, 106, 150, 58, 110, 154, 54, 105, 150, 46, 97, 141, 43, 95, 140, 36, 91, 138, 51, 108, 158, 73, 130, 178, 85, 138, 182, 76, 125, 169, 50, 110, 162, 35, 98, 149, 29, 89, 138, 35, 86, 133, 44, 83, 126, 78, 106, 138, 202, 219, 233, 211, 228, 234, 97, 126, 140, 65, 104, 126, 54, 94, 129, 48, 87, 124, 58, 97, 133, 48, 87, 123, 40, 80, 116, 45, 82, 119, 47, 84, 122, 48, 87, 126, 47, 89, 130, 46, 89, 132, 51, 97, 140, 39, 92, 138, 39, 93, 139, 48, 102, 148, 47, 101, 147, 39, 93, 139, 28, 85, 133, 40, 101, 153, 67, 129, 182, 67, 126, 176, 46, 98, 142, 51, 96, 139, 50, 108, 161, 35, 97, 147, 32, 92, 143, 33, 88, 141, 41, 88, 138, 46, 84, 125, 104, 133, 159, 170, 197, 211, 64, 100, 119, 54, 97, 121, 52, 94, 128, 53, 95, 130, 61, 103, 139, 58, 100, 135, 54, 96, 131, 45, 83, 120, 42, 79, 118, 41, 80, 120, 46, 88, 130, 49, 92, 135, 46, 92, 136, 42, 95, 139, 40, 93, 138, 39, 92, 136, 37, 90, 135, 40, 93, 138, 44, 102, 151, 63, 125, 178, 47, 110, 164, 31, 90, 140, 15, 60, 103, 51, 93, 136, 68, 124, 177, 42, 100, 148, 31, 88, 137, 38, 91, 146, 37, 87, 139, 43, 89, 132, 42, 79, 113, 71, 107, 133, 49, 89, 114, 31, 77, 105, 27, 71, 105, 38, 82, 117, 49, 93, 128, 56, 100, 135, 58, 102, 137, 53, 92, 128, 56, 94, 131, 60, 99, 137, 57, 99, 139, 53, 97, 138, 50, 95, 137, 45, 94, 136, 39, 88, 131, 33, 83, 125, 42, 91, 133, 62, 112, 154, 79, 132, 179, 73, 131, 181, 56, 116, 168, 38, 97, 146, 13, 64, 108, 40, 85, 127, 61, 116, 168, 49, 102, 148, 35, 85, 132, 43, 91, 143, 39, 90, 139, 42, 92, 134, 44, 88, 125, 40, 81, 112, 42, 85, 115, 27, 72, 104, 23, 67, 102, 30, 74, 109, 27, 71, 106, 29, 73, 108, 36, 80, 115, 47, 86, 120, 56, 95, 128, 62, 101, 135, 66, 109, 144, 75, 119, 156, 69, 113, 152, 49, 95, 134, 43, 88, 127, 43, 88, 127, 60, 105, 144, 85, 130, 170, 109, 156, 197, 93, 145, 190, 60, 115, 164, 26, 82, 130, 29, 82, 126, 20, 64, 107, 54, 107, 160, 56, 105, 149, 45, 89, 132, 43, 86, 134, 40, 89, 134, 40, 92, 132, 40, 87, 123, 38, 81, 115, 36, 79, 114, 26, 69, 105, 22, 66, 101, 29, 73, 108, 25, 69, 104, 29, 73, 108, 19, 63, 98, 18, 58, 89, 32, 70, 100, 47, 87, 118, 61, 104, 137, 74, 119, 152, 66, 111, 145, 53, 96, 131, 52, 95, 130, 45, 87, 123, 67, 109, 145, 89, 131, 167, 105, 146, 182, 89, 135, 175, 48, 99, 145, 24, 77, 124, 34, 84, 129, 21, 67, 110], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284451368208}], \"selected_variable\": {\"name\": [\"<SArray>\"], \"dtype\": \"Image\", \"view_component\": \"Images\", \"view_file\": \"sarray\", \"descriptives\": {\"rows\": 1}, \"type\": \"SArray\", \"view_components\": [\"Images\"]}}, e);\n",
       "                });\n",
       "            })();\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "cat = image_test[0:1]\n",
    "cat['image'].show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 85,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "PROGRESS: Starting pairwise querying.\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | Query points | # Pairs | % Complete. | Elapsed Time |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | 0            | 1       | 0.196464    | 13.696ms     |\n",
      "PROGRESS: | Done         |         | 100         | 141.682ms    |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n"
     ]
    },
    {
     "data": {
      "application/javascript": [
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//cdnjs.cloudflare.com/ajax/libs/font-awesome/4.1.0/css/font-awesome.min.css\"\n",
       "}));\n",
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//dato.com/files/canvas/1.6.1/css/canvas.css\"\n",
       "}));\n",
       "\n",
       "            (function(){\n",
       "\n",
       "                var e = null;\n",
       "                if (typeof element == 'undefined') {\n",
       "                    var scripts = document.getElementsByTagName('script');\n",
       "                    var thisScriptTag = scripts[scripts.length-1];\n",
       "                    var parentDiv = thisScriptTag.parentNode;\n",
       "                    e = document.createElement('div');\n",
       "                    parentDiv.appendChild(e);\n",
       "                } else {\n",
       "                    e = element[0];\n",
       "                }\n",
       "\n",
       "                if (typeof requirejs !== 'undefined') {\n",
       "                    // disable load timeout; ipython_app.js is large and can take a while to load.\n",
       "                    requirejs.config({waitSeconds: 0});\n",
       "                }\n",
       "\n",
       "                require(['//dato.com/files/canvas/1.6.1/js/ipython_app.js'], function(IPythonApp){\n",
       "                    var app = new IPythonApp();\n",
       "                    app.attachView('sarray','Images', {\"ipython\": true, \"rows\": [{\"format\": \"raw\", \"value\": [215, 219, 231, 215, 219, 232, 216, 219, 233, 214, 217, 230, 213, 216, 230, 209, 215, 226, 208, 217, 221, 206, 215, 219, 201, 208, 217, 197, 203, 218, 194, 200, 221, 199, 204, 221, 142, 128, 131, 76, 46, 46, 81, 55, 57, 147, 136, 139, 160, 149, 154, 152, 141, 144, 156, 147, 150, 159, 148, 154, 160, 153, 157, 164, 156, 160, 160, 154, 158, 158, 151, 156, 159, 149, 157, 159, 150, 156, 157, 147, 154, 156, 145, 153, 152, 142, 149, 147, 137, 143, 141, 131, 136, 142, 131, 136, 215, 219, 231, 215, 219, 232, 215, 219, 232, 213, 217, 229, 212, 216, 229, 212, 214, 217, 206, 215, 217, 203, 211, 219, 197, 205, 218, 194, 201, 218, 196, 201, 218, 178, 180, 192, 92, 56, 55, 77, 50, 49, 112, 98, 100, 173, 162, 169, 162, 153, 157, 160, 152, 154, 164, 157, 159, 164, 155, 160, 165, 158, 163, 165, 155, 162, 167, 160, 166, 164, 155, 162, 160, 148, 155, 153, 142, 149, 160, 150, 159, 162, 154, 162, 157, 151, 156, 152, 143, 148, 139, 129, 133, 135, 124, 128, 215, 219, 231, 215, 219, 231, 214, 218, 230, 214, 218, 229, 214, 217, 227, 216, 211, 207, 207, 213, 215, 200, 207, 218, 195, 202, 220, 193, 201, 216, 196, 202, 216, 125, 101, 101, 79, 49, 48, 88, 67, 67, 157, 147, 152, 168, 160, 166, 164, 155, 158, 170, 163, 168, 169, 164, 166, 169, 160, 165, 169, 162, 167, 167, 159, 167, 166, 156, 164, 166, 155, 163, 163, 153, 158, 160, 150, 157, 160, 151, 158, 159, 150, 156, 157, 148, 155, 155, 145, 152, 152, 141, 147, 143, 131, 135, 216, 220, 232, 215, 219, 231, 214, 218, 230, 214, 218, 230, 214, 217, 227, 216, 213, 207, 205, 210, 216, 199, 203, 219, 196, 202, 219, 194, 204, 220, 164, 155, 162, 89, 54, 48, 77, 52, 52, 126, 110, 113, 173, 162, 168, 167, 159, 163, 170, 162, 166, 172, 163, 168, 171, 164, 168, 171, 163, 168, 171, 162, 169, 169, 161, 167, 165, 153, 160, 165, 154, 160, 163, 153, 158, 166, 155, 162, 165, 154, 160, 155, 144, 149, 156, 144, 151, 153, 143, 151, 151, 140, 148, 143, 131, 137, 217, 221, 233, 215, 219, 231, 215, 219, 231, 215, 219, 231, 217, 219, 229, 221, 222, 219, 199, 203, 211, 195, 202, 217, 198, 202, 220, 190, 193, 206, 109, 80, 77, 78, 50, 49, 94, 72, 74, 163, 154, 155, 166, 157, 158, 169, 158, 158, 173, 163, 167, 170, 158, 161, 172, 161, 168, 173, 166, 170, 173, 163, 170, 171, 161, 164, 169, 155, 160, 170, 158, 162, 162, 151, 157, 162, 151, 157, 167, 156, 164, 164, 153, 160, 158, 147, 153, 157, 146, 151, 149, 138, 144, 143, 132, 137, 217, 221, 233, 215, 219, 231, 214, 218, 230, 213, 217, 229, 222, 224, 232, 228, 227, 233, 192, 196, 211, 196, 202, 220, 196, 209, 225, 150, 128, 133, 80, 48, 46, 76, 51, 56, 144, 129, 134, 167, 158, 161, 165, 155, 156, 173, 161, 163, 175, 164, 168, 173, 162, 168, 175, 167, 171, 175, 165, 167, 174, 162, 169, 168, 157, 159, 156, 145, 146, 171, 159, 162, 168, 157, 163, 167, 156, 163, 167, 155, 165, 168, 157, 165, 159, 147, 155, 151, 140, 144, 145, 133, 137, 149, 137, 141, 217, 221, 233, 216, 220, 232, 214, 218, 230, 215, 219, 231, 166, 167, 174, 200, 198, 206, 194, 201, 218, 194, 200, 219, 177, 173, 184, 93, 65, 61, 75, 53, 53, 120, 100, 97, 172, 162, 166, 169, 158, 161, 167, 154, 156, 177, 166, 169, 181, 171, 175, 174, 166, 173, 175, 166, 172, 171, 160, 164, 173, 163, 171, 136, 125, 129, 101, 91, 88, 155, 141, 141, 175, 164, 169, 174, 162, 170, 167, 156, 165, 165, 154, 162, 161, 150, 157, 150, 138, 143, 148, 136, 140, 147, 135, 139, 217, 221, 233, 216, 220, 232, 215, 219, 231, 217, 221, 234, 113, 108, 113, 140, 130, 127, 163, 161, 169, 144, 143, 149, 153, 139, 139, 139, 122, 116, 132, 114, 102, 164, 147, 139, 161, 150, 142, 150, 138, 130, 135, 122, 116, 152, 138, 134, 149, 132, 127, 175, 162, 161, 180, 168, 175, 176, 164, 170, 177, 171, 180, 136, 126, 130, 87, 76, 68, 137, 121, 119, 178, 168, 173, 173, 162, 169, 168, 157, 164, 163, 152, 158, 158, 146, 151, 160, 147, 155, 163, 150, 158, 160, 147, 154, 218, 220, 233, 216, 219, 232, 215, 219, 232, 208, 212, 224, 92, 82, 85, 96, 78, 69, 111, 99, 93, 129, 116, 110, 167, 156, 155, 179, 168, 171, 171, 161, 158, 157, 137, 124, 120, 103, 92, 117, 98, 86, 102, 86, 81, 127, 108, 96, 147, 122, 108, 139, 122, 116, 168, 157, 155, 155, 145, 145, 200, 199, 207, 157, 149, 147, 116, 102, 91, 150, 137, 137, 176, 166, 170, 173, 162, 168, 169, 156, 164, 159, 147, 153, 159, 146, 150, 164, 151, 158, 166, 153, 161, 159, 145, 153, 217, 219, 232, 216, 218, 231, 217, 218, 229, 193, 195, 207, 95, 79, 74, 110, 88, 80, 154, 138, 132, 181, 165, 159, 207, 200, 205, 205, 207, 219, 199, 200, 209, 159, 138, 131, 143, 118, 101, 137, 110, 93, 115, 98, 91, 118, 103, 92, 184, 166, 159, 125, 113, 114, 149, 132, 126, 117, 101, 102, 213, 214, 226, 172, 170, 179, 133, 121, 123, 157, 143, 143, 147, 131, 129, 174, 158, 166, 169, 156, 165, 162, 149, 157, 168, 156, 164, 166, 154, 162, 162, 151, 158, 158, 146, 154, 218, 220, 233, 216, 218, 232, 216, 220, 234, 174, 176, 187, 90, 73, 70, 148, 125, 109, 194, 169, 157, 215, 204, 208, 220, 221, 230, 220, 223, 231, 218, 216, 224, 174, 154, 152, 162, 140, 127, 127, 100, 84, 146, 120, 103, 147, 124, 116, 169, 145, 133, 138, 122, 113, 148, 134, 124, 123, 103, 97, 154, 143, 141, 153, 143, 144, 133, 124, 127, 151, 136, 137, 140, 119, 111, 156, 139, 134, 175, 164, 169, 175, 160, 169, 170, 156, 165, 164, 151, 158, 156, 144, 150, 158, 146, 152, 218, 220, 233, 214, 218, 231, 216, 219, 233, 173, 164, 169, 134, 106, 90, 184, 152, 131, 205, 184, 171, 218, 214, 222, 221, 222, 232, 225, 226, 235, 218, 220, 231, 187, 172, 169, 156, 136, 127, 140, 116, 102, 147, 115, 98, 126, 99, 84, 171, 135, 105, 105, 81, 71, 132, 112, 105, 95, 80, 75, 130, 118, 114, 140, 127, 123, 128, 115, 114, 140, 125, 124, 159, 143, 139, 126, 113, 112, 165, 156, 163, 159, 144, 150, 163, 147, 148, 161, 145, 149, 161, 145, 149, 163, 148, 151, 217, 219, 232, 214, 218, 230, 218, 216, 229, 152, 133, 128, 169, 146, 138, 194, 172, 157, 201, 173, 151, 210, 197, 193, 215, 213, 223, 216, 218, 226, 203, 201, 209, 157, 129, 111, 145, 112, 92, 141, 114, 99, 133, 104, 90, 114, 84, 72, 183, 145, 108, 135, 106, 86, 143, 110, 95, 110, 95, 93, 200, 199, 207, 153, 147, 148, 129, 112, 111, 119, 102, 100, 144, 131, 127, 152, 145, 156, 188, 186, 198, 108, 92, 95, 99, 83, 78, 160, 140, 141, 176, 157, 168, 153, 134, 136, 218, 220, 233, 217, 219, 232, 209, 210, 222, 141, 114, 104, 212, 201, 202, 212, 206, 208, 184, 150, 123, 193, 164, 138, 202, 187, 180, 209, 207, 215, 200, 193, 196, 146, 111, 92, 141, 107, 88, 120, 97, 84, 86, 68, 60, 117, 87, 74, 163, 126, 95, 140, 103, 84, 139, 102, 78, 169, 141, 129, 218, 219, 228, 131, 123, 125, 104, 88, 81, 98, 83, 76, 122, 105, 97, 143, 138, 161, 209, 208, 226, 154, 141, 139, 99, 80, 73, 153, 127, 129, 156, 139, 144, 135, 116, 116, 219, 221, 234, 216, 218, 232, 204, 204, 219, 154, 126, 110, 213, 204, 206, 217, 214, 217, 170, 136, 110, 157, 118, 88, 170, 135, 108, 197, 174, 168, 170, 142, 125, 143, 103, 83, 122, 90, 75, 98, 76, 68, 68, 55, 55, 76, 59, 56, 118, 84, 71, 111, 79, 63, 107, 76, 63, 158, 121, 101, 196, 192, 200, 115, 101, 104, 106, 90, 83, 103, 87, 77, 128, 107, 97, 111, 97, 127, 206, 205, 220, 206, 209, 220, 157, 142, 127, 113, 91, 76, 121, 105, 101, 164, 149, 152, 220, 221, 234, 215, 218, 232, 208, 209, 223, 159, 136, 126, 213, 211, 218, 204, 202, 208, 140, 115, 102, 132, 104, 88, 148, 112, 93, 160, 124, 97, 136, 92, 70, 122, 86, 69, 97, 73, 60, 101, 74, 64, 84, 63, 60, 67, 53, 52, 82, 62, 57, 92, 71, 60, 82, 59, 53, 145, 116, 103, 125, 116, 120, 105, 91, 87, 92, 77, 76, 94, 76, 73, 119, 96, 84, 131, 113, 124, 207, 209, 223, 217, 219, 236, 157, 150, 150, 127, 115, 114, 138, 122, 119, 173, 160, 166, 219, 221, 234, 218, 223, 235, 173, 164, 171, 129, 109, 105, 219, 218, 228, 186, 179, 188, 102, 86, 85, 96, 82, 77, 108, 88, 76, 136, 106, 91, 129, 93, 74, 105, 73, 61, 79, 60, 55, 76, 57, 54, 73, 55, 54, 74, 55, 53, 71, 57, 55, 88, 70, 68, 84, 66, 63, 79, 66, 70, 76, 65, 70, 99, 87, 86, 67, 53, 55, 102, 84, 78, 118, 94, 83, 150, 132, 131, 211, 204, 220, 213, 184, 201, 202, 191, 208, 177, 176, 188, 146, 130, 133, 170, 157, 160, 219, 221, 233, 211, 210, 220, 116, 88, 81, 132, 117, 117, 226, 229, 238, 171, 156, 160, 104, 84, 77, 96, 80, 77, 95, 83, 77, 105, 87, 80, 119, 94, 77, 95, 70, 60, 72, 56, 54, 68, 54, 55, 75, 56, 53, 77, 60, 55, 78, 65, 63, 95, 79, 77, 79, 65, 65, 51, 40, 52, 84, 74, 81, 94, 83, 86, 74, 60, 60, 127, 109, 101, 125, 102, 92, 140, 120, 118, 207, 199, 211, 216, 198, 214, 195, 188, 197, 183, 180, 187, 146, 132, 139, 169, 153, 163, 222, 227, 240, 167, 132, 134, 121, 81, 62, 101, 85, 78, 172, 167, 178, 163, 155, 154, 127, 115, 110, 130, 116, 114, 125, 113, 112, 111, 95, 90, 117, 98, 88, 79, 63, 58, 63, 51, 52, 71, 56, 55, 88, 69, 62, 90, 72, 69, 90, 75, 73, 101, 87, 79, 70, 58, 61, 55, 45, 56, 109, 100, 107, 68, 56, 59, 86, 72, 72, 133, 116, 110, 130, 109, 101, 113, 94, 92, 210, 210, 217, 221, 228, 244, 177, 167, 158, 122, 107, 95, 140, 123, 124, 168, 151, 161, 201, 189, 197, 125, 74, 57, 137, 92, 70, 99, 73, 63, 69, 58, 67, 117, 113, 124, 138, 134, 143, 123, 113, 115, 124, 112, 112, 152, 136, 134, 114, 97, 90, 76, 60, 57, 64, 52, 54, 82, 68, 66, 96, 80, 73, 104, 90, 85, 77, 66, 65, 68, 56, 58, 65, 55, 62, 63, 53, 64, 83, 74, 81, 78, 66, 67, 117, 104, 103, 120, 105, 102, 90, 71, 67, 113, 97, 98, 222, 223, 233, 211, 207, 217, 150, 131, 121, 127, 101, 90, 145, 122, 128, 165, 147, 150, 149, 103, 96, 116, 73, 57, 133, 95, 73, 122, 85, 68, 65, 55, 58, 73, 68, 72, 122, 118, 130, 121, 114, 121, 107, 95, 98, 136, 121, 117, 102, 87, 81, 75, 59, 57, 77, 64, 66, 92, 79, 77, 87, 74, 70, 100, 89, 86, 79, 69, 66, 66, 50, 55, 51, 39, 48, 63, 53, 60, 89, 78, 82, 104, 92, 93, 94, 83, 81, 93, 80, 81, 127, 110, 113, 162, 149, 155, 199, 193, 203, 141, 122, 124, 104, 83, 79, 151, 126, 128, 168, 146, 155, 160, 140, 144, 118, 60, 49, 113, 84, 73, 131, 92, 70, 126, 97, 72, 90, 77, 71, 70, 62, 64, 74, 67, 71, 91, 85, 89, 87, 77, 78, 103, 90, 86, 78, 66, 65, 74, 61, 61, 88, 75, 76, 98, 85, 83, 93, 82, 83, 87, 76, 78, 87, 73, 70, 83, 64, 58, 52, 39, 44, 60, 49, 53, 81, 69, 71, 93, 80, 80, 117, 104, 102, 164, 150, 155, 188, 172, 179, 188, 174, 182, 171, 157, 162, 134, 117, 120, 143, 124, 126, 172, 153, 156, 169, 151, 157, 167, 147, 154, 100, 62, 57, 106, 83, 73, 111, 83, 67, 118, 97, 89, 167, 154, 161, 153, 145, 150, 118, 109, 114, 78, 69, 74, 87, 78, 80, 86, 76, 76, 77, 65, 65, 76, 62, 60, 87, 72, 71, 125, 112, 111, 158, 149, 153, 174, 164, 169, 158, 145, 152, 119, 105, 106, 75, 62, 65, 86, 75, 79, 131, 117, 121, 169, 155, 157, 174, 158, 161, 180, 164, 168, 182, 165, 170, 185, 169, 172, 189, 174, 177, 190, 174, 181, 186, 169, 179, 178, 159, 165, 174, 158, 161, 178, 161, 167, 90, 71, 67, 84, 66, 64, 92, 73, 70, 163, 145, 150, 187, 175, 181, 191, 181, 188, 191, 179, 189, 181, 170, 178, 174, 165, 171, 159, 148, 153, 128, 117, 121, 139, 128, 129, 163, 151, 155, 189, 177, 183, 191, 179, 185, 191, 178, 186, 193, 180, 191, 191, 180, 188, 171, 160, 163, 175, 162, 165, 187, 170, 174, 188, 171, 177, 185, 168, 174, 186, 170, 175, 186, 169, 175, 187, 171, 175, 186, 169, 174, 186, 170, 176, 185, 170, 177, 180, 161, 167, 176, 159, 163, 176, 159, 166, 75, 61, 60, 70, 60, 54, 138, 124, 124, 195, 182, 186, 195, 183, 184, 195, 183, 187, 191, 179, 184, 186, 174, 175, 189, 177, 179, 195, 184, 188, 194, 183, 188, 194, 182, 185, 196, 184, 190, 195, 183, 191, 195, 182, 189, 191, 179, 184, 189, 178, 184, 191, 179, 185, 193, 180, 183, 186, 169, 172, 183, 165, 169, 186, 168, 174, 190, 173, 179, 188, 172, 177, 188, 171, 176, 192, 175, 181, 193, 177, 182, 191, 175, 181, 188, 173, 179, 181, 163, 167, 181, 164, 168, 182, 165, 173, 65, 57, 56, 126, 114, 115, 191, 176, 178, 195, 183, 184, 201, 187, 193, 202, 188, 197, 200, 186, 192, 192, 175, 177, 189, 172, 176, 196, 181, 188, 193, 179, 185, 193, 178, 182, 195, 180, 187, 199, 186, 194, 197, 185, 191, 193, 182, 188, 191, 178, 183, 190, 175, 180, 190, 173, 177, 187, 168, 172, 182, 165, 168, 183, 165, 168, 184, 167, 170, 186, 170, 173, 184, 168, 172, 186, 170, 176, 188, 173, 179, 186, 171, 176, 185, 168, 173, 180, 161, 165, 184, 167, 171, 185, 168, 177, 87, 78, 82, 186, 171, 175, 202, 186, 189, 203, 192, 196, 201, 188, 194, 199, 184, 191, 200, 188, 192, 203, 191, 194, 195, 180, 184, 199, 185, 192, 199, 186, 193, 198, 186, 193, 200, 186, 192, 199, 187, 193, 199, 188, 192, 195, 183, 187, 193, 176, 181, 191, 173, 178, 192, 174, 180, 188, 171, 175, 184, 168, 171, 180, 163, 166, 182, 163, 165, 187, 171, 172, 187, 170, 172, 186, 169, 174, 185, 169, 176, 186, 170, 176, 185, 168, 174, 182, 163, 167, 187, 170, 177, 185, 169, 178, 150, 139, 143, 195, 180, 182, 196, 182, 181, 203, 190, 191, 204, 189, 193, 204, 186, 191, 195, 178, 179, 198, 185, 186, 198, 183, 187, 203, 189, 196, 202, 190, 196, 199, 188, 194, 202, 188, 195, 196, 183, 189, 197, 184, 188, 191, 177, 181, 193, 176, 182, 194, 180, 185, 195, 180, 186, 195, 180, 184, 192, 177, 181, 186, 168, 171, 183, 164, 166, 186, 169, 172, 190, 172, 175, 191, 173, 176, 186, 170, 175, 187, 170, 176, 185, 168, 174, 186, 167, 171, 189, 171, 178, 189, 173, 181, 190, 177, 181, 200, 183, 186, 202, 187, 188, 204, 189, 194, 203, 190, 195, 203, 190, 193, 199, 183, 182, 197, 182, 181, 203, 189, 192, 204, 191, 197, 199, 186, 191, 196, 182, 186, 203, 189, 195, 198, 183, 188, 196, 181, 185, 195, 179, 184, 196, 182, 186, 198, 186, 190, 199, 184, 190, 193, 178, 183, 190, 175, 178, 187, 169, 170, 190, 171, 173, 190, 174, 178, 190, 172, 176, 184, 167, 169, 185, 169, 174, 189, 172, 178, 186, 168, 174, 187, 168, 171, 185, 166, 171, 191, 173, 180, 200, 186, 189, 201, 185, 187, 201, 184, 188, 206, 191, 198, 204, 192, 197, 203, 191, 195, 199, 185, 185, 197, 180, 179, 202, 188, 191, 204, 191, 196, 202, 187, 190, 195, 180, 181, 198, 184, 190, 198, 183, 187, 199, 184, 186, 194, 179, 181, 192, 180, 181, 193, 178, 181, 193, 176, 181, 190, 172, 176, 184, 167, 169, 185, 167, 167, 187, 170, 170, 190, 175, 178, 191, 172, 177, 192, 174, 179, 193, 176, 182, 193, 176, 182, 186, 168, 174, 181, 162, 164, 177, 157, 160, 183, 164, 168, 204, 190, 194, 198, 182, 182, 195, 177, 175, 203, 188, 188, 203, 189, 191, 203, 186, 190, 201, 181, 184, 195, 177, 174, 203, 189, 191, 204, 191, 197, 202, 188, 191, 193, 178, 178, 192, 177, 181, 197, 182, 186, 199, 185, 187, 192, 176, 176, 184, 168, 168, 189, 171, 172, 188, 168, 170, 187, 168, 169, 185, 166, 166, 185, 166, 166, 186, 169, 169, 190, 173, 176, 192, 174, 179, 195, 179, 185, 195, 179, 186, 194, 178, 184, 187, 169, 175, 182, 163, 165, 177, 158, 160, 187, 169, 173, 206, 192, 195, 203, 187, 187, 195, 176, 172, 196, 175, 172, 198, 182, 180, 195, 178, 175, 193, 172, 169, 191, 171, 166, 198, 182, 181, 201, 187, 194, 199, 185, 190, 190, 173, 174, 190, 175, 175, 194, 179, 185, 193, 179, 182, 186, 168, 167, 187, 167, 167, 187, 167, 168, 187, 167, 169, 186, 166, 164, 186, 166, 165, 183, 163, 163, 188, 169, 169, 191, 172, 174, 193, 177, 183, 196, 182, 188, 193, 178, 185, 192, 176, 184, 187, 170, 176, 188, 170, 173, 192, 173, 177, 194, 178, 187], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284371832080}], \"selected_variable\": {\"name\": [\"<SArray>\"], \"dtype\": \"Image\", \"view_component\": \"Images\", \"view_file\": \"sarray\", \"descriptives\": {\"rows\": 1}, \"type\": \"SArray\", \"view_components\": [\"Images\"]}}, e);\n",
       "                });\n",
       "            })();\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "knn_model_cat.query(cat)\n",
    "image_train_cat[image_train_cat['id'] == 16289]['image'].show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 86,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "PROGRESS: Starting pairwise querying.\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | Query points | # Pairs | % Complete. | Elapsed Time |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | 0            | 1       | 0.196464    | 18.286ms     |\n",
      "PROGRESS: | Done         |         | 100         | 131.19ms     |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n"
     ]
    },
    {
     "data": {
      "application/javascript": [
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//cdnjs.cloudflare.com/ajax/libs/font-awesome/4.1.0/css/font-awesome.min.css\"\n",
       "}));\n",
       "$(\"head\").append($(\"<link/>\").attr({\n",
       "  rel:  \"stylesheet\",\n",
       "  type: \"text/css\",\n",
       "  href: \"//dato.com/files/canvas/1.6.1/css/canvas.css\"\n",
       "}));\n",
       "\n",
       "            (function(){\n",
       "\n",
       "                var e = null;\n",
       "                if (typeof element == 'undefined') {\n",
       "                    var scripts = document.getElementsByTagName('script');\n",
       "                    var thisScriptTag = scripts[scripts.length-1];\n",
       "                    var parentDiv = thisScriptTag.parentNode;\n",
       "                    e = document.createElement('div');\n",
       "                    parentDiv.appendChild(e);\n",
       "                } else {\n",
       "                    e = element[0];\n",
       "                }\n",
       "\n",
       "                if (typeof requirejs !== 'undefined') {\n",
       "                    // disable load timeout; ipython_app.js is large and can take a while to load.\n",
       "                    requirejs.config({waitSeconds: 0});\n",
       "                }\n",
       "\n",
       "                require(['//dato.com/files/canvas/1.6.1/js/ipython_app.js'], function(IPythonApp){\n",
       "                    var app = new IPythonApp();\n",
       "                    app.attachView('sarray','Images', {\"ipython\": true, \"rows\": [{\"format\": \"raw\", \"value\": [16, 17, 11, 18, 19, 13, 20, 21, 15, 24, 25, 19, 26, 27, 21, 22, 23, 17, 19, 20, 14, 19, 20, 15, 16, 17, 12, 12, 13, 8, 11, 12, 8, 28, 17, 6, 88, 44, 8, 84, 41, 13, 84, 46, 31, 91, 51, 34, 97, 56, 36, 101, 61, 40, 85, 51, 33, 74, 45, 28, 79, 47, 29, 92, 54, 35, 96, 53, 33, 103, 58, 34, 86, 48, 27, 86, 52, 34, 107, 68, 51, 90, 61, 48, 101, 93, 92, 116, 130, 145, 103, 110, 123, 98, 94, 100, 12, 13, 9, 15, 16, 12, 20, 21, 17, 23, 24, 19, 27, 28, 22, 24, 25, 19, 20, 21, 15, 21, 22, 16, 16, 17, 12, 13, 14, 9, 12, 13, 9, 25, 15, 5, 81, 41, 10, 80, 41, 14, 83, 45, 25, 100, 55, 33, 108, 61, 39, 100, 57, 36, 67, 31, 16, 62, 30, 19, 75, 39, 25, 99, 57, 37, 112, 65, 43, 99, 55, 31, 74, 38, 19, 80, 45, 29, 102, 62, 43, 98, 66, 53, 105, 95, 95, 114, 126, 142, 102, 108, 123, 97, 92, 99, 19, 19, 17, 22, 22, 20, 20, 20, 17, 23, 25, 19, 28, 29, 23, 26, 27, 21, 21, 22, 16, 21, 22, 16, 16, 17, 12, 16, 16, 11, 14, 16, 12, 23, 18, 13, 78, 45, 25, 102, 68, 50, 94, 59, 39, 102, 57, 34, 108, 61, 37, 112, 67, 43, 100, 61, 40, 105, 64, 45, 111, 66, 47, 114, 67, 46, 124, 75, 52, 103, 61, 36, 81, 46, 29, 78, 43, 28, 102, 61, 40, 99, 72, 61, 108, 103, 105, 118, 133, 149, 103, 109, 123, 96, 94, 100, 23, 23, 21, 70, 70, 69, 64, 63, 60, 29, 29, 24, 25, 26, 21, 26, 27, 22, 22, 23, 17, 22, 23, 18, 18, 19, 14, 16, 16, 12, 15, 17, 15, 46, 44, 46, 112, 84, 75, 106, 78, 70, 96, 65, 52, 105, 64, 42, 107, 64, 38, 118, 73, 46, 121, 80, 52, 123, 82, 55, 122, 80, 53, 120, 80, 53, 121, 82, 54, 107, 67, 41, 87, 52, 37, 82, 45, 30, 101, 59, 37, 83, 63, 54, 84, 85, 88, 108, 123, 135, 88, 93, 102, 77, 77, 82, 29, 28, 28, 78, 77, 81, 116, 104, 102, 104, 94, 91, 37, 35, 32, 25, 25, 21, 24, 23, 20, 23, 23, 20, 19, 19, 17, 16, 15, 14, 22, 23, 24, 97, 90, 89, 151, 118, 108, 111, 87, 81, 111, 85, 77, 111, 70, 48, 110, 66, 40, 114, 70, 43, 115, 72, 45, 119, 80, 51, 123, 78, 50, 114, 71, 46, 113, 72, 43, 110, 66, 40, 86, 49, 34, 81, 41, 24, 97, 54, 32, 70, 49, 41, 49, 44, 44, 61, 62, 66, 56, 54, 60, 52, 49, 51, 29, 28, 28, 49, 48, 52, 108, 92, 88, 156, 139, 128, 90, 83, 72, 31, 30, 21, 23, 23, 18, 40, 39, 34, 60, 57, 53, 68, 63, 60, 66, 61, 58, 130, 111, 102, 135, 95, 80, 122, 95, 86, 126, 105, 100, 103, 70, 55, 94, 60, 40, 92, 58, 39, 94, 59, 40, 99, 61, 38, 101, 57, 33, 93, 51, 28, 91, 51, 29, 87, 47, 25, 74, 40, 25, 73, 41, 28, 88, 53, 40, 63, 45, 40, 51, 44, 43, 52, 49, 49, 53, 49, 52, 53, 48, 49, 27, 26, 24, 56, 56, 59, 105, 88, 82, 137, 105, 88, 139, 114, 97, 109, 95, 84, 98, 87, 81, 117, 110, 105, 162, 153, 146, 158, 144, 136, 117, 100, 89, 127, 96, 79, 128, 84, 67, 123, 93, 80, 129, 113, 109, 92, 75, 69, 55, 38, 29, 55, 38, 30, 63, 44, 34, 83, 53, 38, 94, 61, 42, 101, 63, 38, 92, 59, 37, 103, 71, 49, 89, 59, 37, 63, 44, 36, 67, 47, 46, 55, 41, 40, 52, 48, 46, 55, 53, 53, 58, 54, 55, 58, 54, 54, 26, 25, 22, 64, 64, 65, 99, 82, 75, 130, 92, 76, 161, 127, 112, 164, 140, 131, 168, 149, 144, 173, 160, 154, 211, 196, 186, 172, 149, 136, 122, 93, 75, 144, 106, 87, 143, 101, 87, 135, 104, 89, 120, 108, 106, 90, 85, 87, 38, 33, 34, 31, 26, 28, 46, 38, 38, 86, 67, 59, 106, 87, 72, 140, 105, 73, 129, 99, 69, 138, 113, 82, 147, 118, 81, 65, 57, 45, 49, 42, 45, 50, 41, 41, 54, 53, 51, 60, 60, 58, 63, 58, 58, 64, 59, 58, 31, 31, 27, 67, 66, 66, 116, 99, 93, 143, 114, 102, 181, 158, 147, 194, 179, 171, 196, 182, 177, 198, 185, 177, 206, 187, 174, 156, 127, 109, 131, 97, 75, 162, 126, 108, 152, 115, 104, 151, 120, 104, 125, 115, 112, 79, 79, 84, 37, 37, 41, 21, 22, 26, 24, 23, 26, 58, 49, 44, 103, 93, 77, 160, 127, 88, 149, 121, 83, 144, 120, 79, 177, 149, 99, 85, 82, 64, 41, 40, 45, 51, 47, 49, 56, 56, 56, 63, 62, 61, 66, 61, 61, 68, 64, 63, 29, 29, 29, 70, 66, 66, 118, 103, 100, 160, 141, 133, 180, 168, 159, 185, 172, 167, 206, 195, 192, 196, 183, 172, 174, 153, 133, 141, 112, 90, 148, 123, 105, 175, 150, 137, 172, 139, 123, 178, 150, 133, 142, 130, 126, 65, 65, 67, 29, 30, 32, 19, 20, 23, 18, 18, 21, 57, 52, 45, 142, 124, 100, 186, 156, 120, 166, 145, 104, 175, 158, 118, 185, 168, 126, 87, 81, 67, 42, 44, 50, 47, 49, 57, 46, 46, 52, 60, 59, 62, 69, 65, 67, 70, 67, 66, 51, 51, 52, 77, 72, 74, 117, 103, 102, 156, 142, 135, 156, 147, 137, 138, 123, 114, 154, 140, 131, 159, 141, 132, 136, 110, 98, 126, 99, 87, 166, 147, 140, 201, 184, 176, 183, 158, 143, 201, 177, 163, 142, 130, 126, 46, 46, 47, 18, 19, 21, 17, 18, 20, 22, 22, 25, 43, 38, 34, 138, 119, 97, 166, 136, 107, 185, 162, 122, 157, 147, 114, 173, 168, 135, 98, 94, 82, 46, 47, 49, 50, 53, 62, 45, 45, 53, 51, 49, 54, 70, 66, 69, 76, 72, 72, 60, 58, 59, 79, 74, 77, 127, 115, 116, 143, 132, 126, 143, 136, 124, 143, 125, 112, 128, 110, 94, 105, 86, 72, 127, 100, 88, 142, 123, 110, 167, 151, 144, 209, 197, 190, 176, 159, 148, 195, 175, 165, 149, 137, 134, 44, 42, 45, 23, 24, 28, 30, 31, 34, 33, 33, 38, 42, 37, 39, 74, 60, 50, 121, 95, 74, 177, 144, 103, 173, 147, 109, 193, 179, 144, 124, 119, 108, 46, 50, 52, 52, 55, 63, 45, 45, 53, 43, 42, 46, 68, 64, 67, 80, 76, 75, 59, 56, 56, 71, 68, 70, 131, 121, 123, 147, 135, 130, 137, 128, 117, 150, 130, 119, 128, 110, 95, 94, 77, 63, 140, 112, 103, 156, 143, 129, 162, 146, 136, 196, 181, 173, 182, 167, 156, 175, 158, 148, 132, 120, 114, 50, 49, 51, 32, 34, 38, 39, 40, 44, 44, 44, 50, 48, 46, 53, 44, 41, 40, 98, 80, 65, 176, 139, 97, 150, 117, 83, 145, 128, 101, 101, 98, 94, 45, 50, 56, 48, 52, 61, 42, 42, 50, 39, 38, 42, 68, 64, 67, 87, 80, 81, 65, 61, 60, 73, 69, 71, 135, 125, 127, 149, 134, 128, 113, 101, 92, 111, 92, 85, 129, 114, 105, 116, 105, 101, 128, 103, 105, 112, 99, 95, 134, 111, 105, 195, 174, 167, 193, 177, 167, 167, 151, 140, 118, 108, 99, 51, 50, 52, 40, 41, 47, 42, 43, 49, 50, 51, 56, 47, 50, 58, 52, 56, 60, 114, 101, 90, 180, 144, 101, 126, 103, 83, 94, 89, 82, 69, 70, 75, 55, 57, 65, 53, 55, 64, 40, 41, 48, 37, 36, 40, 69, 65, 66, 90, 82, 83, 71, 66, 67, 88, 80, 81, 119, 107, 106, 130, 115, 104, 135, 119, 112, 128, 114, 108, 152, 144, 142, 158, 152, 152, 140, 124, 124, 114, 93, 91, 159, 125, 110, 200, 176, 164, 198, 182, 173, 170, 156, 149, 114, 107, 104, 53, 53, 58, 46, 49, 56, 44, 47, 54, 46, 49, 55, 39, 40, 46, 57, 58, 65, 132, 119, 107, 190, 152, 106, 178, 140, 102, 133, 115, 102, 68, 67, 68, 54, 58, 68, 46, 50, 60, 31, 36, 40, 37, 38, 39, 69, 63, 63, 92, 83, 83, 78, 73, 74, 89, 80, 80, 87, 76, 74, 94, 81, 71, 121, 103, 98, 141, 126, 119, 146, 138, 137, 160, 150, 152, 164, 144, 143, 168, 141, 138, 179, 140, 125, 200, 172, 156, 197, 177, 164, 167, 152, 145, 106, 101, 102, 54, 56, 62, 53, 57, 64, 49, 52, 59, 43, 46, 53, 42, 45, 51, 63, 64, 72, 105, 93, 84, 156, 126, 89, 152, 121, 90, 123, 108, 101, 71, 73, 75, 73, 79, 91, 50, 54, 66, 34, 39, 45, 36, 37, 39, 70, 64, 64, 98, 89, 90, 85, 79, 81, 89, 81, 80, 65, 57, 54, 72, 61, 55, 130, 111, 108, 167, 149, 140, 132, 122, 119, 128, 121, 124, 170, 154, 149, 199, 178, 172, 205, 175, 163, 207, 177, 161, 192, 169, 152, 154, 141, 132, 86, 84, 88, 53, 56, 63, 57, 60, 67, 51, 54, 61, 47, 51, 57, 49, 53, 60, 54, 55, 61, 75, 66, 60, 114, 96, 74, 139, 124, 111, 136, 130, 134, 95, 99, 105, 90, 96, 108, 64, 69, 81, 43, 49, 56, 40, 41, 44, 71, 65, 66, 106, 96, 97, 90, 83, 84, 90, 82, 82, 73, 66, 63, 97, 87, 84, 164, 142, 141, 165, 144, 132, 97, 87, 82, 88, 83, 87, 181, 166, 159, 206, 189, 180, 201, 179, 170, 218, 194, 183, 193, 174, 159, 137, 127, 119, 67, 67, 74, 51, 54, 62, 55, 58, 65, 52, 55, 62, 50, 53, 60, 46, 49, 53, 47, 44, 44, 93, 83, 77, 130, 118, 109, 140, 129, 123, 152, 145, 150, 144, 145, 148, 103, 106, 115, 71, 74, 87, 47, 53, 61, 45, 46, 51, 78, 72, 75, 116, 107, 108, 88, 79, 81, 90, 84, 83, 93, 88, 85, 105, 97, 96, 148, 127, 125, 152, 128, 116, 81, 66, 61, 77, 65, 70, 164, 141, 136, 186, 162, 155, 191, 166, 161, 211, 190, 185, 184, 169, 158, 117, 110, 103, 57, 58, 66, 52, 55, 65, 55, 58, 65, 54, 57, 64, 49, 52, 59, 42, 42, 45, 69, 61, 56, 129, 116, 109, 162, 150, 146, 124, 112, 108, 142, 129, 129, 161, 155, 153, 107, 107, 113, 67, 71, 83, 50, 56, 65, 45, 46, 52, 89, 83, 85, 122, 112, 114, 96, 87, 88, 99, 90, 91, 105, 98, 97, 107, 100, 98, 115, 99, 96, 121, 96, 90, 98, 74, 67, 102, 83, 79, 132, 107, 103, 153, 126, 121, 175, 148, 142, 189, 163, 156, 158, 142, 137, 89, 86, 84, 50, 52, 58, 47, 50, 60, 47, 50, 59, 47, 49, 57, 43, 43, 50, 46, 45, 49, 85, 77, 75, 151, 136, 132, 162, 148, 144, 125, 114, 112, 145, 129, 122, 151, 138, 131, 115, 115, 120, 77, 84, 94, 62, 70, 79, 51, 53, 59, 94, 88, 88, 121, 110, 112, 106, 97, 98, 108, 99, 100, 111, 102, 103, 95, 89, 86, 72, 59, 56, 115, 95, 91, 139, 118, 112, 152, 131, 121, 186, 162, 153, 178, 154, 147, 165, 146, 138, 158, 140, 137, 107, 98, 98, 53, 54, 57, 43, 47, 54, 42, 46, 55, 41, 44, 53, 36, 37, 44, 36, 36, 42, 46, 46, 49, 87, 81, 81, 158, 146, 145, 171, 159, 158, 131, 121, 118, 165, 148, 140, 171, 155, 147, 131, 127, 129, 83, 86, 92, 63, 67, 74, 60, 60, 65, 104, 97, 97, 120, 110, 112, 104, 95, 96, 107, 98, 99, 111, 103, 103, 107, 102, 99, 100, 89, 86, 136, 122, 120, 149, 135, 131, 181, 162, 152, 228, 206, 197, 194, 176, 169, 157, 147, 141, 101, 95, 96, 56, 56, 60, 44, 50, 54, 43, 47, 54, 44, 46, 54, 44, 45, 52, 37, 36, 42, 38, 37, 42, 46, 45, 48, 77, 72, 71, 146, 136, 134, 182, 173, 173, 143, 133, 129, 168, 151, 142, 185, 168, 160, 143, 134, 131, 92, 87, 89, 61, 59, 63, 73, 70, 75, 114, 106, 108, 123, 112, 115, 104, 95, 96, 108, 99, 100, 115, 106, 107, 114, 108, 106, 113, 104, 102, 84, 74, 74, 76, 70, 68, 149, 139, 138, 168, 155, 156, 136, 126, 126, 96, 93, 92, 48, 48, 51, 44, 48, 52, 44, 49, 53, 44, 46, 51, 49, 50, 57, 46, 46, 53, 44, 42, 48, 41, 39, 43, 54, 51, 49, 79, 71, 66, 115, 104, 99, 150, 141, 139, 163, 151, 146, 174, 156, 146, 174, 157, 146, 166, 151, 145, 132, 120, 118, 85, 77, 79, 94, 89, 93, 125, 116, 118, 126, 115, 118, 108, 99, 100, 111, 102, 103, 113, 104, 105, 115, 109, 107, 114, 106, 105, 86, 78, 78, 81, 78, 78, 76, 73, 79, 59, 55, 63, 73, 69, 75, 64, 65, 67, 42, 45, 48, 48, 52, 56, 49, 51, 53, 52, 50, 52, 59, 57, 62, 55, 54, 60, 47, 46, 51, 42, 39, 41, 64, 56, 50, 107, 95, 86, 130, 116, 108, 128, 117, 111, 168, 155, 148, 189, 173, 164, 171, 153, 143, 169, 151, 142, 170, 155, 149, 117, 107, 107, 104, 97, 102, 127, 118, 122, 129, 118, 122, 107, 98, 99, 110, 101, 102, 111, 102, 103, 115, 107, 105, 118, 110, 108, 119, 111, 109, 120, 114, 112, 79, 76, 77, 40, 38, 44, 64, 62, 68, 48, 49, 50, 42, 43, 47, 53, 52, 57, 71, 68, 69, 93, 87, 87, 70, 64, 66, 59, 57, 62, 57, 56, 61, 57, 51, 51, 93, 79, 73, 134, 117, 109, 151, 134, 126, 135, 118, 111, 152, 138, 131, 188, 176, 170, 182, 167, 160, 169, 150, 138, 178, 163, 154, 137, 128, 127, 118, 111, 115, 131, 121, 127, 131, 122, 125, 109, 100, 101, 112, 103, 104, 112, 103, 104, 117, 109, 107, 120, 112, 110, 121, 113, 110, 123, 115, 113, 108, 103, 102, 64, 60, 63, 61, 58, 61, 50, 50, 50, 63, 62, 64, 95, 92, 94, 97, 90, 89, 125, 116, 113, 103, 94, 93, 86, 80, 81, 79, 73, 75, 83, 74, 73, 126, 111, 109, 155, 137, 135, 164, 147, 145, 148, 131, 129, 147, 132, 126, 171, 158, 151, 177, 161, 152, 166, 144, 131, 172, 150, 140, 153, 138, 134, 130, 120, 120, 132, 122, 123, 135, 125, 128, 111, 102, 103, 110, 101, 103, 114, 105, 106, 119, 111, 110, 120, 112, 110, 122, 114, 112, 125, 117, 115, 125, 117, 117, 97, 90, 90, 58, 53, 52, 64, 61, 60, 87, 82, 82, 131, 124, 123, 112, 102, 98, 125, 113, 107, 133, 119, 114, 137, 123, 118, 100, 88, 85, 103, 92, 91, 139, 125, 127, 154, 138, 141, 155, 139, 142, 154, 138, 140, 156, 140, 136, 180, 162, 154, 176, 155, 144, 150, 126, 114, 144, 118, 107, 139, 120, 114, 128, 116, 114, 131, 121, 119, 133, 123, 125, 111, 102, 103, 111, 102, 104, 116, 107, 108, 119, 111, 109, 121, 113, 111, 125, 117, 115, 129, 121, 119, 130, 120, 120, 115, 106, 103, 93, 86, 81, 102, 96, 94, 118, 110, 108, 152, 141, 138, 142, 128, 122, 139, 123, 114, 136, 117, 108, 141, 120, 111, 116, 98, 90, 117, 104, 101, 144, 130, 131, 152, 137, 138, 152, 137, 139, 144, 129, 130, 145, 129, 124, 152, 130, 121, 135, 108, 96, 117, 92, 80, 125, 104, 93, 124, 108, 102, 131, 119, 119, 137, 124, 124, 133, 123, 125, 112, 103, 104, 112, 103, 104, 117, 108, 109, 119, 111, 110, 124, 116, 114, 126, 118, 117, 127, 119, 117, 129, 116, 115, 139, 128, 122, 127, 118, 111, 119, 111, 106, 133, 121, 115, 154, 139, 131, 154, 137, 128, 148, 130, 119, 140, 118, 105, 129, 104, 92, 124, 103, 93, 131, 117, 113, 147, 134, 133, 147, 134, 133, 146, 134, 133, 148, 135, 134, 145, 130, 127, 142, 120, 113, 129, 104, 95, 127, 105, 97, 137, 122, 115, 136, 124, 121, 136, 125, 127, 138, 125, 127, 133, 123, 126, 111, 101, 102, 112, 103, 104, 117, 108, 109, 121, 112, 113, 124, 115, 116, 123, 114, 115, 126, 117, 117, 126, 113, 109, 131, 118, 111, 131, 119, 110, 121, 110, 99, 141, 123, 111, 150, 129, 116, 158, 138, 125, 156, 134, 121, 148, 123, 108, 131, 107, 94, 119, 101, 92, 144, 130, 125, 147, 136, 135, 143, 133, 132, 143, 133, 131, 144, 133, 132, 144, 130, 130, 147, 132, 131, 145, 130, 129, 142, 127, 127, 139, 128, 128, 138, 129, 129, 137, 127, 128, 132, 122, 123, 133, 123, 126, 109, 100, 101, 110, 101, 102, 114, 105, 106, 116, 107, 109, 119, 110, 111, 121, 112, 113, 122, 113, 113, 124, 115, 113, 125, 113, 108, 128, 114, 105, 122, 105, 93, 129, 107, 94, 134, 111, 97, 149, 126, 112, 155, 132, 118, 144, 120, 108, 135, 114, 104, 136, 119, 112, 145, 131, 128, 144, 134, 133, 143, 133, 133, 141, 131, 131, 141, 131, 130, 143, 130, 131, 142, 129, 130, 140, 127, 128, 138, 125, 126, 136, 125, 127, 133, 123, 124, 133, 123, 123, 129, 119, 120, 128, 119, 121, 105, 96, 97, 107, 98, 99, 111, 102, 103, 114, 105, 106, 119, 110, 111, 120, 111, 112, 118, 109, 110, 119, 113, 113, 126, 117, 114, 123, 108, 100, 123, 103, 92, 121, 98, 86, 124, 101, 89, 130, 107, 95, 129, 106, 94, 131, 111, 103, 139, 121, 115, 146, 131, 128, 142, 129, 128, 142, 132, 133, 143, 133, 134, 141, 131, 132, 141, 131, 132, 138, 127, 129, 138, 126, 128, 135, 123, 126, 132, 121, 123, 133, 122, 124, 130, 120, 121, 128, 118, 119, 127, 117, 118, 127, 117, 120], \"height\": 32, \"channels\": 3, \"width\": 32, \"type\": \"image\", \"id\": 140284371830672}], \"selected_variable\": {\"name\": [\"<SArray>\"], \"dtype\": \"Image\", \"view_component\": \"Images\", \"view_file\": \"sarray\", \"descriptives\": {\"rows\": 1}, \"type\": \"SArray\", \"view_components\": [\"Images\"]}}, e);\n",
       "                });\n",
       "            })();\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "knn_model_dog.query(cat)\n",
    "image_train_dog[image_train_dog['id'] == 16976]['image'].show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### 3.  A simple example of nearest-neighbors classification."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 46,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "PROGRESS: Starting pairwise querying.\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | Query points | # Pairs | % Complete. | Elapsed Time |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | 0            | 1       | 0.196464    | 27.1ms       |\n",
      "PROGRESS: | Done         |         | 100         | 166.445ms    |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "36.15573070978294"
      ]
     },
     "execution_count": 46,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "knn_model_cat.query(cat)['distance'].mean()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 47,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "PROGRESS: Starting pairwise querying.\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | Query points | # Pairs | % Complete. | Elapsed Time |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | 0            | 1       | 0.196464    | 26.119ms     |\n",
      "PROGRESS: | Done         |         | 100         | 157.284ms    |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "37.77071136184157"
      ]
     },
     "execution_count": 47,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "knn_model_dog.query(cat)['distance'].mean()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### 4.  [Challenging Question] Computing nearest neighbors accuracy using SFrame operations."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 51,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "image_test_auto = image_test[image_test['label'] == 'automobile']\n",
    "image_test_bird = image_test[image_test['label'] == 'bird']\n",
    "image_test_cat = image_test[image_test['label'] == 'cat']\n",
    "image_test_dog = image_test[image_test['label'] == 'dog']"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 65,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "PROGRESS: Starting blockwise querying.\n",
      "PROGRESS: max rows per data block: 7668\n",
      "PROGRESS: number of reference data blocks: 2\n",
      "PROGRESS: number of query data blocks: 1\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | Query points | # Pairs | % Complete. | Elapsed Time |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | 1000         | 255000  | 50.0982     | 4.93s        |\n",
      "PROGRESS: | Done         | 509000  | 100         | 5.24s        |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: Starting blockwise querying.\n",
      "PROGRESS: max rows per data block: 7668\n",
      "PROGRESS: number of reference data blocks: 2\n",
      "PROGRESS: number of query data blocks: 1\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | Query points | # Pairs | % Complete. | Elapsed Time |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | 1000         | 255000  | 50.0982     | 1.46s        |\n",
      "PROGRESS: | Done         | 509000  | 100         | 1.50s        |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: Starting blockwise querying.\n",
      "PROGRESS: max rows per data block: 7668\n",
      "PROGRESS: number of reference data blocks: 2\n",
      "PROGRESS: number of query data blocks: 1\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | Query points | # Pairs | % Complete. | Elapsed Time |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | 1000         | 239000  | 50          | 1.16s        |\n",
      "PROGRESS: | Done         | 478000  | 100         | 1.51s        |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: Starting blockwise querying.\n",
      "PROGRESS: max rows per data block: 7668\n",
      "PROGRESS: number of reference data blocks: 2\n",
      "PROGRESS: number of query data blocks: 1\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | Query points | # Pairs | % Complete. | Elapsed Time |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n",
      "PROGRESS: | 1000         | 255000  | 50.0982     | 2.72s        |\n",
      "PROGRESS: | Done         | 509000  | 100         | 2.93s        |\n",
      "PROGRESS: +--------------+---------+-------------+--------------+\n"
     ]
    }
   ],
   "source": [
    "dog_cat_neighbors = knn_model_cat.query(image_test_dog, k=1)\n",
    "dog_auto_neighbors = knn_model_auto.query(image_test_dog, k=1)\n",
    "dog_bird_neighbors = knn_model_bird.query(image_test_dog, k=1)\n",
    "dog_dog_neighbors = knn_model_dog.query(image_test_dog, k=1)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 70,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "#dog_distances = {}\n",
    "#dog_distances['dog-dog'] = dog_dog_neighbors['distance']\n",
    "#dog_distances['dog-cat'] = dog_cat_neighbors['distance']\n",
    "#dog_distances['dog-auto'] = dog_auto_neighbors['distance']\n",
    "#dog_distances['dog-bird'] = dog_bird_neighbors['distance']\n",
    "dog_distances = graphlab.SFrame({'dog-dog': dog_dog_neighbors['distance'], 'dog-cat': dog_cat_neighbors['distance'], 'dog-auto': dog_auto_neighbors['distance'], 'dog-bird': dog_bird_neighbors['distance']})"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 78,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div style=\"max-height:1000px;max-width:1500px;overflow:auto;\"><table frame=\"box\" rules=\"cols\">\n",
       "    <tr>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">dog-auto</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">dog-bird</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">dog-cat</th>\n",
       "        <th style=\"padding-left: 1em; padding-right: 1em; text-align: center\">dog-dog</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">41.9579761457</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">41.7538647304</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">36.4196077068</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">33.4773590373</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">46.0021331807</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">41.3382958925</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">38.8353268874</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">32.8458495684</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">42.9462290692</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">38.6157590853</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">36.9763410854</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">35.0397073189</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">41.6866060048</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">37.0892269954</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">34.5750072914</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">33.9010327697</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">39.2269664935</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">38.272288694</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">34.778824791</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">37.4849250909</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">40.5845117698</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">39.1462089236</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">35.1171578292</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">34.945165344</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">45.1067352961</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">40.523040106</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">40.6095830913</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">39.0957278345</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">41.3221140974</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">38.1947918393</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">39.9036867306</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">37.7696131032</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">41.8244654995</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">40.1567131661</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">38.0674700168</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">35.1089144603</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">45.4976929401</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">45.5597962603</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">42.7258732951</td>\n",
       "        <td style=\"padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top\">43.2422832585</td>\n",
       "    </tr>\n",
       "</table>\n",
       "[1000 rows x 4 columns]<br/>Note: Only the head of the SFrame is printed.<br/>You can use print_rows(num_rows=m, num_columns=n) to print more rows and columns.\n",
       "</div>"
      ],
      "text/plain": [
       "Columns:\n",
       "\tdog-auto\tfloat\n",
       "\tdog-bird\tfloat\n",
       "\tdog-cat\tfloat\n",
       "\tdog-dog\tfloat\n",
       "\n",
       "Rows: 1000\n",
       "\n",
       "Data:\n",
       "+---------------+---------------+---------------+---------------+\n",
       "|    dog-auto   |    dog-bird   |    dog-cat    |    dog-dog    |\n",
       "+---------------+---------------+---------------+---------------+\n",
       "| 41.9579761457 | 41.7538647304 | 36.4196077068 | 33.4773590373 |\n",
       "| 46.0021331807 | 41.3382958925 | 38.8353268874 | 32.8458495684 |\n",
       "| 42.9462290692 | 38.6157590853 | 36.9763410854 | 35.0397073189 |\n",
       "| 41.6866060048 | 37.0892269954 | 34.5750072914 | 33.9010327697 |\n",
       "| 39.2269664935 |  38.272288694 |  34.778824791 | 37.4849250909 |\n",
       "| 40.5845117698 | 39.1462089236 | 35.1171578292 |  34.945165344 |\n",
       "| 45.1067352961 |  40.523040106 | 40.6095830913 | 39.0957278345 |\n",
       "| 41.3221140974 | 38.1947918393 | 39.9036867306 | 37.7696131032 |\n",
       "| 41.8244654995 | 40.1567131661 | 38.0674700168 | 35.1089144603 |\n",
       "| 45.4976929401 | 45.5597962603 | 42.7258732951 | 43.2422832585 |\n",
       "+---------------+---------------+---------------+---------------+\n",
       "[1000 rows x 4 columns]\n",
       "Note: Only the head of the SFrame is printed.\n",
       "You can use print_rows(num_rows=m, num_columns=n) to print more rows and columns."
      ]
     },
     "execution_count": 78,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "dog_distances"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 79,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "def is_dog_correct(row):\n",
    "    if row['dog-dog'] < row['dog-auto'] and row['dog-dog'] < row['dog-bird'] and row['dog-dog'] < row['dog-cat']:\n",
    "        return 1\n",
    "    else:\n",
    "        return 0"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 80,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "678"
      ]
     },
     "execution_count": 80,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "apply_result = dog_distances.apply(is_dog_correct)\n",
    "apply_result.sum()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 83,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "PROGRESS: Creating a validation set from 5 percent of training data. This may take a while.\n",
      "          You can set ``validation_set=None`` to disable validation tracking.\n",
      "\n",
      "PROGRESS: WARNING: Detected extremely low variance for feature(s) 'deep_features' because all entries are nearly the same.\n",
      "Proceeding with model training using all features. If the model does not provide results of adequate quality, exclude the above mentioned feature(s) from the input dataset.\n",
      "PROGRESS: Logistic regression:\n",
      "PROGRESS: --------------------------------------------------------\n",
      "PROGRESS: Number of examples          : 1905\n",
      "PROGRESS: Number of classes           : 4\n",
      "PROGRESS: Number of feature columns   : 1\n",
      "PROGRESS: Number of unpacked features : 4096\n",
      "PROGRESS: Number of coefficients    : 12291\n",
      "PROGRESS: Starting L-BFGS\n",
      "PROGRESS: --------------------------------------------------------\n",
      "PROGRESS: +-----------+----------+-----------+--------------+-------------------+---------------------+\n",
      "PROGRESS: | Iteration | Passes   | Step size | Elapsed Time | Training-accuracy | Validation-accuracy |\n",
      "PROGRESS: +-----------+----------+-----------+--------------+-------------------+---------------------+\n",
      "PROGRESS: | 1         | 5        | 0.000131  | 8.966314     | 0.744357          | 0.690000            |\n",
      "PROGRESS: | 2         | 9        | 0.250000  | 16.747461    | 0.767454          | 0.770000            |\n",
      "PROGRESS: | 3         | 10       | 0.250000  | 18.662630    | 0.771129          | 0.770000            |\n",
      "PROGRESS: | 4         | 11       | 0.250000  | 20.229719    | 0.776903          | 0.770000            |\n",
      "PROGRESS: | 5         | 12       | 0.250000  | 21.781430    | 0.782152          | 0.750000            |\n",
      "PROGRESS: | 6         | 13       | 0.250000  | 25.155795    | 0.792126          | 0.750000            |\n",
      "PROGRESS: | 7         | 14       | 0.250000  | 28.072409    | 0.801050          | 0.760000            |\n",
      "PROGRESS: | 8         | 15       | 0.250000  | 29.613280    | 0.833071          | 0.760000            |\n",
      "PROGRESS: | 9         | 16       | 0.250000  | 31.177646    | 0.844619          | 0.770000            |\n",
      "PROGRESS: | 10        | 17       | 0.250000  | 33.230441    | 0.870341          | 0.780000            |\n",
      "PROGRESS: +-----------+----------+-----------+--------------+-------------------+---------------------+\n"
     ]
    }
   ],
   "source": [
    "dog_classifier = graphlab.logistic_classifier.create(image_train,\n",
    "                                                         features=['deep_features'],\n",
    "                                                         target='label')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 84,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "{'accuracy': 0.66, 'confusion_matrix': Columns:\n",
       " \ttarget_label\tstr\n",
       " \tpredicted_label\tstr\n",
       " \tcount\tint\n",
       " \n",
       " Rows: 4\n",
       " \n",
       " Data:\n",
       " +--------------+-----------------+-------+\n",
       " | target_label | predicted_label | count |\n",
       " +--------------+-----------------+-------+\n",
       " |     dog      |       bird      |   58  |\n",
       " |     dog      |       cat       |  261  |\n",
       " |     dog      |    automobile   |   21  |\n",
       " |     dog      |       dog       |  660  |\n",
       " +--------------+-----------------+-------+\n",
       " [4 rows x 3 columns]}"
      ]
     },
     "execution_count": 84,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "dog_classifier.evaluate(image_test_dog)"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 2",
   "language": "python",
   "name": "python2"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 2
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython2",
   "version": "2.7.10"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 0
}
